(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    162526,       4462]
NotebookOptionsPosition[    157485,       4321]
NotebookOutlinePosition[    157878,       4338]
CellTagsIndexPosition[    157835,       4335]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Section 3.2 : The simplest BH and its shear \
perturbations",
 FontSize->36]], "Title",
 CellChangeTimes->{{3.62400943566842*^9, 3.624009447262717*^9}, {
  3.624343205539671*^9, 3.624343210055524*^9}, {3.6479548495109177`*^9, 
  3.647954860119376*^9}, {3.6531971109986906`*^9, 3.65319712188195*^9}, {
  3.654898039375553*^9, 3.654898046172756*^9}, {3.6549649519722257`*^9, 
  3.6549649714591427`*^9}, {3.6550801834298763`*^9, 3.655080189862011*^9}, {
  3.655149925444542*^9, 3.6551499355612507`*^9}, {3.7174057433853664`*^9, 
  3.717405751748907*^9}, {3.7181068796186867`*^9, 3.71810688483368*^9}, {
  3.7283618346346083`*^9, 3.728361844620948*^9}, {3.7599323535345836`*^9, 
  3.759932356778657*^9}, {3.770471580424083*^9, 3.7704715857773504`*^9}, {
  3.77339332586162*^9, 3.773393329783368*^9}}],

Cell[TextData[StyleBox["In this notebook we simply familiarize with the \
package for GR calculations an on how to extract equations and solutions from \
it.\nThe computations are explained in section 3.2.",
 Background->RGBColor[0.9, 1, 1]]], "Text",
 CellChangeTimes->{{3.7719623058831425`*^9, 3.7719623311435833`*^9}, {
  3.773393334367256*^9, 3.7733933441223154`*^9}, {3.7772911302785153`*^9, 
  3.7772911304478197`*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6240094492315493`*^9, 3.6240094511847925`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FS", "=", "FullSimplify"}], ";"}]], "Input",
 CellChangeTimes->{{3.6240094529973536`*^9, 3.624009456528799*^9}}],

Cell[CellGroupData[{

Cell["RG code (just run)", "Chapter",
 CellChangeTimes->{{3.624009473685851*^9, 3.624009475529693*^9}, {
  3.6549518052233996`*^9, 3.6549518071706877`*^9}, {3.7704715886587873`*^9, 
  3.77047159020128*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 2  RG&TC-Code",
 FontWeight->"Bold"]], "Subsection",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrigRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]_", "]"}], "2"]}]}], "->", "x"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cot", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"y_.", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]_", "]"}], "2"]}]}], ":>", 
      RowBox[{"y", "/;", 
       RowBox[{
        RowBox[{"x", "+", "y"}], "===", "0"}]}]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FaSi", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FaSi", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FacSimp", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Equal", "]"}], ":=", 
   RowBox[{"Equal", "[", 
    RowBox[{
     RowBox[{"FacSimp", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"x", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Rule", "]"}], ":=", 
   RowBox[{"Rule", "[", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"coll", "[", "x", "]"}], "/.", "simpRules"}], ",", 
        "FormVars", ",", "Factor"}], "]"}], "/.", "simpRules"}], ")"}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroQ", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Normal", "[", "x", "]"}]}], "}"}], "]"}], "]"}], "===", 
    RowBox[{"{", "0", "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroL", "[", "x_", "]"}], ":=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroN", "[", "x_", "]"}], ":=", 
  RowBox[{"Length", "[", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"indepTerms", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"redPlus", "[", 
    RowBox[{"redTimes", "[", 
     RowBox[{
      RowBox[{"nonZeroL", "[", "x", "]"}], ",", "opt"}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"redTimes", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"opt_:", 
     RowBox[{"{", "}"}]}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tmp$", " ", "=", " ", 
       RowBox[{"Select", "[", 
        RowBox[{"x", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "#1", "]"}], " ", "===", " ", "Times"}], " ", 
          "&"}]}], "]"}]}], ",", " ", "rst$"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"rst$", " ", "=", " ", 
      RowBox[{"Complement", "[", 
       RowBox[{"x", ",", " ", "tmp$"}], "]"}]}], ";", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"rst$", ",", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"numb2", "[", 
           RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", "tmp$"}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"NumericQ", "[", "x", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{
     RowBox[{"x_", "^", "y_."}], ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{"opt", ",", "x"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", "x"}], ";", 
  RowBox[{
   RowBox[{"numb2", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Times", "@@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"numb1", "[", 
        RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", 
      RowBox[{"Level", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redPlus", "[", "x_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "#", "]"}], "===", "Plus"}], "&"}]}], 
         "]"}]}], ",", "rst$", ",", "i$", ",", "negi$"}], "}"}], ",", 
     RowBox[{
      RowBox[{"rst$", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"x", ",", "tmp$"}], "]"}]}], ";", 
      RowBox[{"i$", "=", "1"}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i$", "<", 
         RowBox[{"Length", "[", "tmp$", "]"}]}], ",", 
        RowBox[{
         RowBox[{"negi$", "=", 
          RowBox[{"Select", "[", 
           RowBox[{"tmp$", ",", 
            RowBox[{
             RowBox[{"#", "===", 
              RowBox[{"-", 
               RowBox[{"tmp$", "[", 
                RowBox[{"[", "i$", "]"}], "]"}]}]}], "&"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"negi$", "=!=", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"tmp$", "=", 
            RowBox[{"Complement", "[", 
             RowBox[{"tmp$", ",", "negi$"}], "]"}]}]}], "]"}], ";", 
         RowBox[{"i$", "=", 
          RowBox[{"i$", "+", "1"}]}]}]}], "]"}], ";", 
      RowBox[{"Union", "[", 
       RowBox[{"tmp$", ",", "rst$"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RiemSym", "[", "h_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "a_", ",", "c_", ",", "d_"}], "]"}], "=", "0"}], 
     ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}], 
     ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"b", ",", "a", ",", "c", ",", "d"}], "]"}]}], "/;", 
       RowBox[{"a", ">", "b"}]}]}], ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"a", ",", "b", ",", "d", ",", "c"}], "]"}]}], "/;", 
       RowBox[{"c", ">", "d"}]}]}], ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"c", ",", "d", ",", "a", ",", "b"}], "]"}], "/;", 
       RowBox[{
        RowBox[{"a", ">", "c"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "===", "c"}], "&&", 
          RowBox[{"b", ">", "d"}]}], ")"}]}]}]}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"epsilon", "[", "a__", "]"}], ":=", 
   RowBox[{"Signature", "[", 
    RowBox[{"{", "a", "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroTensor", "[", "rnk_", "]"}], ":=", 
   RowBox[{"Fold", "[", 
    RowBox[{"Table", ",", "0", ",", 
     RowBox[{"List", "/@", 
      RowBox[{"Table", "[", 
       RowBox[{"Dim", ",", 
        RowBox[{"{", "rnk", "}"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"f_", "[", "y__", "]"}], ",", "g_", ",", 
    RowBox[{"ord_:", "2"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"FuncRepRules", "[", 
    RowBox[{
     RowBox[{"f", "[", "y", "]"}], ",", "g", ",", "ord"}], "]"}], "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "y", "]"}], "->", "g"}], "}"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"indexList", "[", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"{", "y", "}"}], "]"}], ",", "ord"}], "]"}]}]}], "}"}], 
     ",", "\n", "       ", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"indL", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "[", "f", "]"}], "[",
             "y", "]"}], " ", "->", " ", "\n", "            ", 
           RowBox[{"Expand", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"D", "[", 
              RowBox[{"g", ",", 
               RowBox[{"Sequence", "@@", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", "y", "}"}], ",", 
                   RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}]}], "]"}],
              "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "indL", "]"}]}], "}"}]}], "]"}], ";", 
      "tmp$"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"indexList", "[", 
   RowBox[{"varNo_", ",", "ord_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp$", ",", "indL"}], "}"}], ",", 
    RowBox[{
     RowBox[{"tmp$", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{"RotateRight", ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"varNo", "-", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"varNo", "-", "1"}]}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ord", ">", "1"}], ",", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"indL", "=", "tmp$"}], ";", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"tmp$", "=", 
             RowBox[{"Join", "[", 
              RowBox[{"tmp$", ",", 
               RowBox[{"Map", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Plus", "[", 
                   RowBox[{
                    RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], 
                 ",", "indL"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "varNo"}], "}"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ord", "-", "1"}], "}"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"Union", "[", "tmp$", "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"MatrixForm", "[", "x", "]"}], "/;", 
    RowBox[{"Dim", "<", "10"}]}]}], ";", 
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", "x"}], ";", 
  RowBox[{"DeclareForms", "[", 
   RowBox[{"1", ",", 
    RowBox[{"e", "[", "_", "]"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"stPrint", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"y_", ":", "Null"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"y", "===", "Null"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
        RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontSlant", "\[Rule]", "\"\<Italic\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"timePrint", "[", 
    RowBox[{"x_", ",", "sT_"}], "]"}], ":=", 
   RowBox[{"Print", "[", 
    RowBox[{
     RowBox[{"x", "<>", "\"\< computed in \>\""}], ",", 
     RowBox[{
      RowBox[{"TimeUsed", "[", "]"}], "-", "sT"}], ",", "\"\< sec\>\""}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"myCoef$", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_SeriesData", ",", "y__"}], "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "->", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"#", ",", "y"}], "]"}], "&"}], ",", 
        RowBox[{"x", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_", ",", "y__"}], "]"}], ":=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{"gIN_", ",", "xIN_", ",", "opt___"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"frameOpt", "=", "0"}], ",", "eIN", ",", 
       RowBox[{"Ropt", "=", "True"}], ",", 
       RowBox[{"Wopt", "=", "True"}], ",", "idMat", ",", "eFrame", ",", 
       "dxRul", ",", "Bmat", ",", "Amat", ",", 
       RowBox[{"NP$", "=", "False"}], ",", "de", ",", "a", ",", "b", ",", "c",
        ",", "id", ",", "k", ",", "StrCon", ",", "\[Gamma]Udd", ",", 
       "\[Gamma]ddd", ",", "gddd", ",", "Gamddd", ",", "rmn", ",", "tmp", ",",
        "RUd", ",", "Rg", ",", "gg", ",", "sT", ",", "Cflat", ",", "EinSp"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"Clear", "[", 
       RowBox[{
       "GUdd", ",", "\[Omega]Ud", ",", "RUddd", ",", "Rdd", ",", "EUd", ",", 
        "R", ",", "Wdddd", ",", "detg", ",", "rtAbsdetg", ",", "eta", ",", 
        "HStar", ",", "PS", ",", "PH"}], "]"}], ";", "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Transpose", "[", "gIN", "]"}], "=!=", "gIN"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"MatrixForm", "[", "gIN", "]"}], ",", 
           "\"\< is not a symmetric matrix\>\""}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", " ", 
      RowBox[{"Dim", "=", 
       RowBox[{"Length", "[", "xIN", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Dim", "=!=", 
         RowBox[{"Length", "[", "gIN", "]"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{
          "\"\<Metric and coordinate dimensions don't match\>\"", ",", "1"}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"gIN", "===", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"NP$", "=", "True"}]}], "]"}], ";", 
      RowBox[{"eFrame", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"e", ",", 
         RowBox[{"{", "Dim", "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"frameOpt", "=", 
         RowBox[{"0", " ", "=", 
          RowBox[{">", " ", "coordFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"1", " ", "=", 
          RowBox[{">", " ", "explicitFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"2", " ", "=", 
          RowBox[{">", " ", "implicitFrame"}]}]}]}], " ", "*)"}], "\n", 
      "\t\t", "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"{", "opt", "}"}], "]"}], ">", "0"}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", "opt", "}"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "e"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", "dxRuleList", "]"}], "===", "List"}], "&&", 
              RowBox[{
               RowBox[{"Head", "[", "deList", "]"}], "===", "List"}]}], ",", 
             RowBox[{
              RowBox[{"frameOpt", "=", "2"}], ";", 
              RowBox[{"eIN", "=", "eFrame"}]}], ",", 
             RowBox[{
              RowBox[{"stPrint", "[", 
               RowBox[{
               "\"\<dxRuleList and/or deList have not been defined!\>\"", ",",
                 "1"}], "]"}], ";", 
              RowBox[{"Return", "[", "]"}]}]}], "]"}]}], "]"}], ";", "\n", 
         "\t", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"!", 
             RowBox[{"IntegerQ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "opt", "}"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"d", "[", "0", "]"}], "=!=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<matrixEDCcode.nb must be evaluated before section 2 \
RG&TC-Code!\>\"", ",", "1"}], "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "2"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{
               RowBox[{"{", "opt", "}"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"frameOpt", "=!=", "2"}], ",", 
              RowBox[{
               RowBox[{"eIN", "=", 
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ";", 
               RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{"IntegerQ", "[", 
             RowBox[{"opt", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{"opt", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"frameOpt", "=!=", "2"}], ",", 
             RowBox[{
              RowBox[{"eIN", "=", "opt"}], ";", 
              RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ",", "\n", "\t", 
           "True", ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<Wrong optional arguments!\>\"", ",", "1"}], "]"}], 
            ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"FreeQ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"gIN", ",", "eIN", ",", 
             RowBox[{"{", "deList", "}"}]}], "}"}], ",", "SeriesData"}], 
          "]"}]}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{"gIN", ",", "eIN", ",", 
                 RowBox[{"{", "deList", "}"}]}], "}"}], "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "SeriesData"}], 
               "&"}]}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"xIN", ",", "tmp"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"de", "[", "1", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<d\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{
             RowBox[{"de", "[", "2", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<\[ScriptD]\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{"DeclareForms", "[", 
             RowBox[{"1", ",", 
              RowBox[{"\[ScriptD]", "[", "_", "]"}], ",", 
              RowBox[{"de", "[", "1", "]"}], ",", 
              RowBox[{"de", "[", "2", "]"}]}], "]"}], ";", 
            RowBox[{
             RowBox[{"d", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "1", "]"}]}], ";", 
            RowBox[{
             RowBox[{"\[ScriptD]", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "2", "]"}]}], ";", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"de", "[", "1", "]"}], "]"}], "=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"d", "[", "tmp", "]"}], "=", "0"}]}], "]"}]}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "1"}], ",", 
        RowBox[{
         RowBox[{"DeclareForms", "[", 
          RowBox[{"1", ",", 
           RowBox[{"\[ScriptD]", "[", "_", "]"}]}], "]"}], ";", 
         RowBox[{"origFRin$", "=", 
          RowBox[{"eIN", "/.", 
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"d", "/@", "xIN"}], ",", 
               RowBox[{"\[ScriptD]", "/@", "xIN"}]}], "}"}]}], "]"}]}]}], ";", 
         RowBox[{"eTO$dx", "=", 
          RowBox[{"MapThread", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"e", "/@", 
               RowBox[{"Range", "[", "Dim", "]"}]}], ",", "origFRin$"}], 
             "}"}]}], "]"}]}]}]}], "]"}], ";", "\n", "\t\t\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"frameOpt", ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Union", "[", 
             RowBox[{"FormDegree", "/@", "eIN"}], "]"}], "=!=", 
            RowBox[{"{", "1", "}"}]}], "||", 
           RowBox[{
            RowBox[{"Length", "[", "eIN", "]"}], "=!=", "Dim"}], "||", 
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"eIN", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"e", "[", "_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"y_", "|", 
                  RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
                 RowBox[{"0", "/;", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}],
              "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{"\"\<coframe has incorrect form\>\"", ",", "1"}], "]"}], 
         ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\t", "\n", "\t\t", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "Rule"}], "||", 
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "RuleDelayed"}]}], 
        ",", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "simpRules", "}"}]}]}], "]"}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "simpRules", "]"}], "=!=", "List"}], ",", " ", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "}"}]}]}], "]"}], ";", 
      RowBox[{"idMat", "=", 
       RowBox[{"IdentityMatrix", "[", "Dim", "]"}]}], ";", "\n", "\n", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Amat", "=", "idMat"}], ";", 
         RowBox[{"Bmat", "=", "idMat"}], ";", 
         RowBox[{"eIN", "=", 
          RowBox[{"d", "/@", "xIN"}]}], ";", 
         RowBox[{"dxRul", "=", 
          RowBox[{"{", "}"}]}]}], ",", "\n", 
        RowBox[{
         RowBox[{"frameOpt", "===", "1"}], "&&", 
         RowBox[{"zeroQ", "[", 
          RowBox[{"eIN", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
             RowBox[{
              RowBox[{"y_", "|", 
               RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
              RowBox[{"0", "/;", 
               RowBox[{"MemberQ", "[", 
                RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{"Bmat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"eIN", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"d", "[", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "b", "]"}], "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Det", "[", "Bmat", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sT", "=", 
             RowBox[{"TimeUsed", "[", "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ByteCount", "[", "eIN", "]"}], ">", 
               RowBox[{"1500", "*", "Dim"}]}], ",", 
              RowBox[{"stPrint", "[", 
               RowBox[{"\"\<Computing d[coframe]...\>\"", ",", "1"}], "]"}]}],
              "]"}], ";", 
            RowBox[{"Amat", "=", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Inverse", "[", "Bmat", "]"}], "]"}]}], ";", 
            RowBox[{"dxRul", "=", 
             RowBox[{"MapThread", "[", 
              RowBox[{"Rule", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"d", "[", "xIN", "]"}], ",", 
                 RowBox[{"Amat", ".", "eFrame"}]}], "}"}]}], "]"}]}], ";", 
            RowBox[{"de", "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"FreeQ", "[", 
                RowBox[{"eIN", ",", "SeriesData"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{
                 RowBox[{"d", "[", "eIN", "]"}], "/.", "dxRul"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{"Wedge", "[", 
                 RowBox[{
                  RowBox[{"FacSimp", "[", 
                   RowBox[{
                    RowBox[{"FacSimp", "[", 
                    RowBox[{"d", "[", "Bmat", "]"}], "]"}], "/.", "dxRul"}], 
                   "]"}], ",", 
                  RowBox[{
                   RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], "]"}], 
                "]"}]}], "]"}]}], ";", 
            RowBox[{"timePrint", "[", 
             RowBox[{"\"\<d[coframe]\>\"", ",", "sT"}], "]"}], ";", 
            RowBox[{"tmp", "=", 
             RowBox[{
              RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
            RowBox[{"MapThread", "[", 
             RowBox[{"Set", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], 
             "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<coframe does not span space!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}], ",", "\n", 
        RowBox[{"frameOpt", "===", "2"}], ",", 
        RowBox[{
         RowBox[{"de", "=", "deList"}], ";", 
         RowBox[{"dxRul", "=", "dxRuleList"}], ";", 
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
         RowBox[{"MapThread", "[", 
          RowBox[{"Set", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], "]"}], 
         ";", 
         RowBox[{"Amat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"tmp", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"eIN", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
      "\n", "\t\t", "\n", 
      RowBox[{"k", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "x_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "x_Symbol"}], ")"}], "b_."]}], "->", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["x", "2"]}], ")"}], "b"]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "-", "y_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "+", "y_Symbol"}], ")"}], "b_."]}], 
          "\[Rule]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "-", 
             SuperscriptBox["y", "2"]}], ")"}], "b"]}]}], "}"}]}], ";", 
      RowBox[{"gdd", "=", "gIN"}], ";", 
      RowBox[{"coordList", "=", "xIN"}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gdd = \>\"", ",", 
        RowBox[{"MF", "[", "gdd", "]"}]}], "]"}], ";", 
      RowBox[{"tmp", "=", 
       RowBox[{"eIN", ".", "gIN", ".", "eIN"}]}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = \>\"", ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "tmp", "]"}], "===", "SeriesData"}], ",", 
           RowBox[{"FacSimp", "[", "tmp", "]"}], ",", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Expand", "[", "tmp", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], 
                RowBox[{"d", "[", "b_", "]"}]}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], 
                RowBox[{"e", "[", "b_", "]"}]}]}], "}"}], ",", "Factor"}], 
            "]"}]}], "]"}], "//.", "k"}]}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"gUU", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Inverse", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      RowBox[{"detg", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Det", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      "\n", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gUU = \>\"", ",", 
        RowBox[{"MF", "[", "gUU", "]"}]}], "]"}], ";", 
      RowBox[{"Clear", "[", "k", "]"}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<gUU\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"rtAbsdetg", "=", 
       RowBox[{"PowerExpand", "[", 
        RowBox[{"Power", "[", 
         RowBox[{
          RowBox[{"Factor", "[", 
           RowBox[{"detg", "^", "2"}], "]"}], ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"SetAttributes", "[", 
       RowBox[{"HStar", ",", 
        RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", 
        RowBox[{"rtAbsdetg", "=", "I"}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_SeriesData", "]"}], ":=", 
       RowBox[{"x", "/.", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "->", 
         RowBox[{"HStar", "/@", 
          RowBox[{"x", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}]}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Plus", "]"}], ":=", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Plus", "@@", 
         RowBox[{"HStar", "/@", "x"}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_", "*", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"HStar", "[", "y", "]"}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Wedge", "@@", 
          RowBox[{"e", "/@", 
           RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Wedge", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", "/", "detg"}], "/;", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], "===", "Dim"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_Wedge", "|", "x_e"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"HStar", "[", "x", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"FacSimp", "[", 
          RowBox[{"inn", "[", 
           RowBox[{"x", ",", 
            RowBox[{"Wedge", "@@", 
             RowBox[{"e", "/@", 
              RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "]"}], "]"}]}]}]}], 
      ";", "\t\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Array", "[", 
          RowBox[{"epsilon", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", "Dim", "}"}]}], "]"}]}], "]"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "a__", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "a", "]"}], "=", 
        RowBox[{"Raise", "[", 
         RowBox[{
          RowBox[{"eta", "[", "]"}], ",", "a"}], "]"}]}]}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"e", "[", "a_", "]"}], "]"}], ":=", 
          RowBox[{"de", "[", 
           RowBox[{"[", "a", "]"}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "a_"}], "]"}], "=", "0"}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"StrCon", "[", 
             RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{"-", 
           RowBox[{"myCoef$", "[", 
            RowBox[{
             RowBox[{"de", "[", 
              RowBox[{"[", "c", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"e", "[", "a", "]"}], "\[Wedge]", 
              RowBox[{"e", "[", "b", "]"}]}]}], "]"}]}]}], ";", "\n", 
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"StrCon", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", 
          RowBox[{"gdd", ".", "\[Gamma]Udd"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"zeroTensor", "[", "3", "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", "\[Gamma]Udd"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"(*", 
       RowBox[{"*", " ", "Tests"}], " ", "**)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "[", "gdd", "]"}], "/.", "dxRul"}], ")"}], "/.", 
           RowBox[{
            RowBox[{"e", "[", "_", "]"}], "->", "0"}]}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<Warning: d[] on some symbols not defined!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Print", "[", 
             RowBox[{"indepTerms", "[", 
              RowBox[{"FacSimp", "[", "tmp", "]"}], "]"}], "]"}]}]}], "]"}], 
         ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"frameOpt", "===", "2"}], "&&", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ByteCount", "[", "deList", "]"}], "+", 
                RowBox[{"ByteCount", "[", "dxRuleList", "]"}]}], ")"}], "/", 
              "Dim"}], "<", "6000"}]}], ",", 
           RowBox[{
            RowBox[{"tmp", "=", 
             RowBox[{"FacSimp", "[", 
              RowBox[{"d", "[", "deList", "]"}], "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
              RowBox[{
               RowBox[{"stPrint", "[", 
                RowBox[{
                "\"\<Warning: deList not closed! d[deList]=\>\"", ",", "1"}], 
                "]"}], ";", 
               RowBox[{"Print", "[", "tmp", "]"}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"!", 
                  RowBox[{"zeroQ", "[", 
                   RowBox[{"tmp", "/.", 
                    RowBox[{
                    RowBox[{"d", "[", "_", "]"}], "->", "0"}]}], "]"}]}], ",", 
                 RowBox[{"Return", "[", "]"}]}], "]"}]}]}], "]"}]}]}], 
          "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "pD", "]"}], ";", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"pD", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Amat", "===", "idMat"}], ",", 
          RowBox[{"D", "[", 
           RowBox[{"x", ",", 
            RowBox[{"coordList", "[", 
             RowBox[{"[", "y", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "y"}], "]"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"x", ",", 
               RowBox[{"coordList", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}]}], "]"}]}]}], ";", 
      "\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "c"}], "]"}], "]"}], ",", "b"}], "]"}], "+", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"b", ",", "c"}], "]"}], "]"}], ",", "a"}], "]"}], "-", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "b"}], "]"}], "]"}], ",", "c"}], "]"}]}], 
           ")"}], "/", "2"}], "]"}]}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"gddd", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"Clear", "[", "tmp", "]"}], ";", 
         RowBox[{"k", "=", 
          RowBox[{"gUU", ".", "Gamddd"}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"k", "[", 
             RowBox[{"[", 
              RowBox[{"c", ",", "a", ",", "b"}], "]"}], "]"}], "]"}]}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}]}], ",",
         "\n", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{
            RowBox[{"Array", "[", 
             RowBox[{"gddd", ",", 
              RowBox[{"{", 
               RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Gamma]ddd", "+", 
               RowBox[{"Transpose", "[", "\[Gamma]ddd", "]"}], "-", 
               RowBox[{"Transpose", "[", 
                RowBox[{"\[Gamma]ddd", ",", 
                 RowBox[{"{", 
                  RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], "]"}]}], ")"}], 
             "/", "2"}]}], "]"}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Union", "[", 
               RowBox[{"NumericQ", "/@", 
                RowBox[{"Flatten", "[", "gUU", "]"}]}], "]"}], "===", 
              RowBox[{"{", "True", "}"}]}], "&&", 
             RowBox[{
              RowBox[{"nonZeroN", "[", "gUU", "]"}], "===", "Dim"}]}], ",", 
            RowBox[{"gUU", ".", "Gamddd"}], ",", 
            RowBox[{"FaSi", "[", 
             RowBox[{"gUU", ".", "Gamddd"}], "]"}]}], "]"}]}]}]}], "]"}], ";",
       "\n", "\t\t", "\n", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Gamma\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{"\[Omega]Ud", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], 
              RowBox[{"e", "[", "k", "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"a", ",", "Dim"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
      RowBox[{
       RowBox[{"rmn", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"rmn", "[", 
         RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "id", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "c", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"\[Gamma]Udd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "id"}], "]"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdddd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"rmn", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
        "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Riemann(dddd)\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdddd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Flat Space!\>\"", "]"}], ";", 
         RowBox[{"Clear", "[", 
          RowBox[{"Rdd", ",", "EUd", ",", "R", ",", "Wdddd"}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Rg", "=", 
       RowBox[{"gUU", ".", "Rdddd"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{"Ropt", ",", 
        RowBox[{
         RowBox[{"Clear", "[", "rmn", "]"}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}],
          ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"rmn", "[", 
             RowBox[{"a", ",", "b", ",", "id", ",", "c"}], "]"}]}], "/;", 
           RowBox[{"c", ">", "id"}]}]}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"rmn", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"Rg", "[", 
             RowBox[{"[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "]"}], 
            "]"}]}]}], ";", 
         RowBox[{"RUddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"rmn", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Riemann(Uddd)\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"Rg", "=", "RUddd"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<RUddd not computed\>\"", ",", "1"}], "]"}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "tmp", "]"}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Rg", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "a", ",", "k", ",", "b"}], "]"}], "]"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", 
      "\t\t\t\t", "\n", 
      RowBox[{"RUd", "=", 
       RowBox[{"gUU", ".", "Rdd"}]}], ";", 
      RowBox[{"R", "=", 
       RowBox[{"FaSi", "[", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"RUd", "[", 
           RowBox[{"[", 
            RowBox[{"a", ",", "a"}], "]"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"a", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Ricci\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Wopt", "||", 
         RowBox[{"Dim", "<", "4"}]}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"Dim", ">", "3"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
             RowBox[{"Wdddd", "=", "Rdddd"}], ",", "\n", "\t", 
             RowBox[{
              RowBox[{"gg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "gdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"gg", "=", 
               RowBox[{"gg", "-", 
                RowBox[{"Transpose", "[", "gg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "Rdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", "Rg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"Rg", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}]}], 
                 "]"}]}]}], ";", "\n", 
              RowBox[{"Clear", "[", "rmn", "]"}], ";", 
              RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
              RowBox[{
               RowBox[{"rmn", "[", 
                RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
               RowBox[{
                RowBox[{"rmn", "[", 
                 RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
                RowBox[{"FaSi", "[", 
                 RowBox[{
                  RowBox[{"Rdddd", "[", 
                   RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                   "]"}], "-", 
                  RowBox[{
                   RowBox[{"Rg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], "+", 
                  RowBox[{"R", " ", 
                   RowBox[{
                    RowBox[{"gg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], ")"}]}]}]}], 
                 "]"}]}]}], ";", 
              RowBox[{"Wdddd", "=", 
               RowBox[{"Array", "[", 
                RowBox[{"rmn", ",", 
                 RowBox[{"{", 
                  RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], 
                  "}"}]}], "]"}]}]}]}], "]"}], ",", 
           RowBox[{"Wdddd", "=", 
            RowBox[{"zeroTensor", "[", "4", "]"}]}]}], "]"}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Weyl\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", "Wdddd", "]"}], ",", 
           RowBox[{
            RowBox[{"Cflat", "=", "True"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dim", "=!=", "3"}], "||", 
               RowBox[{"zeroQ", "[", "CF3d", "]"}]}], ",", 
              RowBox[{"stPrint", "[", "\"\<Conformally Flat\>\"", "]"}]}], 
             "]"}]}]}], "]"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<Weyl tensor not computed\>\"", ",", "1"}], "]"}]}], 
       "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Ricci Flat\>\"", "]"}], ";", 
         RowBox[{"EUd", "=", "Rdd"}]}], ",", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"EUd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{"RUd", " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], " ", "R", "*", "idMat"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Einstein\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", 
            RowBox[{"EUd", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "-", 
                RowBox[{"1", "/", "Dim"}]}], ")"}], "R", "*", "idMat"}]}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", "\"\<Einstein Space\>\"", "]"}], ";", 
            RowBox[{"EinSp", "=", "True"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", ">", "2"}], "&&", "Cflat", "&&", "EinSp"}], ")"}], "||", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", "===", "2"}], "&&", 
           RowBox[{"zeroQ", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"covD", "[", "R", "]"}], "]"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
        "stPrint", "[", "\"\<Space of Constant Curvature!\>\"", "]"}]}], 
       "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", "NPdefs"}], "]"}], ";"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CF3d", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"stPrint", "[", 
      RowBox[{"\"\<Testing for 3-dim conformal flatness...\>\"", ",", "1"}], 
      "]"}], ";", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tmp$", "=", 
         RowBox[{
          RowBox[{"covD", "[", "Rdd", "]"}], "-", 
          RowBox[{"Outer", "[", 
           RowBox[{"Times", ",", "gdd", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"covD", "[", "R", "]"}], "/", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{"Dim", "-", "1"}], ")"}]}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"FaSi", "[", 
        RowBox[{"tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], 
      "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NPdefs", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "4"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{"FaSi", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ")"}], "/", "4"}], 
       "]"}]}], ";", 
     RowBox[{"\[CapitalLambda]", "=", 
      RowBox[{
       RowBox[{"-", "R"}], "/", 
       RowBox[{"2", "4"}]}]}], ";", 
     RowBox[{
     "tmp$", " ", "=", " ", 
      "\"\<NP variables PH[i,j], \[CapitalLambda] \>\""}], ";", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "Wdddd", "]"}], " ", "=!=", " ", "Symbol"}], ",",
        " ", 
       RowBox[{
        RowBox[{
         RowBox[{"PS", "[", "0", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "2", ",", "4"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "1", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4", ",", "2", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "2", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "3", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "4", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{"tmp$", " ", "=", " ", 
         RowBox[{"StringJoin", "[", 
          RowBox[{"tmp$", ",", " ", "\"\<and PS[i] \>\""}], "]"}]}]}]}], 
      "]"}], ";", " ", 
     RowBox[{"stPrint", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"tmp$", ",", " ", "\"\<defined.\>\""}], "]"}], ",", " ", 
       "1"}], "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{"y_Wedge", ",", "x_"}], "]"}], ":=", 
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"Rest", "[", "y", "]"}], ",", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"First", "[", "y", "]"}], ",", "x"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "+", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "x"}], "]"}], "+", 
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "*", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "*", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_"}], "]"}], ":=", 
   RowBox[{"0", "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_Wedge"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", 
       RowBox[{"First", "[", "x", "]"}]}], "]"}], "*", 
     RowBox[{"Rest", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", 
      RowBox[{"FormDegree", "[", 
       RowBox[{"First", "[", "x", "]"}], "]"}]}], "*", 
     RowBox[{
      RowBox[{"First", "[", "x", "]"}], "\[Wedge]", 
      RowBox[{"inn", "[", 
       RowBox[{
        RowBox[{"e", "[", "a", "]"}], ",", 
        RowBox[{"Rest", "[", "x", "]"}]}], "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"e", "[", "b_", "]"}]}], "]"}], ":=", 
   RowBox[{"gUU", "[", 
    RowBox[{"[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MoveIndex", "[", 
    RowBox[{"x_", ",", "i_", ",", "g_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "indL"}], "}"}], ",", 
     "\n", "    ", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"i", "===", "1"}], ",", 
       RowBox[{"g", ".", "x"}], ",", 
       RowBox[{"i", "===", "rnk1"}], ",", 
       RowBox[{"x", ".", "g"}], ",", "True", ",", 
       RowBox[{
        RowBox[{"indL", "=", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "->", "1"}], ",", 
            RowBox[{"1", "->", "i"}]}], "}"}]}]}], ";", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"g", ".", 
           RowBox[{"Transpose", "[", 
            RowBox[{"x", ",", "indL"}], "]"}]}], ",", "indL"}], "]"}]}]}], 
      "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lower", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gdd"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Raise", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gUU"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"multiDot", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"rnk2", "=", 
        RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Sort", "/@", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", "indPr", "}"}], "]"}]}]}], ",", 
       RowBox[{"ordPr", "=", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}], "||", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk2"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ordPr", "]"}], "===", "1"}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotOne", "[", 
          RowBox[{"x", ",", "y", ",", "indPr"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"rnk1", "===", "rnk2"}], "&&", 
         RowBox[{"rnk1", "===", 
          RowBox[{"Length", "[", "ordPr", "]"}]}]}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotAll", "[", 
          RowBox[{"x", ",", "y", ",", "ordPr"}], "]"}], "]"}], ",", "True", 
        ",", 
        RowBox[{"OKindCon", "[", 
         RowBox[{
          RowBox[{"dotOne", "[", 
           RowBox[{"x", ",", "y", ",", 
            RowBox[{"ordPr", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"renumb", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"ordPr", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], "/@", 
           RowBox[{"Rest", "[", "ordPr", "]"}]}]}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"renumb", "[", 
     RowBox[{"rnk_", ",", "j_"}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_"}], "}"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"j", ">", "b"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "2"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dotOne", "[", 
   RowBox[{"x_", ",", "y_", ",", 
    RowBox[{"{", 
     RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rnk1", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
      RowBox[{"rnk2", "=", 
       RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
      RowBox[{"tmp$", "=", 
       RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmp$", "===", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
       RowBox[{"tmp$", "=", "Wedge"}], ",", 
       RowBox[{"tmp$", "=", "Dot"}]}], "]"}], ";", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{"tmp$", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"x", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk1", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rnk1", "\[Rule]", "i"}], ",", 
              RowBox[{"i", "\[Rule]", "rnk1"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk2", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"j", "\[Rule]", "1"}], ",", 
              RowBox[{"1", "\[Rule]", "j"}]}], "}"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"rnk1", "+", "j", "-", "2"}]}], "]"}], ",", "1"}], "]"}],
          ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"rnk1", "+", "j", "-", "1"}], ",", 
           RowBox[{"rnk1", "+", "rnk2", "-", "2"}]}], "]"}]}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dotAll", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s$", ",", "allInd", ",", "sumInd", ",", 
       RowBox[{"tmp$", "=", 
        RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"allInd", "=", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{"s$", ",", 
          RowBox[{"Transpose", "[", "indPr", "]"}], ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], "/.", 
        RowBox[{
         RowBox[{"s$", "[", "i_", "]"}], ":>", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<s$\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
      RowBox[{"sumInd", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"allInd", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", 
              RowBox[{"allInd", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}]}], "}"}],
         "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tmp$", "===", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
        RowBox[{"tmp$", "=", "Wedge"}], ",", 
        RowBox[{"tmp$", "=", "Times"}]}], "]"}], ";", 
      RowBox[{"Sum", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Unevaluated", "[", 
          RowBox[{"tmp$", "[", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
            RowBox[{"y", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
          "]"}], ",", 
         RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"x_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Union", "[", "indL", "]"}], "]"}], "<", 
         RowBox[{"Length", "[", "indL", "]"}]}], "||", 
        RowBox[{
         RowBox[{"Length", "[", "indL", "]"}], ">", "rnk1"}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Sort", "[", "indL", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}]}], ",", 
       RowBox[{"errWarn", ";", 
        RowBox[{"Return", "[", "]"}]}], ",", 
       RowBox[{"OKindCon", "[", 
        RowBox[{"x", ",", 
         RowBox[{"Sort", "[", 
          RowBox[{"Sort", "/@", 
           RowBox[{"{", "indPr", "}"}]}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"newPrList", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Rest", "[", "x", "]"}], "-", "1"}], "/.", 
    RowBox[{"k_", ":>", 
     RowBox[{
      RowBox[{"k", "-", "1"}], "/;", 
      RowBox[{"k", ">", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", "1"}]}]}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"FacSimp", "[", 
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", "indPr", "]"}], "===", "1"}]}]}], ";", 
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s$", ",", "allInd", ",", "sumInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"TensorRank", "[", "x", "]"}], "]"}], "/.", 
          RowBox[{"Apply", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"Apply", "[", 
             RowBox[{"Sequence", ",", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Transpose", "[", 
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{
                    RowBox[{"s$", "[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}], "]"}], "&"}], 
                ",", "indPr"}], "]"}], ",", "1"}], "]"}], ",", "1"}], "]"}]}],
          "/.", 
         RowBox[{
          RowBox[{"s$", "[", "i_", "]"}], ":>", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<s$\>\"", "<>", 
            RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
       RowBox[{"sumInd", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Union", "[", "allInd", "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "allInd", "]"}], "/", "2"}], "}"}]}], 
            "]"}]}], "}"}], "]"}]}], ";", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Sum", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Unevaluated", "[", 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}], "]"}]}]}], "]"}], 
    "/;", 
    RowBox[{
     RowBox[{"TensorRank", "[", "x", "]"}], "===", 
     RowBox[{"2", 
      RowBox[{"Length", "[", "indPr", "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"OKindCon", "[", 
    RowBox[{
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"newPrList", "[", "indPr", "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ConOne", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "tr1List", ",", 
       "tr2List"}], "}"}], ",", 
     RowBox[{
      RowBox[{"tr1List", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"j", "->", "i"}], "}"}]}], ")"}], "/.", 
        RowBox[{"k_", ":>", 
         RowBox[{
          RowBox[{"k", "-", "1"}], "/;", 
          RowBox[{"k", ">", "j"}]}]}]}]}], ";", 
      RowBox[{"tr2List", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}]}], 
        "]"}]}], ";", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"x", ",", "tr1List"}], "]"}], ",", "tr2List"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"rnk1", "-", "2"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"errWarn", ":=", 
   RowBox[{"stPrint", "[", 
    RowBox[{"\"\<Wrong tensor rank or number(s) of indices!\>\"", ",", "1"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covDiv", "[", 
    RowBox[{"x_", ",", "UpList_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{"x", ",", "UpList"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k", "=", 
         RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "divInd", ",", 
        "allInd", ",", "freeInd", ",", "hhD", ",", "s", ",", "lt", ",", 
        "aInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{
            RowBox[{"Sort", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{"Head", "[", "x", "]"}], "=!=", "List"}]}], ",", 
         RowBox[{"errWarn", ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "1"}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"Select", "[", 
             RowBox[{"UpList", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "List"}], "&"}]}], 
             "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", "UpList", "}"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"aInd", "/@", 
           RowBox[{"Range", "[", "k", "]"}]}], ")"}], "/.", 
         RowBox[{
          RowBox[{"aInd", "[", "divInd", "]"}], "->", "s"}]}]}], ";", 
       RowBox[{"freeInd", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"allInd", ",", 
          RowBox[{
           RowBox[{"#", "=!=", "s"}], "&"}]}], "]"}]}], ";", 
       RowBox[{"Off", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"lt", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$VersionNumber", "<", "3.5"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"hhD", "[", 
                RowBox[{
                 RowBox[{"x", "[", 
                  RowBox[{"[", 
                   RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                 "s"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "+", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], "]"}],
                  ",", 
                 RowBox[{
                  RowBox[{"GUdd", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "Dim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Unevaluated", "[", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"hhD", "[", 
                 RowBox[{
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                  "s"}], "]"}], "+", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], 
                    "]"}], ",", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "]"}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"k", " ", ">", "1"}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{"Table", "@@", "lt"}]}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"pD", "[", 
              RowBox[{
               RowBox[{"x", "[", 
                RowBox[{"[", "s$", "]"}], "]"}], ",", "s$"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"s$", ",", "s$", ",", "j"}], "]"}], "]"}], 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "Dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
       RowBox[{"On", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       RowBox[{"Return", "[", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"lt", "/.", 
           RowBox[{"hhD", "->", "pD"}]}], "]"}], "]"}], "]"}]}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"c$D", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_", ",", "y_List"}], "]"}], ":=", "errWarn"}], ";", 
  RowBox[{
   RowBox[{"covD", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", "x", "]"}], "=", 
    RowBox[{"c$D", "[", "x", "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c$D", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"UpList_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
           RowBox[{
            RowBox[{
             RowBox[{"Sort", "[", 
              RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], 
             "\[LeftDoubleBracket]", 
             RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ">", "k"}]}], 
          ")"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "x", "]"}], "===", "List"}], ",", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{"cDcomp", "[", 
           RowBox[{"x", ",", "k", ",", "UpList"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"k", "+", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"pD", "[", 
            RowBox[{"x", ",", "i"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cDcomp", "[", 
     RowBox[{"x_", ",", "rnk_", ",", 
      RowBox[{"UpList_:", 
       RowBox[{"{", "}"}]}]}], "]"}], "[", "y__", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y$", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"{", "y", "}"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ",", 
       RowBox[{"z$", "=", 
        RowBox[{
         RowBox[{"{", "y", "}"}], "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", "y$"}], "]"}], "]"}], ",", "z$"}], "]"}],
        "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"UpList", ",", "i"}], "]"}], ",", 
           RowBox[{
            RowBox[{"GUdd", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"y$", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "z$", ",", "j"}], "]"}], 
             "]"}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}], 
           ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "z$", ",", 
                RowBox[{"y$", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}]}],
           "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "Dim"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "rnk"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "0", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdddd", "]"}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{"indepTerms", "[", 
       RowBox[{"tmp$", "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}]}], 
         "]"}], "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "5", ",", "3", ",", "4"}], "}"}]}], 
         "]"}]}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "1", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdd", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "RUddd", "]"}], "===", "Symbol"}], ",", 
        RowBox[{"RUddd", "=", 
         RowBox[{"Raise", "[", 
          RowBox[{"Rdddd", ",", "1"}], "]"}]}]}], "]"}], ";", 
      RowBox[{"FaSi", "[", 
       RowBox[{"indepTerms", "[", 
        RowBox[{
         RowBox[{"covDiv", "[", 
          RowBox[{"RUddd", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}], "+", "tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "2", "]"}], ":=", 
   RowBox[{"indepTerms", "[", 
    RowBox[{"covDiv", "[", 
     RowBox[{"EUd", ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PrePrint", "=", " ", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ByteCount", "[", "#", "]"}], " ", ">", " ", "200000"}], ",", 
      RowBox[{"Short", "[", 
       RowBox[{"#", ",", "100"}], "]"}], ",", " ", "#"}], "]"}], "&"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{
   "cDcomp", ",", "CF3d", ",", "ConOne", ",", "c$D", ",", "dotAll", ",", 
    "dotOne", ",", "epsilon", ",", "errWarn", ",", "FacSimp", ",", "FaSi", 
    ",", "indexList", ",", "inn", ",", "MF", ",", "MoveIndex", ",", 
    "newPrList", ",", "NPdefs", ",", "numb1", ",", "numb2", ",", "OKindCon", 
    ",", "redPlus", ",", "redTimes", ",", "renumb", ",", "RiemSym", ",", 
    "zeroTensor"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.6205808502542887`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Homework", "Chapter",
 CellChangeTimes->{{3.624040920155903*^9, 3.6240409216247253`*^9}, {
  3.7181075829076543`*^9, 3.718107592976757*^9}, {3.7704715994732914`*^9, 
  3.7704716001689467`*^9}, {3.771962428026105*^9, 3.7719624335413*^9}}],

Cell[CellGroupData[{

Cell["Model and EOMs", "Section",
 CellChangeTimes->{{3.62400950390606*^9, 3.6240095065468335`*^9}, {
  3.729006114091935*^9, 3.72900611499006*^9}}],

Cell[TextData[StyleBox["Let us learn the package command.\nWe need to define \
the coordinates and the metric. Trick: Expand the metric, especially if you \
have complicated perturbations or actions. And then run RGtensors, it will \
compute a lot for you...",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770556056497218*^9, 3.7705561042255473`*^9}, {
  3.7719623493063564`*^9, 3.7719623496196737`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "r"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"gtt", "[", "r", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"gxx", "[", "r", "]"}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"hxy", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"hxy", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], ",", 
       RowBox[{"gxx", "[", "r", "]"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"grr", "[", "r", "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gexp", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.570167330426721*^9, {3.570167711460515*^9, 3.5701677604433165`*^9}, {
   3.5701875806651926`*^9, 3.570187583672364*^9}, {3.5701876605677624`*^9, 
   3.5701876639509563`*^9}, {3.570187735649057*^9, 3.570187745717633*^9}, {
   3.5701886532425404`*^9, 3.5701886590188704`*^9}, {3.5710344839574785`*^9, 
   3.5710345490622025`*^9}, {3.5710565998820677`*^9, 3.571056609206601*^9}, {
   3.571056688575141*^9, 3.5710566960055656`*^9}, {3.571057753245036*^9, 
   3.5710577696369743`*^9}, {3.5710584597704477`*^9, 3.571058487839053*^9}, {
   3.571162597044566*^9, 3.571162634373329*^9}, {3.572352151919235*^9, 
   3.5723521744285226`*^9}, {3.5723527649783*^9, 3.572352805412613*^9}, {
   3.5723544810774555`*^9, 3.572354481370472*^9}, {3.572783907767783*^9, 
   3.572783910698951*^9}, {3.5727852817183685`*^9, 3.5727852851825666`*^9}, {
   3.572847181580718*^9, 3.572847187575061*^9}, {3.5728479839206095`*^9, 
   3.572848013493301*^9}, {3.5728683898720317`*^9, 3.5728684127023373`*^9}, {
   3.5768411793242626`*^9, 3.5768411960782213`*^9}, {3.576841393342504*^9, 
   3.576841400301902*^9}, {3.588570366786084*^9, 3.588570605641746*^9}, {
   3.588676297756776*^9, 3.588676313015649*^9}, {3.588679147362764*^9, 
   3.588679147494772*^9}, {3.589176462654968*^9, 3.5891764682232866`*^9}, {
   3.5891765005721364`*^9, 3.5891765490069065`*^9}, {3.5891765827008343`*^9, 
   3.5891766018889313`*^9}, {3.589176698654466*^9, 3.5891767473842535`*^9}, {
   3.5891781666334295`*^9, 3.5891781823983316`*^9}, {3.5892026584710283`*^9, 
   3.58920267756212*^9}, {3.5892027244858036`*^9, 3.589202733565323*^9}, {
   3.5892038518332844`*^9, 3.589203878423805*^9}, {3.5892057669598236`*^9, 
   3.5892057873969927`*^9}, {3.58920631763332*^9, 3.589206320231469*^9}, {
   3.589207357322787*^9, 3.589207393252842*^9}, {3.5896209102385693`*^9, 
   3.5896209119556675`*^9}, {3.5896210590570817`*^9, 3.589621064654402*^9}, {
   3.5907551876956787`*^9, 3.5907552091219044`*^9}, {3.5907566716935587`*^9, 
   3.5907566860873823`*^9}, {3.592217073930195*^9, 3.5922171581900144`*^9}, {
   3.59256777152232*^9, 3.592567782218931*^9}, {3.5927224828902206`*^9, 
   3.5927225021913247`*^9}, {3.592755344267173*^9, 3.592755345044217*^9}, {
   3.5927555533841333`*^9, 3.592755559335474*^9}, 3.592755679146327*^9, {
   3.592914201124915*^9, 3.5929142298985605`*^9}, {3.592914325799046*^9, 
   3.5929143259670553`*^9}, {3.5931684118583736`*^9, 3.593168433449609*^9}, {
   3.593168691672378*^9, 3.593168692003397*^9}, {3.593177947440778*^9, 
   3.5931779569343204`*^9}, {3.5932379656937857`*^9, 
   3.5932379657697897`*^9}, {3.5939694634234915`*^9, 
   3.5939694642905407`*^9}, {3.612679384297059*^9, 3.6126794442260604`*^9}, 
   3.612891633755241*^9, {3.6128925243427753`*^9, 3.6128925729956837`*^9}, {
   3.6128930187745657`*^9, 3.6128930511441402`*^9}, {3.612902044032016*^9, 
   3.612902045532769*^9}, {3.619853651851103*^9, 3.619853652299033*^9}, {
   3.62002395456089*^9, 3.6200239553877697`*^9}, {3.620378552850563*^9, 
   3.62037858294659*^9}, {3.620378635267205*^9, 3.620378639328519*^9}, {
   3.647955058271038*^9, 3.6479550759139366`*^9}, {3.654952055484351*^9, 
   3.6549520601464434`*^9}, {3.65496552447079*^9, 3.654965613278685*^9}, {
   3.654967324844714*^9, 3.654967331347026*^9}, {3.654967833826115*^9, 
   3.654967840397472*^9}, {3.6549678980236807`*^9, 3.654967929730706*^9}, {
   3.6549689142126083`*^9, 3.654968939296237*^9}, {3.654968970212738*^9, 
   3.6549689784762173`*^9}, {3.6550802832354965`*^9, 3.655080308532049*^9}, {
   3.6550810089691243`*^9, 3.655081032446229*^9}, {3.6550818735510454`*^9, 
   3.6550818886860847`*^9}, {3.6550823294532814`*^9, 
   3.6550823549695144`*^9}, {3.6550828590494404`*^9, 
   3.6550828645060587`*^9}, {3.655142501906828*^9, 3.6551425101522913`*^9}, {
   3.717407249755625*^9, 3.7174072858519745`*^9}, {3.71810690905823*^9, 
   3.7181069110819144`*^9}, {3.718107615324473*^9, 3.7181076566420736`*^9}, {
   3.728361666539886*^9, 3.7283616992502537`*^9}, {3.7293176051119976`*^9, 
   3.729317616446021*^9}, {3.729318641016193*^9, 3.7293186419880533`*^9}, {
   3.72931877729201*^9, 3.72931881047895*^9}, {3.7293194501514435`*^9, 
   3.729319456779991*^9}, {3.7323639845148983`*^9, 3.7323640003734674`*^9}, {
   3.7323640554966245`*^9, 3.732364057585289*^9}, {3.770471606406065*^9, 
   3.770471649934743*^9}, {3.7704720477159286`*^9, 3.770472061929146*^9}, {
   3.7704721415514297`*^9, 3.7704721434266443`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"gexp", ",", "xCoord"}], "]"}]], "Input",
 CellChangeTimes->{{3.6549656052443523`*^9, 3.6549656064331408`*^9}, {
  3.6550829279111032`*^9, 3.655082930866063*^9}, {3.7174072166162825`*^9, 
  3.7174072169184837`*^9}, {3.728968246688678*^9, 3.728968246862032*^9}, {
  3.7293176192533307`*^9, 3.72931761948652*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"gtt", "[", "r", "]"}], "0", "0", "0"},
       {"0", 
        RowBox[{"gxx", "[", "r", "]"}], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"hxy", "[", 
            RowBox[{"t", ",", "r"}], "]"}], " ", "\[Epsilon]"}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 2, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1],
         Editable->False], "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"hxy", "[", 
            RowBox[{"t", ",", "r"}], "]"}], " ", "\[Epsilon]"}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 2, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1],
         Editable->False], 
        RowBox[{"gxx", "[", "r", "]"}], "0"},
       {"0", "0", "0", 
        RowBox[{"grr", "[", "r", "]"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
      $CellContext`gtt[$CellContext`r], 0, 0, 0}, {0, 
      $CellContext`gxx[$CellContext`r], 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1], 0}, {0, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1], 
      $CellContext`gxx[$CellContext`r], 0}, {0, 0, 0, 
      $CellContext`grr[$CellContext`r]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910716279793`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(ds\\), \\(2\\)]\\) = \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "r", "]"}], "2"], " ", 
        RowBox[{"grr", "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "t", "]"}], "2"], " ", 
        RowBox[{"gtt", "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "x", "]"}], "2"], " ", 
        RowBox[{"gxx", "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "y", "]"}], "2"], " ", 
        RowBox[{"gxx", "[", "r", "]"}]}]}], ")"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"d", "[", "x", "]"}], " ", 
      RowBox[{"d", "[", "y", "]"}], " ", 
      RowBox[{"hxy", "[", 
       RowBox[{"t", ",", "r"}], "]"}], " ", "\[Epsilon]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
      SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`\[Epsilon], 
     0, {$CellContext`d[$CellContext`r]^2 $CellContext`grr[$CellContext`r] + \
$CellContext`d[$CellContext`t]^2 $CellContext`gtt[$CellContext`r] + \
$CellContext`d[$CellContext`x]^2 $CellContext`gxx[$CellContext`r] + \
$CellContext`d[$CellContext`y]^2 $CellContext`gxx[$CellContext`r], 
      2 $CellContext`d[$CellContext`x] $CellContext`d[$CellContext`y] \
$CellContext`hxy[$CellContext`t, $CellContext`r]}, 0, 2, 1],
    Editable->False]}],
  SequenceForm["\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = ", 
   SeriesData[$CellContext`\[Epsilon], 
    0, {$CellContext`d[$CellContext`r]^2 $CellContext`grr[$CellContext`r] + \
$CellContext`d[$CellContext`t]^2 $CellContext`gtt[$CellContext`r] + \
$CellContext`d[$CellContext`x]^2 $CellContext`gxx[$CellContext`r] + \
$CellContext`d[$CellContext`y]^2 $CellContext`gxx[$CellContext`r], 
     2 $CellContext`d[$CellContext`x] $CellContext`d[$CellContext`y] \
$CellContext`hxy[$CellContext`t, $CellContext`r]}, 0, 2, 1]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910716279793`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           RowBox[{"gtt", "[", "r", "]"}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`gtt[$CellContext`r]^(-1)}, 0, 3, 1],
         Editable->False], "0", "0", "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           RowBox[{"gxx", "[", "r", "]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"hxy", "[", 
              RowBox[{"t", ",", "r"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           SuperscriptBox[
            RowBox[{"gxx", "[", "r", "]"}], "3"]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`gxx[$CellContext`r]^(-1), 
           0, $CellContext`gxx[$CellContext`r]^(-3) \
$CellContext`hxy[$CellContext`t, $CellContext`r]^2}, 0, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"hxy", "[", 
              RowBox[{"t", ",", "r"}], "]"}], " ", "\[Epsilon]"}], 
            SuperscriptBox[
             RowBox[{"gxx", "[", "r", "]"}], "2"]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 2, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`gxx[$CellContext`r]^(-2) \
$CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1],
         Editable->False], "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"hxy", "[", 
              RowBox[{"t", ",", "r"}], "]"}], " ", "\[Epsilon]"}], 
            SuperscriptBox[
             RowBox[{"gxx", "[", "r", "]"}], "2"]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "2"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 2, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`gxx[$CellContext`r]^(-2) \
$CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           RowBox[{"gxx", "[", "r", "]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"hxy", "[", 
              RowBox[{"t", ",", "r"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           SuperscriptBox[
            RowBox[{"gxx", "[", "r", "]"}], "3"]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`gxx[$CellContext`r]^(-1), 
           0, $CellContext`gxx[$CellContext`r]^(-3) \
$CellContext`hxy[$CellContext`t, $CellContext`r]^2}, 0, 3, 1],
         Editable->False], "0"},
       {"0", "0", "0", 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           RowBox[{"grr", "[", "r", "]"}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`grr[$CellContext`r]^(-1)}, 0, 3, 1],
         Editable->False]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`gtt[$CellContext`r]^(-1)}, 0, 3, 1], 0, 0, 0}, {0, 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`gxx[$CellContext`r]^(-1), 
        0, $CellContext`gxx[$CellContext`r]^(-3) \
$CellContext`hxy[$CellContext`t, $CellContext`r]^2}, 0, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`gxx[$CellContext`r]^(-2) \
$CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1], 0}, {0, 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`gxx[$CellContext`r]^(-2) \
$CellContext`hxy[$CellContext`t, $CellContext`r]}, 1, 2, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`gxx[$CellContext`r]^(-1), 
        0, $CellContext`gxx[$CellContext`r]^(-3) \
$CellContext`hxy[$CellContext`t, $CellContext`r]^2}, 0, 3, 1], 0}, {0, 0, 0, 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`grr[$CellContext`r]^(-1)}, 0, 3, 1]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910716436014`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910716436014`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.016000000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.016000000000000014`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910716436014`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.014999999999999902`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.014999999999999902`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910716592226`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.04699999999999993`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.04699999999999993, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.777291071712592*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.06300000000000017`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.06300000000000017, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.777291071790705*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.20299999999999985`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.20299999999999985`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910719755735`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.03100000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.03100000000000014, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7289680242370596`*^9, 3.728968248045136*^9, 3.729001935403493*^9, 
   3.729317621105878*^9, 3.7293186559980583`*^9, 3.729318820883957*^9, 
   3.7293194621725445`*^9, 3.7293331145483694`*^9, 3.7294051997188153`*^9, 
   3.7294133732149525`*^9, 3.7294323323248324`*^9, 3.729432499655442*^9, 
   3.729487932511797*^9, 3.730709977766046*^9, 3.7307138717451043`*^9, 
   3.730736300060354*^9, 3.7323605258317504`*^9, 3.7323634671441407`*^9, 
   3.7323640151162806`*^9, {3.732364059980197*^9, 3.732364070103574*^9}, 
   3.7323900253256187`*^9, 3.744018783129775*^9, 3.7599314804328203`*^9, 
   3.759932370565354*^9, 3.762708851535878*^9, 3.7704716635099115`*^9, 
   3.7704720732239995`*^9, 3.770472146423413*^9, 3.773393391076026*^9, 
   3.7772910720133266`*^9}]
}, Open  ]]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["For example we have the Ricci scalar and Riemann \
tensor",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770556134119877*^9, 3.7705561462607226`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rdd", "//", "Simplify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"R", "//", "Simplify"}], ";"}]}], "Input",
 CellChangeTimes->{{3.770471695459597*^9, 3.7704717284190392`*^9}, {
  3.7704720831223125`*^9, 3.7704720845301476`*^9}, {3.7733933935094814`*^9, 
  3.773393394151767*^9}, {3.7772910901187105`*^9, 3.7772910952494726`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Here are the Einstein equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770556153430641*^9, 3.7705561635977907`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSEinstein", "=", 
   RowBox[{"Rdd", "-", 
    RowBox[{
     FractionBox["1", "2"], "gdd", 
     RowBox[{"(", 
      RowBox[{"R", "-", 
       RowBox[{"2", "\[CapitalLambda]"}]}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7290058192821693`*^9, 3.7290058521451735`*^9}, {
  3.7293179049418793`*^9, 3.7293179235382404`*^9}, {3.730709993342537*^9, 
  3.73070999819814*^9}, {3.7704716822446957`*^9, 3.770471687658569*^9}, {
  3.7704717394836493`*^9, 3.7704717454892435`*^9}, {3.7704721009543343`*^9, 
  3.770472105442848*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQSEinstein0", "=", 
   RowBox[{"EQSEinstein", "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQSEinstein1", "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQSEinstein", ",", "\[Epsilon]"}], "]"}], "//", "Simplify"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.729317946367911*^9, 3.729317972442868*^9}, {
  3.770471737253578*^9, 3.770471737820932*^9}, {3.7704720885094395`*^9, 
  3.7704721220270863`*^9}, {3.770472168093687*^9, 3.770472177374276*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution for the background", "Section",
 CellChangeTimes->{{3.728361377463107*^9, 3.728361378492499*^9}, {
  3.7283617863474226`*^9, 3.728361789914644*^9}}],

Cell[TextData[StyleBox["Let us make a simple ansatz",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7705561829585915`*^9, 3.7705561860224347`*^9}, {
  3.7719623642015877`*^9, 3.771962365401801*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gtt", "[", "r_", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", "1"}], 
    SuperscriptBox["r", "2"]], " ", 
   RowBox[{"f", "[", "r", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gxx", "[", "r_", "]"}], ":=", 
  SuperscriptBox["r", 
   RowBox[{"-", "2"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"grr", "[", "r_", "]"}], ":=", 
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["r", "2"], 
    RowBox[{"f", "[", "r", "]"}]}]]}]}], "Input",
 CellChangeTimes->{
  3.728361388213914*^9, {3.7293194765457516`*^9, 3.729319482698206*^9}, {
   3.72931952289369*^9, 3.7293195233023877`*^9}, {3.7307100161118298`*^9, 
   3.7307100171429844`*^9}, {3.7599324376894274`*^9, 
   3.7599324492455077`*^9}, {3.759935397660673*^9, 3.759935398235634*^9}, {
   3.770471762363538*^9, 3.770471768352191*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQSEinstein0", "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7283613935510645`*^9, 3.7283614037104235`*^9}, {
  3.7283617789867663`*^9, 3.7283618140893126`*^9}, {3.7290061292039595`*^9, 
  3.7290061374678917`*^9}, {3.7704717708798027`*^9, 3.7704717739156923`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"f", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[CapitalLambda]"}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"f", "[", "r", "]"}]}], "+", 
         RowBox[{"r", " ", 
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
      SuperscriptBox["r", "2"]], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "\[CapitalLambda]"}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"f", "[", "r", "]"}]}], "-", 
       RowBox[{"4", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "\[CapitalLambda]"}], "+", 
       RowBox[{"6", " ", 
        RowBox[{"f", "[", "r", "]"}]}], "-", 
       RowBox[{"4", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{"\[CapitalLambda]", "+", 
       RowBox[{"3", " ", 
        RowBox[{"f", "[", "r", "]"}]}], "-", 
       RowBox[{"r", " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"f", "[", "r", "]"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7283613970167294`*^9, 3.7283614041033745`*^9}, {
   3.7290061328614545`*^9, 3.7290061378169947`*^9}, 3.7293179798113823`*^9, 
   3.7293188286230164`*^9, 3.7293194953389874`*^9, 3.7293195253584485`*^9, 
   3.729333121546278*^9, 3.7294052071723533`*^9, 3.7294133815609674`*^9, 
   3.729432343980837*^9, 3.7294325092433734`*^9, 3.729487943345254*^9, 
   3.7307100380517197`*^9, 3.7307138805445156`*^9, 3.73073633588133*^9, 
   3.7323605337389927`*^9, 3.732363474629609*^9, 3.7323640807284403`*^9, 
   3.7323900402883787`*^9, 3.7440188515737553`*^9, 3.75993156012868*^9, 
   3.759932451951005*^9, 3.759935400147606*^9, 3.762708878497473*^9, 
   3.770471776611106*^9, 3.7704721814310617`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Here is the Schwarzschild solution (we fix the \
integration constant by asking f(uh)=0)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7705562028406534`*^9, 3.7705562067375875`*^9}, {
  3.771962381691332*^9, 3.7719623823134727`*^9}, {3.77339342406179*^9, 
  3.7733934345563793`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "r", "]"}], "/.", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[CapitalLambda]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"f", "[", "r", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "\[Equal]", "0"}], 
      ",", "f", ",", "r"}], "]"}]}], "/.", 
   RowBox[{"\[CapitalLambda]", "\[Rule]", 
    RowBox[{"-", "3"}]}]}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"%", "/.", 
        RowBox[{"r", "\[Rule]", "rh"}]}], ")"}], "\[Equal]", "0"}], ",", 
     RowBox[{"C", "[", "1", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7283614168610306`*^9, 3.72836142411891*^9}, {
  3.728361796174157*^9, 3.728361816106798*^9}, {3.7704717845281496`*^9, 
  3.770471843800861*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", "+", 
   RowBox[{
    SuperscriptBox["r", "3"], " ", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.728361424477436*^9, 3.7290061442441015`*^9, 3.7293179885128765`*^9, 
   3.729318828736079*^9, {3.729319501207035*^9, 3.729319528416218*^9}, 
   3.729333121717758*^9, 3.729405207349368*^9, 3.7294133817216005`*^9, 
   3.729432344185196*^9, 3.729432509695697*^9, 3.7294879435465617`*^9, 
   3.730710044036888*^9, 3.7307138808902006`*^9, 3.7307363463401604`*^9, 
   3.73236053402269*^9, 3.7323634748552284`*^9, 3.732364080975772*^9, 
   3.7323900408017807`*^9, 3.7599315654821997`*^9, 3.7599324570857887`*^9, 
   3.7627088854405384`*^9, {3.7704717870593147`*^9, 3.7704718440713367`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", "-", 
   FractionBox[
    SuperscriptBox["r", "3"], 
    SuperscriptBox["rh", "3"]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.728361424477436*^9, 3.7290061442441015`*^9, 3.7293179885128765`*^9, 
   3.729318828736079*^9, {3.729319501207035*^9, 3.729319528416218*^9}, 
   3.729333121717758*^9, 3.729405207349368*^9, 3.7294133817216005`*^9, 
   3.729432344185196*^9, 3.729432509695697*^9, 3.7294879435465617`*^9, 
   3.730710044036888*^9, 3.7307138808902006`*^9, 3.7307363463401604`*^9, 
   3.73236053402269*^9, 3.7323634748552284`*^9, 3.732364080975772*^9, 
   3.7323900408017807`*^9, 3.7599315654821997`*^9, 3.7599324570857887`*^9, 
   3.7627088854405384`*^9, {3.7704717870593147`*^9, 3.770471844075327*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["This will be useful for after",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770556212238867*^9, 3.770556233311341*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f2nd", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "\[CapitalLambda]"}], "+", 
        RowBox[{"6", " ", 
         RowBox[{"f", "[", "r", "]"}]}], "-", 
        RowBox[{"4", " ", "r", " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{
       RowBox[{"f", "''"}], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cosmo", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[CapitalLambda]"}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"f", "[", "r", "]"}]}], "+", 
         RowBox[{"r", " ", 
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], "\[Equal]", 
       "0"}], ",", "\[CapitalLambda]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7704718673292594`*^9, 3.7704718950362253`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations for perturbations", "Section",
 CellChangeTimes->{{3.7283619513768835`*^9, 3.7283619526213694`*^9}, {
  3.729318730104987*^9, 3.7293187326645775`*^9}, {3.732364426272627*^9, 
  3.732364428589834*^9}}],

Cell[TextData[StyleBox["These are the equations for the perturbations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770556267541769*^9, 3.770556273830931*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EQSEinstein1", "/.", "f2nd"}], "/.", "cosmo"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.770472199898831*^9, 3.770472210380939*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", 
        RowBox[{"f", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"hxy", "[", 
            RowBox[{"t", ",", "r"}], "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{
            SuperscriptBox["hxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "r", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"hxy", "[", 
            RowBox[{"t", ",", "r"}], "]"}]}], "-", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["hxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "r"}], "]"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{
               SuperscriptBox["hxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{
         SuperscriptBox["hxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], 
      RowBox[{"2", " ", 
       RowBox[{"f", "[", "r", "]"}]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", 
        RowBox[{"f", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"hxy", "[", 
            RowBox[{"t", ",", "r"}], "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{
            SuperscriptBox["hxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"f", "[", "r", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"hxy", "[", 
            RowBox[{"t", ",", "r"}], "]"}]}], "-", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["hxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "r"}], "]"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{
               SuperscriptBox["hxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{
         SuperscriptBox["hxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], 
      RowBox[{"2", " ", 
       RowBox[{"f", "[", "r", "]"}]}]], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.770472201421517*^9, 3.770472210742682*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["Let us make it nicer",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7705562869574957`*^9, 3.7705562891644363`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "r"}], " ", 
     RowBox[{"f", "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"hxy", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], "+", 
       RowBox[{"r", " ", 
        RowBox[{
         SuperscriptBox["hxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "r", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"hxy", "[", 
         RowBox[{"t", ",", "r"}], "]"}]}], "-", 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["hxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "r"}], "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{
            SuperscriptBox["hxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{
      SuperscriptBox["hxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "r"}], "]"}]}]}], "/.", 
   RowBox[{"hxy", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "r"}], "}"}], ",", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "I"}], " ", "w", " ", "t"}], "]"}], 
       RowBox[{"h", "[", "r", "]"}]}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"-", "1"}], 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "w"}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"f", "[", "r", "]"}], "2"]}]], "%"}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"h", "''"}], "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"h", "'"}], "[", "r", "]"}], ",", 
       RowBox[{"h", "[", "r", "]"}]}], "}"}], ",", "Expand"}], "]"}], 
   "&"}]}]}], "Input",
 CellChangeTimes->{{3.7704722227757187`*^9, 3.770472262581754*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "r", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox["r", "2"]]}], "+", 
     FractionBox[
      SuperscriptBox["w", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "r", "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"r", " ", 
       RowBox[{"f", "[", "r", "]"}]}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["2", "r"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], 
      RowBox[{"f", "[", "r", "]"}]]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["h", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["h", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output",
 CellChangeTimes->{{3.7704722370767565`*^9, 3.770472263096447*^9}}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["And let us use the trick explained in the lectures to \
go directly to EF coordinates",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770556294757265*^9, 3.7705562973971214`*^9}, {
  3.7719623954186687`*^9, 3.771962408474944*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", 
          SuperscriptBox["r", "2"]]}], "+", 
        FractionBox[
         SuperscriptBox["w", "2"], 
         SuperscriptBox[
          RowBox[{"f", "[", "r", "]"}], "2"]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], 
         RowBox[{"r", " ", 
          RowBox[{"f", "[", "r", "]"}]}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["2", "r"], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], 
         RowBox[{"f", "[", "r", "]"}]]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["h", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "/.", 
    RowBox[{"h", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{"r", ",", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "I"}], " ", "w", " ", 
          RowBox[{"Integrate", "[", 
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{"f", "[", "r", "]"}]}], ",", "r"}], "]"}]}], "]"}], 
        SuperscriptBox["r", 
         RowBox[{"-", "2"}]], 
        RowBox[{"H", "[", "r", "]"}]}]}], "]"}]}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["r", 
      RowBox[{"-", "2"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"f", "[", "r", "]"}]], 
         RowBox[{"\[DifferentialD]", "r"}]}]}]}]]}]], "%"}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "''"}], "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"H", "'"}], "[", "r", "]"}], ",", 
       RowBox[{"H", "[", "r", "]"}]}], "}"}], ",", "Expand"}], "]"}], 
   "&"}]}]}], "Input",
 CellChangeTimes->{{3.770472469702941*^9, 3.7704725704649105`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "w", " ", 
    RowBox[{"H", "[", "r", "]"}]}], 
   RowBox[{"r", " ", 
    RowBox[{"f", "[", "r", "]"}]}]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "r"]}], "-", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "w"}], 
      RowBox[{"f", "[", "r", "]"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], 
      RowBox[{"f", "[", "r", "]"}]]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "r", "]"}]}]], "Output",
 CellChangeTimes->{{3.7704724897816114`*^9, 3.7704725710170517`*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["These are the equations you find in section 3.2 and \
later.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7733934603894987`*^9, 3.773393470212121*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"New Kernel1",
WindowSize->{1520, 781},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
Magnification->1.5,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 820, 12, 134, "Title"],
Cell[1403, 36, 425, 6, 74, "Text"],
Cell[1831, 44, 122, 2, 45, "Input"],
Cell[1956, 48, 147, 3, 45, "Input"],
Cell[CellGroupData[{
Cell[2128, 55, 206, 3, 108, "Chapter"],
Cell[CellGroupData[{
Cell[2359, 62, 123, 3, 399403, "Subsection"],
Cell[2485, 67, 187, 5, 2585380, "Input"],
Cell[2675, 74, 719, 23, 2734845, "Input"],
Cell[3397, 99, 661, 21, 4401823, "Input"],
Cell[4061, 122, 1735, 56, 7812783, "Input"],
Cell[5799, 180, 318, 10, 2585380, "Input"],
Cell[6120, 192, 327, 10, 2585380, "Input"],
Cell[6450, 204, 330, 10, 2585380, "Input"],
Cell[6783, 216, 321, 11, 2585380, "Input"],
Cell[7107, 229, 915, 28, 4401823, "Input"],
Cell[8025, 259, 1009, 35, 4401823, "Input"],
Cell[9037, 296, 1486, 43, 11220477, "Input"],
Cell[10526, 341, 1378, 41, 6124240, "Input"],
Cell[11907, 384, 167, 5, 2585380, "Input"],
Cell[12077, 391, 307, 9, 2585380, "Input"],
Cell[12387, 402, 1820, 52, 7812783, "Input"],
Cell[14210, 456, 1543, 44, 7812783, "Input"],
Cell[15756, 502, 359, 11, 2585380, "Input"],
Cell[16118, 515, 947, 25, 4401823, "Input"],
Cell[17068, 542, 325, 10, 2585380, "Input"],
Cell[17396, 554, 777, 24, 4401823, "Input"],
Cell[18176, 580, 46332, 1195, 278163135, "Input"],
Cell[64511, 1777, 926, 27, 4401823, "Input"],
Cell[65440, 1806, 4515, 133, 12928969, "Input"],
Cell[69958, 1941, 2300, 78, 11220477, "Input"],
Cell[72261, 2021, 1034, 31, 6124240, "Input"],
Cell[73298, 2054, 494, 15, 2585380, "Input"],
Cell[73795, 2071, 494, 15, 2585380, "Input"],
Cell[74292, 2088, 2808, 78, 9535636, "Input"],
Cell[77103, 2168, 551, 19, 2585380, "Input"],
Cell[77657, 2189, 2389, 66, 7812783, "Input"],
Cell[80049, 2257, 2292, 64, 9535636, "Input"],
Cell[82344, 2323, 1181, 35, 6124240, "Input"],
Cell[83528, 2360, 424, 15, 2585380, "Input"],
Cell[83955, 2377, 2998, 85, 14636911, "Input"],
Cell[86956, 2464, 1453, 45, 6124240, "Input"],
Cell[88412, 2511, 188, 5, 2585380, "Input"],
Cell[88603, 2518, 9071, 232, 31674394, "Input"],
Cell[97677, 2752, 535, 17, 2585380, "Input"],
Cell[98215, 2771, 1725, 51, 6124240, "Input"],
Cell[99943, 2824, 2192, 66, 9535636, "Input"],
Cell[102138, 2892, 729, 21, 2585380, "Input"],
Cell[102870, 2915, 913, 27, 4401823, "Input"],
Cell[103786, 2944, 231, 7, 2585380, "Input"],
Cell[104020, 2953, 323, 10, 2585380, "Input"],
Cell[104346, 2965, 477, 9, 4401823, "Input"],
Cell[104826, 2976, 186, 5, 2585380, "Input"],
Cell[105015, 2983, 89, 1, 4401823, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[105153, 2990, 243, 3, 90, "Chapter"],
Cell[CellGroupData[{
Cell[105421, 2997, 148, 2, 106, "Section"],
Cell[105572, 3001, 412, 6, 102, "Text"],
Cell[105987, 3009, 5577, 97, 104, "Input"],
Cell[CellGroupData[{
Cell[111589, 3110, 363, 6, 45, "Input"],
Cell[CellGroupData[{
Cell[111977, 3120, 3231, 74, 111, "Print"],
Cell[115211, 3196, 2960, 62, 40, "Print"],
Cell[118174, 3260, 6649, 158, 179, "Print"],
Cell[124826, 3420, 999, 17, 34, "Print"],
Cell[125828, 3439, 1040, 17, 34, "Print"],
Cell[126871, 3458, 1056, 17, 34, "Print"],
Cell[127930, 3477, 1051, 17, 34, "Print"],
Cell[128984, 3496, 1035, 17, 34, "Print"],
Cell[130022, 3515, 1036, 17, 34, "Print"],
Cell[131061, 3534, 1043, 17, 34, "Print"]
}, Open  ]]
}, Open  ]],
Cell[132131, 3555, 273, 9, 8, "Text"],
Cell[132407, 3566, 273, 9, 8, "Text"],
Cell[132683, 3577, 182, 3, 45, "Text"],
Cell[132868, 3582, 377, 7, 75, "Input"],
Cell[133248, 3591, 273, 9, 8, "Text"],
Cell[133524, 3602, 156, 2, 45, "Text"],
Cell[133683, 3606, 568, 13, 70, "Input"],
Cell[134254, 3621, 568, 13, 75, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134859, 3639, 163, 2, 106, "Section"],
Cell[135025, 3643, 205, 3, 45, "Text"],
Cell[135233, 3648, 854, 23, 165, "Input"],
Cell[CellGroupData[{
Cell[136112, 3675, 294, 4, 45, "Input"],
Cell[136409, 3681, 2969, 76, 130, "Output"]
}, Open  ]],
Cell[139393, 3760, 316, 5, 45, "Text"],
Cell[CellGroupData[{
Cell[139734, 3769, 1079, 31, 75, "Input"],
Cell[140816, 3802, 761, 14, 50, "Output"],
Cell[141580, 3818, 754, 14, 69, "Output"]
}, Open  ]],
Cell[142349, 3835, 152, 2, 45, "Text"],
Cell[142504, 3839, 1395, 41, 80, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143936, 3885, 216, 3, 106, "Section"],
Cell[144155, 3890, 168, 2, 45, "Text"],
Cell[CellGroupData[{
Cell[144348, 3896, 193, 5, 45, "Input"],
Cell[144544, 3903, 4595, 137, 233, "Output"]
}, Open  ]],
Cell[149154, 4043, 147, 2, 45, "Text"],
Cell[CellGroupData[{
Cell[149326, 4049, 2914, 96, 145, "Input"],
Cell[152243, 4147, 1084, 35, 73, "Output"]
}, Open  ]],
Cell[153342, 4185, 273, 9, 8, "Text"],
Cell[153618, 4196, 261, 4, 45, "Text"],
Cell[CellGroupData[{
Cell[153904, 4204, 2468, 78, 160, "Input"],
Cell[156375, 4284, 870, 26, 68, "Output"]
}, Open  ]],
Cell[157260, 4313, 185, 3, 45, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

