(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    249697,       5327]
NotebookOptionsPosition[    245857,       5206]
NotebookOutlinePosition[    246203,       5221]
CellTagsIndexPosition[    246160,       5218]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Section 3.4 : the Txy correlator numerically", "Title",
 CellChangeTimes->{{3.749846429603025*^9, 3.749846435181451*^9}, {
  3.751519023154038*^9, 3.751519032954296*^9}, {3.7515431693674345`*^9, 
  3.751543171336177*^9}, {3.7702237155723066`*^9, 3.770223717727358*^9}, {
  3.771962470418024*^9, 3.7719624817954717`*^9}, {3.773392970284009*^9, 
  3.7733929762547235`*^9}},
 ExpressionUUID -> "560a7c9e-cab5-4b63-a28c-3523fae2c01a"],

Cell[TextData[StyleBox["In this notebook:\n1) we derive numerically the shear \
correlator at finite frequency in the theory of arXiv:1601.03384\n2) we read \
numerically the elastic modulus and the viscosity\n3) we check numerically \
the analytic formulas derived in the lectures\n4) we check the zero \
temperature power law derived in the lectures\n\nThe computations are \
described in section 3.4 of the notes.",
 FontSize->18,
 FontSlant->"Italic",
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.771962494042267*^9, 3.771962570076596*^9}, {
  3.773392980098143*^9, 3.77339299154038*^9}, {3.777291559701845*^9, 
  3.7772915598676653`*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7515433420353947`*^9, 3.75154334354336*^9}}],

Cell[CellGroupData[{

Cell["Numerical routine", "Section",
 CellChangeTimes->{{3.608114868497301*^9, 3.608114872912833*^9}, {
  3.770223741094873*^9, 3.7702237445399437`*^9}, {3.770223883314438*^9, 
  3.770223884394333*^9}},
 ExpressionUUID -> "56773a04-0bed-44ed-aa81-2da1becfc931"],

Cell[CellGroupData[{

Cell["message catch (let us be fancy)", "Subsection",
 CellChangeTimes->{{3.651027342224827*^9, 3.65102734442384*^9}, {
  3.771962591600705*^9, 3.7719625975107903`*^9}},
 ExpressionUUID -> "8a26b4cf-eb6a-4ca1-b51a-3219c0b58db4"],

Cell[TextData[StyleBox["this stops the integration if NDSolve finds a stiff \
system",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.717079212937269*^9, 3.71707922929598*^9}},
 ExpressionUUID -> "61e08607-179e-4299-b568-15615f495a18"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"NDSolve", "::", "ndsz"}], "MessageName"], "=", 
    "\"\<Could not perform the integration\>\""}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"Unprotect", "[", "Message", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Message", "[", 
   RowBox[{
    RowBox[{"mm", " ", ":", 
     StyleBox[
      RowBox[{"NDSolve", "::", "ndsz"}], "MessageName"]}], ",", "m___"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"$inMsg", "=", "True"}], ",", "result"}], "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{"mm", ",", "m"}], "]"}], ";", "\n", "\n", 
      RowBox[{"Abort", "[", "]"}]}]}], "]"}], "/;", 
   RowBox[{"!", 
    RowBox[{"TrueQ", "[", "$inMsg", "]"}]}]}]}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "Message", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6510273971376753`*^9, 3.651027439100522*^9}, {
  3.716878762754228*^9, 3.71687877022867*^9}},
 ExpressionUUID -> "730da66f-ad5b-44f7-a460-d1b9ad2bdbf1"]
}, Closed]],

Cell[CellGroupData[{

Cell["eoms", "Subsection",
 CellChangeTimes->{{3.60811456657498*^9, 3.608114566950328*^9}},
 ExpressionUUID -> "90f2721d-8dc2-4158-ac6f-3444907c9b57"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"e1", "[", 
    RowBox[{"M2_", ",", "\[Omega]1_"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "M2", " ", 
        SuperscriptBox["u", "5"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
     RowBox[{"h", "[", "u", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"6", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "+", "M2"}], ")"}], " ", 
        SuperscriptBox["u", "3"]}], "-", 
       RowBox[{"4", " ", "M2", " ", 
        SuperscriptBox["u", "6"]}], "-", 
       RowBox[{"6", " ", "\[ImaginaryI]", " ", "u", " ", "\[Omega]1"}]}], 
      ")"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "-", 
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["u", "3"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"M2", " ", 
        SuperscriptBox["u", "3"]}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["h", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}]}], " ", ";"}]], "Input",
 CellChangeTimes->{{3.608114461353334*^9, 3.608114482005959*^9}, {
   3.608114532274555*^9, 3.608114546022718*^9}, {3.6081162444360847`*^9, 
   3.608116255351364*^9}, {3.608116297946883*^9, 3.608116298303133*^9}, {
   3.608117396326599*^9, 3.608117475557654*^9}, {3.6081175282247343`*^9, 
   3.608117589025673*^9}, {3.608145303551969*^9, 3.6081453511519337`*^9}, 
   3.6081454102877283`*^9, {3.614903166357081*^9, 3.614903220888982*^9}, {
   3.614972102381304*^9, 3.614972236044791*^9}, {3.619126902125711*^9, 
   3.6191269143121853`*^9}, {3.619127012359384*^9, 3.619127069400412*^9}, {
   3.716878794331892*^9, 3.7168788279970093`*^9}, {3.749701914353735*^9, 
   3.749701919041525*^9}, {3.751111408248742*^9, 3.7511114106577797`*^9}, {
   3.751543336400469*^9, 3.751543336722604*^9}},
 ExpressionUUID -> "5a6d56fe-f5a2-44f8-8b89-d3da9d69472e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["asymptotics ", "Subsection",
 CellChangeTimes->{{3.608114894920824*^9, 3.608114896320691*^9}},
 ExpressionUUID -> "f26f0bfb-f19a-4b1d-ad63-d62867b47369"],

Cell[TextData[StyleBox["Here we find the perturbative solutions close to the \
boundary an the horizon and we prepare everything for the numerical \
integrations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771962618617282*^9, 3.771962640332779*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "u_", "]"}], "=", 
   RowBox[{"Sum", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"hir", "[", "i", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "u"}], ")"}], "i"]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"e1", "[", 
      RowBox[{"M2", ",", "\[Omega]1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "1", ",", "5"}], "}"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{"hir", "[", "0", "]"}], "\[Rule]", "hH"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "4"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hir", "[", "1", "]"}], ",", 
       RowBox[{"hir", "[", "2", "]"}], ",", 
       RowBox[{"hir", "[", "3", "]"}], ",", 
       RowBox[{"hir", "[", "4", "]"}], ",", 
       RowBox[{"hir", "[", "5", "]"}]}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.751543437473193*^9, 3.751543585465506*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"hir", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "hH", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "M2"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "3"}], "+", "M2", "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{"hir", "[", "2", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"hH", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", " ", 
         SuperscriptBox["M2", "2"]}], "+", 
        RowBox[{"M2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "36"}], "+", 
           RowBox[{"29", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}], 
        "+", 
        RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}], 
   ",", 
   RowBox[{
    RowBox[{"hir", "[", "3", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"hH", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "18"}], " ", 
         SuperscriptBox["M2", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["M2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"108", "+", 
           RowBox[{"5", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}], 
        "+", 
        RowBox[{"3", " ", "\[Omega]1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", "\[Omega]1"}], 
          ")"}]}], "+", 
        RowBox[{"M2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "162"}], "+", 
           RowBox[{"312", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
           RowBox[{"113", " ", 
            SuperscriptBox["\[Omega]1", "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"3", " ", "M2"}], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}], 
   ",", 
   RowBox[{
    RowBox[{"hir", "[", "4", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"hH", " ", "\[Omega]1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"332", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["M2", "3"]}], "-", 
        RowBox[{"45", " ", "\[Omega]1"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["M2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"668", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{"353", " ", "\[Omega]1"}]}], ")"}]}], "+", 
        RowBox[{"M2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"720", " ", "\[ImaginaryI]"}], "+", 
           RowBox[{"762", " ", "\[Omega]1"}], "-", 
           RowBox[{"224", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["\[Omega]1", "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "6"}], "+", 
        RowBox[{"2", " ", "M2"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"3", " ", "M2"}], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}], 
   ",", 
   RowBox[{
    RowBox[{"hir", "[", "5", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "hH", " ", "\[Omega]1", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"15220", " ", 
         SuperscriptBox["M2", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["M2", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"164220", "-", 
           RowBox[{"78709", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], 
          ")"}]}], "+", 
        RowBox[{"135", " ", 
         RowBox[{"(", 
          RowBox[{"24", "-", 
           RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
           SuperscriptBox["\[Omega]1", "2"]}], ")"}]}], "-", 
        RowBox[{"45", " ", 
         SuperscriptBox["M2", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3648"}], "+", 
           RowBox[{"3548", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
           RowBox[{"933", " ", 
            SuperscriptBox["\[Omega]1", "2"]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", "M2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6840"}], "+", 
           RowBox[{"6345", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
           RowBox[{"750", " ", 
            SuperscriptBox["\[Omega]1", "2"]}], "+", 
           RowBox[{"448", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"60", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "6"}], "+", 
        RowBox[{"2", " ", "M2"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", "M2", "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"3", " ", "M2"}], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "15"}], "+", 
        RowBox[{"5", " ", "M2"}], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}]}],
   "}"}]], "Output",
 CellChangeTimes->{{3.7515434580233135`*^9, 3.7515435414441786`*^9}, {
   3.75154357320126*^9, 3.751543585794587*^9}, 3.7516347514087605`*^9, 
   3.751634852805007*^9, 3.751672041299308*^9, 3.756446662035033*^9, 
   3.757162996992111*^9, 3.7572238997626123`*^9, 3.7575077517232847`*^9, 
   3.757512187755185*^9, 3.75852769332219*^9, 3.759329200354126*^9, 
   3.7594963388523846`*^9, 3.7594994008682575`*^9, 3.770223887481862*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"IRcoeff", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"hir", "[", "0", "]"}], "\[Rule]", "hH"}], ",", 
     RowBox[{
      RowBox[{"hir", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "hH", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "M2"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"-", "3"}], "+", "M2", "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}]]}]}], ",", 
     RowBox[{
      RowBox[{"hir", "[", "2", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"hH", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox["M2", "2"]}], "+", 
          RowBox[{"M2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "36"}], "+", 
             RowBox[{"29", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], 
            ")"}]}], "+", 
          RowBox[{"3", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}],
      ",", 
     RowBox[{
      RowBox[{"hir", "[", "3", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"hH", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "18"}], " ", 
           SuperscriptBox["M2", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["M2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"108", "+", 
             RowBox[{"5", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}],
           "+", 
          RowBox[{"3", " ", "\[Omega]1", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", "\[Omega]1"}], 
            ")"}]}], "+", 
          RowBox[{"M2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "162"}], "+", 
             RowBox[{"312", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
             RowBox[{"113", " ", 
              SuperscriptBox["\[Omega]1", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"3", " ", "M2"}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}],
      ",", 
     RowBox[{
      RowBox[{"hir", "[", "4", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"hH", " ", "\[Omega]1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"332", " ", "\[ImaginaryI]", " ", 
           SuperscriptBox["M2", "3"]}], "-", 
          RowBox[{"45", " ", "\[Omega]1"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["M2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"668", " ", "\[ImaginaryI]"}], "+", 
             RowBox[{"353", " ", "\[Omega]1"}]}], ")"}]}], "+", 
          RowBox[{"M2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"720", " ", "\[ImaginaryI]"}], "+", 
             RowBox[{"762", " ", "\[Omega]1"}], "-", 
             RowBox[{"224", " ", "\[ImaginaryI]", " ", 
              SuperscriptBox["\[Omega]1", "2"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          RowBox[{"2", " ", "M2"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"3", " ", "M2"}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}]}]]}],
      ",", 
     RowBox[{
      RowBox[{"hir", "[", "5", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", "hH", " ", "\[Omega]1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"15220", " ", 
           SuperscriptBox["M2", "4"]}], "+", 
          RowBox[{
           SuperscriptBox["M2", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"164220", "-", 
             RowBox[{"78709", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], 
            ")"}]}], "+", 
          RowBox[{"135", " ", 
           RowBox[{"(", 
            RowBox[{"24", "-", 
             RowBox[{"22", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
             SuperscriptBox["\[Omega]1", "2"]}], ")"}]}], "-", 
          RowBox[{"45", " ", 
           SuperscriptBox["M2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3648"}], "+", 
             RowBox[{"3548", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
             RowBox[{"933", " ", 
              SuperscriptBox["\[Omega]1", "2"]}]}], ")"}]}], "+", 
          RowBox[{"3", " ", "M2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6840"}], "+", 
             RowBox[{"6345", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "+", 
             RowBox[{"750", " ", 
              SuperscriptBox["\[Omega]1", "2"]}], "+", 
             RowBox[{"448", " ", "\[ImaginaryI]", " ", 
              SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"60", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "+", 
          RowBox[{"2", " ", "M2"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", "M2", "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"3", " ", "M2"}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "15"}], "+", 
          RowBox[{"5", " ", "M2"}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Omega]1"}]}], 
         ")"}]}]]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.716878015555065*^9, 3.716878017059781*^9}, {
  3.716878502793489*^9, 3.716878507613336*^9}, {3.749701875277917*^9, 
  3.749701875487331*^9}, {3.7511110657935658`*^9, 3.751111074704764*^9}, {
  3.751543596718377*^9, 3.751543596939786*^9}},
 ExpressionUUID -> "a5c4def1-5bd5-478d-9773-82176d302918"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h", "[", "u_", "]"}], "=", 
   RowBox[{"Sum", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"hUV", "[", "i", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", "u", ")"}], "i"]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"e1", "[", 
       RowBox[{"M2", ",", "\[Omega]1"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "0", ",", "5"}], "}"}]}], "]"}], "/.", 
    RowBox[{
     RowBox[{"hUV", "[", "0", "]"}], "\[Rule]", "h0"}]}], "/.", 
   RowBox[{
    RowBox[{"hUV", "[", "3", "]"}], "\[Rule]", "h3"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"%", ",", "4"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"hUV", "[", "1", "]"}], ",", 
       RowBox[{"hUV", "[", "2", "]"}], ",", 
       RowBox[{"hUV", "[", "4", "]"}], ",", 
       RowBox[{"hUV", "[", "5", "]"}]}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "h", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7515438340258274`*^9, 3.7515439918388844`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "h0", " ", "\[Omega]1"}], "+", 
      RowBox[{"hUV", "[", "1", "]"}]}], ")"}]}], "+", 
   RowBox[{"6", " ", 
    RowBox[{"hUV", "[", "2", "]"}], " ", "u"}], "-", 
   RowBox[{"6", " ", "\[ImaginaryI]", " ", "\[Omega]1", " ", 
    RowBox[{"hUV", "[", "2", "]"}], " ", 
    SuperscriptBox["u", "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", "\[ImaginaryI]", " ", "h3", " ", 
       "\[Omega]1"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", "M2"}], ")"}], " ", 
       RowBox[{"hUV", "[", "1", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"hUV", "[", "4", "]"}]}]}], ")"}], " ", 
    SuperscriptBox["u", "3"]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "M2"}], ")"}], " ", 
       RowBox[{"hUV", "[", "2", "]"}]}], "-", 
      RowBox[{"9", " ", "\[ImaginaryI]", " ", "\[Omega]1", " ", 
       RowBox[{"hUV", "[", "4", "]"}]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"hUV", "[", "5", "]"}]}]}], ")"}], " ", 
    SuperscriptBox["u", "4"]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", "h0", " ", "M2"}], "+", 
      RowBox[{"3", " ", "h3", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", "M2"}], ")"}]}], "-", 
      RowBox[{"8", " ", "\[ImaginaryI]", " ", "\[Omega]1", " ", 
       RowBox[{"hUV", "[", "5", "]"}]}]}], ")"}], " ", 
    SuperscriptBox["u", "5"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "u", "]"}], "6"],
    SeriesData[$CellContext`u, 0, {}, 0, 6, 1],
    Editable->False]}],
  SeriesData[$CellContext`u, 0, {
   6 (Complex[0, 1] $CellContext`h0 $CellContext`\[Omega]1 + $CellContext`hUV[
      1]), 6 $CellContext`hUV[2], 
    Complex[0, -6] $CellContext`\[Omega]1 $CellContext`hUV[2], 
    Complex[0, -12] $CellContext`h3 $CellContext`\[Omega]1 + (
      3 + $CellContext`M2) $CellContext`hUV[1] - 12 $CellContext`hUV[4], 
    2 (2 (3 + $CellContext`M2) $CellContext`hUV[2] + 
     Complex[0, -9] $CellContext`\[Omega]1 $CellContext`hUV[4] - 
     15 $CellContext`hUV[5]), 
    3 (6 $CellContext`h0 $CellContext`M2 + 
     3 $CellContext`h3 (3 + $CellContext`M2) + 
     Complex[0, -8] $CellContext`\[Omega]1 $CellContext`hUV[5])}, 0, 6, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.751543843660061*^9, 3.751543992320546*^9}, 
   3.751634751508082*^9, 3.7516348528823633`*^9, 3.751672041369809*^9, 
   3.756446662119698*^9, 3.757162997054604*^9, 3.757223899862862*^9, 
   3.7575077518099546`*^9, 3.7575121878399334`*^9, 3.7585276935227237`*^9, 
   3.7593292004384804`*^9, 3.759496338935193*^9, 3.7594994009849453`*^9, 
   3.7702238875978403`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"hUV", "[", "1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "h0", " ", "\[Omega]1"}]}], ",", 
   RowBox[{
    RowBox[{"hUV", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"hUV", "[", "4", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "12"]}], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", "h3"}], "+", 
       RowBox[{"h0", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "M2"}], ")"}]}]}], ")"}], " ", "\[Omega]1"}]}], 
   ",", 
   RowBox[{
    RowBox[{"hUV", "[", "5", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "20"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", "h3"}], "+", 
       RowBox[{"h0", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", "M2"}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["\[Omega]1", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.751543843660061*^9, 3.751543992320546*^9}, 
   3.751634751508082*^9, 3.7516348528823633`*^9, 3.751672041369809*^9, 
   3.756446662119698*^9, 3.757162997054604*^9, 3.757223899862862*^9, 
   3.7575077518099546`*^9, 3.7575121878399334`*^9, 3.7585276935227237`*^9, 
   3.7593292004384804`*^9, 3.759496338935193*^9, 3.7594994009849453`*^9, 
   3.770223887622964*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"UVcoeff", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"hUV", "[", "0", "]"}], "\[Rule]", "h0"}], ",", 
     RowBox[{
      RowBox[{"hUV", "[", "3", "]"}], "\[Rule]", "h3"}], ",", 
     RowBox[{
      RowBox[{"hUV", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "h0", " ", "\[Omega]1"}]}], ",", 
     RowBox[{
      RowBox[{"hUV", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"hUV", "[", "4", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "12"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", "h3"}], "+", 
         RowBox[{"h0", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", "M2"}], ")"}]}]}], ")"}], " ", "\[Omega]1"}]}], 
     ",", 
     RowBox[{
      RowBox[{"hUV", "[", "5", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "20"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"12", " ", "h3"}], "+", 
         RowBox[{"h0", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", "M2"}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["\[Omega]1", "2"]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.751544001839094*^9, 3.751544019271491*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UVcoeff", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"huv", "[", "0", "]"}], "\[Rule]", "h0"}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "3", "]"}], "\[Rule]", "h3"}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "h0", " ", "\[Omega]1"}]}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "2", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "4", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "20"]}], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"20", " ", "h3"}], "+", 
         RowBox[{"h0", " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", "M2"}], ")"}]}]}], ")"}], " ", "\[Omega]1"}]}], 
     ",", 
     RowBox[{
      RowBox[{"huv", "[", "5", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "100"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"20", " ", "h3"}], "+", 
         RowBox[{"h0", " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", "M2"}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["\[Omega]1", "2"]}]}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "6", "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "150"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "h0", " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", "M2"}], ")"}], " ", 
          SuperscriptBox["\[Omega]1", "3"]}], "+", 
         RowBox[{"5", " ", "h3", " ", 
          RowBox[{"(", 
           RowBox[{"15", "+", 
            RowBox[{"3", " ", "M2"}], "+", 
            RowBox[{"8", " ", "\[ImaginaryI]", " ", 
             SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "7", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"5", " ", "h3", " ", 
            RowBox[{"(", 
             RowBox[{"315", "+", 
              RowBox[{"63", " ", "M2"}], "+", 
              RowBox[{"40", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", "h0", " ", 
            RowBox[{"(", 
             RowBox[{"150", "+", 
              RowBox[{"60", " ", "M2"}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox["M2", "2"]}], "+", 
              RowBox[{"25", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Omega]1", "3"]}], "+", 
              RowBox[{"5", " ", "\[ImaginaryI]", " ", "M2", " ", 
               SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}]}], ")"}]}], 
        "2100"]}]}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "8", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Omega]1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"160", " ", "h3", " ", 
            RowBox[{"(", 
             RowBox[{"105", "+", 
              RowBox[{"21", " ", "M2"}], "+", 
              RowBox[{"5", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}], "+", 
           RowBox[{"h0", " ", 
            RowBox[{"(", 
             RowBox[{"3825", "+", 
              RowBox[{"1530", " ", "M2"}], "+", 
              RowBox[{"153", " ", 
               SuperscriptBox["M2", "2"]}], "+", 
              RowBox[{"200", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Omega]1", "3"]}], "+", 
              RowBox[{"40", " ", "\[ImaginaryI]", " ", "M2", " ", 
               SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}]}], ")"}]}], 
        "28000"]}]}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "9", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{
        RowBox[{"32", " ", "h3", " ", 
         RowBox[{"(", 
          RowBox[{"225", "+", 
           RowBox[{"90", " ", "M2"}], "+", 
           RowBox[{"9", " ", 
            SuperscriptBox["M2", "2"]}], "+", 
           RowBox[{"225", " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["\[Omega]1", "3"]}], "+", 
           RowBox[{"45", " ", "\[ImaginaryI]", " ", "M2", " ", 
            SuperscriptBox["\[Omega]1", "3"]}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["\[Omega]1", "6"]}]}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", " ", "h0", " ", "\[Omega]1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"69", " ", 
            SuperscriptBox["M2", "2"], " ", 
            SuperscriptBox["\[Omega]1", "2"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["\[Omega]1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"345", "+", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}], "+", 
           RowBox[{"M2", " ", 
            RowBox[{"(", 
             RowBox[{"480", "+", 
              RowBox[{"690", " ", 
               SuperscriptBox["\[Omega]1", "2"]}], "+", 
              RowBox[{"8", " ", "\[ImaginaryI]", " ", 
               SuperscriptBox["\[Omega]1", "5"]}]}], ")"}]}]}], ")"}]}]}], 
       "21600"]}], ",", 
     RowBox[{
      RowBox[{"huv", "[", "10", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "945000"]}], "\[ImaginaryI]", " ", "\[Omega]1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"25", " ", "h3", " ", 
          RowBox[{"(", 
           RowBox[{"22725", "+", 
            RowBox[{"909", " ", 
             SuperscriptBox["M2", "2"]}], "+", 
            RowBox[{"5400", " ", "\[ImaginaryI]", " ", 
             SuperscriptBox["\[Omega]1", "3"]}], "-", 
            RowBox[{"64", " ", 
             SuperscriptBox["\[Omega]1", "6"]}], "+", 
            RowBox[{"90", " ", "M2", " ", 
             RowBox[{"(", 
              RowBox[{"101", "+", 
               RowBox[{"12", " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "h0", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"189", " ", 
             SuperscriptBox["M2", "3"]}], "+", 
            RowBox[{"15", " ", 
             SuperscriptBox["M2", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"189", "+", 
               RowBox[{"22", " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["\[Omega]1", "3"]}]}], ")"}]}], "+", 
            RowBox[{"25", " ", 
             RowBox[{"(", 
              RowBox[{"945", "+", 
               RowBox[{"330", " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["\[Omega]1", "3"]}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[Omega]1", "6"]}]}], ")"}]}], "-", 
            RowBox[{"5", " ", "M2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2835"}], "-", 
               RowBox[{"240", " ", "\[ImaginaryI]", " ", "\[Omega]1"}], "-", 
               RowBox[{"660", " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["\[Omega]1", "3"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["\[Omega]1", "6"]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.716878015555065*^9, 3.716878017059781*^9}, {
   3.749701598346389*^9, 3.749701598551093*^9}, 3.751111048875223*^9},
 ExpressionUUID -> "c8dbc92b-f779-42fb-bc26-3d41acef044d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"hSIR", "[", 
      RowBox[{"hH_", ",", "\[Omega]1_", ",", "M2_"}], "]"}], "[", "y_", "]"}],
     "=", " ", 
    RowBox[{
     RowBox[{"Sum", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"hir", "[", "i", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "y"}], ")"}], "i"]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}], "/.", " ", 
     "IRcoeff"}]}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.608108436877945*^9, 3.60810847842187*^9}, {
   3.608108516933975*^9, 3.608108517005941*^9}, {3.608108554126642*^9, 
   3.608108579726841*^9}, {3.608108628579259*^9, 3.608108663488885*^9}, {
   3.608114384827063*^9, 3.608114416610093*^9}, {3.614902686262484*^9, 
   3.6149027341292143`*^9}, {3.614968916510988*^9, 3.614968968247665*^9}, {
   3.614972340654851*^9, 3.614972351244051*^9}, 3.619126168116119*^9, {
   3.619126276793289*^9, 3.619126294273636*^9}, {3.716878880683056*^9, 
   3.716878938918264*^9}, {3.7497019713054667`*^9, 3.74970198532621*^9}},
 ExpressionUUID -> "37ca9fbb-5468-4df5-b91c-07985ec400a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hSUV", "[", 
    RowBox[{"h0_", ",", "h3_", ",", "\[Omega]1_", ",", "M2_"}], "]"}], "[", 
   "y_", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"Sum", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"huv", "[", "i", "]"}], " ", 
      SuperscriptBox["y", "i"]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "5"}], "}"}]}], "]"}], " ", "/.", " ", 
   "UVcoeff"}]}]], "Input",
 CellChangeTimes->{{3.6044084524781303`*^9, 3.604408523561131*^9}, {
   3.604417030895759*^9, 3.6044170613574877`*^9}, 3.604419307601075*^9, 
   3.604467762601192*^9, {3.604917909034773*^9, 3.604917923096058*^9}, {
   3.604917959828383*^9, 3.604917961921788*^9}, {3.6081024652076273`*^9, 
   3.6081025063300056`*^9}, {3.608102542338654*^9, 3.608102566358201*^9}, {
   3.608102614621563*^9, 3.608102624824095*^9}, {3.6081026560526657`*^9, 
   3.608102664215766*^9}, {3.608113621622764*^9, 3.6081136386469173`*^9}, {
   3.6081137078744583`*^9, 3.608113715592881*^9}, {3.6081444984864283`*^9, 
   3.6081445129120913`*^9}, {3.614902151560534*^9, 3.614902182190576*^9}, {
   3.614966482659285*^9, 3.614966526300696*^9}, {3.614969070720744*^9, 
   3.614969088846571*^9}, {3.614972283287258*^9, 3.614972293357153*^9}, {
   3.619127483922477*^9, 3.619127484067679*^9}, {3.716878971391079*^9, 
   3.716879043274974*^9}, {3.749701988201056*^9, 3.749702005712772*^9}, 
   3.75154381311773*^9, {3.7515440390107327`*^9, 3.7515440526921244`*^9}, 
   3.751635004991952*^9, {3.7516721306520567`*^9, 3.751672131278562*^9}},
 ExpressionUUID -> "119a6039-c29d-4183-9829-152f30abdf01"],

Cell[BoxData[
 RowBox[{"h0", "+", 
  RowBox[{"h3", " ", 
   SuperscriptBox["y", "3"]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", "h0", " ", "y", " ", "\[Omega]1"}], "-", 
  RowBox[{
   FractionBox["1", "20"], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"20", " ", "h3"}], "+", 
     RowBox[{"h0", " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", "M2"}], ")"}]}]}], ")"}], " ", 
   SuperscriptBox["y", "4"], " ", "\[Omega]1"}], "-", 
  RowBox[{
   FractionBox["3", "100"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"20", " ", "h3"}], "+", 
     RowBox[{"h0", " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", "M2"}], ")"}]}]}], ")"}], " ", 
   SuperscriptBox["y", "5"], " ", 
   SuperscriptBox["\[Omega]1", "2"]}]}]], "Output",
 CellChangeTimes->{{3.75163500556242*^9, 3.751635011231305*^9}, 
   3.751672041467245*^9, 3.751672135604407*^9, 3.7564466622043924`*^9, 
   3.757162997161398*^9, 3.7572238999823465`*^9, 3.7575077518946557`*^9, 
   3.7575121879402003`*^9, 3.75852769364006*^9, 3.75932920051659*^9, 
   3.7594963390128307`*^9, 3.7594994010946555`*^9, 3.7702238877061267`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["integration from the horizon", "Subsection",
 CellChangeTimes->{{3.60811493991251*^9, 3.608114944462865*^9}, {
  3.60811769533834*^9, 3.608117696312426*^9}, {3.616386251176715*^9, 
  3.616386251849597*^9}},
 ExpressionUUID -> "05f2638a-1bad-4a93-a21f-ba1e836288b5"],

Cell["\<\
We integrate from the horizon to a matching point in the middle\
\>", "Text",
 CellChangeTimes->{{3.7733930320437403`*^9, 3.7733930418715315`*^9}},
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"intIR", "[", 
     RowBox[{"hH_", ",", "\[Omega]1_", ",", "M2_"}], "]"}], "[", 
    RowBox[{"\[Epsilon]_", ",", "\[Epsilon]H_", ",", "ymatch_"}], "]"}], ":=",
    " ", 
   RowBox[{"Module", "[", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"bcsIR", ",", "systemIR"}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "asymptotics", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bcsIR", "=", " ", 
       RowBox[{"{", "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "[", 
           RowBox[{"1", "-", "\[Epsilon]H"}], "]"}], " ", "\[Equal]", "  ", 
          RowBox[{
           RowBox[{"hSIR", "[", 
            RowBox[{"hH", ",", "\[Omega]1", ",", "M2"}], "]"}], "[", 
           RowBox[{"1", "-", "\[Epsilon]H"}], "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"h", "'"}], "[", 
           RowBox[{"1", "-", "\[Epsilon]H"}], "]"}], " ", "\[Equal]", "  ", 
          RowBox[{
           RowBox[{
            RowBox[{"hSIR", "[", 
             RowBox[{"hH", ",", "\[Omega]1", ",", "M2"}], "]"}], "'"}], "[", 
           RowBox[{"1", "-", "\[Epsilon]H"}], "]"}]}]}], " ", "}"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"system", " ", "to", " ", "be", " ", "integrated"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"systemIR", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"e1", "[", 
           RowBox[{"M2", ",", "\[Omega]1"}], "]"}], "\[Equal]", "0"}], ",", 
         " ", "bcsIR"}], " ", "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"NDSolve", "[", "   ", 
       RowBox[{"systemIR", ",", " ", 
        RowBox[{"{", "h", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", 
          RowBox[{"ymatch", "-", "0.001"}], ",", 
          RowBox[{"1", "-", " ", "\[Epsilon]H"}]}], "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "\n", " ", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.6163859954001217`*^9, {3.616386046197892*^9, 3.616386067525025*^9}, 
   3.616386148448151*^9, {3.616386232942335*^9, 3.616386244211418*^9}, {
   3.616386283078623*^9, 3.616386306489835*^9}, 3.616386365248589*^9, {
   3.6191550701256533`*^9, 3.6191551146224213`*^9}, {3.716879122831769*^9, 
   3.7168793178257627`*^9}, {3.716879409191337*^9, 3.716879409470536*^9}, {
   3.749702058432925*^9, 3.749702105948223*^9}, 3.749702142542469*^9, {
   3.751543747442354*^9, 3.7515437497242503`*^9}},
 ExpressionUUID -> "cc83d96b-5d1e-46bb-85e2-3a69138f1d08"]
}, Open  ]],

Cell[CellGroupData[{

Cell["integration from the boundary", "Subsection",
 CellChangeTimes->{{3.60811493991251*^9, 3.608114944462865*^9}, {
  3.60811769533834*^9, 3.608117696312426*^9}},
 ExpressionUUID -> "1e2e873f-8c0d-4047-b088-8234b754a322"],

Cell["We integrate from the UV to a matching point in the middle", "Text",
 CellChangeTimes->{{3.7733930576526146`*^9, 3.7733930666092367`*^9}},
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"intUV", "[", 
     RowBox[{"h0_", ",", "h3_", ",", "\[Omega]1_", ",", "M2_"}], "]"}], "[", 
    RowBox[{"\[Epsilon]_", ",", "\[Epsilon]H_", ",", "ymatch_"}], "]"}], ":=",
    " ", 
   RowBox[{"Module", "[", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"bcsUV", ",", "systemUV"}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", "asymptotics", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bcsUV", "=", " ", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "[", "\[Epsilon]", "]"}], " ", "\[Equal]", "  ", 
          RowBox[{
           RowBox[{"hSUV", "[", 
            RowBox[{"h0", ",", "h3", ",", "\[Omega]1", ",", "M2"}], "]"}], 
           "[", "\[Epsilon]", "]"}]}], " ", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"h", "'"}], "[", "\[Epsilon]", "]"}], " ", "\[Equal]", 
          "  ", 
          RowBox[{
           RowBox[{
            RowBox[{"hSUV", "[", 
             RowBox[{"h0", ",", "h3", ",", "\[Omega]1", ",", "M2"}], "]"}], 
            "'"}], "[", "\[Epsilon]", "]"}]}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"system", " ", "to", " ", "be", " ", "integrated"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"systemUV", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"e1", "[", 
           RowBox[{"M2", ",", "\[Omega]1"}], "]"}], "\[Equal]", "0"}], ",", 
         " ", "bcsUV"}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"NDSolve", "[", "   ", 
       RowBox[{"systemUV", ",", " ", 
        RowBox[{"{", "h", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "\[Epsilon]", ",", 
          RowBox[{"ymatch", "+", "0.01"}]}], " ", "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "\n", " ", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.6163859954001217`*^9, {3.616386046197892*^9, 3.616386067525025*^9}, 
   3.616386148448151*^9, {3.619154691967984*^9, 3.619154899049852*^9}, 
   3.619154945994768*^9, {3.716906339326762*^9, 3.716906492528219*^9}, {
   3.74970215596106*^9, 3.749702198195945*^9}, {3.751543767206541*^9, 
   3.751543767504735*^9}},
 ExpressionUUID -> "c2c04001-9122-422d-b30d-519020dc088e"],

Cell["Let us check the integration works", "Text",
 CellChangeTimes->{{3.773393076273972*^9, 3.7733930813636055`*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"intUV", "[", 
   RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "[", 
  RowBox[{"0.1", ",", "0.1", ",", "0.5"}], "]"}]], "Input",
 CellChangeTimes->{{3.751634971116064*^9, 3.751634979851036*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"h", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                  GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                  ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.1`", ",", "0.51`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                  GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                  ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.1`", ",", "0.51`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("InterpolatingFunction[{{0.1, 0.51}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7516349802105007`*^9, 3.7516720416745057`*^9, 
  3.751672144153178*^9, 3.756446662567421*^9, 3.7571629973085384`*^9, 
  3.75722390023236*^9, 3.7575077520639067`*^9, 3.7575121882410355`*^9, 
  3.758527693868605*^9, 3.7593292010715218`*^9, 3.759496339162472*^9, 
  3.759499401449704*^9, 3.770223888090347*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["matching procedure", "Subsection",
 CellChangeTimes->{{3.60648056192155*^9, 3.606480562265699*^9}, 
   3.608119047727962*^9, 3.608127240503818*^9, {3.65559916789657*^9, 
   3.655599168840431*^9}, {3.716906543249805*^9, 3.7169065453278913`*^9}, {
   3.717052796310843*^9, 3.717052796516905*^9}, {3.771962656454821*^9, 
   3.7719626587997036`*^9}},
 ExpressionUUID -> "f4ad8eff-7cf2-4943-bb66-54bd0e4378a0"],

Cell[TextData[StyleBox["We match the two solutions in an intermediate point \
in the middle of the bulk",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7733930977791386`*^9, 3.7733931088233695`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MatchingEqs", "[", 
    RowBox[{
     RowBox[{"h0_", "?", "NumberQ"}], ",", 
     RowBox[{"h3_", "?", "NumberQ"}], ",", 
     RowBox[{"\[Omega]1_", "?", "NumberQ"}], ",", 
     RowBox[{"M2_", "?", "NumberQ"}]}], "]"}], ":=", "  ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Epsilon]", ",", "\[Epsilon]H", ",", "ymatch", ",", " ", "intIRaux", 
       ",", "intUVaux", ",", " ", "IRval", ",", "UVval"}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Epsilon]", "=", "0.01"}], ";", 
      RowBox[{"\[Epsilon]H", "=", "0.001"}], ";", 
      RowBox[{"ymatch", " ", "=", " ", "0.5"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"intIRaux", "=", 
       RowBox[{
        RowBox[{"intIR", "[", 
         RowBox[{"1", ",", "\[Omega]1", ",", "M2"}], "]"}], "[", 
        RowBox[{"\[Epsilon]", ",", "\[Epsilon]H", ",", "ymatch"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"intUVaux", "=", 
       RowBox[{
        RowBox[{"intUV", "[", 
         RowBox[{"h0", ",", "h3", ",", "\[Omega]1", ",", "M2"}], "]"}], "[", 
        RowBox[{"\[Epsilon]", ",", "\[Epsilon]H", ",", "ymatch"}], "]"}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"IRval", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"h", "[", "ymatch", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"h", "'"}], "[", "ymatch", "]"}]}], " ", "}"}], " ", "/.",
          "  ", "intIRaux"}], "  ", "//", " ", "Flatten"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"UVval", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"h", "[", "ymatch", "]"}], ",", " ", 
           RowBox[{
            RowBox[{"h", "'"}], "[", "ymatch", "]"}]}], " ", "}"}], " ", "/.",
          "  ", "intUVaux"}], "  ", "//", " ", "Flatten"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"IRval", " ", "-", " ", "UVval"}]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6064807963106422`*^9, 3.606480856156304*^9}, {
   3.606482259023543*^9, 3.606482270601215*^9}, {3.6064826489277563`*^9, 
   3.606482669671791*^9}, {3.6064841474481916`*^9, 3.606484158755926*^9}, {
   3.606485855346878*^9, 3.6064858697288837`*^9}, {3.60777197841564*^9, 
   3.60777201707512*^9}, {3.6077722333412437`*^9, 3.607772351156351*^9}, {
   3.607923148290694*^9, 3.6079232721457167`*^9}, {3.6081181526965513`*^9, 
   3.60811824142407*^9}, {3.6081183114801903`*^9, 3.608118372889263*^9}, {
   3.6081184240808907`*^9, 3.608118438843404*^9}, {3.6081185302691936`*^9, 
   3.608118614812294*^9}, {3.608145962650556*^9, 3.608145974906663*^9}, {
   3.614903798920782*^9, 3.6149038818804817`*^9}, {3.614973254708387*^9, 
   3.614973512783347*^9}, {3.6150058351109457`*^9, 3.6150059110596027`*^9}, {
   3.619128394745327*^9, 3.61912843084124*^9}, {3.653650183268071*^9, 
   3.653650183410754*^9}, 3.653650271902297*^9, 3.653650388530942*^9, 
   3.653650485999456*^9, {3.7169065511130753`*^9, 3.716906851985077*^9}, {
   3.7169069838826303`*^9, 3.716907005115601*^9}, {3.7170537624978437`*^9, 
   3.717053762971019*^9}, {3.7170794278837347`*^9, 3.7170794289589*^9}, {
   3.7497022438979683`*^9, 3.749702318283779*^9}},
 ExpressionUUID -> "ff7285df-ed0a-4b61-b4f5-398848423c84"],

Cell[TextData[StyleBox["This matching routine solves the matching equations \
with a FindRoot and the next gives the green function as \[OpenCurlyQuote]\
\[CloseCurlyQuote]subleading/leading\[CloseCurlyQuote]\[CloseCurlyQuote].",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.717079439832539*^9, 3.7170794778487053`*^9}, {
  3.71707953592036*^9, 3.717079551710451*^9}, {3.770223849649392*^9, 
  3.7702238567579627`*^9}, {3.7733931233655415`*^9, 3.773393142505849*^9}},
 ExpressionUUID -> "48f2f8e8-f4ff-4ad9-9f54-d8e1463d7e0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GetGreensFunction", "[", " ", 
    RowBox[{"\[Omega]1_", ",", "M2_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", " ", "h0", ",", "h3"}], "}"}], ",", " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"h0", ",", "h3"}], "}"}], " ", "=", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], "/.", " ", 
        RowBox[{"FindRoot", "[", " ", 
         RowBox[{
          RowBox[{"MatchingEqs", "[", 
           RowBox[{"x", ",", "y", ",", "\[Omega]1", ",", "M2"}], "]"}], ",", 
          " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"x", " ", ",", " ", 
              RowBox[{"1", "-", "\[ImaginaryI]"}]}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"y", ",", " ", 
              RowBox[{"1", "-", "\[ImaginaryI]"}]}], "}"}]}], "}"}]}], 
         "]"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", " ", 
         FractionBox["3", "2"]}], " ", 
        FractionBox["h3", "h0"]}], "}"}]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.720804010197337*^9, 3.7208040107946453`*^9}, {
  3.74970233876046*^9, 3.7497024204999313`*^9}, {3.749702720389984*^9, 
  3.74970273163509*^9}, {3.749702830807458*^9, 3.749702831163341*^9}, {
  3.7515437847266917`*^9, 3.751543786561748*^9}, {3.7571629744068346`*^9, 
  3.757162983581647*^9}},
 ExpressionUUID -> "aad025fc-8189-454b-97ca-e14cd9e8b1b8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["frequency dependent green function", "Section",
 CellChangeTimes->{{3.71705377574924*^9, 3.71705377766257*^9}, {
  3.770223870183851*^9, 3.770223876317226*^9}},
 ExpressionUUID -> "6bcb99b8-043d-4c53-be46-a21c488e9a68"],

Cell["The routine is GetGreensFunction[\[Omega], m2].", "Text",
 CellChangeTimes->{{3.751519280418715*^9, 3.7515193111790113`*^9}, {
  3.751519389399988*^9, 3.75151944376173*^9}, {3.770223963023246*^9, 
  3.7702239690305843`*^9}, {3.7733931643473835`*^9, 3.7733931648949175`*^9}},
 FontWeight->"Bold"],

Cell["Lets choose a random value of m2 and plot the result", "Text",
 CellChangeTimes->{{3.7702239499022694`*^9, 3.770223959633919*^9}},
 FontWeight->"Bold"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"exRe", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"GetGreensFunction", "[", 
            RowBox[{"xx", ",", "1"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "//", "Re"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "0", ",", "10", ",", "0.1"}], "}"}]}], "]"}], ",", 
     "xx"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exIm", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"GetGreensFunction", "[", 
            RowBox[{"xx", ",", "1"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "//", "Im"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "0", ",", "10", ",", "0.1"}], "}"}]}], "]"}], ",", 
     "xx"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.770223973222043*^9, 3.7702240189328365`*^9}, {
  3.770224107258435*^9, 3.770224110938761*^9}, {3.770224148244955*^9, 
  3.7702241564866953`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ListPlot", "[", 
  RowBox[{"exRe", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Omega]\>\"", ",", "\"\<Re[G(\[Omega])]\>\""}], "}"}]}], 
   ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"exIm", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\[Omega]\>\"", ",", "\"\<Im[G(\[Omega])]\>\""}], "}"}]}], 
   ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7702241144788327`*^9, 3.770224117422447*^9}, {
  3.7702241770979085`*^9, 3.770224235880686*^9}, {3.7702242875095625`*^9, 
  3.7702242907023983`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
     GeometricTransformationBox[InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->8.96], {0., 0.}], CompressedData["
1:eJxF0n9Q03UYB/DxK1B+b+PHBsLGRLnACNAiT/w8EhdEoU0luEmGdAgoVBeH
QBAgdcqZ1QVi/BZilvwOmBYIo4tOTQZOIFQcbIvFT2mEUMJGC/L5XM/d54/P
fZ/n9bzvex9+3HsH400YDEb8+jFaP8aM/yv0xTRGrWGKlJVuVAfZW1nsEOE2
jfdfCFfoVRKROU12BmzUELnlvjtEaDmD3x+QZw/cFqXKZshTTUVOiYZz6ltn
sX+CVDBPJj/XNEcSjm/UJLFQBu2QNz/C+RkSNBDd/pF4nvTLNuoRSbuiUcx+
+Ad6C2T1t0SnVDct9v9JFqq/zvXI1qL/mFgFnrCey9fi/BJxTbv76+JWLe77
i+wCbbkimnpPyBArqWqOO4/eCnH8XQsjKXPo6cjPnouhLkdm0NOTjgiXls7F
SfT+IYmRlRcjwjXoMYDH8ffPy1JjPwO2VWikYSFj6BuBfcKiOldyD+eN4Uy+
3xeFWYO4zwSKJeeXHc/3oWcKRu8kuAal9KJnCgvsVqfjRR3omcGufrd7PjPN
6D0Dn0RPEOXmGvTMYaTkfb8JcSF6FuB79GVp5s7P0LOARi+hZnv3BfQ2wRVR
+Ju+8hr0NoO5PCuzcLwRPUvIlTm8mxx3FT0rqFp+q6Uurhs9K2jKZscYWfWi
Zw2az7vE2WU30bOBsgCDaDJQhp4tfHUyfXdwvBw9O1DY3un5qXwQ++3A9NLc
0YJrw+jbQXF5k1V+8wj5bzzAHqKF1fvac+7jPnvIy7GuWxGMoseE13ljNQMV
D9FjgqnNlOuTaQV6TOgMcsmL2TSOeVjgI40avG4YR48FIv+3P8gYUKLHhrTA
HU3aPSr02NByzJnpdVqFHhtOMBsnvK6p0HMAUWmfWjqmQs8BJGFmVsUrKvQc
YVGsEUVYqtFzhNjxdjbfgb4fRzC50HnY00mNnhOEpqR6vspSo+cEt14KzkpZ
n3/qOcPIgUM/JhhoPmd44/ZDi6sLNJ8zfLdfLLyhovk4UGLhHfDNHZqPA6V1
bbGj3TQfFwS9Et+uBupxQXE9DjzLqMcFw+lWqb6Aei4wKwlxKsqgngtU9QgL
ipOo5wqv2Bw6HHmEeq5Q0z4trt1PPVeQJi0v3Qym3hYYqJ96ITuQeltgz+NL
lea+1HMDxaQwtm4b9dygN/wyL8adem7QZV30ZRyHeu6g6tZ9usSinjvICjSl
UbbU44Hk466MdEsVvi8eeLd21u61oD4PODdOWf5tRud5MBV1MVVuQvfxgC27
zOIYU48P2338C3sY1OMDg9zvSzEo0eODP7eNo1pToseHoe8X7Br0SvT4sCqX
nz2mp+/PA3hzS2cXdUr0PKBMFqtu0FHPA2zqGf2NOup5wBk/6+AfdNTzADHj
XOJdHfUEEF6f/Bpj3X/6fwTw7b7n2wL01BNAmDdn9YGeegI4OLo8z1mjngCq
h6vtI9eotxWMm9KXC9fv/wJ/Dr+n
      "]]}, {}}, {}, {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Omega]\"", TraditionalForm], 
    FormBox["\"Re[G(\[Omega])]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10.}, {0, 0.9847312223444091}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.77022413923888*^9, {3.770224279917842*^9, 3.7702242910988836`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0, 0, 1], AbsolutePointSize[6], AbsoluteThickness[1.6], 
     GeometricTransformationBox[InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->8.96], {0., 0.}], CompressedData["
1:eJxF0nswXHcUB/BFsIJYSzwX+/CYSb0fTRuJ32nqVWUmQWmxHrtZNDXDsPXo
JFGJkm3SEiGJaCU0pkgYiSTFrOwiXg2J6qaJJMRrRYboCkkppXSP6Zn5/XHn
nvM5d+7vy+IlBwvUKBSKYOOobBxVyv9lNROl0Rf8eu/F0s1qJt73z6fv7Tsp
UT73kjzJU/dx2TmJu9tm/U4+bZGuHY//Ed8PkZTcktL6iHKJUhsliTFVy9ns
C9g/QQayWMHvLh+XJMRv1hQpzDMevLF8mijnXxKFyw2+wqqa9Pdt1iyxXGg9
6q+4TZSegnSG9O6q02nH/nnCTG6ZYlzqJUp/gejMqhe9+HsA5xfJRJLni1Le
Q6Lc95ZofK/rFTo0hN4SKT108U2u/Qh6yySX8teRZoMx9FaIY6hDgfDeOHqr
pEuzzb3AdhK9NVLRaFDdSJejR4Evposjzp2QYz8FzPzLekfS5OirgIZHZVG6
fGteFezzvby0xiZwnxqUT42VLgrH0dsGkwsZV35rHEVvGwzo7xsXCobRUweW
5n2XbL0h9DRAZ8/S9fJCGXqawEk9xd1FG0CPCtqXnb68GtuNHhXavdx3q3rc
QU8LxD4iG3V5HXrbIdklUJaQmYaeNvAGoz0e11bh/eoAs9D03ofsWxKlpwNN
dsOTTvWtmAddyCSa5jf92vG+d0DIZ3/aB8vvYh70IOybI+Wiu13o0eCT8yU/
6C11Yz8NxLFB/D/O9qBPA3646TT/Wo/kv3E3fXC85UWlh/XgPn2onRdlZ1/p
Ro8OQXMObba1XejRQbjdQ/FPRid6dFgJGn2bbLH1PQbQlV7xQK+6HT0DcAiz
UTRw2tAzBG8YN2B4StAzBEv/mZx8JzF6hjAX/6h0Znczejthj5X1RHXMbfR2
AuNxDXTWN6JnBG8CHgZqv3MdPSNopEby7Frq0DOCgIShnJivatAzBrpwMa7t
chV6xvCtxde8VbdK9ExAvJ92fN27HL2N54qDZ1afXUDPBPJq802bnIvRM4UR
X7OYTOtC9EzBRzA82B8uQs8MnlCLU51TTqBnBnNhvrUlqkfRMwP7cL8s9QdC
9Mwh7Fl//MeOSeiZg+1g6vpabBx6DOjb7xlDyzuIHgMohtJjP7s4o8eAAWu9
q+a672PeLMAkKLFAzgjEfFpA1LSbtWt1CObZElJaMtj878Ixr5YQIHJNPsOK
wHxbQmjqtcWG2Uj0rOBO0k9V0q4o9KygKVqrasWSix4TpPOUuRxbLlHmiwnR
rz8oC1Xjos+EpoYK1TE7Ls4zQUc2lPJcnYv7mLAkFvpQlqLQY0Hly7RX6fQt
jwUH4iKyb3K3PBb4ZkWsn3205bGA7n+YLRRFo8cCcZG54NfpGPTY0LrP9XTu
sVj02GBUVibIN4lDjw0zH0XukKrw0GODbFXDgSfjoceGCEPmNLWNjx4HLh14
3mHzyyH8Pxzwy1B4+rcK0ONAR5nvqwF6AnocKKlxWqiySUSPA6eSFp48fe9z
9KxBqrs23RF6mPwLXhm1hg==
      "]]}, {}}, {}, {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"\[Omega]\"", TraditionalForm], 
    FormBox["\"Im[G(\[Omega])]\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 10.}, {-0.19276093323667984`, 0.6723129052327413}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.77022413923888*^9, {3.770224279917842*^9, 3.7702242911531167`*^9}}]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"This", " ", "is", " ", "figure", " ", "18."}], "Text"]], "Input",
 CellChangeTimes->{
  3.7509226331033916`*^9, 3.75092370054895*^9, {3.7733931754713397`*^9, 
   3.773393178229344*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Read the elastic modulus and the viscosity", "Section",
 CellChangeTimes->{{3.7571622821556635`*^9, 3.7571622837773333`*^9}, 
   3.759329201519306*^9, {3.7702241693223085`*^9, 3.7702241740803404`*^9}}],

Cell[TextData[StyleBox["Let us define the elastic modulus and viscosity. We \
use a cutoff, play with it.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719626991979647`*^9, 3.7719627144238477`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"G0", "[", 
   RowBox[{"M2_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{"Re", "[", 
   RowBox[{
    RowBox[{"GetGreensFunction", "[", 
     RowBox[{"0.001", ",", "M2"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Visc", "[", 
   RowBox[{"M2_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"-", "1"}], "0.001"], 
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"GetGreensFunction", "[", " ", 
      RowBox[{"0.001", ",", "M2"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.757162312291106*^9, 3.7571623583131075`*^9}, {
  3.757162988651376*^9, 3.7571629903035784`*^9}, {3.7585277035444837`*^9, 
  3.758527711095235*^9}, {3.7702243038746767`*^9, 3.7702243045496225`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataetaovers", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"Sqrt", "[", "m2", "]"}], 
          FractionBox[
           RowBox[{"3", "-", "m2"}], 
           RowBox[{"4", "\[Pi]"}]]], ",", 
         FractionBox[
          RowBox[{"Visc", "[", "m2", "]"}], 
          RowBox[{"2", "\[Pi]"}]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "2.98", ",", "0.01"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataG", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"Sqrt", "[", "m2", "]"}], 
          FractionBox[
           RowBox[{"3", "-", "m2"}], 
           RowBox[{"4", "\[Pi]"}]]], ",", 
         RowBox[{"G0", "[", "m2", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "2.98", ",", "0.01"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.759329205752885*^9, 3.7593292352358475`*^9}, {
  3.7593292823850393`*^9, 3.7593293064053335`*^9}, {3.759496319870643*^9, 
  3.759496330843892*^9}, {3.7702243247357044`*^9, 3.7702243701330996`*^9}}],

Cell[BoxData[{
 RowBox[{"ListPlot", "[", 
  RowBox[{"dataetaovers", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<m/T\>\"", ",", "\"\<\[Eta]/s\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Orange"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"dataG", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<m/T\>\"", ",", "\"\<G\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
   RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7702243812578106`*^9, 3.7702244190329075`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[1, 0.5, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
     GeometricTransformationBox[InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->8.96], {0., 0.}], CompressedData["
1:eJxFl/c/FY7/xUncyN5u9rquvWe8XsaVUdkyklVCRtkSkpBCJJTIHpkhKfV2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      "]]}, {}}, InsetBox[
    GraphicsBox[{{{}, {{{}, {}, 
         {RGBColor[1, 0.5, 0], PointSize[0.0055000000000000005`], Thickness[
          Large], LineBox[CompressedData["
1:eJw1l3k4lN/7x8fMmDEIpSQtSGVJyVbSch+VpcUnlCIkpCTJVkQRFVnSQrKF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           "]]}}, {
         {RGBColor[1, 0.5, 0], AbsolutePointSize[6], Thickness[Large], 
          GeometricTransformationBox[InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->8.96], {0., 0.}], CompressedData["
1:eJxFl3k0lO8bxsfMmDF2KUkLUllSEkpa7kdlafENpUiSpCTJVkQRFVnSQrKF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           "]]}, {}}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
        {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[
         1.6], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJw1mHk8lOsbxpUtkX3JhOxjzb6X+7aMZKmIOJSlOqKEklAnJUuyRVlKyL5k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          "]]}}, {}, {}, {{}, {}}}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{
       FormBox["\"m/T\"", TraditionalForm], 
       FormBox["\"\[Eta]/s\"", TraditionalForm]},
     AxesOrigin->{0, 0.03858504733841585},
     AxesStyle->Directive[
       GrayLevel[0], 12],
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     LabelStyle->Directive[Bold, Medium, 
       GrayLevel[0]],
     Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}},
     PlotRange->{{0, 1.5}, {0, 0.09}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], 
    Scaled[{0.5977483439712727, 0.60620695930048}], 
    Center, {80.6899938754086, 0.07429962160696504}, {{1., 0.}, {0., 
    1.}}], {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"m/T\"", TraditionalForm], 
    FormBox["\"\[Eta]/s\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{20.836735, 31.}, {8.791317, 21.}},
  ImageSize->{449., Automatic},
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.7883735598243364`, 
   87.63030443139249}, {-0.004763626952072278, 0.08410761406973641}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->{Automatic, Automatic}]], "Input", "Input",
 CellChangeTimes->{{3.770226975707054*^9, 
  3.7702269757339616`*^9}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0, 1, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
     GeometricTransformationBox[InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->8.96], {0., 0.}], CompressedData["
1:eJxFV3dUDo73TlTS1C7tvXdpqHsbLy0VigYpKaJFWypKCZVVIhFKIUkb0aBE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      "]]}, {}}, InsetBox[
    GraphicsBox[{{{}, {{{}, {}, 
         {RGBColor[0, 1, 0], PointSize[0.007333333333333334], Thickness[
          Large], LineBox[CompressedData["
1:eJw1mHlcjfn7xhNiEhFlSxtRojJaSOPKvmSsCUmKJHvEIMughCaNpYxi0KJN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           "]]}}, {
         {RGBColor[0, 1, 0], AbsolutePointSize[6], Thickness[Large], 
          GeometricTransformationBox[InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->8.96], {0., 0.}], CompressedData["
1:eJxFmAlYjfn7xlPEJCLKljaiRDJaSOPOvmSsCUmKJHu2QZZBCU0aSxnFoEWb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           "]]}, {}}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
        {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[
         1.6], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxd1zmIXlUYgOE/cYPUsY3YRSytXTptk3oqwVga29iaOhY2Wtgkjc2AIBhB
RI2ikUTcx13HXRN3J+5L7v/o96K3eYZh/nPP+d4zA3P1rXccvG33arW6dtdq
tfj/5669mzdvH7n7xv9673hy39FzB04+MPr+ifH++5bnwdHPbY7nDyxfPTT6
3MPjnq3jh6/f88honUfHazaOPbWz/7HRuo+PJy5+auv4E6P3PDlet35Ojd77
9HhqZ//FlZ8Z7ePZ8eD6Rc+N9nV63D6yLPT8aJ9nxjuXbR0+O9r3C6MKL47O
kbesF35pdK5c3rJx7OXROV8Z18fYSud+dbxq2ca+10ZzyNsPLc/ro7lsjcsq
ezfTnN4YLyzL7KS5vTnesF7ordEcc72to2+P5vrOePbM8qQ5vzteud7Ye6O5
53qZjfdHHT4YnSN1SedKnbZH50zd0rk/HHVMy6SuH43mkrKkOX086p7mlu7B
J6M5pnuR5vrp6J6kOad789lo7ukepQ6fjzqkDqlD6vDFqEPqkDp8Od6z7pA6
pA7nRh1Sh9Th/KhD6pA6fDXqkDqkDl+POqQOqcM3ow6pQ+rw7egcqUs6V+qU
zpm6pXN/N+qY5pC6prmkzmlO34+6p7ml38s0x3Qv0lx/GN2TNOd0b9Lc0z1K
HX4cdUgdUofUIXVIHVKHnVGH1CF1SB1Sh9ThwqhD6pA6pA6pQ+rw06hD6pA6
pA6pQ+rw86hD6pA6pA6pQ+qQOvwy6pA6pA6pQ+qQOvw66pA6pL+TqUPqkDr8
NuqQOqQOqUPqkDr8PuqQOqQOqUPqkDqkDn+MOqQOqUPqkDqkDn+OOqQOqUPq
kDqkDn+NOqQOqUPqkDrkP/923PSvzpG6pHOlTrk+5qHULf1dSB3THFLXNJfU
Oc1p16h7mlu6B2mO6V6kuaZ7kuac7k2ae7pHKcPuUYfUIXVIHdK9Sx1Sh9Qh
dUgdUofUIXW4ZNQhdUgdUofUIXVIHVKH1CF1SB1Sh0tHHVKH1CF1SB1Sh9Qh
dUgdUofUIXVIHS4bdUgdUofUIXVIHVKH1CF1SB1Sh9Th8lGH1CF1SB1Sh9Qh
dUgdUofUIXVIHVKHK0YdUofUIXVIHVKH1CF1SB1Sh/wbcIC1Lg==
          "]]}}, {}, {}, {{}, {}}}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{
       FormBox[
       "\"\\!\\(\\*SuperscriptBox[\\(m\\), \\(2\\)]\\)\"", TraditionalForm], 
       FormBox["\"G\"", TraditionalForm]},
     AxesOrigin->{0, 0},
     AxesStyle->Directive[
       GrayLevel[0], 12],
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     LabelStyle->Directive[Bold, Medium, 
       GrayLevel[0]],
     Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}},
     PlotRange->{{0, 0.5}, {0, 0.42852066136841527`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], 
    Scaled[{0.6077669897327427, 0.4226917556191212}], 
    Center, {65.97883045640167, 1.2327097176594402}, {{1., 0.}, {0., 
    1.}}], {}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"m/T\"", TraditionalForm], 
    FormBox["\"G\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{13.693878, 31.}, {15.102602, 21.}},
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.7883735598243364`, 
   87.63030443139249}, {-0.03215017896368974, 1.5753587692207973`}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.7702270088595033`*^9, 3.7702270088914165`*^9}}],

Cell[TextData[StyleBox["This is fig.19",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.77339322188623*^9, 3.7733932245999403`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the analytic formulae", "Section",
 CellChangeTimes->{{3.7702244234080944`*^9, 3.770224427846897*^9}}],

Cell[TextData[StyleBox["Here we define the analytic formula derived in the \
lectures",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771962746737338*^9, 3.771962760542369*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dataetaovers2", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"Sqrt", "[", "m2", "]"}], 
          FractionBox[
           RowBox[{"3", "-", "m2"}], 
           RowBox[{"4", "\[Pi]"}]]], ",", 
         FractionBox[
          RowBox[{"Visc", "[", "m2", "]"}], 
          RowBox[{"2", "\[Pi]"}]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "0.5", ",", "0.001"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dataG2", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"Sqrt", "[", "m2", "]"}], 
          FractionBox[
           RowBox[{"3", "-", "m2"}], 
           RowBox[{"4", "\[Pi]"}]]], ",", 
         RowBox[{"G0", "[", "m2", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "0.5", ",", "0.001"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.770224919900859*^9, 3.7702249418995075`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataG3", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{"G0", "[", "m2", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "0.5", ",", "0.001"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7702261232686944`*^9, 3.7702261268307066`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Gformula", "[", "m2_", "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["m2", "2"], 
     FractionBox["2", 
      RowBox[{"\[Nu]", "+", "1"}]]}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"3", "\[Equal]", 
        FractionBox[
         RowBox[{"\[Nu]", "+", "4"}], "2"]}], ",", "\[Nu]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7702244750120993`*^9, 3.770224526951968*^9}, {
   3.770224621743837*^9, 3.770224626604594*^9}, {3.7702246591889215`*^9, 
   3.770224683578751*^9}, 3.7702252158528347`*^9, {3.770226009308891*^9, 
   3.7702260102873898`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"etaoversformula", "[", "m2_", "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", "\[Pi]"}]], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["2", "3"], 
        FractionBox["2", 
         RowBox[{"\[Nu]", "+", "1"}]], "m2", " ", 
        RowBox[{"HarmonicNumber", "[", 
         RowBox[{
          FractionBox["1", "3"], 
          RowBox[{"(", 
           RowBox[{"\[Nu]", "+", "1"}], ")"}]}], "]"}]}]}], ")"}]}], "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"3", "\[Equal]", 
        FractionBox[
         RowBox[{"\[Nu]", "+", "4"}], "2"]}], ",", "\[Nu]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.770224551756276*^9, 3.770224681719515*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ANetaovers", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"Sqrt", "[", "m2", "]"}], 
          FractionBox[
           RowBox[{"3", "-", "m2"}], 
           RowBox[{"4", "\[Pi]"}]]], ",", 
         RowBox[{"etaoversformula", "[", "m2", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "2.98", ",", "0.01"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ANG", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{"Gformula", "[", "m2", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "2.98", ",", "0.01"}], "}"}]}], "]"}], 
     ",", "m2"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7702246428446627`*^9, 3.7702246523876705`*^9}, {
  3.7702246875628304`*^9, 3.770224701121316*^9}, {3.770226153186184*^9, 
  3.770226153639391*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "X_", "]"}], "=", 
   SuperscriptBox["X", "3"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"m2", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"V", "'"}], "[", 
      SuperscriptBox["x", "2"], "]"}], 
     SuperscriptBox["x", "2"]], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "V", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7702251232406263`*^9, 3.770225148699712*^9}, {
  3.7702252431711135`*^9, 3.770225256265373*^9}, {3.7702259721810207`*^9, 
  3.770225973401862*^9}}],

Cell[TextData[StyleBox["And here we check them with the numerics",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719627668202558`*^9, 3.771962772870547*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"dataetaovers2", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<m/T\>\"", ",", "\"\<\[Eta]/s\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Orange"}], "}"}]}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"ANetaovers", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<m/T\>\"", ",", "\"\<\[Eta]/s\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", "Black"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.09"}], "}"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"dataG3", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SuperscriptBox[\(m\), \(2\)]\)\>\"", ",", "\"\<G\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Green"}], "}"}]}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"ANG", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SuperscriptBox[\(m\), \(2\)]\)\>\"", ",", "\"\<G\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", "Black"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7702247210170155`*^9, 3.7702248873132887`*^9}, {
  3.770224947200573*^9, 3.7702249489284377`*^9}, {3.770226133376687*^9, 
  3.770226139933279*^9}, {3.7702268501685514`*^9, 3.770226850264304*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{{}, {}, 
      {RGBColor[1, 0.5, 0], PointSize[0.0055000000000000005`], Thickness[
       Large], LineBox[CompressedData["
1:eJw1l3k4lN/7x8fMmDEIpSQtSGVJyVbSch+VpcUnlCIkpCTJVkQRFVnSQrKF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        "]]}}, {
      {RGBColor[1, 0.5, 0], AbsolutePointSize[6], Thickness[Large], 
       GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->8.96], {0., 0.}], CompressedData["
1:eJxFl3k0lO8bxsfMmDF2KUkLUllSEkpa7kdlafENpUiSpCTJVkQRFVnSQrKF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        "]]}, {}}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
      Dashing[{Small, Small}], LineBox[CompressedData["
1:eJw1mHk8lOsbxpUtkX3JhOxjzb6X+7aMZKmIOJSlOqKEklAnJUuyRVlKyL5k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       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"m/T\"", TraditionalForm], 
    FormBox["\"\[Eta]/s\"", TraditionalForm]},
  AxesOrigin->{0, 0.03858504733841585},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1.5}, {0, 0.09}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.770224733238168*^9, 3.7702248878364267`*^9}, {
  3.7702268423722296`*^9, 
  3.7702268506906433`*^9}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 GraphicsBox[{{{}, {{{}, {}, 
      {RGBColor[0, 1, 0], PointSize[0.007333333333333334], Thickness[Large], 
       LineBox[CompressedData["
1:eJw1mHlcjfn7xhNiEhFlSxtRojJaSOPKvmSsCUmKJHvEIMughCaNpYxi0KJN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        "]]}}, {
      {RGBColor[0, 1, 0], AbsolutePointSize[6], Thickness[Large], 
       GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->8.96], {0., 0.}], CompressedData["
1:eJxFmAlYjfn7xlPEJCLKljaiRDJaSOPOvmSsCUmKJHu2QZZBCU0aSxnFoEWb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        "]]}, {}}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
      Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxd1zmIXlUYgOE/cYPUsY3YRSytXTptk3oqwVga29iaOhY2Wtgkjc2AIBhB
RI2ikUTcx13HXRN3J+5L7v/o96K3eYZh/nPP+d4zA3P1rXccvG33arW6dtdq
tfj/5669mzdvH7n7xv9673hy39FzB04+MPr+ifH++5bnwdHPbY7nDyxfPTT6
3MPjnq3jh6/f88honUfHazaOPbWz/7HRuo+PJy5+auv4E6P3PDlet35Ojd77
9HhqZ//FlZ8Z7ePZ8eD6Rc+N9nV63D6yLPT8aJ9nxjuXbR0+O9r3C6MKL47O
kbesF35pdK5c3rJx7OXROV8Z18fYSud+dbxq2ca+10ZzyNsPLc/ro7lsjcsq
ezfTnN4YLyzL7KS5vTnesF7ordEcc72to2+P5vrOePbM8qQ5vzteud7Ye6O5
53qZjfdHHT4YnSN1SedKnbZH50zd0rk/HHVMy6SuH43mkrKkOX086p7mlu7B
J6M5pnuR5vrp6J6kOad789lo7ukepQ6fjzqkDqlD6vDFqEPqkDp8Od6z7pA6
pA7nRh1Sh9Th/KhD6pA6fDXqkDqkDl+POqQOqcM3ow6pQ+rw7egcqUs6V+qU
zpm6pXN/N+qY5pC6prmkzmlO34+6p7ml38s0x3Qv0lx/GN2TNOd0b9Lc0z1K
HX4cdUgdUofUIXVIHVKHnVGH1CF1SB1Sh9ThwqhD6pA6pA6pQ+rw06hD6pA6
pA6pQ+rw86hD6pA6pA6pQ+qQOvwy6pA6pA6pQ+qQOvw66pA6pL+TqUPqkDr8
NuqQOqQOqUPqkDr8PuqQOqQOqUPqkDqkDn+MOqQOqUPqkDqkDn+OOqQOqUPq
kDqkDn+NOqQOqUPqkDrkP/923PSvzpG6pHOlTrk+5qHULf1dSB3THFLXNJfU
Oc1p16h7mlu6B2mO6V6kuaZ7kuac7k2ae7pHKcPuUYfUIXVIHdK9Sx1Sh9Qh
dUgdUofUIXW4ZNQhdUgdUofUIXVIHVKH1CF1SB1Sh0tHHVKH1CF1SB1Sh9Qh
dUgdUofUIXVIHS4bdUgdUofUIXVIHVKH1CF1SB1Sh9Th8lGH1CF1SB1Sh9Qh
dUgdUofUIXVIHVKHK0YdUofUIXVIHVKH1CF1SB1Sh/wbcIC1Lg==
       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*SuperscriptBox[\\(m\\), \\(2\\)]\\)\"", TraditionalForm], 
    FormBox["\"G\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.5}, {0, 0.42852066136841527`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.770224733238168*^9, 3.7702248878364267`*^9}, {
  3.7702268423722296`*^9, 3.7702268508013496`*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["This is fig.19\nAs expected at small m the agreement \
is good.\nYou can try to obtain the next order in the formulas and see if it \
improves.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771962779574356*^9, 3.771962804271922*^9}, {
  3.773393252151726*^9, 3.773393258751625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the power law at large m/T", "Section",
 CellChangeTimes->{{3.7702249657964134`*^9, 3.770224973341875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"asy", "=", 
    RowBox[{"Interpolation", "[", "dataetaovers", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.7702270603585095`*^9, 3.7702270898551755`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"asy", "[", "x", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "22"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<m/T\>\"", ",", "\"\<\[Eta]/s\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.02", "]"}], ",", "Blue", ",", 
       RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogLogPlot", "[", 
   RowBox[{
    SuperscriptBox["x", 
     RowBox[{"-", "2"}]], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "22"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.770227091328828*^9, 3.77022723591378*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0, 0, 1], Thickness[0.02], Opacity[0.5], 
       LineBox[CompressedData["
1:eJwV13c8VW8YAPCLu+xI4UfIKA1RKSqca28VipSRVSgykoQUhchKIg0iMyuh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        "]]},
      Annotation[#, "Charting`Private`Tag$1131940#1"]& ]}, {}, {}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwlxX1M1GUcAPA7OLhHuTuRE++5iJ82THTDImrrasrzxekfIm9aaLJ56AUr
D5ZDLiLMKDgijGWjeMnbLQFfwBrcJug6zOfboiKZqYFOypKDCKWrKYIXnvR2
3z8++zxi27u1MEylUmX+5/+D2U/fTfncgLQC6Cq2XesxIK2Ac7L18gGPAWkF
DJU6z8AJA9IKLO/yFVubDEgrsEFX/1tdqQFpBeoHRkdG1xiQVkBJO4jvt+mR
joe8Qe/rFQ4d0g+Dr+LsqD0vCuk4aB+82TO+cSHSD8GbvdMOv3kB0mY41n9h
bE7NkOYwUfzO2uYfIpFeCrtO7wn/oiMC6VhY+ahSPtmgQXoJRKzxXGstDEfa
CMl5xsldGWFIx0DTqlZbh0WN9GKI/UB3vlKvQjoa5DMN58745yWth9qab/DQ
oaCko+BrY467fN2cpBeAy7//it0YkLQW2gO2iTe8M5LWwPpMf05L3bSkwyDm
SvJHQ6tvS1oFntTGF8XJ3yUdFEUv67dN5UxKe+iAOHgvGBj+eEzS08LzpLXt
aOF1SftFgtN8buyrIUmPi75nq0vgQr/0hh4WBYseW5bSclgWhT4pjqef3W5f
K8UnoS/K0gf7f3XEXRa0T/7SV9nf+e2IuBH6lkzbMdjW3ewT9B1ZIGI+ey04
IehZ6TrSpVI2TQn6vnzFPXzMOfOnoP+WdWE/bfKfuCNoNa52Ru8p08wIWoNP
9LUnBSz3BB2J/d2+2Jdsfwma4cp9BYlnvPdFYuiFePvWhp/npx4IWofvPm7v
W5H+j6gNvQhzze78+IsqoKPRNXvqVMKEGujFOGD5I+5wTDjQRuzclns1KkkD
9BLMHmpImBURQMfi9dPTzqyiSKCXYvyrb1vaq7RAm9DhSD5QVasF2oTnS298
ubteC7QJy/at27y8SQu0CS/tndvp7tQCbcIqe0l18yUt0Ca8mb/7+/cUBjTH
1PxoY1ECA5pjo1VuT1/FgOa4fme8j6UwoDm68kbu1mxkQHPMyt1ifquYAc3x
6PMqa34JA5pj8LnuttQyBjTHjq36pPlKBjRHdc53qRUfMqA5vpBdXr2jhQHN
sSsrccDiZkBzzMus2RI4zoDm6Ml4qunqpwxojtqM8R97PQxojtbNDcsaexnQ
HHvS0wocXgY0x38BuHlM6A==
        "]]},
      Annotation[#, "Charting`Private`Tag$1131987#1"]& ]}, {}, {}}, InsetBox[
    StyleBox[Cell[TextData[Cell[BoxData[
      FormBox[
       StyleBox[
        SuperscriptBox["T", 
         RowBox[{"-", "2"}]],
        FontSize->18], TraditionalForm]],
      FormatType->"TraditionalForm"]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     Background->GrayLevel[1.]], {1.1726499387480667, -4.966078145649651}, {
    Left, Baseline},
    Alignment->{Left, Top}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"m/T\"", TraditionalForm], 
    FormBox["\"\[Eta]/s\"", TraditionalForm]},
  AxesOrigin->NCache[{-Log[
       Rational[
       512, 11]], -6.282496152448208}, {-3.8404293522411375`, \
-6.282496152448208}],
  AxesStyle->Directive[
    GrayLevel[0], 12],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{27.979592, 31.}, {9.697958, 21.}},
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Log, Exp}, {Log, Exp}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Log, Exp}, {Log, Exp}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Log, Exp}, {Log, Exp}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Log, Exp}, {Log, Exp}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-3.9848350148577927`, 
   3.2354481159749713`}, {-6.490967819186075, -2.321534484428734}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->FrontEndValueCache[{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledTicks[{Log, Exp}]}, {{{-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.912023005428146, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.506557897319982, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.659260036932778, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.916290731874155, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.912023005428146, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.0943445622221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.248495242049359, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.382026634673881, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.499809670330265, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.298317366548036, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.703782474656201, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.991464547107982, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.214608098422191, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}, {{-6.214608098422191, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.002\"", 0.002, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.298317366548036, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.912023005428146, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.020\"", 0.02, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.050\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.502290170873972, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.809142990314028, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.521460917862246, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.115995809754082, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.961845129926823, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.710530701645918, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.199705077879927, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.506557897319982, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.659260036932778, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.2072749131897207`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.120263536200091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.0402208285265546`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.9661128563728327`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.8971199848858813`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.8325814637483102`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.7719568419318752`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.7147984280919266`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Input",
 CellChangeTimes->{{3.7702272463664136`*^9, 3.770227248461995*^9}}],

Cell[TextData[StyleBox["This is fig.19",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.773393275309102*^9, 3.7733932777193065`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1520, 781},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 436, 6, 101, "Title"],
Cell[1019, 30, 668, 11, 186, "Text"],
Cell[1690, 43, 119, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[1834, 49, 261, 4, 70, "Section"],
Cell[CellGroupData[{
Cell[2120, 57, 228, 3, 49, "Subsection"],
Cell[2351, 62, 241, 4, 27, "Text"],
Cell[2595, 68, 1087, 32, 164, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3719, 105, 150, 2, 41, "Subsection"],
Cell[3872, 109, 2107, 51, 34, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6016, 165, 159, 2, 49, "Subsection"],
Cell[6178, 169, 260, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[6463, 177, 1928, 56, 113, "Input"],
Cell[8394, 235, 7034, 191, 135, "Output"]
}, Open  ]],
Cell[15443, 429, 7423, 194, 147, "Input"],
Cell[CellGroupData[{
Cell[22891, 627, 1842, 54, 94, "Input"],
Cell[24736, 683, 2877, 71, 30, "Output"],
Cell[27616, 756, 1379, 38, 45, "Output"]
}, Open  ]],
Cell[29010, 797, 1324, 39, 49, "Input"],
Cell[30337, 838, 273, 9, 5, "Text"],
Cell[30613, 849, 7572, 191, 172, "Input"],
Cell[38188, 1042, 1183, 27, 36, "Input"],
Cell[CellGroupData[{
Cell[39396, 1073, 1611, 30, 36, "Input"],
Cell[41010, 1105, 1117, 28, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42176, 1139, 271, 4, 49, "Subsection"],
Cell[42450, 1145, 178, 4, 30, "Text"],
Cell[42631, 1151, 2668, 62, 221, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45336, 1218, 223, 3, 49, "Subsection"],
Cell[45562, 1223, 165, 2, 30, "Text"],
Cell[45730, 1227, 2385, 58, 221, "Input"],
Cell[48118, 1287, 139, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[48282, 1293, 235, 5, 30, "Input"],
Cell[48520, 1300, 9647, 191, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[58216, 1497, 411, 6, 49, "Subsection"],
Cell[58630, 1505, 206, 3, 30, "Text"],
Cell[58839, 1510, 3510, 72, 259, "Input"],
Cell[62352, 1584, 534, 7, 30, "Text"],
Cell[62889, 1593, 1701, 42, 185, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64639, 1641, 225, 3, 70, "Section"],
Cell[64867, 1646, 301, 4, 30, "Text"],
Cell[65171, 1652, 157, 2, 30, "Text"],
Cell[65331, 1656, 1221, 35, 50, "Input"],
Cell[CellGroupData[{
Cell[66577, 1695, 1350, 31, 50, "Input"],
Cell[67930, 1728, 3215, 69, 250, "Output"],
Cell[71148, 1799, 3292, 70, 234, "Output"]
}, Open  ]],
Cell[74455, 1872, 221, 5, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74713, 1882, 207, 2, 70, "Section"],
Cell[74923, 1886, 208, 3, 30, "Text"],
Cell[75134, 1891, 843, 22, 68, "Input"],
Cell[75980, 1915, 1369, 39, 116, "Input"],
Cell[77352, 1956, 1222, 27, 50, "Input"],
Cell[78577, 1985, 44585, 761, 290, 36319, 624, "CachedBoxData", "BoxData", \
"Input"],
Cell[123165, 2748, 26893, 470, 246, "Input"],
Cell[150061, 3220, 138, 2, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150236, 3227, 114, 1, 70, "Section"],
Cell[150353, 3230, 184, 3, 30, "Text"],
Cell[150540, 3235, 1219, 37, 116, "Input"],
Cell[151762, 3274, 450, 13, 30, "Input"],
Cell[152215, 3289, 694, 19, 49, "Input"],
Cell[152912, 3310, 839, 26, 50, "Input"],
Cell[153754, 3338, 1113, 32, 84, "Input"],
Cell[154870, 3372, 678, 20, 94, "Input"],
Cell[155551, 3394, 165, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[155741, 3400, 3533, 91, 135, "Input"],
Cell[159277, 3493, 32275, 548, 228, 28113, 478, "CachedBoxData", "BoxData", \
"Output"],
Cell[191555, 4043, 18798, 326, 249, "Output"]
}, Open  ]],
Cell[210368, 4372, 315, 5, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210720, 4382, 119, 1, 70, "Section"],
Cell[210842, 4385, 232, 6, 50, "Input"],
Cell[211077, 4393, 1301, 36, 74, "Input"],
Cell[212381, 4431, 33306, 767, 232, "Input"],
Cell[245690, 5200, 139, 2, 30, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

