(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     97709,       2305]
NotebookOptionsPosition[     95072,       2217]
NotebookOutlinePosition[     95419,       2232]
CellTagsIndexPosition[     95376,       2229]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Section", " ", "4.2"}], " ", ":", 
    SubscriptBox["AdS", "2"]}], TraditionalForm]],
  FontSize->72],
 StyleBox[" and the superconducting instability",
  FontSize->72]
}], "Title",
 CellChangeTimes->{{3.6316961190502315`*^9, 3.631696124284901*^9}, {
  3.770142739182457*^9, 3.7701427465824594`*^9}, {3.7719590550466375`*^9, 
  3.7719590559756913`*^9}, {3.7733924297266254`*^9, 3.7733924403738117`*^9}},
 TextAlignment->Center],

Cell[TextData[StyleBox["In this notebook we study the instability of a probe \
scalar on top of the RN black hole. This is basically the first step towards \
an holographic superconductor.\nWe will obtain the critical temperature \
numerically via a simple shooting technique in function of the charge and the \
mass of such scalar.\nThe computations are explained in section 4.2 of the \
notes.",
 FontSize->18,
 FontSlant->"Italic",
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.771958867911254*^9, 3.77195902840561*^9}, {
  3.7733924488049192`*^9, 3.773392458481433*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6316961259256163`*^9, 3.6316961273163204`*^9}, {
  3.7719590822248487`*^9, 3.7719590846805162`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FS", "=", "FullSimplify"}], ";"}]], "Input",
 CellChangeTimes->{{3.6316961285886574`*^9, 3.6316961322526617`*^9}, {
  3.7701430508803263`*^9, 3.7701430517245026`*^9}}],

Cell[CellGroupData[{

Cell["Equations and preliminaries", "Section",
 CellChangeTimes->{{3.631696141050153*^9, 3.631696144597221*^9}}],

Cell[TextData[StyleBox["Here we just define our equation of motion, the \
temperature of our background and few other useful things.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701427899440255`*^9, 3.7701428101974554`*^9}, {
  3.7719591943476553`*^9, 3.771959223915079*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Mu]", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6317901866964197`*^9, 3.631790186863533*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "r_", "]"}], "=", 
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    FractionBox["m0", "r"], "+", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Mu]", "2"], "4"], 
     FractionBox[
      SuperscriptBox["rh", "2"], 
      SuperscriptBox["r", "2"]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0", "=", 
   RowBox[{
    SuperscriptBox["rh", "3"], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["\[Mu]", "2"], 
       RowBox[{"4", " ", 
        SuperscriptBox["rh", "2"]}]]}], ")"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.631696163282173*^9, 3.6316962382419715`*^9}, {
  3.6316962702711873`*^9, 3.63169627635933*^9}, {3.77014304357196*^9, 
  3.7701430460019045`*^9}, {3.770728512549136*^9, 3.7707285126369*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "r", "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["2", "r"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"f", "'"}], "[", "r", "]"}], 
        RowBox[{"f", "[", "r", "]"}]]}], ")"}], 
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "r", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"q", " ", "\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{"r", "-", "rh"}], ")"}]}], "+", 
           RowBox[{"r", " ", "\[Omega]"}]}], ")"}], "2"], 
        RowBox[{
         SuperscriptBox["r", "2"], 
         SuperscriptBox[
          RowBox[{"f", "[", "r", "]"}], "2"]}]], "-", 
       FractionBox[
        SuperscriptBox["m", "2"], 
        RowBox[{"f", "[", "r", "]"}]]}], ")"}], 
     RowBox[{"\[Phi]", "[", "r", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6316962794821157`*^9, 3.6316963785582323`*^9}, 
   3.631697733086519*^9, {3.7707285144171886`*^9, 3.770728519700018*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Temp", "[", "rh_", "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"f", "'"}], "[", "rh", "]"}], 
     RowBox[{"4", "\[Pi]"}]], "//", "Expand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6316965570536366`*^9, 3.6316965618510585`*^9}, {
   3.6316972822808046`*^9, 3.6316972894062233`*^9}, {3.6316973385520535`*^9, 
   3.631697341520969*^9}, {3.631790199260855*^9, 3.631790199419961*^9}, {
   3.6317916796860723`*^9, 3.631791685473962*^9}, 3.7701429060317955`*^9, {
   3.770143054050888*^9, 3.7701430543522043`*^9}, {3.7707285216647663`*^9, 
   3.770728521754528*^9}, {3.7707287723785405`*^9, 3.7707287757993965`*^9}, 
   3.7707288158882294`*^9, {3.7707292438384495`*^9, 3.7707292481045218`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["T=0 instability and BF bound", "Section",
 CellChangeTimes->{{3.631790168388127*^9, 3.631790173390486*^9}, {
  3.7719592351416826`*^9, 3.771959239083916*^9}}],

Cell[TextData[StyleBox["We build a function which is zero wherever the BF \
bound is saturated",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.77014295986639*^9, 3.7701429653161354`*^9}, {
  3.7719592511344833`*^9, 3.771959287831251*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TC0", "[", 
    RowBox[{"q_", ",", "\[CapitalDelta]_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], "+", 
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"]}]}], ")"}]}]}], "/.", 
     RowBox[{"m", "->", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", "\[CapitalDelta]"}], "+", 
        SuperscriptBox["\[CapitalDelta]", "2"]}], "]"}]}]}], "//", 
    "Expand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.631790235812395*^9, 3.6317903278722095`*^9}, {
   3.631790362707592*^9, 3.631790384217037*^9}, {3.770142947943218*^9, 
   3.7701429519202175`*^9}, {3.770728682645424*^9, 3.7707287112908463`*^9}, 
   3.7707288181392107`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"T0", "=", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TC0", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "1", ",", "6"}], "}"}], ",", 
    RowBox[{"ContourStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<q\>\"", ",", "\"\<\[CapitalDelta]\>\""}], "}"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6317903982974873`*^9, 3.6317904677010884`*^9}, {
  3.631803191751973*^9, 3.6318031930645466`*^9}, {3.770142970956254*^9, 
  3.77014302039101*^9}, {3.77014368118412*^9, 3.770143685874536*^9}, {
  3.7707285753542795`*^9, 3.7707285755686674`*^9}, {3.7707286109301834`*^9, 
  3.770728617305094*^9}, {3.7707288283329906`*^9, 3.770728840752759*^9}, {
  3.7707300940224967`*^9, 3.7707300961857104`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJw1VAs0lHkUH/P6xngN8/CqVqE8iupQUrp31kreykm2qC05iR15lJ1sIbSh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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {GrayLevel[0], Thickness[Large], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 
        87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 
        103, 104, 105, 106, 107, 108, 109}]},
      RowBox[{
        RowBox[{
          FractionBox["1", "4"], "-", 
          FractionBox[
           SuperscriptBox["x", "2"], "3"], "-", 
          FractionBox["y", "2"], "+", 
          FractionBox[
           SuperscriptBox["y", "2"], "6"]}], "\[Equal]", "0"}]],
     Annotation[#, 
      Rational[1, 4] + Rational[-1, 3] $CellContext`x^2 + 
       Rational[-1, 2] $CellContext`y + Rational[1, 6] $CellContext`y^2 == 0, 
      "Tooltip"]& ]}],
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{
    FormBox["\"q\"", TraditionalForm], 
    FormBox["\"\[CapitalDelta]\"", TraditionalForm]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic},
  PlotRange->{{0, 3}, {1, 6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.631790427785285*^9, 3.6317904684115634`*^9}, 
   3.6317979258891425`*^9, 3.631802154146897*^9, 3.6318031936895647`*^9, 
   3.631810153448573*^9, 3.631817712709855*^9, 3.6319042788931236`*^9, 
   3.631985726842561*^9, 3.632219855205158*^9, 3.632229863624298*^9, 
   3.6325901360015073`*^9, {3.770142972845973*^9, 3.7701430207236614`*^9}, 
   3.7701430606637526`*^9, 3.770143645405263*^9, {3.7701436824250393`*^9, 
   3.7701436865164533`*^9}, 3.7707285761570945`*^9, {3.770728612182787*^9, 
   3.7707286178376694`*^9}, {3.7707288292066245`*^9, 3.7707288412225027`*^9}, 
   3.7707313277489114`*^9, 3.7719593020417657`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"RegionPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TC0", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "<", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "1", ",", "6"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<q\>\"", ",", "\"\<\[CapitalDelta]\>\""}], "}"}]}], ",", 
   RowBox[{"RotateLabel", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7719593055853453`*^9, 3.7719593134068813`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxlmHlYU1cah0MSNiEIYXGI2umo1aDWVtt0XNDz1VuxtYpxKTrUhoJL0ai4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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHnc11MWx39XtmzZRSVPItEiLVpEq1JpsS8RGZpqKsvIEkklS9YUFaVG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          "]], PolygonBox[CompressedData["
1:eJwtlGmIiFEUhu8Zxr41IjSyDSYlpSSlNPnn50wYk3XGiLITxr4vI4xdiFCW
smRnNHaDsQxj+eW3oSgK2Xnezvnx9H7nu/e7595z3/N1K56RPz0jpTQMGsJG
S+kYNIe/xEXocxgEVcTl6DRoBn+IC9BH0AfKiAvRWhgA54iHo4+hL5QTH0dP
xNq1cIDnBfBN+dGRcASawNHkudbD7+Q5tbcNkVt7XAFPoT984N129CS0gAR7
YQ60hgawBV5CHnxmyir0GQyEj8T56FVoD5OIN6F1MBg+Ee9CZ0NLsHjeEbn0
bhbcge6QA3PhdOT+wrTD6BL4wXNjnRHWwC/ipugVuAylxO3QMfAChsBr3i1C
n0A/eE98Fj0Db3lug1ZCCXSEDnH2PZARNdDcC9A2vlmLToWusYel6GRoFHvU
2E3oEnMewn34zljvqPVW+Je85vr2gfmY1tgWNcmJOYfQaugFmTAOXsFQeMP4
PfRinK2nPAT7IBeyoCZqqlrmxloTzOdqzdtwy9yr2rO8OR/qk3tUdzMTesQd
qZYjzL2pmpbp3qGzuSflLXlSXpTH7sL42KvWkLcXwrvkHi+F/fA1eU6NHTT3
tuZo7SrIjhzLzD0hL/xkfLF5jTKjxvPQidAp1lwXnpFX1BOn0J3mXmwF56Nm
WXHH18w9LS/LEzfgunmvZkftK8x7QXeg3hgbXsuL3JXhJe2hGC6Ze1M9ol5f
ad576nn9K1ab95L+Geqd0ea9rh5Sr40y/zeo56bA8ji7el5e32zea/L8bvMz
6mzy8H+Yz5U5
          "]]}]}, {}, {}, {}, {}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJwt0ulSDQAYBuCDyFIkXIB/3AP30EKhbClCHCqVFrs49lKEQlIhWyhLCFG2
iijRIkyuw3Nm/Hjm/Wa+me/P985PCyZsnRAIBNqZSHiex0IWE08GTy0e8ohW
0nhMAm2s4wnp5DHEDqrJIJ8PJFLDEp7TzjPWs5NhCrjIJQr5yFIuk0Q3RWyg
hTespZNaiuniHW/JZBcjlHCF3Qywh43UkUwPe9nEPnpZxlWW84n9bOYAn1lB
PSm85BUvyKKUUQ7SwCG+cZgtHOEnIRo5yiDHuM41UunjOOFnneALK7nBKr5y
kiCn6Gc1TazhNdvoYDvljFHGTU7znQqyOcMvKrnFWX5QRQ7n+c05bpPLey5w
j/s84A7N3CWGv7o0W47LP4wxRD89dIa7RjP1VBGigHTiWMQC5jKH2PBNYpjF
TKKJYgbTmcZUIpnCZCKY9L/3/wBP1mf7
       "]]}}], 
   StyleBox[InsetBox[
     StyleBox[Cell[TextData[StyleBox["UNSTABLE !",
       FontSize->36]],
       GeneratedCell->False,
       CellAutoOverwrite->False,
       CellBaseline->Baseline,
       TextAlignment->Left],
      FontSize->12,
      FontWeight->Bold], {0.6973335855079523, 1.8802950075848557}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    Background->RGBColor[1., 1., 1., 0.]]},
  AspectRatio->1,
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, Automatic},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"\[CapitalDelta]\"", TraditionalForm], None}, {
     FormBox["\"q\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{21., 1.755102}, {36., 0.5}},
  Method->{
   "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
    "AxesInFront" -> True},
  PlotRange->{{-0.0625, 3.0625}, {0.8958333333333333, 6.104166666666667}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.7719593303546047`*^9, 3.771959333620283*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical routine", "Section",
 CellChangeTimes->{{3.631696385231174*^9, 3.6316963861714106`*^9}, {
   3.6317968771567707`*^9, 3.631796879115085*^9}, 3.6317979274652014`*^9, {
   3.770143293611231*^9, 3.770143294926676*^9}}],

Cell[TextData[StyleBox["We define the equation we need to solve",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719593694514737`*^9, 3.7719593760913067`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "\[CapitalDelta]"}], "+", 
     SuperscriptBox["\[CapitalDelta]", "2"]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ", "[", 
   RowBox[{"rh_", ",", "q_", ",", "\[CapitalDelta]_"}], "]"}], "=", 
  RowBox[{"eq", "//", "FS"}]}]}], "Input",
 CellChangeTimes->{{3.6316963956430845`*^9, 3.6316964227983885`*^9}, {
  3.6316964798932357`*^9, 3.631696483594606*^9}, {3.631697772586791*^9, 
  3.6316977839829984`*^9}, {3.6317904968826804`*^9, 3.6317905117956905`*^9}, {
  3.770143033255251*^9, 3.770143033655697*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["r", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["q", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"r", "-", "rh"}], ")"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["r", "4"]}], "+", 
         SuperscriptBox["rh", "2"], "-", 
         RowBox[{"r", " ", 
          RowBox[{"(", 
           RowBox[{"rh", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["rh", "3"]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "\[CapitalDelta]"}], ")"}], " ", 
       "\[CapitalDelta]"}]}], ")"}], " ", 
    RowBox[{"\[Phi]", "[", "r", "]"}]}], "+", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", 
       SuperscriptBox["r", "3"]}], "-", "rh", "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["rh", "3"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["r", "4"]}], "+", 
      SuperscriptBox["rh", "2"], "-", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"rh", "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["rh", "3"]}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], "+", 
   RowBox[{"r", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["r", "4"]}], "+", 
       SuperscriptBox["rh", "2"], "-", 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"rh", "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["rh", "3"]}]}], ")"}]}]}], ")"}], "2"], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], 
  RowBox[{"r", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["r", "4"]}], "+", 
      SuperscriptBox["rh", "2"], "-", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"rh", "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["rh", "3"]}]}], ")"}]}]}], ")"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.6316963963482966`*^9, 3.631696425342396*^9}, 
   3.631696484805374*^9, 3.6316977452014112`*^9, 3.631697785389326*^9, 
   3.631790483078409*^9, 3.6317905143884377`*^9, 3.631797937912216*^9, 
   3.6318021582096195`*^9, 3.6318101549017797`*^9, 3.631817714100574*^9, 
   3.631904280426925*^9, 3.6319857286811333`*^9, 3.6322200340276814`*^9, 
   3.6322298650306234`*^9, {3.7701430360937333`*^9, 3.770143063386497*^9}, 
   3.7701432310527678`*^9, 3.7707288568966017`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["It is a second order equation in \[Phi], therefore we \
have to specify two boundaries conditions: the value of \[Phi] at the horizon \
and its derivative.\nthe value is meaningless because it can be scaled away, \
the derivative comes from solving the equation close to the horizon",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770143149886435*^9, 3.770143164587473*^9}, {
  3.7719593813872633`*^9, 3.771959426363484*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "G", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "r", "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["2", "r"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"G", "'"}], "[", "r", "]"}], 
        RowBox[{"G", "[", "r", "]"}]]}], ")"}], 
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "r", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"q", " ", "\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{"r", "-", "rh"}], ")"}]}], "+", 
           RowBox[{"r", " ", "\[Omega]"}]}], ")"}], "2"], 
        RowBox[{
         SuperscriptBox["r", "2"], 
         SuperscriptBox[
          RowBox[{"G", "[", "r", "]"}], "2"]}]], "-", 
       FractionBox[
        SuperscriptBox["m", "2"], 
        RowBox[{"G", "[", "r", "]"}]]}], ")"}], 
     RowBox[{"\[Phi]", "[", "r", "]"}]}]}], "//", "Simplify"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", 
     RowBox[{"G", "[", "r", "]"}]}], "/.", 
    RowBox[{"\[Omega]", "\[Rule]", "0"}]}], "//", "Expand"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"r", "\[Rule]", "rh"}]}], "/.", 
   RowBox[{
    RowBox[{"G", "[", "rh", "]"}], "\[Rule]", "0"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Phi]", "'"}], "[", "rh", "]"}]}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.631790740898511*^9, 3.631790818280465*^9}, {
  3.770143104772504*^9, 3.7701431406460843`*^9}, {3.7701432048351245`*^9, 
  3.770143208824303*^9}, {3.7719594505021577`*^9, 3.771959451773245*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "rh", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m", "2"], " ", 
      RowBox[{"\[Phi]", "[", "rh", "]"}]}], 
     RowBox[{
      SuperscriptBox["G", "\[Prime]",
       MultilineFunction->None], "[", "rh", "]"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.6317907340068827`*^9, 3.631790818645709*^9}, 
   3.6317979380022764`*^9, 3.631802158803404*^9, 3.631810154979909*^9, 
   3.631817714225566*^9, 3.6319042805154*^9, 3.6319857288032103`*^9, 
   3.6322298651399994`*^9, {3.7701430962746124`*^9, 3.7701431412245483`*^9}, 
   3.770728858564144*^9, 3.771959452173001*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"G", "[", "r_", "]"}], "=", 
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    FractionBox["m0", "r"], "+", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Mu]", "2"], "4"], 
     FractionBox[
      SuperscriptBox["rh", "2"], 
      SuperscriptBox["r", "2"]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0", "=", 
   RowBox[{
    SuperscriptBox["rh", "3"], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["\[Mu]", "2"], 
       RowBox[{"4", " ", 
        SuperscriptBox["rh", "2"]}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    RowBox[{"\[Phi]", "[", "rh", "]"}]}], 
   RowBox[{
    SuperscriptBox["G", "\[Prime]",
     MultilineFunction->None], "[", "rh", "]"}]], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.6317908458009405`*^9, 3.6317908584834614`*^9}, {
  3.770143222875109*^9, 3.770143223403661*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "rh", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "3"}], "+", "\[CapitalDelta]"}], ")"}], " ", 
   "\[CapitalDelta]", " ", 
   RowBox[{"\[Phi]", "[", "rh", "]"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", 
   RowBox[{"12", " ", 
    SuperscriptBox["rh", "2"]}]}]]], "Output",
 CellChangeTimes->{{3.631790847491082*^9, 3.6317908589177485`*^9}, 
   3.6317979380312967`*^9, 3.6318021717572556`*^9, 3.631810154995535*^9, 
   3.63181771427244*^9, 3.6319042805434055`*^9, 3.6319857288243914`*^9, 
   3.6322298651556253`*^9, 3.770143180690346*^9, {3.7701432245582275`*^9, 
   3.7701432326109676`*^9}, 3.7707288667362967`*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Here we solve the equation shooting from the horizon \
with the boundary conditions we have found.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771959467951497*^9, 3.771959487032259*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Epsilon]", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.631802018349448*^9, 3.631802022990348*^9}, {
  3.6318103948595057`*^9, 3.631810395470914*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NSol", "[", 
   RowBox[{
    RowBox[{"rh_", "?", "NumericQ"}], ",", 
    RowBox[{"q_", "?", "NumericQ"}], ",", 
    RowBox[{"\[CapitalDelta]_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"EQ", "[", 
        RowBox[{"rh", ",", "q", ",", "\[CapitalDelta]"}], "]"}], "\[Equal]", 
       "0"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]", "[", 
        RowBox[{"rh", "+", "\[Epsilon]"}], "]"}], "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", 
        RowBox[{"rh", "+", "\[Epsilon]"}], "]"}], "\[Equal]", 
       FractionBox[
        RowBox[{"4", " ", "rh", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", "\[CapitalDelta]"}], ")"}], " ", 
         "\[CapitalDelta]", " "}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["rh", "2"]}]}]]}]}], "}"}], ",", "\[Phi]", ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", 
      RowBox[{"rh", "+", "\[Epsilon]"}], ",", 
      FractionBox["1", "\[Epsilon]"]}], "}"}], ",", 
    RowBox[{"Method", "\[Rule]", "\"\<StiffnessSwitching\>\""}], ",", 
    RowBox[{"MaxSteps", "\[Rule]", "50000"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.631696495270568*^9, 3.631696649068864*^9}, {
  3.6316967084932604`*^9, 3.631696712267782*^9}, {3.6316968597173533`*^9, 
  3.631696860467396*^9}, {3.6316969047375784`*^9, 3.6316969413326273`*^9}, {
  3.631696992007448*^9, 3.6316970266656337`*^9}, {3.6316978212163677`*^9, 
  3.6316978692481437`*^9}, {3.6316979576202765`*^9, 3.6316979580109234`*^9}, {
  3.6317905178377466`*^9, 3.631790568818981*^9}, {3.631790870480514*^9, 
  3.6317908774281783`*^9}, {3.6317910658516865`*^9, 3.631791085138637*^9}, {
  3.6317915099611197`*^9, 3.6317915304919057`*^9}, {3.6318020249279566`*^9, 
  3.631802049663704*^9}, {3.7701432576838865`*^9, 3.7701432688372803`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Routine to find the critical temperature ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "c"], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Section",
 CellChangeTimes->{{3.6317914746884375`*^9, 3.631791480993671*^9}, {
  3.6317922497207947`*^9, 3.6317922501360717`*^9}, {3.631792923329056*^9, 
  3.6317929338821397`*^9}, {3.631796885769548*^9, 3.6317968873406086`*^9}, {
  3.6317983356152344`*^9, 3.6317983357503233`*^9}, {3.7719595289567966`*^9, 
  3.771959537506276*^9}}],

Cell[TextData[StyleBox["Let us implement a routine which define the leading \
coefficient of the field near the boundary.\nRemember that is the source of \
the dual operator. We are just asking for a solution with zero source at w=0",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701433558461685`*^9, 3.770143364894661*^9}, {
  3.7719595472686195`*^9, 3.771959574298005*^9}, {3.7733925184691563`*^9, 
  3.7733925269127135`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Leading", "[", 
   RowBox[{
    RowBox[{"rh_", "?", "NumericQ"}], ",", 
    RowBox[{"q_", "?", "NumericQ"}], ",", 
    RowBox[{"\[CapitalDelta]_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[CapitalDelta]", " ", 
      RowBox[{"\[Phi]", "[", 
       FractionBox["1", "\[Epsilon]"], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "\[Epsilon]"], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", 
       FractionBox["1", "\[Epsilon]"], "]"}]}]}], ")"}], "/.", 
   RowBox[{"NSol", "[", 
    RowBox[{"rh", ",", "q", ",", "\[CapitalDelta]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6317981751334906`*^9, 3.631798203372446*^9}, {
  3.631798266111568*^9, 3.6317982719624977`*^9}, {3.6318020856177683`*^9, 
  3.631802105351215*^9}, {3.7701433182580843`*^9, 3.7701433294242516`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiscretePlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Leading", "[", 
     RowBox[{"xx", ",", "2", ",", "1.5"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xx", ",", "0.501", ",", "1.5", ",", "0.01"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
   RowBox[{"Filling", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6317982862991285`*^9, 3.631798373926959*^9}, {
  3.631798564703043*^9, 3.631798571648707*^9}, {3.770143332732231*^9, 
  3.7701433470843315`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0, 0, 1], PointSize[0.004766666666666667], AbsoluteThickness[
    1.6]}, 
   {RGBColor[0, 0, 1], PointSize[0.004766666666666667], AbsoluteThickness[
    1.6], {}, PointBox[CompressedData["
1:eJwt0nlQU1cUB+AHWhtFMyGjo1abIi64C6MVq3JPFBcWKxErbbWtsaItaDFW
GYKjFc3UpQqDCnUbOogbbaUVRIsstxER64JEDK6ALw8SEiBke0nYhL7tj8yb
O78595x7vkz4dkfsFl+CIOKZH/utV1umhIhIyNxwRSMhKBwUIro2fj0JytWS
4X/PpnAqG18jYdlwSW1GJIUfXVh+y/WOhLRljdICBYU/XB+/6G2MAeatWuNf
uYLCO6Qa7cMLBph6OhR7Z1CYOTAFBjjedO/nGb4U5uLlFGzfY/PJfGDAbHX6
aQoW68vu/KUxYOZyvdpCQfG8rP7KEANmp4lf1Az6zzaPHaYnMdcuvRm0B7a4
JdtJzMVvmyF/UEpxnvMt7tezD2qBmVJ1cExvE1akn06SalogeGzcjjJHI85j
x9e3gH76kRE3XzRgmm03xQirHqd7bAVv8ApuACOQtKw0Jfk1PpPETmyEk/Hh
SeFzXuE2dh3jTXDCGVY8pOEFXsyOn2QCZ+GM7DN7n2OundYExy9/V/WFfz3m
YmkruEZE/Tjn/DPMrTe+FTpgvsM8rg5z67jVCvTCkdMGndBh3sMM6syEbXd6
awQPM9inKWRE1UPBwwxdEbalFXvvCx5mILXpx7STqjC3jhgL5Aa6pvxTocXc
+BcsIH8Soi/JLBU8LBDQWvXs40M3BI820L6Zn9PwJF/waANi2+vqopIswYM5
N1E9iaMPIN6jHYjE4+ryURcR79HO/B+y+4pFhYj3aAc5nSTPPF+CeI8OUIpc
R1ZP0CLeowPk7+OuuQN3Ee/RAYQjTlNrvI94Dysol3867of6R4j3sAJRPeqx
b00t4j2sIPcdd/al6SniPTpBsTi23tL+DPEenWBvDNoaRtejDM6jE9IslpNf
Ey8RyXnYQHnpXtZMyWvEe9ggLeXXrRkTGxDvYQOyznTl+4VNKLF896kxg+2Q
qx6J1kwnUdaYwXHiWXaQ96nDpJ8YEBfH2UF3e9jK7ZEUMukC33T/xOTldWWp
G5qReFZRju2qHezlNyabk1rQgqNLlEYdk/s1+dVpjIg5MAV2SJPdzp99zoR+
YeNABwSr7xa6C1sRW10d7YC02MaYjx6ZEXM5M5IDiKgPxlwyWhA7TVGOA1SX
pe/t82lHXLtqB8jXXlVdlHUgLrYx9clzxf5hVrSfe5ATVH4Bxn+/6kT51dGh
R5c4QbnsefQf+2zoKTt+ohOulx3caYyxox623Skn6CQ5ERkGO5rIDeAE9c6N
ULPLgVaFsg9yArmSFOUOcaJkdh1iF2R2fpk8+JwT/caOH+oCcv8eVdcsF+La
KV0gP1g7kFrpQnY2PuoCFRW15PDnNOLWW+SC3BgyQWal0VJuQUw+eUFVmMYt
eNAgX5fQ++dYj+BBg0psb3tx3SN40KDbadt0OMIreNAQPHqou4T0Ch40SMhv
oraldgkeNASsuzk1T9oteDD3qcP9Y691Cx5uUASNEu1f0SN4uEG1O7wjyNAj
eLhBsjHy9+i9vYKHG+SV6+dbRvcJHm4gLlVnD9zoEzzckJu7SZ+ueCd4eEDy
X7folPWd4OEB3YOna8XH+gUPDwQsmNTUP3VA8PAAea/g1eb7A4IHU/9KJpfN
JYD38EBExZWhVQcJ4D28oDj2xJpXRwDv4QWiKzGrNNAHeA8vyIefzR+2ywd4
Dy+QKVkvT971Ad6DORefd8eO9AXewwtKcY1f9BZf+B/adkGK
     "]], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0.501, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{352., Automatic},
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{0.501, 1.491}, {-8.733339736418386*^-6, 0.000035086968159817}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.631798343484518*^9, 3.6317983758932753`*^9}, 
   3.6317985752241063`*^9, 3.6318023000827107`*^9, 3.6319857509433346`*^9, 
   3.7701433504189525`*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Closed]],

Cell[CellGroupData[{

Cell["Let us get some data", "Section",
 CellChangeTimes->{{3.631805113609842*^9, 3.631805117467431*^9}, {
  3.77014342515812*^9, 3.770143429014484*^9}, {3.7707289139012156`*^9, 
  3.770728916917153*^9}}],

Cell[TextData[StyleBox["What we are going to do is to search for solution \
with zero leading. See the lectures for an explanation of why this is the \
sign of an instability.\nWe are going to do it very brutally with a manual \
search.\nYou can implement this routine much better, try!",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7707299752894325`*^9, 3.7707299870381804`*^9}, {
  3.7719595895154123`*^9, 3.7719596463496113`*^9}, {3.7733925477196007`*^9, 
  3.7733925501695557`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"16", " ", "\[Pi]", " ", "rh"}]]}], "+", 
     FractionBox[
      RowBox[{"3", " ", "rh"}], 
      RowBox[{"4", " ", "\[Pi]"}]]}], "\[Equal]", "TT"}], ",", "rh"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7707292673599997`*^9, 3.7707292717718267`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"rh", "\[Rule]", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "-", 
        SqrtBox[
         RowBox[{"3", "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           SuperscriptBox["TT", "2"]}]}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"rh", "\[Rule]", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
        SqrtBox[
         RowBox[{"3", "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Pi]", "2"], " ", 
           SuperscriptBox["TT", "2"]}]}]]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.770729272034952*^9, 3.7707299638713384`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TT", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "3"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "0.01", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
    ",", "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "4"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "1", ",", "2", ",", "0.01"}], "}"}]}], "]"}], ",", 
    "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "5"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "2", ",", "2.6", ",", "0.01"}], "}"}]}], "]"}], ",",
     "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "6"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "2.6", ",", "3", ",", "0.01"}], "}"}]}], "]"}], ",",
     "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line001", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"%%%%", ",", "%%%", ",", "%%", ",", "%"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "TT", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.770729782931017*^9, 3.7707297859944253`*^9}, {
  3.7707299402342873`*^9, 3.7707299461876287`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TT", "=", "0.005"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "3"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "0.01", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
    ",", "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "4"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "1", ",", "2", ",", "0.01"}], "}"}]}], "]"}], ",", 
    "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "5"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "2", ",", "2.6", ",", "0.01"}], "}"}]}], "]"}], ",",
     "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "6"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "2.6", ",", "3", ",", "0.01"}], "}"}]}], "]"}], ",",
     "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line005", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"%%%%", ",", "%%%", ",", "%%", ",", "%"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "TT", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7707298569865365`*^9, 3.7707298591557126`*^9}, {
  3.7707299486280794`*^9, 3.7707299533891196`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TT", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "3"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "0.01", ",", "1", ",", "0.01"}], "}"}]}], "]"}], 
    ",", "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "4"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "1", ",", "2", ",", "0.01"}], "}"}]}], "]"}], ",", 
    "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "5"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "2", ",", "2.6", ",", "0.01"}], "}"}]}], "]"}], ",",
     "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"qi", ",", 
        RowBox[{"\[CapitalDelta]x", "/.", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Leading", "[", 
             RowBox[{
              RowBox[{
               FractionBox["1", "6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Pi]", " ", "TT"}], "+", 
                 SqrtBox[
                  RowBox[{"3", "+", 
                   RowBox[{"16", " ", 
                    SuperscriptBox["\[Pi]", "2"], " ", 
                    SuperscriptBox["TT", "2"]}]}]]}], ")"}]}], ",", "qi", ",",
               "\[CapitalDelta]x"}], "]"}], "\[Equal]", "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[CapitalDelta]x", ",", "6"}], "}"}]}], "]"}]}]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"qi", ",", "2.6", ",", "3", ",", "0.01"}], "}"}]}], "]"}], ",",
     "qi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"line01", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"%%%%", ",", "%%%", ",", "%%", ",", "%"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "TT", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.770729935033724*^9, 3.7707299604317436`*^9}}],

Cell[TextData[StyleBox["What we are doing is fixing the critical temperature \
to a certain value and search at fixed conformal dimension which is the \
charge of the scalar at which the leading term is zero.\nThis is not \
necessarily the best way, try others.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719596624714766`*^9, 3.7719596953781557`*^9}, {
  3.7733925665160217`*^9, 3.7733925775316086`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot", "Section",
 CellChangeTimes->{{3.631803219497378*^9, 3.6318032246851683`*^9}, {
   3.7707318891952906`*^9, 3.7707318895587673`*^9}, 3.771959700609893*^9, 
   3.773392582023303*^9}],

Cell[TextData[StyleBox["Here we finally plot our results together with the \
analytic formula for the T=0 instability",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771959709430543*^9, 3.771959723403441*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", "line001", "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<q\>\"", ",", "\"\<\[CapitalDelta]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Filling", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", "Thick", ",", "Dashed"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Black", "]"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", "line005", "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<q\>\"", ",", "\"\<\[CapitalDelta]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Filling", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Purple", ",", "Thick", ",", "Dashed"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Black", "]"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
    RowBox[{"Prolog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"LightGray", ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "]"}]}], "}"}]}]}], "]"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", "line01", "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<q\>\"", ",", "\"\<\[CapitalDelta]\>\""}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"Filling", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Red", ",", "Thick", ",", "Dashed"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"Directive", "[", "Black", "]"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
    RowBox[{"Prolog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"LightGray", ",", 
       RowBox[{"Rectangle", "[", 
        RowBox[{
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
         RowBox[{"Scaled", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "]"}]}], "]"}]}], "}"}]}]}], "]"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RegionPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"TC0", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "<", "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "1", ",", "6"}], "}"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<q\>\"", ",", "\"\<\[CapitalDelta]\>\""}], "}"}]}], ",", 
    RowBox[{"RotateLabel", "\[Rule]", "False"}], ",", 
    RowBox[{"BoundaryStyle", "\[Rule]", "Black"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%%%", ",", "%%%", ",", "%%", ",", "%", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "5"}], "}"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.770731416611021*^9, 3.770731519147741*^9}, {
  3.770731563380562*^9, 3.7707315991250963`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJxd2HlczPkfB/Dv3DPN0Ry1WfzcXcQWYV29P2xIKEehjViWFSFbrnaLLSFW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     "], {{{}, {}, {}, {}}, {{}, {}, 
       {RGBColor[0, 0, 1], PointSize[0.007333333333333334], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJwV01VgEAQABNARY/RGjo3a6JZukC7pbnSkxJAOJURJJZSSMOju7pRupFtC
6cYg3z7e3e/9XGRU9/rRsQICAjKJmI5NHOISSDyCiE8CEpKIxCQhKcGEkIzk
pCAlqUhNKGkII5y0pCM9GchIBJExO8hMFrKSjezkICe5yE0e8pKPj8hPAQpS
iMIUoSjFKE4JSlKK0pShLB9TjvJUoCKVqEwVqlKN6tTgE2pSi9rUoS71qE8D
GtKIxjShKc1oTgta0orWtOFTPiOKtrSjPR3oSCc+pzNd6Eo3ounOF/SgJ73o
TR/60o/+DGAgX/IVgxjMEIbyNcP4hm8ZzghGMorRjOE7vmcs4xjPBH7gRyYy
iclMYSo/MY3pzGAmP/MLv/Ibs5jNHOYyj/ksYCGLWMwSlrKM5axgJatYzRrW
so71bGAjm9jMFrayje3sYCe72M0e9vI7+9jPAQ5yiMMc4SjHOM4JTnKK0/zB
Gc5yjvNc4CKXuMwVrnKN69zgT25yi9vc4S/+5i73uM8DHvKIxzzhKc94zgte
8op/+Jf/+J/XvOEt73hPzPljEZs4xCWQeAQRnwQkJBGJSUJSggkhGclJQUpS
kZpQ0hBGOGlJR3oykJEIIsnKB1Tcg9A=
         "]]}}}], {}, {}, {{}, {}}}, {{}, GraphicsComplexBox[CompressedData["
1:eJxF2HlcTekfB/Bz96W7nav42bI1SpZQtob5PiplzNhqjKiZkaVkZMQYkuzL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     "], {{{}, {}, {}, {}}, {{}, {}, 
       {RGBColor[0.5, 0, 0.5], PointSize[0.007333333333333334], 
        AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTratheVlL9u2l7G2zGVbW8tuy7Ztuy2+5+ni/f7b
7+b7g5t0rNohMCAgIKsIuaEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP
+CQgIYlITBKSkowgkhNMClKSitSkIS3pSE8GMpKJzGQJ6U42spODnOQiN3nI
Sz7yU4CCFKIwRfiBohSjOCX4kZKUojRlKEs5yvMTFahIJSpThapUozo1qEkt
alOHn6lLPerTgIY0ojFNaEozmtOClrSiNW1oSzva04GOdKIzXehKN7rTg570
ojd96Es/+jOAgfzCIAYzhKEMYzgjGMkoRvMrY/iN3xnLOMYzgYlMYjJTmMo0
pjODP5jJLGYzh7nMYz4LWMgiFrOEpSxjOStYySpWs4a1rGM9f/IXG/ibjWxi
M1vYyja2s4Od7GI3e9jLPv7hX/ZzgIMc4jBHOMoxjnOCk5ziNGc4yznOc4GL
XOIyV7jKNa5zg5vc4jZ3uMs97vOAhzziMU94yjOe84KXvOI1b3jLO97zgf/4
n4984jNf+ErI+AMJRWjCEJZwhCcCEYlEZKIQlWhEJwYxiUVs4hCXeMQnAQlJ
RGKSkJRkBJGcYFKQklSkJg1pSUd6MpCRTGQmS+D33/UNkpyF/A==
         "]]}}}], {}, {}, {{}, {}}}, {{}, GraphicsComplexBox[CompressedData["
1:eJxl2GdUVFcXBuA7fZjGDMUWgpUiVcWoEWFvE0RFjQQGY8GoiN3YNWqsEUVF
RBE1xIIRW2IkKhoECQEUBVEBC0QMIE1p4sAU2sB8MLNd+fHdP6zDZc49+332
nHsWA0NWByxiMwwznMUwPT9/sEqYWL41DF7/5Fg5u7gJTOMYuJMSPDGovAnu
2O6t//rOWaiZ9+pVdcPH+xdglG+hf7O+CX6O7bl+Bc8FeWZKRTMkG/8+ATjN
5z2LhjZD96D7NzcgrelEP0/fZvr8LVA92OftsbgZREXxa7xESfBc1Dtg+YFm
ME4Xmwx/vVQm7P2jGYYGR2VqHVMh/EHutKH/NNN60kAfUbijg62GC92fLopP
h/mRbpPGgxoajM/LgJh1nHNbV6phpEfPdQ8svFI9Hvyspuffh0lplTO+ylbD
Pa1j9xOy4MfvYpYpW9QgNq7nIfhXjAg54qCBAOMDs+H3J41z42dqqN4cUIeM
mBMUoYGKrT0TPoJB/e5tePeXhtb7GGY/788rVWlgbc/y1jyBKsN5he0QLeXz
FI6X5T48+o0WGOOVD9ezMw47RGipnnwYOmaUZ0GaFiaV9zygAMICwsce1Gip
vgLIDJ3lccpBB0cyewp4BtyAJ1a3Z+vAWK7Hczi5mZlZF6kDYzlFz+F+SvZj
xwwd1f+iO+dV3gs1Oujfsxzbl5D4mTr4hEML5fESHqqW3EyZ3QJLFvdchRD1
yegjjyJbKJ8iOJD/aItNRgv0zGaVUAR3XW1269UtlNc/4LjasjbZvhV0PdNp
/4FFRy4kBM1qpfxewfYDUby8iFbwNjZAMfwstvrOLq2V8iyGCTePx81UtYJx
eXtfQ3+1bu/SQW2U778Q7pLvGqRsgyePe65/IcLFLe7V3jbKuwS6ktePDUtq
A2vjAkvhd7+UXZLaNsq/FGwc7W+s69cOxumCy+D4lYsDk6a0k8cbcM2e9Xnx
tnaq5w0s3TBt5b/X2snnDdgE2Y1JK22n+t5AiHn0wF3mHeRVDtHLvPcJsYPq
LYcVxw7rI9d0kF85jJPEDtae66D6K6BEXSibUNBBnhXgW8KqWcfSg2m6ClAt
/F69e7iefCvhhn/1hQ0L9JRPJSzK6OJMPaon70pgVtqdEGboKa8qsJ40OSJe
pSf/KsjUhC53GdBJ+VVBeP+SXqend1I/VMOQ29UW6h2dlGc1uOvb/EYmdFJ/
VMNc+wEBc0o6Kd+3oDibzVsh6aJ+eQsWocN6hXp2Ud5vIb7wtd53eRd9399B
xMBhI6xiuyj/dyC/NNj18cMu6qd3MD+Ps3C1ros8asDX1WuBfoiBPGrg2MmL
278PNJBHDXhct3Uq220gjxp4FHTkucd1A3nUAqgMVRtLDeRRC9MiMioD+Aya
PGphrl+Xe8inDJo86iAoOSB86UgGTR510Hv9pXmLpzBo6s86cHAIrp0TwqDJ
ox7uHawPnLyFQZNHPXjGRjx2O8KgyaMeTubZe0suM2jyaIBaj8shFX8xaPJo
gPkj421uvGDQ5NEAe3LyYzbXM2jyeA/vBypbxrBZaPJ4D+/ipqxq7sNCk8d7
2JT+aOBFdxaaPBphmsRp+te+LDR5NMIObUKjLpiFJo9GOFtuAyfWs9Dk8QH2
N367yP0gC00eH+BBcuLezHMsNHl8gJU5tdemJ7HQ5KGCBYsGuBY9+f+xqT4V
2KuczWdVsdDk1T3OtNn5sp1F9aogVuJ2YKqCjSY/Ffy4z+ebNAc21a+C+IxI
ibM3G02eKshOD7gbrWRTHk2wPi71hHY5G02+TTD+zfibgbvZlE8TCK82Dr12
ko0m7yZ4LN80iJ3ApryaYEXc4fiA+2zyb4IwvF1+tpiNxuVZNUPSKHb5WxWb
+qEZztsk5ToJOGiMs/u95f3FpKTln3LQGFdUMyT0Op56yYODpvdTMwTW/qYp
ncxB0/e3GfJOR39vOZ9DeavBdeQvwT6bONQ/ahBYXft77SEO5a+GVTJWwqnz
HOonNaQnDpuYeYdDHmqoqLhzpvoph/pLDULXqBxeNYc8NNAnJrVkUAeHPDSQ
NDXrwzgFlzw0kNn6r7XSgUseGjDzuj1/qReXPDRQGP2qaksglzw0UF81OWn/
Mi55dL8H657Ux+zkkocWiqxlR88e55KHFp59XpN68SqXPLTwzoXZ9VsGlzy0
sCib1/B7EReN8WVqYfMrqcW191zy0ML9iDjOVQ6PPHRwoK9T/qW+PPLQQZKy
9/5z7jzy0IFoWfq4nybw6Puqg6w+pR2Rc3jkoYPAOQWFu9fyyEMHynVDX68P
55FHCxQ69u0TeoZHHi0wM6nuVEAijzxawKnPqo2QwyOPFlhnP/WmUxmPPFpA
m2U/30rLI48WkNUsO6QX8cmjFerP+PlUDuCTRyukPEiLyR7FJ49W+Mt97sHf
p/LJoxUm34wfHhXCJ49WWO/zy4k1m/nk0QrV6fOz/A/zyaMVQq7sz3G/wCeP
Nnjr/CxBmsInjzZ4fG7Qrro8PhqnW9MG9StLJj2o5pNHG7zs/8Lylw4+ebTB
hPB19VsVAvJogx8fDigOdBCQRztEc7+qc/YSkEc7HJ5caccJFJBHO9htTzrx
aqmAPNqh17C5vn/sEJBHOzxK8fIOixHQftoO2Reuh8/8TUAeHcBPuOvski5A
0/mtA15E2XsYXgrIowNmaFIuFdQLyKMDQixZUfEsIXl0wDh5gGZDbyF5dED8
jeelE1yF5KEH7x2HZvT6UkgeenDePXXh25lC8tBDf+9CyZ+rhOShB8OtX2fv
DROShx72WNgplT8LyUMPysydzODrQvLQg0Vu7uKmLCF5dMLmTY2Rf78Wkkcn
PD5zY1tkk5A8OmGE7/XP5wjMyKMT+sxYl+v4qRl5dMLF81PG6EaYkUcnXCpf
ve/eJDPy6IKkxc13j3xrRh5d4Ky7Vzp3gxl5dHWfJxI1TgfNyKMLfty2htMa
Z0YeXXA3L1yedduMPLrgZf2SgdG5ZuRhgMuR8zznlZuRhwHcL59d6NJiRh4G
2HN1bFybREQeBvh7Xn/1g0Ei8jDA2yBdSMwYEXkYwKlY0rLgKxF5MLj9pxXX
3UP/G/9AY1N9DE7wSYvp3CIiLwaVdzZdyY0SoTE+LwaLFcUfYi+KyI/BXKnl
6qV3RVQ/gzkTg5xGF4jIk8FCv1V2/Hci2r8Z9A2eEfpSLyJfBk+WFNZdsBBT
PgwOuHw0dYOjmLwZZNV4l/h4i2k/YVAzZ4q/tVJM/gz2anTq+3aZmPJj4asy
Z8+knWLqBxZyRceS9x8X037DQsf3G0/Oviqm/mBhnEdjkUuGmPJl4RHXlu2G
QjHtpyx8OuD7Q88axJQ3CwukXvxLbAn1Dws/bOrbuKWPhPJnYVHrCd+v3CT0
/mPhw6AZFoN9JOTBwmMHygJbZ0mov1iolsRJn66WkAcbVUd14y/slZAHG6V+
9uqtpyTkwcbYrBWDA25IqP/YOOr2+xdDH0rIg41eyzPM2CUS8mBjmF39veJm
CXmwsTz0W94toZQ82Jji3pUXaSslDzZmhZyxWzpSSh5snN7eJfjST0oebPQI
LtxsO19KHmwcG/dwS/tGKXmwMfHFEklRhJQ8OOg3zWvErV+k5MHB8WV/NxxN
kpIHB+udZnmteSIlDw6OKw21m14pJQ8OBrQNu+TWJiUPDkaH6dNl5jLy4KDi
deemD0Nk5MHB0dazc/LHysiDg8M7nJJv+svIg4P2tdsnHl8sIw8O3hYpN27e
JiOP7nNH79NfBkfLyIOL0mV+iXhFRh5cVEq9suzSZOTBRfs1uFX8QkYeXPRZ
a/u8qVZGHlwsP3ks/x+DjDy4qP7z6/Xp1ubkwcV9p1mpV5zNab/gougeXj06
3pw8uFhSeX78D9+YkwcXbcS3di76zpw8uDghUrXIf89/Y18am3y4mBpWoPGM
NScfLv70+r6L4x/m5MNDdt4wmXWWOfl0v+f3rYplvzYnHx6umP78qUplTj48
tHQJKlrNkZMPD9dOOXV6iUxOPjz884dZSfP6ysmHh5N8fnWYOUROPjzcpjz3
3t9dTj48PBPrb+Y3Vk4+3WNl9tYvJ8jJh4cL3C2+8PKXkw8Pq7/+bN7oOXLy
4WPDps+eDV8sp/M4H90Yy1Mua+Xkw8cKUW6ywzY5+fBx0J5v3AaHy8mHjwtH
/9FqGy2n8zsf39Rn9fnkjJx8+Njvu0OHe1+Rk0/3/XOqWVaJcvLh49LTJVsV
aXLy4WPKLc8mWY6cPPh4LEqVKnkhp/2ej+s9ykpEZXLy4KO6X02gWZ2cPARY
41NrK9TKyUOAl33SvAWMgjy6xwGYyBcryEOAU4N9t/F7KchDgDcsL8byByrI
o/scYXATC1wU5CHAwftv5QtGK8hDgFPE3DrhFwryEOCYqtoZomkK8hBg6K5h
vSUzFeQhwNPLzjnJFirIQ4Abgpij8lUK8hDitRHWfpZbFPjx/12mXN7Ax/sf
x/8D8eyIpw==
     "], {{{}, {}, {}, {}}, {{}, {}, 
       {RGBColor[1, 0, 0], PointSize[0.007333333333333334], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJwl1FO4EAYYBuBzsm2dTratheVlL9u2l7G2zGVbW8tuy7Ztuy2+5+ni/f7b
7+b7g5t0rNohMCAgIKsIuaEITRjCEo7wRCAikYhMFKISjejEICaxiE0c4hKP
+CQgIYlITBKSkowgkhNMClKSitSkIS3pSE8GMpKJzGQJ6U42spODnOQiN3nI
Sz7yU4CCFKIwRfiBohSjOCX4kZKUojRlKEs5yvMTFahIJSpThapUozo1qEkt
alOHn6lLPerTgIY0ojFNaEozmtOClrSiNW1oSzva04GOdKIzXehKN7rTg570
ojd96Es/+jOAgfzCIAYzhKEMYzgjGMkoRvMrY/iN3xnLOMYzgYlMYjJTmMo0
pjODP5jJLGYzh7nMYz4LWMgiFrOEpSxjOStYySpWs4a1rGM9f/IXG/ibjWxi
M1vYyja2s4Od7GI3e9jLPv7hX/ZzgIMc4jBHOMoxjnOCk5ziNGc4yznOc4GL
XOIyV7jKNa5zg5vc4jZ3uMs97vOAhzziMU94yjOe84KXvOI1b3jLO97zgf/4
n4984jNf+ErI+AMJRWjCEJZwhCcCEYlEZKIQlWhEJwYxiUVs4hCXeMQnAQlJ
RGKSkJRkBJGcYFKQklSkJg1pSUd6MpCRTGQmS+D33/UNkpyF/A==
         "]]}}}], {}, {}, {{}, {}}}, GraphicsComplexBox[CompressedData["
1:eJxlmHlYU1cah0MSNiEIYXGI2umo1aDWVtt0XNDz1VuxtYpxKTrUhoJL0ai4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    "], {{
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[0.3], EdgeForm[None], 
       GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmHnc11MWx39XtmzZRSVPItEiLVpEq1JpsS8RGZpqKsvIEkklS9YUFaVG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          "]], PolygonBox[CompressedData["
1:eJwtlGmIiFEUhu8Zxr41IjSyDSYlpSSlNPnn50wYk3XGiLITxr4vI4xdiFCW
smRnNHaDsQxj+eW3oSgK2Xnezvnx9H7nu/e7595z3/N1K56RPz0jpTQMGsJG
S+kYNIe/xEXocxgEVcTl6DRoBn+IC9BH0AfKiAvRWhgA54iHo4+hL5QTH0dP
xNq1cIDnBfBN+dGRcASawNHkudbD7+Q5tbcNkVt7XAFPoT984N129CS0gAR7
YQ60hgawBV5CHnxmyir0GQyEj8T56FVoD5OIN6F1MBg+Ee9CZ0NLsHjeEbn0
bhbcge6QA3PhdOT+wrTD6BL4wXNjnRHWwC/ipugVuAylxO3QMfAChsBr3i1C
n0A/eE98Fj0Db3lug1ZCCXSEDnH2PZARNdDcC9A2vlmLToWusYel6GRoFHvU
2E3oEnMewn34zljvqPVW+Je85vr2gfmY1tgWNcmJOYfQaugFmTAOXsFQeMP4
PfRinK2nPAT7IBeyoCZqqlrmxloTzOdqzdtwy9yr2rO8OR/qk3tUdzMTesQd
qZYjzL2pmpbp3qGzuSflLXlSXpTH7sL42KvWkLcXwrvkHi+F/fA1eU6NHTT3
tuZo7SrIjhzLzD0hL/xkfLF5jTKjxvPQidAp1lwXnpFX1BOn0J3mXmwF56Nm
WXHH18w9LS/LEzfgunmvZkftK8x7QXeg3hgbXsuL3JXhJe2hGC6Ze1M9ol5f
ad576nn9K1ab95L+Geqd0ea9rh5Sr40y/zeo56bA8ji7el5e32zea/L8bvMz
6mzy8H+Yz5U5
          "]]}]}, {}, {}, {}, {}}, 
     {GrayLevel[0], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0ulSDQAYBuCDyFIkXIB/3AP30EKhbClCHCqVFrs49lKEQlIhWyhLCFG2
iijRIkyuw3Nm/Hjm/Wa+me/P985PCyZsnRAIBNqZSHiex0IWE08GTy0e8ohW
0nhMAm2s4wnp5DHEDqrJIJ8PJFLDEp7TzjPWs5NhCrjIJQr5yFIuk0Q3RWyg
hTespZNaiuniHW/JZBcjlHCF3Qywh43UkUwPe9nEPnpZxlWW84n9bOYAn1lB
PSm85BUvyKKUUQ7SwCG+cZgtHOEnIRo5yiDHuM41UunjOOFnneALK7nBKr5y
kiCn6Gc1TazhNdvoYDvljFHGTU7znQqyOcMvKrnFWX5QRQ7n+c05bpPLey5w
j/s84A7N3CWGv7o0W47LP4wxRD89dIa7RjP1VBGigHTiWMQC5jKH2PBNYpjF
TKKJYgbTmcZUIpnCZCKY9L/3/wBP1mf7
       "]]}}], InsetBox[
    StyleBox[Cell["T=0",
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     FontSize->16,
     FontWeight->Bold,
     FontOpacity->1.,
     Background->GrayLevel[1.]], {1.6589861751152073, 4.465437788018432}, {
    Left, Baseline},
    Alignment->{Left, Top}], 
   StyleBox[InsetBox[
     StyleBox[Cell["T=0.1",
       GeneratedCell->False,
       CellAutoOverwrite->False,
       CellBaseline->Baseline,
       TextAlignment->Left],
      FontSize->16,
      FontWeight->Bold,
      FontOpacity->1.], {2.400921658986175, 3.408602150537634}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    Background->RGBColor[1., 1., 1., 0.]]},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.5225},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"\[CapitalDelta]\"", TraditionalForm], None}, {
     FormBox["\"q\"", TraditionalForm], None}},
  FrameStyle->Directive[
    GrayLevel[0]],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{25., 9.5}, {40., 7.5}},
  LabelStyle->Directive[
    GrayLevel[0], Bold, Medium],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 3.}, {1., 5.}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.770731903657403*^9, 3.770731915592721*^9}, 
   3.770731964179603*^9, 3.7733925993486404`*^9}],

Cell[TextData[StyleBox["This is our fig.20",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7733925947988787`*^9, 3.773392612938507*^9}}]
}, Closed]]
}, Open  ]]
},
WindowSize->{1520, 781},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 494, 13, 242, "Title"],
Cell[1077, 37, 598, 10, 86, "Text"],
Cell[1678, 49, 175, 3, 30, "Input"],
Cell[1856, 54, 202, 4, 30, "Input"],
Cell[CellGroupData[{
Cell[2083, 62, 112, 1, 70, "Section"],
Cell[2198, 65, 286, 4, 30, "Text"],
Cell[2487, 71, 216, 5, 50, "Input"],
Cell[2706, 78, 835, 25, 99, "Input"],
Cell[3544, 105, 1175, 36, 56, "Input"],
Cell[4722, 143, 763, 15, 51, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5522, 163, 164, 2, 56, "Section"],
Cell[5689, 167, 245, 4, 30, "Text"],
Cell[5937, 173, 902, 26, 49, "Input"],
Cell[CellGroupData[{
Cell[6864, 203, 1056, 23, 30, "Input"],
Cell[7923, 228, 4419, 87, 389, "Output"]
}, Open  ]],
Cell[12357, 318, 550, 14, 30, "Input"],
Cell[12910, 334, 11738, 211, 389, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[24685, 550, 230, 3, 56, "Section"],
Cell[24918, 555, 166, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[25109, 561, 660, 16, 54, "Input"],
Cell[25772, 579, 2787, 81, 52, "Output"]
}, Open  ]],
Cell[28574, 663, 456, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[29055, 673, 1923, 61, 135, "Input"],
Cell[30981, 736, 754, 18, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31772, 759, 997, 33, 146, "Input"],
Cell[32772, 794, 676, 16, 48, "Output"]
}, Open  ]],
Cell[33463, 813, 273, 9, 5, "Text"],
Cell[33739, 824, 221, 3, 30, "Text"],
Cell[33963, 829, 239, 6, 30, "Input"],
Cell[34205, 837, 1995, 46, 52, "Input"],
Cell[36203, 885, 273, 9, 5, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[36513, 899, 505, 11, 56, "Section"],
Cell[37021, 912, 437, 6, 49, "Text"],
Cell[37461, 920, 920, 23, 49, "Input"],
Cell[CellGroupData[{
Cell[38406, 947, 588, 14, 30, "Input"],
Cell[38997, 963, 4485, 102, 212, "Output"]
}, Open  ]],
Cell[43497, 1068, 273, 9, 5, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[43807, 1082, 204, 3, 56, "Section"],
Cell[44014, 1087, 495, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[44534, 1098, 385, 12, 51, "Input"],
Cell[44922, 1112, 876, 28, 47, "Output"]
}, Open  ]],
Cell[45813, 1143, 4712, 131, 250, "Input"],
Cell[50528, 1276, 4714, 131, 250, "Input"],
Cell[55245, 1409, 4657, 130, 250, "Input"],
Cell[59905, 1541, 417, 6, 49, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[60359, 1552, 193, 3, 56, "Section"],
Cell[60555, 1557, 216, 3, 30, "Text"],
Cell[60774, 1562, 5477, 143, 164, "Input"],
Cell[66254, 1707, 28644, 502, 388, "Input"],
Cell[94901, 2211, 143, 2, 30, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)

