(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    429962,      11583]
NotebookOptionsPosition[    419905,      11290]
NotebookOutlinePosition[    420252,      11305]
CellTagsIndexPosition[    420209,      11302]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Gauge invariant variables",
 FontSize->72]], "Title",
 CellChangeTimes->{{3.6252071161148157`*^9, 3.625207116739846*^9}, {
  3.693751856213512*^9, 3.6937518604172955`*^9}, {3.7403682951472645`*^9, 
  3.7403682963280687`*^9}, {3.7706193076918716`*^9, 3.770619311632391*^9}}],

Cell[TextData[StyleBox["In this notebook:\n0) we derive the background \
geometry of arXiv:1411.1003\n1) we derive the equations for the vector \
perturbations in the model of arXiv:1411.1003\n2) we find the gauge invariant \
combinations and we write down the independent equations in terms of them\n\n\
This is an exercise that you can find in section 4.3 of the notes",
 FontSize->18,
 FontSlant->"Italic",
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.7719603219156413`*^9, 3.771960416037775*^9}, {
  3.7719604586818485`*^9, 3.771960471935235*^9}, {3.7733926788871355`*^9, 
  3.773392694458805*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6240094492315493`*^9, 3.6240094511847925`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FS", "=", "FullSimplify"}], ";"}]], "Input",
 CellChangeTimes->{{3.6240094529973536`*^9, 3.624009456528799*^9}}],

Cell[CellGroupData[{

Cell["\<\
The package for tensorial calculus (just run, or if you brave open it)\
\>", "Chapter",
 CellChangeTimes->{{3.624009473685851*^9, 3.624009475529693*^9}, {
  3.7706193190153418`*^9, 3.7706193205806017`*^9}, {3.7719604371214685`*^9, 
  3.771960452057476*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 2  RG&TC-Code",
 FontWeight->"Bold"]], "Subsection",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrigRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]_", "]"}], "2"]}]}], "->", "x"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cot", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"y_.", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]_", "]"}], "2"]}]}], ":>", 
      RowBox[{"y", "/;", 
       RowBox[{
        RowBox[{"x", "+", "y"}], "===", "0"}]}]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FaSi", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FaSi", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FacSimp", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Equal", "]"}], ":=", 
   RowBox[{"Equal", "[", 
    RowBox[{
     RowBox[{"FacSimp", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"x", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Rule", "]"}], ":=", 
   RowBox[{"Rule", "[", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"coll", "[", "x", "]"}], "/.", "simpRules"}], ",", 
        "FormVars", ",", "Factor"}], "]"}], "/.", "simpRules"}], ")"}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroQ", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Normal", "[", "x", "]"}]}], "}"}], "]"}], "]"}], "===", 
    RowBox[{"{", "0", "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroL", "[", "x_", "]"}], ":=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroN", "[", "x_", "]"}], ":=", 
  RowBox[{"Length", "[", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"indepTerms", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"redPlus", "[", 
    RowBox[{"redTimes", "[", 
     RowBox[{
      RowBox[{"nonZeroL", "[", "x", "]"}], ",", "opt"}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"redTimes", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"opt_:", 
     RowBox[{"{", "}"}]}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tmp$", " ", "=", " ", 
       RowBox[{"Select", "[", 
        RowBox[{"x", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "#1", "]"}], " ", "===", " ", "Times"}], " ", 
          "&"}]}], "]"}]}], ",", " ", "rst$"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"rst$", " ", "=", " ", 
      RowBox[{"Complement", "[", 
       RowBox[{"x", ",", " ", "tmp$"}], "]"}]}], ";", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"rst$", ",", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"numb2", "[", 
           RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", "tmp$"}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"NumericQ", "[", "x", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{
     RowBox[{"x_", "^", "y_."}], ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{"opt", ",", "x"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", "x"}], ";", 
  RowBox[{
   RowBox[{"numb2", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Times", "@@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"numb1", "[", 
        RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", 
      RowBox[{"Level", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redPlus", "[", "x_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "#", "]"}], "===", "Plus"}], "&"}]}], 
         "]"}]}], ",", "rst$", ",", "i$", ",", "negi$"}], "}"}], ",", 
     RowBox[{
      RowBox[{"rst$", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"x", ",", "tmp$"}], "]"}]}], ";", 
      RowBox[{"i$", "=", "1"}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i$", "<", 
         RowBox[{"Length", "[", "tmp$", "]"}]}], ",", 
        RowBox[{
         RowBox[{"negi$", "=", 
          RowBox[{"Select", "[", 
           RowBox[{"tmp$", ",", 
            RowBox[{
             RowBox[{"#", "===", 
              RowBox[{"-", 
               RowBox[{"tmp$", "[", 
                RowBox[{"[", "i$", "]"}], "]"}]}]}], "&"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"negi$", "=!=", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"tmp$", "=", 
            RowBox[{"Complement", "[", 
             RowBox[{"tmp$", ",", "negi$"}], "]"}]}]}], "]"}], ";", 
         RowBox[{"i$", "=", 
          RowBox[{"i$", "+", "1"}]}]}]}], "]"}], ";", 
      RowBox[{"Union", "[", 
       RowBox[{"tmp$", ",", "rst$"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RiemSym", "[", "h_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "a_", ",", "c_", ",", "d_"}], "]"}], "=", "0"}], 
     ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}], 
     ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"b", ",", "a", ",", "c", ",", "d"}], "]"}]}], "/;", 
       RowBox[{"a", ">", "b"}]}]}], ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"a", ",", "b", ",", "d", ",", "c"}], "]"}]}], "/;", 
       RowBox[{"c", ">", "d"}]}]}], ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"c", ",", "d", ",", "a", ",", "b"}], "]"}], "/;", 
       RowBox[{
        RowBox[{"a", ">", "c"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "===", "c"}], "&&", 
          RowBox[{"b", ">", "d"}]}], ")"}]}]}]}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"epsilon", "[", "a__", "]"}], ":=", 
   RowBox[{"Signature", "[", 
    RowBox[{"{", "a", "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroTensor", "[", "rnk_", "]"}], ":=", 
   RowBox[{"Fold", "[", 
    RowBox[{"Table", ",", "0", ",", 
     RowBox[{"List", "/@", 
      RowBox[{"Table", "[", 
       RowBox[{"Dim", ",", 
        RowBox[{"{", "rnk", "}"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"f_", "[", "y__", "]"}], ",", "g_", ",", 
    RowBox[{"ord_:", "2"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"FuncRepRules", "[", 
    RowBox[{
     RowBox[{"f", "[", "y", "]"}], ",", "g", ",", "ord"}], "]"}], "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "y", "]"}], "->", "g"}], "}"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"indexList", "[", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"{", "y", "}"}], "]"}], ",", "ord"}], "]"}]}]}], "}"}], 
     ",", "\n", "       ", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"indL", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "[", "f", "]"}], "[",
             "y", "]"}], " ", "->", " ", "\n", "            ", 
           RowBox[{"Expand", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"D", "[", 
              RowBox[{"g", ",", 
               RowBox[{"Sequence", "@@", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", "y", "}"}], ",", 
                   RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}]}], "]"}],
              "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "indL", "]"}]}], "}"}]}], "]"}], ";", 
      "tmp$"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"indexList", "[", 
   RowBox[{"varNo_", ",", "ord_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp$", ",", "indL"}], "}"}], ",", 
    RowBox[{
     RowBox[{"tmp$", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{"RotateRight", ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"varNo", "-", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"varNo", "-", "1"}]}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ord", ">", "1"}], ",", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"indL", "=", "tmp$"}], ";", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"tmp$", "=", 
             RowBox[{"Join", "[", 
              RowBox[{"tmp$", ",", 
               RowBox[{"Map", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Plus", "[", 
                   RowBox[{
                    RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], 
                 ",", "indL"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "varNo"}], "}"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ord", "-", "1"}], "}"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"Union", "[", "tmp$", "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"MatrixForm", "[", "x", "]"}], "/;", 
    RowBox[{"Dim", "<", "10"}]}]}], ";", 
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", "x"}], ";", 
  RowBox[{"DeclareForms", "[", 
   RowBox[{"1", ",", 
    RowBox[{"e", "[", "_", "]"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"stPrint", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"y_", ":", "Null"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"y", "===", "Null"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
        RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontSlant", "\[Rule]", "\"\<Italic\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"timePrint", "[", 
    RowBox[{"x_", ",", "sT_"}], "]"}], ":=", 
   RowBox[{"Print", "[", 
    RowBox[{
     RowBox[{"x", "<>", "\"\< computed in \>\""}], ",", 
     RowBox[{
      RowBox[{"TimeUsed", "[", "]"}], "-", "sT"}], ",", "\"\< sec\>\""}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"myCoef$", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_SeriesData", ",", "y__"}], "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "->", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"#", ",", "y"}], "]"}], "&"}], ",", 
        RowBox[{"x", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_", ",", "y__"}], "]"}], ":=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{"gIN_", ",", "xIN_", ",", "opt___"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"frameOpt", "=", "0"}], ",", "eIN", ",", 
       RowBox[{"Ropt", "=", "True"}], ",", 
       RowBox[{"Wopt", "=", "True"}], ",", "idMat", ",", "eFrame", ",", 
       "dxRul", ",", "Bmat", ",", "Amat", ",", 
       RowBox[{"NP$", "=", "False"}], ",", "de", ",", "a", ",", "b", ",", "c",
        ",", "id", ",", "k", ",", "StrCon", ",", "\[Gamma]Udd", ",", 
       "\[Gamma]ddd", ",", "gddd", ",", "Gamddd", ",", "rmn", ",", "tmp", ",",
        "RUd", ",", "Rg", ",", "gg", ",", "sT", ",", "Cflat", ",", "EinSp"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"Clear", "[", 
       RowBox[{
       "GUdd", ",", "\[Omega]Ud", ",", "RUddd", ",", "Rdd", ",", "EUd", ",", 
        "R", ",", "Wdddd", ",", "detg", ",", "rtAbsdetg", ",", "eta", ",", 
        "HStar", ",", "PS", ",", "PH"}], "]"}], ";", "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Transpose", "[", "gIN", "]"}], "=!=", "gIN"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"MatrixForm", "[", "gIN", "]"}], ",", 
           "\"\< is not a symmetric matrix\>\""}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", " ", 
      RowBox[{"Dim", "=", 
       RowBox[{"Length", "[", "xIN", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Dim", "=!=", 
         RowBox[{"Length", "[", "gIN", "]"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{
          "\"\<Metric and coordinate dimensions don't match\>\"", ",", "1"}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"gIN", "===", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"NP$", "=", "True"}]}], "]"}], ";", 
      RowBox[{"eFrame", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"e", ",", 
         RowBox[{"{", "Dim", "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"frameOpt", "=", 
         RowBox[{"0", " ", "=", 
          RowBox[{">", " ", "coordFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"1", " ", "=", 
          RowBox[{">", " ", "explicitFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"2", " ", "=", 
          RowBox[{">", " ", "implicitFrame"}]}]}]}], " ", "*)"}], "\n", 
      "\t\t", "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"{", "opt", "}"}], "]"}], ">", "0"}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", "opt", "}"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "e"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", "dxRuleList", "]"}], "===", "List"}], "&&", 
              RowBox[{
               RowBox[{"Head", "[", "deList", "]"}], "===", "List"}]}], ",", 
             RowBox[{
              RowBox[{"frameOpt", "=", "2"}], ";", 
              RowBox[{"eIN", "=", "eFrame"}]}], ",", 
             RowBox[{
              RowBox[{"stPrint", "[", 
               RowBox[{
               "\"\<dxRuleList and/or deList have not been defined!\>\"", ",",
                 "1"}], "]"}], ";", 
              RowBox[{"Return", "[", "]"}]}]}], "]"}]}], "]"}], ";", "\n", 
         "\t", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"!", 
             RowBox[{"IntegerQ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "opt", "}"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"d", "[", "0", "]"}], "=!=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<matrixEDCcode.nb must be evaluated before section 2 \
RG&TC-Code!\>\"", ",", "1"}], "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "2"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{
               RowBox[{"{", "opt", "}"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"frameOpt", "=!=", "2"}], ",", 
              RowBox[{
               RowBox[{"eIN", "=", 
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ";", 
               RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{"IntegerQ", "[", 
             RowBox[{"opt", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{"opt", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"frameOpt", "=!=", "2"}], ",", 
             RowBox[{
              RowBox[{"eIN", "=", "opt"}], ";", 
              RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ",", "\n", "\t", 
           "True", ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<Wrong optional arguments!\>\"", ",", "1"}], "]"}], 
            ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"FreeQ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"gIN", ",", "eIN", ",", 
             RowBox[{"{", "deList", "}"}]}], "}"}], ",", "SeriesData"}], 
          "]"}]}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{"gIN", ",", "eIN", ",", 
                 RowBox[{"{", "deList", "}"}]}], "}"}], "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "SeriesData"}], 
               "&"}]}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"xIN", ",", "tmp"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"de", "[", "1", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<d\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{
             RowBox[{"de", "[", "2", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<\[ScriptD]\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{"DeclareForms", "[", 
             RowBox[{"1", ",", 
              RowBox[{"\[ScriptD]", "[", "_", "]"}], ",", 
              RowBox[{"de", "[", "1", "]"}], ",", 
              RowBox[{"de", "[", "2", "]"}]}], "]"}], ";", 
            RowBox[{
             RowBox[{"d", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "1", "]"}]}], ";", 
            RowBox[{
             RowBox[{"\[ScriptD]", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "2", "]"}]}], ";", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"de", "[", "1", "]"}], "]"}], "=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"d", "[", "tmp", "]"}], "=", "0"}]}], "]"}]}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "1"}], ",", 
        RowBox[{
         RowBox[{"DeclareForms", "[", 
          RowBox[{"1", ",", 
           RowBox[{"\[ScriptD]", "[", "_", "]"}]}], "]"}], ";", 
         RowBox[{"origFRin$", "=", 
          RowBox[{"eIN", "/.", 
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"d", "/@", "xIN"}], ",", 
               RowBox[{"\[ScriptD]", "/@", "xIN"}]}], "}"}]}], "]"}]}]}], ";", 
         RowBox[{"eTO$dx", "=", 
          RowBox[{"MapThread", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"e", "/@", 
               RowBox[{"Range", "[", "Dim", "]"}]}], ",", "origFRin$"}], 
             "}"}]}], "]"}]}]}]}], "]"}], ";", "\n", "\t\t\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"frameOpt", ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Union", "[", 
             RowBox[{"FormDegree", "/@", "eIN"}], "]"}], "=!=", 
            RowBox[{"{", "1", "}"}]}], "||", 
           RowBox[{
            RowBox[{"Length", "[", "eIN", "]"}], "=!=", "Dim"}], "||", 
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"eIN", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"e", "[", "_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"y_", "|", 
                  RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
                 RowBox[{"0", "/;", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}],
              "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{"\"\<coframe has incorrect form\>\"", ",", "1"}], "]"}], 
         ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\t", "\n", "\t\t", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "Rule"}], "||", 
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "RuleDelayed"}]}], 
        ",", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "simpRules", "}"}]}]}], "]"}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "simpRules", "]"}], "=!=", "List"}], ",", " ", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "}"}]}]}], "]"}], ";", 
      RowBox[{"idMat", "=", 
       RowBox[{"IdentityMatrix", "[", "Dim", "]"}]}], ";", "\n", "\n", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Amat", "=", "idMat"}], ";", 
         RowBox[{"Bmat", "=", "idMat"}], ";", 
         RowBox[{"eIN", "=", 
          RowBox[{"d", "/@", "xIN"}]}], ";", 
         RowBox[{"dxRul", "=", 
          RowBox[{"{", "}"}]}]}], ",", "\n", 
        RowBox[{
         RowBox[{"frameOpt", "===", "1"}], "&&", 
         RowBox[{"zeroQ", "[", 
          RowBox[{"eIN", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
             RowBox[{
              RowBox[{"y_", "|", 
               RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
              RowBox[{"0", "/;", 
               RowBox[{"MemberQ", "[", 
                RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{"Bmat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"eIN", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"d", "[", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "b", "]"}], "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Det", "[", "Bmat", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sT", "=", 
             RowBox[{"TimeUsed", "[", "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ByteCount", "[", "eIN", "]"}], ">", 
               RowBox[{"1500", "*", "Dim"}]}], ",", 
              RowBox[{"stPrint", "[", 
               RowBox[{"\"\<Computing d[coframe]...\>\"", ",", "1"}], "]"}]}],
              "]"}], ";", 
            RowBox[{"Amat", "=", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Inverse", "[", "Bmat", "]"}], "]"}]}], ";", 
            RowBox[{"dxRul", "=", 
             RowBox[{"MapThread", "[", 
              RowBox[{"Rule", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"d", "[", "xIN", "]"}], ",", 
                 RowBox[{"Amat", ".", "eFrame"}]}], "}"}]}], "]"}]}], ";", 
            RowBox[{"de", "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"FreeQ", "[", 
                RowBox[{"eIN", ",", "SeriesData"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{
                 RowBox[{"d", "[", "eIN", "]"}], "/.", "dxRul"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{"Wedge", "[", 
                 RowBox[{
                  RowBox[{"FacSimp", "[", 
                   RowBox[{
                    RowBox[{"FacSimp", "[", 
                    RowBox[{"d", "[", "Bmat", "]"}], "]"}], "/.", "dxRul"}], 
                   "]"}], ",", 
                  RowBox[{
                   RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], "]"}], 
                "]"}]}], "]"}]}], ";", 
            RowBox[{"timePrint", "[", 
             RowBox[{"\"\<d[coframe]\>\"", ",", "sT"}], "]"}], ";", 
            RowBox[{"tmp", "=", 
             RowBox[{
              RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
            RowBox[{"MapThread", "[", 
             RowBox[{"Set", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], 
             "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<coframe does not span space!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}], ",", "\n", 
        RowBox[{"frameOpt", "===", "2"}], ",", 
        RowBox[{
         RowBox[{"de", "=", "deList"}], ";", 
         RowBox[{"dxRul", "=", "dxRuleList"}], ";", 
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
         RowBox[{"MapThread", "[", 
          RowBox[{"Set", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], "]"}], 
         ";", 
         RowBox[{"Amat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"tmp", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"eIN", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
      "\n", "\t\t", "\n", 
      RowBox[{"k", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "x_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "x_Symbol"}], ")"}], "b_."]}], "->", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["x", "2"]}], ")"}], "b"]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "-", "y_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "+", "y_Symbol"}], ")"}], "b_."]}], 
          "\[Rule]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "-", 
             SuperscriptBox["y", "2"]}], ")"}], "b"]}]}], "}"}]}], ";", 
      RowBox[{"gdd", "=", "gIN"}], ";", 
      RowBox[{"coordList", "=", "xIN"}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gdd = \>\"", ",", 
        RowBox[{"MF", "[", "gdd", "]"}]}], "]"}], ";", 
      RowBox[{"tmp", "=", 
       RowBox[{"eIN", ".", "gIN", ".", "eIN"}]}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = \>\"", ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "tmp", "]"}], "===", "SeriesData"}], ",", 
           RowBox[{"FacSimp", "[", "tmp", "]"}], ",", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Expand", "[", "tmp", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], 
                RowBox[{"d", "[", "b_", "]"}]}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], 
                RowBox[{"e", "[", "b_", "]"}]}]}], "}"}], ",", "Factor"}], 
            "]"}]}], "]"}], "//.", "k"}]}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"gUU", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Inverse", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      RowBox[{"detg", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Det", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      "\n", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gUU = \>\"", ",", 
        RowBox[{"MF", "[", "gUU", "]"}]}], "]"}], ";", 
      RowBox[{"Clear", "[", "k", "]"}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<gUU\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"rtAbsdetg", "=", 
       RowBox[{"PowerExpand", "[", 
        RowBox[{"Power", "[", 
         RowBox[{
          RowBox[{"Factor", "[", 
           RowBox[{"detg", "^", "2"}], "]"}], ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"SetAttributes", "[", 
       RowBox[{"HStar", ",", 
        RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", 
        RowBox[{"rtAbsdetg", "=", "I"}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_SeriesData", "]"}], ":=", 
       RowBox[{"x", "/.", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "->", 
         RowBox[{"HStar", "/@", 
          RowBox[{"x", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}]}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Plus", "]"}], ":=", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Plus", "@@", 
         RowBox[{"HStar", "/@", "x"}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_", "*", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"HStar", "[", "y", "]"}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Wedge", "@@", 
          RowBox[{"e", "/@", 
           RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Wedge", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", "/", "detg"}], "/;", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], "===", "Dim"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_Wedge", "|", "x_e"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"HStar", "[", "x", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"FacSimp", "[", 
          RowBox[{"inn", "[", 
           RowBox[{"x", ",", 
            RowBox[{"Wedge", "@@", 
             RowBox[{"e", "/@", 
              RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "]"}], "]"}]}]}]}], 
      ";", "\t\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Array", "[", 
          RowBox[{"epsilon", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", "Dim", "}"}]}], "]"}]}], "]"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "a__", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "a", "]"}], "=", 
        RowBox[{"Raise", "[", 
         RowBox[{
          RowBox[{"eta", "[", "]"}], ",", "a"}], "]"}]}]}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"e", "[", "a_", "]"}], "]"}], ":=", 
          RowBox[{"de", "[", 
           RowBox[{"[", "a", "]"}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "a_"}], "]"}], "=", "0"}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"StrCon", "[", 
             RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{"-", 
           RowBox[{"myCoef$", "[", 
            RowBox[{
             RowBox[{"de", "[", 
              RowBox[{"[", "c", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"e", "[", "a", "]"}], "\[Wedge]", 
              RowBox[{"e", "[", "b", "]"}]}]}], "]"}]}]}], ";", "\n", 
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"StrCon", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", 
          RowBox[{"gdd", ".", "\[Gamma]Udd"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"zeroTensor", "[", "3", "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", "\[Gamma]Udd"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"(*", 
       RowBox[{"*", " ", "Tests"}], " ", "**)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "[", "gdd", "]"}], "/.", "dxRul"}], ")"}], "/.", 
           RowBox[{
            RowBox[{"e", "[", "_", "]"}], "->", "0"}]}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<Warning: d[] on some symbols not defined!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Print", "[", 
             RowBox[{"indepTerms", "[", 
              RowBox[{"FacSimp", "[", "tmp", "]"}], "]"}], "]"}]}]}], "]"}], 
         ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"frameOpt", "===", "2"}], "&&", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ByteCount", "[", "deList", "]"}], "+", 
                RowBox[{"ByteCount", "[", "dxRuleList", "]"}]}], ")"}], "/", 
              "Dim"}], "<", "6000"}]}], ",", 
           RowBox[{
            RowBox[{"tmp", "=", 
             RowBox[{"FacSimp", "[", 
              RowBox[{"d", "[", "deList", "]"}], "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
              RowBox[{
               RowBox[{"stPrint", "[", 
                RowBox[{
                "\"\<Warning: deList not closed! d[deList]=\>\"", ",", "1"}], 
                "]"}], ";", 
               RowBox[{"Print", "[", "tmp", "]"}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"!", 
                  RowBox[{"zeroQ", "[", 
                   RowBox[{"tmp", "/.", 
                    RowBox[{
                    RowBox[{"d", "[", "_", "]"}], "->", "0"}]}], "]"}]}], ",", 
                 RowBox[{"Return", "[", "]"}]}], "]"}]}]}], "]"}]}]}], 
          "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "pD", "]"}], ";", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"pD", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Amat", "===", "idMat"}], ",", 
          RowBox[{"D", "[", 
           RowBox[{"x", ",", 
            RowBox[{"coordList", "[", 
             RowBox[{"[", "y", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "y"}], "]"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"x", ",", 
               RowBox[{"coordList", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}]}], "]"}]}]}], ";", 
      "\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "c"}], "]"}], "]"}], ",", "b"}], "]"}], "+", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"b", ",", "c"}], "]"}], "]"}], ",", "a"}], "]"}], "-", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "b"}], "]"}], "]"}], ",", "c"}], "]"}]}], 
           ")"}], "/", "2"}], "]"}]}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"gddd", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"Clear", "[", "tmp", "]"}], ";", 
         RowBox[{"k", "=", 
          RowBox[{"gUU", ".", "Gamddd"}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"k", "[", 
             RowBox[{"[", 
              RowBox[{"c", ",", "a", ",", "b"}], "]"}], "]"}], "]"}]}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}]}], ",",
         "\n", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{
            RowBox[{"Array", "[", 
             RowBox[{"gddd", ",", 
              RowBox[{"{", 
               RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Gamma]ddd", "+", 
               RowBox[{"Transpose", "[", "\[Gamma]ddd", "]"}], "-", 
               RowBox[{"Transpose", "[", 
                RowBox[{"\[Gamma]ddd", ",", 
                 RowBox[{"{", 
                  RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], "]"}]}], ")"}], 
             "/", "2"}]}], "]"}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Union", "[", 
               RowBox[{"NumericQ", "/@", 
                RowBox[{"Flatten", "[", "gUU", "]"}]}], "]"}], "===", 
              RowBox[{"{", "True", "}"}]}], "&&", 
             RowBox[{
              RowBox[{"nonZeroN", "[", "gUU", "]"}], "===", "Dim"}]}], ",", 
            RowBox[{"gUU", ".", "Gamddd"}], ",", 
            RowBox[{"FaSi", "[", 
             RowBox[{"gUU", ".", "Gamddd"}], "]"}]}], "]"}]}]}]}], "]"}], ";",
       "\n", "\t\t", "\n", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Gamma\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{"\[Omega]Ud", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], 
              RowBox[{"e", "[", "k", "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"a", ",", "Dim"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
      RowBox[{
       RowBox[{"rmn", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"rmn", "[", 
         RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "id", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "c", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"\[Gamma]Udd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "id"}], "]"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdddd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"rmn", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
        "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Riemann(dddd)\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdddd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Flat Space!\>\"", "]"}], ";", 
         RowBox[{"Clear", "[", 
          RowBox[{"Rdd", ",", "EUd", ",", "R", ",", "Wdddd"}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Rg", "=", 
       RowBox[{"gUU", ".", "Rdddd"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{"Ropt", ",", 
        RowBox[{
         RowBox[{"Clear", "[", "rmn", "]"}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}],
          ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"rmn", "[", 
             RowBox[{"a", ",", "b", ",", "id", ",", "c"}], "]"}]}], "/;", 
           RowBox[{"c", ">", "id"}]}]}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"rmn", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"Rg", "[", 
             RowBox[{"[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "]"}], 
            "]"}]}]}], ";", 
         RowBox[{"RUddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"rmn", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Riemann(Uddd)\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"Rg", "=", "RUddd"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<RUddd not computed\>\"", ",", "1"}], "]"}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "tmp", "]"}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Rg", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "a", ",", "k", ",", "b"}], "]"}], "]"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", 
      "\t\t\t\t", "\n", 
      RowBox[{"RUd", "=", 
       RowBox[{"gUU", ".", "Rdd"}]}], ";", 
      RowBox[{"R", "=", 
       RowBox[{"FaSi", "[", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"RUd", "[", 
           RowBox[{"[", 
            RowBox[{"a", ",", "a"}], "]"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"a", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Ricci\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Wopt", "||", 
         RowBox[{"Dim", "<", "4"}]}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"Dim", ">", "3"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
             RowBox[{"Wdddd", "=", "Rdddd"}], ",", "\n", "\t", 
             RowBox[{
              RowBox[{"gg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "gdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"gg", "=", 
               RowBox[{"gg", "-", 
                RowBox[{"Transpose", "[", "gg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "Rdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", "Rg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"Rg", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}]}], 
                 "]"}]}]}], ";", "\n", 
              RowBox[{"Clear", "[", "rmn", "]"}], ";", 
              RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
              RowBox[{
               RowBox[{"rmn", "[", 
                RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
               RowBox[{
                RowBox[{"rmn", "[", 
                 RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
                RowBox[{"FaSi", "[", 
                 RowBox[{
                  RowBox[{"Rdddd", "[", 
                   RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                   "]"}], "-", 
                  RowBox[{
                   RowBox[{"Rg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], "+", 
                  RowBox[{"R", " ", 
                   RowBox[{
                    RowBox[{"gg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], ")"}]}]}]}], 
                 "]"}]}]}], ";", 
              RowBox[{"Wdddd", "=", 
               RowBox[{"Array", "[", 
                RowBox[{"rmn", ",", 
                 RowBox[{"{", 
                  RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], 
                  "}"}]}], "]"}]}]}]}], "]"}], ",", 
           RowBox[{"Wdddd", "=", 
            RowBox[{"zeroTensor", "[", "4", "]"}]}]}], "]"}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Weyl\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", "Wdddd", "]"}], ",", 
           RowBox[{
            RowBox[{"Cflat", "=", "True"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dim", "=!=", "3"}], "||", 
               RowBox[{"zeroQ", "[", "CF3d", "]"}]}], ",", 
              RowBox[{"stPrint", "[", "\"\<Conformally Flat\>\"", "]"}]}], 
             "]"}]}]}], "]"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<Weyl tensor not computed\>\"", ",", "1"}], "]"}]}], 
       "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Ricci Flat\>\"", "]"}], ";", 
         RowBox[{"EUd", "=", "Rdd"}]}], ",", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"EUd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{"RUd", " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], " ", "R", "*", "idMat"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Einstein\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", 
            RowBox[{"EUd", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "-", 
                RowBox[{"1", "/", "Dim"}]}], ")"}], "R", "*", "idMat"}]}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", "\"\<Einstein Space\>\"", "]"}], ";", 
            RowBox[{"EinSp", "=", "True"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", ">", "2"}], "&&", "Cflat", "&&", "EinSp"}], ")"}], "||", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", "===", "2"}], "&&", 
           RowBox[{"zeroQ", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"covD", "[", "R", "]"}], "]"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
        "stPrint", "[", "\"\<Space of Constant Curvature!\>\"", "]"}]}], 
       "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", "NPdefs"}], "]"}], ";"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CF3d", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"stPrint", "[", 
      RowBox[{"\"\<Testing for 3-dim conformal flatness...\>\"", ",", "1"}], 
      "]"}], ";", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tmp$", "=", 
         RowBox[{
          RowBox[{"covD", "[", "Rdd", "]"}], "-", 
          RowBox[{"Outer", "[", 
           RowBox[{"Times", ",", "gdd", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"covD", "[", "R", "]"}], "/", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{"Dim", "-", "1"}], ")"}]}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"FaSi", "[", 
        RowBox[{"tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], 
      "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NPdefs", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "4"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{"FaSi", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ")"}], "/", "4"}], 
       "]"}]}], ";", 
     RowBox[{"\[CapitalLambda]", "=", 
      RowBox[{
       RowBox[{"-", "R"}], "/", 
       RowBox[{"2", "4"}]}]}], ";", 
     RowBox[{
     "tmp$", " ", "=", " ", 
      "\"\<NP variables PH[i,j], \[CapitalLambda] \>\""}], ";", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "Wdddd", "]"}], " ", "=!=", " ", "Symbol"}], ",",
        " ", 
       RowBox[{
        RowBox[{
         RowBox[{"PS", "[", "0", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "2", ",", "4"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "1", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4", ",", "2", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "2", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "3", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "4", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{"tmp$", " ", "=", " ", 
         RowBox[{"StringJoin", "[", 
          RowBox[{"tmp$", ",", " ", "\"\<and PS[i] \>\""}], "]"}]}]}]}], 
      "]"}], ";", " ", 
     RowBox[{"stPrint", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"tmp$", ",", " ", "\"\<defined.\>\""}], "]"}], ",", " ", 
       "1"}], "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{"y_Wedge", ",", "x_"}], "]"}], ":=", 
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"Rest", "[", "y", "]"}], ",", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"First", "[", "y", "]"}], ",", "x"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "+", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "x"}], "]"}], "+", 
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "*", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "*", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_"}], "]"}], ":=", 
   RowBox[{"0", "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_Wedge"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", 
       RowBox[{"First", "[", "x", "]"}]}], "]"}], "*", 
     RowBox[{"Rest", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", 
      RowBox[{"FormDegree", "[", 
       RowBox[{"First", "[", "x", "]"}], "]"}]}], "*", 
     RowBox[{
      RowBox[{"First", "[", "x", "]"}], "\[Wedge]", 
      RowBox[{"inn", "[", 
       RowBox[{
        RowBox[{"e", "[", "a", "]"}], ",", 
        RowBox[{"Rest", "[", "x", "]"}]}], "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"e", "[", "b_", "]"}]}], "]"}], ":=", 
   RowBox[{"gUU", "[", 
    RowBox[{"[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MoveIndex", "[", 
    RowBox[{"x_", ",", "i_", ",", "g_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "indL"}], "}"}], ",", 
     "\n", "    ", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"i", "===", "1"}], ",", 
       RowBox[{"g", ".", "x"}], ",", 
       RowBox[{"i", "===", "rnk1"}], ",", 
       RowBox[{"x", ".", "g"}], ",", "True", ",", 
       RowBox[{
        RowBox[{"indL", "=", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "->", "1"}], ",", 
            RowBox[{"1", "->", "i"}]}], "}"}]}]}], ";", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"g", ".", 
           RowBox[{"Transpose", "[", 
            RowBox[{"x", ",", "indL"}], "]"}]}], ",", "indL"}], "]"}]}]}], 
      "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lower", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gdd"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Raise", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gUU"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"multiDot", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"rnk2", "=", 
        RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Sort", "/@", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", "indPr", "}"}], "]"}]}]}], ",", 
       RowBox[{"ordPr", "=", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}], "||", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk2"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ordPr", "]"}], "===", "1"}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotOne", "[", 
          RowBox[{"x", ",", "y", ",", "indPr"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"rnk1", "===", "rnk2"}], "&&", 
         RowBox[{"rnk1", "===", 
          RowBox[{"Length", "[", "ordPr", "]"}]}]}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotAll", "[", 
          RowBox[{"x", ",", "y", ",", "ordPr"}], "]"}], "]"}], ",", "True", 
        ",", 
        RowBox[{"OKindCon", "[", 
         RowBox[{
          RowBox[{"dotOne", "[", 
           RowBox[{"x", ",", "y", ",", 
            RowBox[{"ordPr", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"renumb", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"ordPr", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], "/@", 
           RowBox[{"Rest", "[", "ordPr", "]"}]}]}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"renumb", "[", 
     RowBox[{"rnk_", ",", "j_"}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_"}], "}"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"j", ">", "b"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "2"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dotOne", "[", 
   RowBox[{"x_", ",", "y_", ",", 
    RowBox[{"{", 
     RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rnk1", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
      RowBox[{"rnk2", "=", 
       RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
      RowBox[{"tmp$", "=", 
       RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmp$", "===", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
       RowBox[{"tmp$", "=", "Wedge"}], ",", 
       RowBox[{"tmp$", "=", "Dot"}]}], "]"}], ";", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{"tmp$", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"x", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk1", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rnk1", "\[Rule]", "i"}], ",", 
              RowBox[{"i", "\[Rule]", "rnk1"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk2", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"j", "\[Rule]", "1"}], ",", 
              RowBox[{"1", "\[Rule]", "j"}]}], "}"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"rnk1", "+", "j", "-", "2"}]}], "]"}], ",", "1"}], "]"}],
          ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"rnk1", "+", "j", "-", "1"}], ",", 
           RowBox[{"rnk1", "+", "rnk2", "-", "2"}]}], "]"}]}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dotAll", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s$", ",", "allInd", ",", "sumInd", ",", 
       RowBox[{"tmp$", "=", 
        RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"allInd", "=", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{"s$", ",", 
          RowBox[{"Transpose", "[", "indPr", "]"}], ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], "/.", 
        RowBox[{
         RowBox[{"s$", "[", "i_", "]"}], ":>", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<s$\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
      RowBox[{"sumInd", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"allInd", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", 
              RowBox[{"allInd", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}]}], "}"}],
         "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tmp$", "===", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
        RowBox[{"tmp$", "=", "Wedge"}], ",", 
        RowBox[{"tmp$", "=", "Times"}]}], "]"}], ";", 
      RowBox[{"Sum", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Unevaluated", "[", 
          RowBox[{"tmp$", "[", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
            RowBox[{"y", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
          "]"}], ",", 
         RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"x_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Union", "[", "indL", "]"}], "]"}], "<", 
         RowBox[{"Length", "[", "indL", "]"}]}], "||", 
        RowBox[{
         RowBox[{"Length", "[", "indL", "]"}], ">", "rnk1"}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Sort", "[", "indL", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}]}], ",", 
       RowBox[{"errWarn", ";", 
        RowBox[{"Return", "[", "]"}]}], ",", 
       RowBox[{"OKindCon", "[", 
        RowBox[{"x", ",", 
         RowBox[{"Sort", "[", 
          RowBox[{"Sort", "/@", 
           RowBox[{"{", "indPr", "}"}]}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"newPrList", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Rest", "[", "x", "]"}], "-", "1"}], "/.", 
    RowBox[{"k_", ":>", 
     RowBox[{
      RowBox[{"k", "-", "1"}], "/;", 
      RowBox[{"k", ">", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", "1"}]}]}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"FacSimp", "[", 
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", "indPr", "]"}], "===", "1"}]}]}], ";", 
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s$", ",", "allInd", ",", "sumInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"TensorRank", "[", "x", "]"}], "]"}], "/.", 
          RowBox[{"Apply", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"Apply", "[", 
             RowBox[{"Sequence", ",", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Transpose", "[", 
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{
                    RowBox[{"s$", "[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}], "]"}], "&"}], 
                ",", "indPr"}], "]"}], ",", "1"}], "]"}], ",", "1"}], "]"}]}],
          "/.", 
         RowBox[{
          RowBox[{"s$", "[", "i_", "]"}], ":>", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<s$\>\"", "<>", 
            RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
       RowBox[{"sumInd", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Union", "[", "allInd", "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "allInd", "]"}], "/", "2"}], "}"}]}], 
            "]"}]}], "}"}], "]"}]}], ";", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Sum", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Unevaluated", "[", 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}], "]"}]}]}], "]"}], 
    "/;", 
    RowBox[{
     RowBox[{"TensorRank", "[", "x", "]"}], "===", 
     RowBox[{"2", 
      RowBox[{"Length", "[", "indPr", "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"OKindCon", "[", 
    RowBox[{
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"newPrList", "[", "indPr", "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ConOne", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "tr1List", ",", 
       "tr2List"}], "}"}], ",", 
     RowBox[{
      RowBox[{"tr1List", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"j", "->", "i"}], "}"}]}], ")"}], "/.", 
        RowBox[{"k_", ":>", 
         RowBox[{
          RowBox[{"k", "-", "1"}], "/;", 
          RowBox[{"k", ">", "j"}]}]}]}]}], ";", 
      RowBox[{"tr2List", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}]}], 
        "]"}]}], ";", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"x", ",", "tr1List"}], "]"}], ",", "tr2List"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"rnk1", "-", "2"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"errWarn", ":=", 
   RowBox[{"stPrint", "[", 
    RowBox[{"\"\<Wrong tensor rank or number(s) of indices!\>\"", ",", "1"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covDiv", "[", 
    RowBox[{"x_", ",", "UpList_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{"x", ",", "UpList"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k", "=", 
         RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "divInd", ",", 
        "allInd", ",", "freeInd", ",", "hhD", ",", "s", ",", "lt", ",", 
        "aInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{
            RowBox[{"Sort", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{"Head", "[", "x", "]"}], "=!=", "List"}]}], ",", 
         RowBox[{"errWarn", ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "1"}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"Select", "[", 
             RowBox[{"UpList", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "List"}], "&"}]}], 
             "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", "UpList", "}"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"aInd", "/@", 
           RowBox[{"Range", "[", "k", "]"}]}], ")"}], "/.", 
         RowBox[{
          RowBox[{"aInd", "[", "divInd", "]"}], "->", "s"}]}]}], ";", 
       RowBox[{"freeInd", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"allInd", ",", 
          RowBox[{
           RowBox[{"#", "=!=", "s"}], "&"}]}], "]"}]}], ";", 
       RowBox[{"Off", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"lt", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$VersionNumber", "<", "3.5"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"hhD", "[", 
                RowBox[{
                 RowBox[{"x", "[", 
                  RowBox[{"[", 
                   RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                 "s"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "+", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], "]"}],
                  ",", 
                 RowBox[{
                  RowBox[{"GUdd", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "Dim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Unevaluated", "[", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"hhD", "[", 
                 RowBox[{
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                  "s"}], "]"}], "+", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], 
                    "]"}], ",", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "]"}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"k", " ", ">", "1"}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{"Table", "@@", "lt"}]}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"pD", "[", 
              RowBox[{
               RowBox[{"x", "[", 
                RowBox[{"[", "s$", "]"}], "]"}], ",", "s$"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"s$", ",", "s$", ",", "j"}], "]"}], "]"}], 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "Dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
       RowBox[{"On", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       RowBox[{"Return", "[", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"lt", "/.", 
           RowBox[{"hhD", "->", "pD"}]}], "]"}], "]"}], "]"}]}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"c$D", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_", ",", "y_List"}], "]"}], ":=", "errWarn"}], ";", 
  RowBox[{
   RowBox[{"covD", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", "x", "]"}], "=", 
    RowBox[{"c$D", "[", "x", "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c$D", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"UpList_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
           RowBox[{
            RowBox[{
             RowBox[{"Sort", "[", 
              RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], 
             "\[LeftDoubleBracket]", 
             RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ">", "k"}]}], 
          ")"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "x", "]"}], "===", "List"}], ",", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{"cDcomp", "[", 
           RowBox[{"x", ",", "k", ",", "UpList"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"k", "+", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"pD", "[", 
            RowBox[{"x", ",", "i"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cDcomp", "[", 
     RowBox[{"x_", ",", "rnk_", ",", 
      RowBox[{"UpList_:", 
       RowBox[{"{", "}"}]}]}], "]"}], "[", "y__", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y$", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"{", "y", "}"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ",", 
       RowBox[{"z$", "=", 
        RowBox[{
         RowBox[{"{", "y", "}"}], "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", "y$"}], "]"}], "]"}], ",", "z$"}], "]"}],
        "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"UpList", ",", "i"}], "]"}], ",", 
           RowBox[{
            RowBox[{"GUdd", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"y$", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "z$", ",", "j"}], "]"}], 
             "]"}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}], 
           ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "z$", ",", 
                RowBox[{"y$", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}]}],
           "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "Dim"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "rnk"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "0", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdddd", "]"}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{"indepTerms", "[", 
       RowBox[{"tmp$", "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}]}], 
         "]"}], "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "5", ",", "3", ",", "4"}], "}"}]}], 
         "]"}]}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "1", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdd", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "RUddd", "]"}], "===", "Symbol"}], ",", 
        RowBox[{"RUddd", "=", 
         RowBox[{"Raise", "[", 
          RowBox[{"Rdddd", ",", "1"}], "]"}]}]}], "]"}], ";", 
      RowBox[{"FaSi", "[", 
       RowBox[{"indepTerms", "[", 
        RowBox[{
         RowBox[{"covDiv", "[", 
          RowBox[{"RUddd", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}], "+", "tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "2", "]"}], ":=", 
   RowBox[{"indepTerms", "[", 
    RowBox[{"covDiv", "[", 
     RowBox[{"EUd", ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PrePrint", "=", " ", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ByteCount", "[", "#", "]"}], " ", ">", " ", "200000"}], ",", 
      RowBox[{"Short", "[", 
       RowBox[{"#", ",", "100"}], "]"}], ",", " ", "#"}], "]"}], "&"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{
   "cDcomp", ",", "CF3d", ",", "ConOne", ",", "c$D", ",", "dotAll", ",", 
    "dotOne", ",", "epsilon", ",", "errWarn", ",", "FacSimp", ",", "FaSi", 
    ",", "indexList", ",", "inn", ",", "MF", ",", "MoveIndex", ",", 
    "newPrList", ",", "NPdefs", ",", "numb1", ",", "numb2", ",", "OKindCon", 
    ",", "redPlus", ",", "redTimes", ",", "renumb", ",", "RiemSym", ",", 
    "zeroTensor"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.6205808502542887`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Background geometry", "Chapter",
 CellChangeTimes->{{3.624040920155903*^9, 3.6240409216247253`*^9}, {
  3.7719604547944355`*^9, 3.7719604560033937`*^9}}],

Cell[CellGroupData[{

Cell["Model and lagrangian", "Section",
 CellChangeTimes->{{3.62400950390606*^9, 3.6240095065468335`*^9}}],

Cell[TextData[StyleBox["Let us define our metric and the perturbations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719604814051*^9, 3.771960488854295*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "u"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "2"]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", 
       RowBox[{"NN", "[", "u", "]"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.570167330426721*^9, {3.570167711460515*^9, 3.5701677604433165`*^9}, {
   3.5701875806651926`*^9, 3.570187583672364*^9}, {3.5701876605677624`*^9, 
   3.5701876639509563`*^9}, {3.570187735649057*^9, 3.570187745717633*^9}, {
   3.5701886532425404`*^9, 3.5701886590188704`*^9}, {3.5710344839574785`*^9, 
   3.5710345490622025`*^9}, {3.5710565998820677`*^9, 3.571056609206601*^9}, {
   3.571056688575141*^9, 3.5710566960055656`*^9}, {3.571057753245036*^9, 
   3.5710577696369743`*^9}, {3.5710584597704477`*^9, 3.571058487839053*^9}, {
   3.571162597044566*^9, 3.571162634373329*^9}, {3.572352151919235*^9, 
   3.5723521744285226`*^9}, {3.5723527649783*^9, 3.572352805412613*^9}, {
   3.5723544810774555`*^9, 3.572354481370472*^9}, {3.572783907767783*^9, 
   3.572783910698951*^9}, {3.5727852817183685`*^9, 3.5727852851825666`*^9}, {
   3.572847181580718*^9, 3.572847187575061*^9}, {3.5728479839206095`*^9, 
   3.572848013493301*^9}, {3.5728683898720317`*^9, 3.5728684127023373`*^9}, {
   3.5768411793242626`*^9, 3.5768411960782213`*^9}, {3.576841393342504*^9, 
   3.576841400301902*^9}, {3.588570366786084*^9, 3.588570605641746*^9}, {
   3.588676297756776*^9, 3.588676313015649*^9}, {3.588679147362764*^9, 
   3.588679147494772*^9}, {3.589176462654968*^9, 3.5891764682232866`*^9}, {
   3.5891765005721364`*^9, 3.5891765490069065`*^9}, {3.5891765827008343`*^9, 
   3.5891766018889313`*^9}, {3.589176698654466*^9, 3.5891767473842535`*^9}, {
   3.5891781666334295`*^9, 3.5891781823983316`*^9}, {3.5892026584710283`*^9, 
   3.58920267756212*^9}, {3.5892027244858036`*^9, 3.589202733565323*^9}, {
   3.5892038518332844`*^9, 3.589203878423805*^9}, {3.5892057669598236`*^9, 
   3.5892057873969927`*^9}, {3.58920631763332*^9, 3.589206320231469*^9}, {
   3.589207357322787*^9, 3.589207393252842*^9}, {3.5896209102385693`*^9, 
   3.5896209119556675`*^9}, {3.5896210590570817`*^9, 3.589621064654402*^9}, {
   3.5907551876956787`*^9, 3.5907552091219044`*^9}, {3.5907566716935587`*^9, 
   3.5907566860873823`*^9}, {3.592217073930195*^9, 3.5922171581900144`*^9}, {
   3.59256777152232*^9, 3.592567782218931*^9}, {3.5927224828902206`*^9, 
   3.5927225021913247`*^9}, {3.592755344267173*^9, 3.592755345044217*^9}, {
   3.5927555533841333`*^9, 3.592755559335474*^9}, 3.592755679146327*^9, {
   3.592914201124915*^9, 3.5929142298985605`*^9}, {3.592914325799046*^9, 
   3.5929143259670553`*^9}, {3.5931684118583736`*^9, 3.593168433449609*^9}, {
   3.593168691672378*^9, 3.593168692003397*^9}, {3.593177947440778*^9, 
   3.5931779569343204`*^9}, {3.5932379656937857`*^9, 
   3.5932379657697897`*^9}, {3.5939694634234915`*^9, 
   3.5939694642905407`*^9}, {3.612679384297059*^9, 3.6126794442260604`*^9}, 
   3.612891633755241*^9, {3.6128925243427753`*^9, 3.6128925729956837`*^9}, {
   3.6128930187745657`*^9, 3.6128930511441402`*^9}, {3.612902044032016*^9, 
   3.612902045532769*^9}, {3.619853651851103*^9, 3.619853652299033*^9}, {
   3.62002395456089*^9, 3.6200239553877697`*^9}, {3.620378552850563*^9, 
   3.62037858294659*^9}, {3.620378635267205*^9, 3.620378639328519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g", ",", "xCoord"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "2"]}], 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "0", "0"},
       {
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]},
       {"0", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], "0"},
       {"0", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "0", 
        RowBox[{"NN", "[", "u", "]"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-$CellContext`at[$CellContext`u]^2, $CellContext`\[Epsilon] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y], 0, 
      0}, {$CellContext`\[Epsilon] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y], $CellContext`ax[$CellContext`u]^2, \
$CellContext`\[Epsilon] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y], $CellContext`\[Epsilon] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, {
     0, $CellContext`\[Epsilon] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y], $CellContext`ax[$CellContext`u]^2, 0}, {
     0, $CellContext`\[Epsilon] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y], 0, 
      $CellContext`NN[$CellContext`u]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.7719608324604745`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(ds\\), \\(2\\)]\\) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "x", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "y", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "u", "]"}], "2"], " ", 
     RowBox[{"NN", "[", "u", "]"}]}], "+", 
    RowBox[{"2", " ", "\[Epsilon]", " ", 
     RowBox[{"d", "[", "t", "]"}], " ", 
     RowBox[{"d", "[", "x", "]"}], " ", 
     RowBox[{"\[Delta]Gtx", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[Epsilon]", " ", 
     RowBox[{"d", "[", "u", "]"}], " ", 
     RowBox[{"d", "[", "x", "]"}], " ", 
     RowBox[{"\[Delta]Gxu", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[Epsilon]", " ", 
     RowBox[{"d", "[", "x", "]"}], " ", 
     RowBox[{"d", "[", "y", "]"}], " ", 
     RowBox[{"\[Delta]Gxy", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}],
  SequenceForm[
  "\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = ", \
-$CellContext`at[$CellContext`u]^2 $CellContext`d[$CellContext`t]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`x]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`y]^2 + \
$CellContext`d[$CellContext`u]^2 $CellContext`NN[$CellContext`u] + 
   2 $CellContext`\[Epsilon] $CellContext`d[$CellContext`t] \
$CellContext`d[$CellContext`x] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] + 
   2 $CellContext`\[Epsilon] $CellContext`d[$CellContext`u] \
$CellContext`d[$CellContext`x] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] + 
   2 $CellContext`\[Epsilon] $CellContext`d[$CellContext`x] \
$CellContext`d[$CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.771960832466942*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gtx", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}]},
       {
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gtx", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gxy", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"\[Delta]Gxu", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gxy", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}]},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"\[Delta]Gxu", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{-($CellContext`ax[$CellContext`u]^4 \
$CellContext`NN[$CellContext`u] - $CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}, {$CellContext`\[Epsilon] \
$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}, {-$CellContext`\[Epsilon]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), ($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`NN[$CellContext`u] $CellContext`\
\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y]^2 - $CellContext`\
\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]^2)/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}, {-$CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), ($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 + $CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.7719608325956564`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.016000000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.016000000000000014`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.7719608326157427`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.07799999999999985`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.07799999999999985, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.771960832622754*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.4690000000000001`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.4690000000000001, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.7719608331062574`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", "8.25`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 8.25, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.7719608418363495`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "2.9529999999999994`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 2.9529999999999994`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.77196084492375*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "18.609`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 18.609, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.771960865077283*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "15.562000000000001`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 15.562000000000001`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.6240095285634937`*^9, 3.6240335783119736`*^9, 3.624040773559617*^9, 
   3.624082625897971*^9, 3.6241099665481873`*^9, 3.6241103199089484`*^9, 
   3.6242152806513796`*^9, 3.624343264480384*^9, 3.6243446318274717`*^9, 
   3.6243450024859467`*^9, 3.6243623699686966`*^9, 3.6243764645715733`*^9, 
   3.6244530173972588`*^9, {3.6244731234282093`*^9, 3.6244731368113213`*^9}, 
   3.624519403725105*^9, 3.624521507800733*^9, 3.624530751221838*^9, 
   3.6245362675804567`*^9, 3.6245459756468983`*^9, 3.624549940731003*^9, 
   3.6245592478487473`*^9, 3.624606376773088*^9, 3.624967606247053*^9, 
   3.625207147678864*^9, 3.693748251831589*^9, 3.693758999411071*^9, 
   3.693808981465432*^9, 3.770619380317526*^9, 3.7719608820268993`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["How to speed it up: expand the metric to second order \
before run the RGtensors command!",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7706193935614796`*^9, 3.7706193970205603`*^9}, {
  3.7719604945532875`*^9, 3.7719605093390317`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "u"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "2"]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", 
       RowBox[{"NN", "[", "u", "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.570167330426721*^9, {3.570167711460515*^9, 3.5701677604433165`*^9}, {
   3.5701875806651926`*^9, 3.570187583672364*^9}, {3.5701876605677624`*^9, 
   3.5701876639509563`*^9}, {3.570187735649057*^9, 3.570187745717633*^9}, {
   3.5701886532425404`*^9, 3.5701886590188704`*^9}, {3.5710344839574785`*^9, 
   3.5710345490622025`*^9}, {3.5710565998820677`*^9, 3.571056609206601*^9}, {
   3.571056688575141*^9, 3.5710566960055656`*^9}, {3.571057753245036*^9, 
   3.5710577696369743`*^9}, {3.5710584597704477`*^9, 3.571058487839053*^9}, {
   3.571162597044566*^9, 3.571162634373329*^9}, {3.572352151919235*^9, 
   3.5723521744285226`*^9}, {3.5723527649783*^9, 3.572352805412613*^9}, {
   3.5723544810774555`*^9, 3.572354481370472*^9}, {3.572783907767783*^9, 
   3.572783910698951*^9}, {3.5727852817183685`*^9, 3.5727852851825666`*^9}, {
   3.572847181580718*^9, 3.572847187575061*^9}, {3.5728479839206095`*^9, 
   3.572848013493301*^9}, {3.5728683898720317`*^9, 3.5728684127023373`*^9}, {
   3.5768411793242626`*^9, 3.5768411960782213`*^9}, {3.576841393342504*^9, 
   3.576841400301902*^9}, {3.588570366786084*^9, 3.588570605641746*^9}, {
   3.588676297756776*^9, 3.588676313015649*^9}, {3.588679147362764*^9, 
   3.588679147494772*^9}, {3.589176462654968*^9, 3.5891764682232866`*^9}, {
   3.5891765005721364`*^9, 3.5891765490069065`*^9}, {3.5891765827008343`*^9, 
   3.5891766018889313`*^9}, {3.589176698654466*^9, 3.5891767473842535`*^9}, {
   3.5891781666334295`*^9, 3.5891781823983316`*^9}, {3.5892026584710283`*^9, 
   3.58920267756212*^9}, {3.5892027244858036`*^9, 3.589202733565323*^9}, {
   3.5892038518332844`*^9, 3.589203878423805*^9}, {3.5892057669598236`*^9, 
   3.5892057873969927`*^9}, {3.58920631763332*^9, 3.589206320231469*^9}, {
   3.589207357322787*^9, 3.589207393252842*^9}, {3.5896209102385693`*^9, 
   3.5896209119556675`*^9}, {3.5896210590570817`*^9, 3.589621064654402*^9}, {
   3.5907551876956787`*^9, 3.5907552091219044`*^9}, {3.5907566716935587`*^9, 
   3.5907566860873823`*^9}, {3.592217073930195*^9, 3.5922171581900144`*^9}, {
   3.59256777152232*^9, 3.592567782218931*^9}, {3.5927224828902206`*^9, 
   3.5927225021913247`*^9}, {3.592755344267173*^9, 3.592755345044217*^9}, {
   3.5927555533841333`*^9, 3.592755559335474*^9}, 3.592755679146327*^9, {
   3.592914201124915*^9, 3.5929142298985605`*^9}, {3.592914325799046*^9, 
   3.5929143259670553`*^9}, {3.5931684118583736`*^9, 3.593168433449609*^9}, {
   3.593168691672378*^9, 3.593168692003397*^9}, {3.593177947440778*^9, 
   3.5931779569343204`*^9}, {3.5932379656937857`*^9, 
   3.5932379657697897`*^9}, {3.5939694634234915`*^9, 
   3.5939694642905407`*^9}, {3.612679384297059*^9, 3.6126794442260604`*^9}, 
   3.612891633755241*^9, {3.6128925243427753`*^9, 3.6128925729956837`*^9}, {
   3.6128930187745657`*^9, 3.6128930511441402`*^9}, {3.612902044032016*^9, 
   3.612902045532769*^9}, {3.619853651851103*^9, 3.619853652299033*^9}, {
   3.62002395456089*^9, 3.6200239553877697`*^9}, {3.620378552850563*^9, 
   3.62037858294659*^9}, {3.620378635267205*^9, 3.620378639328519*^9}, {
   3.770619368765564*^9, 3.7706193769690857`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g2", ",", "xCoord"}], "]"}]], "Input",
 CellChangeTimes->{3.7706193670478387`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "2"]}], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], "0", "0"},
       {
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False]},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], "0", 
        RowBox[{"NN", "[", "u", "]"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-$CellContext`at[$CellContext`u]^2, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], 0, 0}, {
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], $CellContext`ax[$CellContext`u]^2, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1]}, {0, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], $CellContext`ax[$CellContext`u]^2, 0}, {0, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], 0, 
      $CellContext`NN[$CellContext`u]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.7719608821408625`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(ds\\), \\(2\\)]\\) = \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "x", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "u", "]"}], "2"], " ", 
        RowBox[{"NN", "[", "u", "]"}]}]}], ")"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"d", "[", "x", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "t", "]"}], " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"d", "[", "u", "]"}], " ", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"d", "[", "y", "]"}], " ", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}], " ", 
      "\[Epsilon]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
      SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 3, 1],
      Editable->False]}],
    SeriesData[$CellContext`\[Epsilon], 
     0, {-$CellContext`at[$CellContext`u]^2 $CellContext`d[$CellContext`t]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`x]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`y]^2 + \
$CellContext`d[$CellContext`u]^2 $CellContext`NN[$CellContext`u], 
      2 $CellContext`d[$CellContext`x] ($CellContext`d[$CellContext`t] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] + \
$CellContext`d[$CellContext`u] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] + $CellContext`d[$CellContext`y] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y])}, 0,
      3, 1],
    Editable->False]}],
  SequenceForm["\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = ", 
   SeriesData[$CellContext`\[Epsilon], 
    0, {-$CellContext`at[$CellContext`u]^2 $CellContext`d[$CellContext`t]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`x]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`y]^2 + \
$CellContext`d[$CellContext`u]^2 $CellContext`NN[$CellContext`u], 
     2 $CellContext`d[$CellContext`x] ($CellContext`d[$CellContext`t] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] + \
$CellContext`d[$CellContext`u] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] + $CellContext`d[$CellContext`y] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y])}, 0,
     3, 1]],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.7719608821478367`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "4"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {(-1) $CellContext`at[$CellContext`u]^(-2), 
           0, $CellContext`at[$CellContext`u]^(-4) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "4"]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
          4, 1],
         Editable->False]},
       {
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]}], " ", 
               RowBox[{"NN", "[", "u", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Delta]Gtx", "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"at", "[", "u", "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Delta]Gxu", "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"at", "[", "u", "]"}], "2"], " ", 
               RowBox[{"NN", "[", "u", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Delta]Gxy", "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], ")"}], 
            " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "6"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-2), 
           0, $CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-6) $CellContext`NN[$CellContext`u]^(-1) \
(-$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2)}, 
          0, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
          3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False]},
       {
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "4"]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
          3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "6"]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-2), 
           0, $CellContext`ax[$CellContext`u]^(-6) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2}, 
          0, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False]},
       {
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
          4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           RowBox[{"NN", "[", "u", "]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"NN", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`NN[$CellContext`u]^(-1), 
           0, $CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-2) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1],
         Editable->False]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
      SeriesData[$CellContext`\[Epsilon], 
       0, {(-1) $CellContext`at[$CellContext`u]^(-2), 
        0, $CellContext`at[$CellContext`u]^(-4) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
       4, 1]}, {
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-2), 
        0, $CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-6) $CellContext`NN[$CellContext`u]^(-1) \
(-$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2)}, 
       0, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
       3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1]}, {
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
       3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-2), 
        0, $CellContext`ax[$CellContext`u]^(-6) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2}, 
       0, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1]}, {
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
       4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`NN[$CellContext`u]^(-1), 
        0, $CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-2) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.771960882170817*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.015000000000000568`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.015000000000000568`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.771960882182768*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.03200000000000358`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.03200000000000358, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.771960882242178*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.1869999999999976`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.1869999999999976, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.771960882404541*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "1.8599999999999994`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 1.8599999999999994`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.7719608842995396`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.703000000000003`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.703000000000003, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.7719608850774584`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "1.5309999999999988`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 1.5309999999999988`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.7719608866241627`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.3430000000000035`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.3430000000000035, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.770619447906265*^9, 3.771960886994277*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["Not bad no?",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719605175606823`*^9, 3.7719605190169754`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Define the various matter fields and useful \
quantities",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771960525118602*^9, 3.7719605330775127`*^9}}],

Cell[BoxData[{
 RowBox[{"Ad", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"At", "[", "u", "]"}], ",", 
    RowBox[{"\[Epsilon]", "*", 
     RowBox[{"\[Delta]Ax", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"AD", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"Ad", ",", "1"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Add", ":=", 
  RowBox[{"covD", "[", "Ad", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FAdd", ":=", 
  RowBox[{
   RowBox[{"covD", "[", "Ad", "]"}], "-", 
   RowBox[{"Transpose", "[", 
    RowBox[{"covD", "[", "Ad", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"FADd", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"FAdd", ",", "1"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FADD", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"FAdd", ",", "1", ",", "2"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"F2A", ":=", 
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{"Outer", "[", 
     RowBox[{"Times", ",", "FAdd", ",", "FADD"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]\[Alpha]", "[", "u_", "]"}], ":=", "\[Alpha]"}], "\n", 
 RowBox[{
  RowBox[{"\[Phi]xd", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
     RowBox[{"\[Alpha]\[Alpha]", "[", "u", "]"}], ",", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]\[Alpha]", "'"}], "[", "u", "]"}], "x"}], " ", "+", 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]x", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]yd", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"\[Alpha]\[Alpha]", "[", "u", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]\[Alpha]", "'"}], "[", "u", "]"}], " ", "y"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]xU", "=", 
   RowBox[{"Raise", "[", 
    RowBox[{"\[Phi]xd", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]yU", "=", 
   RowBox[{"Raise", "[", 
    RowBox[{"\[Phi]yd", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]xU", ".", "\[Phi]xd"}], "+", 
     RowBox[{"\[Phi]yU", ".", "\[Phi]yd"}]}], "2"]}], ";"}]}], "Input",
 CellChangeTimes->{{3.572867901441095*^9, 3.572867909621563*^9}, {
   3.572867947587734*^9, 3.572867964232686*^9}, 3.572868004770005*^9, {
   3.5728681548565893`*^9, 3.572868160515913*^9}, {3.5885706227857265`*^9, 
   3.5885706335743437`*^9}, {3.5886763282075176`*^9, 3.588676328686545*^9}, {
   3.588679161875594*^9, 3.588679162435626*^9}, {3.589176613958622*^9, 
   3.5891766403151293`*^9}, {3.5891781868285847`*^9, 
   3.5891781889057035`*^9}, {3.589202741782793*^9, 3.5892027467890797`*^9}, {
   3.5892580858651075`*^9, 3.58925808817824*^9}, {3.5892581726700726`*^9, 
   3.58925817297509*^9}, {3.59211606757362*^9, 3.5921160700067587`*^9}, {
   3.5922171668125076`*^9, 3.592217179860254*^9}, {3.592567787601239*^9, 
   3.5925677879202576`*^9}, {3.59256795073757*^9, 3.592567951300602*^9}, {
   3.592722473010656*^9, 3.592722473486683*^9}, {3.592914712905187*^9, 
   3.5929147138212395`*^9}, {3.593168440243997*^9, 3.5931684552968583`*^9}, {
   3.61267945371039*^9, 3.612679459666366*^9}, {3.6126801788663993`*^9, 
   3.612680193122916*^9}, {3.6128928336151857`*^9, 3.612892840685255*^9}, {
   3.6128936214712353`*^9, 3.6128936261751757`*^9}, {3.612901670067477*^9, 
   3.6129016848401947`*^9}, {3.6199304511005983`*^9, 3.619930456673005*^9}, 
   3.620025645677609*^9, 3.620033153563682*^9, {3.6203787248857403`*^9, 
   3.6203787252081413`*^9}, {3.624009548298813*^9, 3.624009568424783*^9}, {
   3.6240096075360465`*^9, 3.6240096081454506`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["This is our lagrangian!",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719605390536623`*^9, 3.771960547999916*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ll", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    SqrtBox[
     FractionBox["detg", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
       RowBox[{"NN", "[", "u", "]"}]}]]], 
    RowBox[{"at", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
    SqrtBox[
     RowBox[{"NN", "[", "u", "]"}]], 
    RowBox[{"(", 
     RowBox[{"R", "-", 
      RowBox[{"2", "\[CapitalLambda]"}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", "F2A"}], "-", " ", 
      RowBox[{"2", " ", "m2", " ", 
       RowBox[{"F", "[", "X", "]"}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6200341676054163`*^9, 3.620034215743165*^9}, {
  3.620034458244574*^9, 3.6200344612821217`*^9}, {3.620378776150002*^9, 
  3.620378781381852*^9}, {3.621336515409584*^9, 3.6213365267986593`*^9}, {
  3.62235246555513*^9, 3.6223524737692547`*^9}, {3.624343244416917*^9, 
  3.6243432463388815`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ll0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ll", "/.", 
     RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "//", "FS"}], "//", 
   "Normal"}]}], "\[IndentingNewLine]", 
 RowBox[{"ll1", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"ll", ",", "\[Epsilon]"}], "]"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"ll2", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"ll", "//", "Simplify"}], ",", 
    SuperscriptBox["\[Epsilon]", "2"]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.620034237198539*^9, 3.62003425835084*^9}, {
  3.62003429885275*^9, 3.620034350132928*^9}, {3.6200344361985683`*^9, 
  3.6200344468218403`*^9}, {3.770619466944113*^9, 3.7706194832399573`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
    RowBox[{"NN", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["At", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"at", "[", "u", "]"}], " ", 
    RowBox[{"ax", "[", "u", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["at", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["ax", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{"ax", "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["NN", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"ax", "[", "u", "]"}], " ", 
       RowBox[{"NN", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["at", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"at", "[", "u", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[CapitalLambda]", "+", 
         RowBox[{"m2", " ", 
          RowBox[{"F", "[", 
           FractionBox[
            SuperscriptBox["\[Alpha]", "2"], 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"NN", "[", "u", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"NN", "[", "u", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["ax", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"ax", "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox["ax", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], " ", 
          RowBox[{
           SuperscriptBox["NN", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["ax", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
     ")"}]}]}], 
  RowBox[{"2", " ", 
   RowBox[{"at", "[", "u", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"NN", "[", "u", "]"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.6240096364749346`*^9, 3.624033643152733*^9, 3.62404084033712*^9, 
   3.624082688479106*^9, 3.6241100289574356`*^9, 3.6241103813181553`*^9, 
   3.6242153475139446`*^9, 3.624343328170949*^9, 3.624344693221055*^9, 
   3.624345063488887*^9, 3.624362436852249*^9, 3.6243765274289856`*^9, 
   3.624453085369273*^9, 3.624473210530443*^9, 3.6245194687282076`*^9, 
   3.624521570569378*^9, 3.6245308154280605`*^9, 3.6245363313960285`*^9, 
   3.624546043162899*^9, 3.6245500055374365`*^9, 3.624559314385298*^9, 
   3.6246064422918663`*^9, 3.6249676689689226`*^9, 3.6252072130102034`*^9, 
   3.693748427140607*^9, {3.6937591723689013`*^9, 3.6937591956057916`*^9}, 
   3.6938091616168957`*^9, 3.7706194851667075`*^9, 3.7719608892023315`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6240096364749346`*^9, 3.624033643152733*^9, 3.62404084033712*^9, 
   3.624082688479106*^9, 3.6241100289574356`*^9, 3.6241103813181553`*^9, 
   3.6242153475139446`*^9, 3.624343328170949*^9, 3.624344693221055*^9, 
   3.624345063488887*^9, 3.624362436852249*^9, 3.6243765274289856`*^9, 
   3.624453085369273*^9, 3.624473210530443*^9, 3.6245194687282076`*^9, 
   3.624521570569378*^9, 3.6245308154280605`*^9, 3.6245363313960285`*^9, 
   3.624546043162899*^9, 3.6245500055374365`*^9, 3.624559314385298*^9, 
   3.6246064422918663`*^9, 3.6249676689689226`*^9, 3.6252072130102034`*^9, 
   3.693748427140607*^9, {3.6937591723689013`*^9, 3.6937591956057916`*^9}, 
   3.6938091616168957`*^9, 3.7706194851667075`*^9, 3.7719608892091675`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"at", "[", "u", "]"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
    SuperscriptBox[
     RowBox[{"NN", "[", "u", "]"}], 
     RowBox[{"5", "/", "2"}]]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"ax", "[", "u", "]"}], "4"]}], " ", 
     SuperscriptBox[
      RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[Delta]Gtx", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["at", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["At", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"at", "[", "u", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"ax", "[", "u", "]"}], "3"], " ", 
     RowBox[{"NN", "[", "u", "]"}], " ", 
     RowBox[{"\[Delta]Gtx", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"ax", "[", "u", "]"}]}], " ", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["at", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["NN", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              RowBox[{
               SuperscriptBox["at", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["ax", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"ax", "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["at", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", 
           RowBox[{"ax", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["at", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gtx", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"at", "[", "u", "]"}], "3"], " ", 
     RowBox[{"ax", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["at", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["NN", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"ax", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["at", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["NN", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "3"], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Delta]Gxu", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["at", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["at", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              RowBox[{
               SuperscriptBox["at", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["ax", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"ax", "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["at", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"ax", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["at", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"ax", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["at", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["\[Delta]Gxu", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
             RowBox[{
              SuperscriptBox["\[Delta]Gxy", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"at", "[", "u", "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["ax", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
          RowBox[{"2", " ", "m2", " ", 
           SuperscriptBox["\[Alpha]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["F", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["\[Alpha]", "2"], 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "3"], " ", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              RowBox[{
               SuperscriptBox["ax", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["NN", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"NN", "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["ax", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["ax", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxu", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"ax", "[", "u", "]"}], " ", 
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               SuperscriptBox["ax", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["NN", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"NN", "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["ax", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["ax", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
          RowBox[{"8", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["ax", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", "m2", " ", 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["\[Alpha]", "2"], 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Delta]\[Phi]x", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"\[CapitalLambda]", "+", 
             RowBox[{"m2", " ", 
              RowBox[{"F", "[", 
               FractionBox[
                SuperscriptBox["\[Alpha]", "2"], 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{"m2", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["F", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["\[Alpha]", "2"], 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Delta]\[Phi]x", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Delta]Ax", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], "+", 
          RowBox[{"2", " ", "m2", " ", "\[Alpha]", " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["F", "\[Prime]",
             MultilineFunction->None], "[", 
            FractionBox[
             SuperscriptBox["\[Alpha]", "2"], 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]\[Phi]x", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[CapitalLambda]", "+", 
                RowBox[{"m2", " ", 
                 RowBox[{"F", "[", 
                  FractionBox[
                   SuperscriptBox["\[Alpha]", "2"], 
                   SuperscriptBox[
                    RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"\[Delta]Gxy", "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Delta]Ax", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], "+", 
             RowBox[{"2", " ", "m2", " ", "\[Alpha]", " ", 
              RowBox[{"\[Delta]Gxy", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["F", "\[Prime]",
                MultilineFunction->None], "[", 
               FractionBox[
                SuperscriptBox["\[Alpha]", "2"], 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]\[Phi]x", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{"\[Delta]Gxu", "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["ax", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"\[Delta]Gxu", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["NN", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"\[Delta]Gxy", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["NN", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["\[Delta]Gxu", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
                RowBox[{
                 SuperscriptBox["\[Delta]Gxy", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], 
            ")"}]}], "+", 
          RowBox[{
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "m2", " ", 
              SuperscriptBox["\[Alpha]", "2"], " ", 
              SuperscriptBox[
               RowBox[{"\[Delta]Gxu", "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox["F", "\[Prime]",
                MultilineFunction->None], "[", 
               FractionBox[
                SuperscriptBox["\[Alpha]", "2"], 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Delta]Gxu", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
             RowBox[{"4", " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Delta]Gxy", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gxy", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gxu", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["\[Delta]Gxu", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
                RowBox[{
                 SuperscriptBox["\[Delta]Gxy", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gxy", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"at", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
     RowBox[{"NN", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"ax", "[", "u", "]"}], " ", 
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["ax", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Delta]Gtx", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Delta]Gxu", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", "m2", " ", 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         FractionBox[
          SuperscriptBox["\[Alpha]", "2"], 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Delta]\[Phi]x", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["At", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["NN", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gtx", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["NN", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["\[Delta]Gtx", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
             RowBox[{
              SuperscriptBox["\[Delta]Gxu", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[CapitalLambda]", "+", 
                RowBox[{"m2", " ", 
                 RowBox[{"F", "[", 
                  FractionBox[
                   SuperscriptBox["\[Alpha]", "2"], 
                   SuperscriptBox[
                    RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{"\[Delta]Gtx", "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Delta]Ax", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], "+", 
             RowBox[{"2", " ", "m2", " ", "\[Alpha]", " ", 
              RowBox[{"\[Delta]Gtx", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["F", "\[Prime]",
                MultilineFunction->None], "[", 
               FractionBox[
                SuperscriptBox["\[Alpha]", "2"], 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]\[Phi]x", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Delta]Gtx", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gxu", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["At", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Ax", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gtx", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gtx", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Delta]Gxu", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gxu", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gtx", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gtx", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  SuperscriptBox["At", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[Delta]Ax", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
                RowBox[{
                 SuperscriptBox["\[Delta]Gtx", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "2", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
                RowBox[{
                 SuperscriptBox["\[Delta]Gxu", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "1", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}], "-", 
             RowBox[{"4", " ", 
              RowBox[{"\[Delta]Gxu", "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxu", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["At", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["ax", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}], "2"], "-", 
             RowBox[{"m2", " ", 
              SuperscriptBox["\[Alpha]", "2"], " ", 
              RowBox[{"NN", "[", "u", "]"}], " ", 
              RowBox[{
               SuperscriptBox["F", "\[Prime]",
                MultilineFunction->None], "[", 
               FractionBox[
                SuperscriptBox["\[Alpha]", "2"], 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}]}], 
          "+", 
          RowBox[{
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Delta]Gtx", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gtx", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gtx", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Delta]Gxy", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Delta]Gxy", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], ")"}]}], 
          "+", 
          RowBox[{"4", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               SuperscriptBox["\[Delta]Gtx", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[Delta]Gxy", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["\[Delta]Gtx", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
             RowBox[{
              SuperscriptBox["\[Delta]Gxy", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6240096364749346`*^9, 3.624033643152733*^9, 3.62404084033712*^9, 
   3.624082688479106*^9, 3.6241100289574356`*^9, 3.6241103813181553`*^9, 
   3.6242153475139446`*^9, 3.624343328170949*^9, 3.624344693221055*^9, 
   3.624345063488887*^9, 3.624362436852249*^9, 3.6243765274289856`*^9, 
   3.624453085369273*^9, 3.624473210530443*^9, 3.6245194687282076`*^9, 
   3.624521570569378*^9, 3.6245308154280605`*^9, 3.6245363313960285`*^9, 
   3.624546043162899*^9, 3.6245500055374365`*^9, 3.624559314385298*^9, 
   3.6246064422918663`*^9, 3.6249676689689226`*^9, 3.6252072130102034`*^9, 
   3.693748427140607*^9, {3.6937591723689013`*^9, 3.6937591956057916`*^9}, 
   3.6938091616168957`*^9, 3.7706194851667075`*^9, 3.7719608899982224`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Equations of motion (risky lazy method)", "Section",
 CellChangeTimes->{{3.6240096569759517`*^9, 3.6240096602104826`*^9}, {
  3.7719605691746836`*^9, 3.7719605752583995`*^9}}],

Cell[TextData[StyleBox["We just use the variational methods package of \
mathematica",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719605829672728`*^9, 3.7719605941574183`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "VariationalMethods`"}]], "Input",
 CellChangeTimes->{3.5919628000845413`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eqN", "=", 
  RowBox[{
   RowBox[{"8", " ", 
    RowBox[{"at", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"NN", "[", "u", "]"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     RowBox[{"EulerEquations", "[", 
      RowBox[{"ll0", ",", 
       RowBox[{"NN", "[", "u", "]"}], ",", 
       RowBox[{"{", "u", "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqat", "=", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"at", "[", "u", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"NN", "[", "u", "]"}], 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     RowBox[{"EulerEquations", "[", 
      RowBox[{"ll0", ",", 
       RowBox[{"at", "[", "u", "]"}], ",", 
       RowBox[{"{", "u", "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqax", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       RowBox[{"ax", "[", "u", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"NN", "[", "u", "]"}], 
        RowBox[{"3", "/", "2"}]]}]]], 
    RowBox[{
     RowBox[{"EulerEquations", "[", 
      RowBox[{"ll0", ",", 
       RowBox[{"ax", "[", "u", "]"}], ",", 
       RowBox[{"{", "u", "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"eqAt", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], 
         RowBox[{"5", "/", "2"}]]}]], 
      RowBox[{"ax", "[", "u", "]"}]}]], 
    RowBox[{
     RowBox[{"EulerEquations", "[", 
      RowBox[{"ll0", ",", 
       RowBox[{"At", "[", "u", "]"}], ",", 
       RowBox[{"{", "u", "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}]}], "Input",
 CellChangeTimes->{{3.612893558590021*^9, 3.612893574835224*^9}, {
  3.6128938207584743`*^9, 3.612893869680931*^9}, {3.612902005258594*^9, 
  3.612902014106138*^9}, {3.612902636321763*^9, 3.6129026373279123`*^9}, {
  3.619936096152042*^9, 3.619936099269494*^9}, {3.61993649129405*^9, 
  3.619936519908162*^9}, {3.620025189496698*^9, 3.6200251925463743`*^9}, {
  3.6200291946062403`*^9, 3.620029208757062*^9}, {3.620033273906701*^9, 
  3.620033275662516*^9}, {3.620034688355049*^9, 3.6200346908020573`*^9}, {
  3.621333741662058*^9, 3.621333742989874*^9}, {3.621333775095559*^9, 
  3.621333802124579*^9}, {3.621336285083427*^9, 3.6213362854035597`*^9}, {
  3.621336432525044*^9, 3.6213364331069736`*^9}, {3.624009683711584*^9, 
  3.6240097110566587`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"ax", "[", "u", "]"}], "2"]}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["At", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"at", "[", "u", "]"}], " ", 
     RowBox[{"ax", "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["at", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["ax", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"at", "[", "u", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[CapitalLambda]", "+", 
          RowBox[{"m2", " ", 
           RowBox[{"F", "[", 
            FractionBox[
             SuperscriptBox["\[Alpha]", "2"], 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], " ", 
        RowBox[{"NN", "[", "u", "]"}]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["ax", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.624009673523596*^9, 3.6240097117129345`*^9}, 
   3.6240336451215773`*^9, 3.62404084221221*^9, 3.624082698167072*^9, 
   3.624110030801276*^9, 3.624110383224495*^9, 3.6242153496546707`*^9, 
   3.6243433541878214`*^9, 3.624344694908633*^9, 3.624345065176464*^9, 
   3.62436243869505*^9, 3.624376529177026*^9, 3.624453087275617*^9, 
   3.6244732125441165`*^9, 3.6245194704782915`*^9, 3.6245215724132195`*^9, 
   3.624530817381276*^9, 3.624536333177363*^9, 3.6245460450691633`*^9, 
   3.6245500073679857`*^9, 3.624559316435549*^9, 3.6246064441044254`*^9, 
   3.6249676706408777`*^9, 3.6252072147446337`*^9, 3.693748432477138*^9, {
   3.6937591787173653`*^9, 3.693759202277977*^9}, 3.693809166038974*^9, 
   3.77061949665022*^9, 3.7719608903885098`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"ax", "[", "u", "]"}], "2"]}], " ", 
     RowBox[{"NN", "[", "u", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["At", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"at", "[", "u", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"\[CapitalLambda]", "+", 
          RowBox[{"m2", " ", 
           RowBox[{"F", "[", 
            FractionBox[
             SuperscriptBox["\[Alpha]", "2"], 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"NN", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["ax", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"ax", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SuperscriptBox["ax", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], " ", 
           RowBox[{
            SuperscriptBox["NN", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["ax", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.624009673523596*^9, 3.6240097117129345`*^9}, 
   3.6240336451215773`*^9, 3.62404084221221*^9, 3.624082698167072*^9, 
   3.624110030801276*^9, 3.624110383224495*^9, 3.6242153496546707`*^9, 
   3.6243433541878214`*^9, 3.624344694908633*^9, 3.624345065176464*^9, 
   3.62436243869505*^9, 3.624376529177026*^9, 3.624453087275617*^9, 
   3.6244732125441165`*^9, 3.6245194704782915`*^9, 3.6245215724132195`*^9, 
   3.624530817381276*^9, 3.624536333177363*^9, 3.6245460450691633`*^9, 
   3.6245500073679857`*^9, 3.624559316435549*^9, 3.6246064441044254`*^9, 
   3.6249676706408777`*^9, 3.6252072147446337`*^9, 3.693748432477138*^9, {
   3.6937591787173653`*^9, 3.693759202277977*^9}, 3.693809166038974*^9, 
   3.77061949665022*^9, 3.7719608904232955`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"at", "[", "u", "]"}]], 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
      RowBox[{"NN", "[", "u", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["At", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"at", "[", "u", "]"}], " ", 
      RowBox[{"ax", "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"ax", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["at", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["NN", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"NN", "[", "u", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["at", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], " ", 
            RowBox[{
             SuperscriptBox["ax", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "+", 
           RowBox[{
            RowBox[{"ax", "[", "u", "]"}], " ", 
            RowBox[{
             SuperscriptBox["at", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
       ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"at", "[", "u", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox[
          RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[CapitalLambda]", "+", 
           RowBox[{"m2", " ", 
            RowBox[{"F", "[", 
             FractionBox[
              SuperscriptBox["\[Alpha]", "2"], 
              SuperscriptBox[
               RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"NN", "[", "u", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", "m2", " ", 
         SuperscriptBox["\[Alpha]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"NN", "[", "u", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["F", "\[Prime]",
           MultilineFunction->None], "[", 
          FractionBox[
           SuperscriptBox["\[Alpha]", "2"], 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"]], "]"}]}], "+", 
        RowBox[{
         RowBox[{"ax", "[", "u", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["ax", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}], " ", 
            RowBox[{
             SuperscriptBox["NN", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            RowBox[{
             SuperscriptBox["ax", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
       ")"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.624009673523596*^9, 3.6240097117129345`*^9}, 
   3.6240336451215773`*^9, 3.62404084221221*^9, 3.624082698167072*^9, 
   3.624110030801276*^9, 3.624110383224495*^9, 3.6242153496546707`*^9, 
   3.6243433541878214`*^9, 3.624344694908633*^9, 3.624345065176464*^9, 
   3.62436243869505*^9, 3.624376529177026*^9, 3.624453087275617*^9, 
   3.6244732125441165`*^9, 3.6245194704782915`*^9, 3.6245215724132195`*^9, 
   3.624530817381276*^9, 3.624536333177363*^9, 3.6245460450691633`*^9, 
   3.6245500073679857`*^9, 3.624559316435549*^9, 3.6246064441044254`*^9, 
   3.6249676706408777`*^9, 3.6252072147446337`*^9, 3.693748432477138*^9, {
   3.6937591787173653`*^9, 3.693759202277977*^9}, 3.693809166038974*^9, 
   3.77061949665022*^9, 3.771960890650098*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"at", "[", "u", "]"}], "2"], " ", 
  RowBox[{"NN", "[", "u", "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     RowBox[{"at", "[", "u", "]"}], " ", 
     RowBox[{"NN", "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["At", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["ax", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "+", 
    RowBox[{
     RowBox[{"ax", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["At", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["at", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{"at", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["NN", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"at", "[", "u", "]"}], " ", 
        RowBox[{"NN", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["At", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.624009673523596*^9, 3.6240097117129345`*^9}, 
   3.6240336451215773`*^9, 3.62404084221221*^9, 3.624082698167072*^9, 
   3.624110030801276*^9, 3.624110383224495*^9, 3.6242153496546707`*^9, 
   3.6243433541878214`*^9, 3.624344694908633*^9, 3.624345065176464*^9, 
   3.62436243869505*^9, 3.624376529177026*^9, 3.624453087275617*^9, 
   3.6244732125441165`*^9, 3.6245194704782915`*^9, 3.6245215724132195`*^9, 
   3.624530817381276*^9, 3.624536333177363*^9, 3.6245460450691633`*^9, 
   3.6245500073679857`*^9, 3.624559316435549*^9, 3.6246064441044254`*^9, 
   3.6249676706408777`*^9, 3.6252072147446337`*^9, 3.693748432477138*^9, {
   3.6937591787173653`*^9, 3.693759202277977*^9}, 3.693809166038974*^9, 
   3.77061949665022*^9, 3.7719608907250257`*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Here we assume an ansatz for our metric and gauge \
field and we obtain our final equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771960676562682*^9, 3.7719606918280554`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"at", "[", "u_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "u"], 
   SqrtBox[
    RowBox[{"f", "[", "u", "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ax", "[", "u_", "]"}], ":=", 
  FractionBox["1", "u"]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NN", "[", "u_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["u", "2"]], 
   FractionBox["1", 
    RowBox[{"f", "[", "u", "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"At", "[", "u_", "]"}], ":=", 
  RowBox[{"\[Mu]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["u", "uh"]}], "+", "1"}], ")"}], " "}]}]}], "Input",
 CellChangeTimes->{{3.6938089592677345`*^9, 3.6938089621526403`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"-", "1"}], "2"], 
   SuperscriptBox["u", "5"], " ", 
   SuperscriptBox["uh", "2"], " ", 
   SqrtBox[
    RowBox[{"f", "[", "u", "]"}]], 
   FractionBox["1", 
    RowBox[{"at", "[", "u", "]"}]], "eqN"}], "//", 
  "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"-", "1"}], "2"], 
   SuperscriptBox["u", "6"], " ", 
   SuperscriptBox["uh", "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"], 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"at", "[", "u", "]"}], "2"]], "eqat"}], "//", 
  "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], 
   SuperscriptBox["u", "7"], " ", 
   SuperscriptBox["uh", "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], 
    RowBox[{"3", "/", "2"}]], "eqax"}], "//", "FS"}], "\[IndentingNewLine]", 
 RowBox[{"eqAt", "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.6240097603090525`*^9, 3.6240097980920935`*^9}, {
  3.62403366057653*^9, 3.6240336609359145`*^9}, {3.6240827195274754`*^9, 
  3.624082728246646*^9}, {3.624343423566168*^9, 3.624343496194688*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
  RowBox[{
   SuperscriptBox["u", "4"], " ", 
   SuperscriptBox["\[Mu]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["uh", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{"m2", " ", 
      RowBox[{"F", "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
     RowBox[{"u", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.624009773934681*^9, 3.6240097989983854`*^9}, 
   3.6240336633804893`*^9, 3.6240416376110015`*^9, 3.6240827296529646`*^9, 
   3.624110031754446*^9, 3.624110384099539*^9, 3.624215351451635*^9, {
   3.6243434521456633`*^9, 3.624343496694685*^9}, 3.624344695502412*^9, 
   3.624345065707741*^9, 3.62436243928583*^9, 3.6243765297010374`*^9, 
   3.624453087994402*^9, 3.6244732132509727`*^9, 3.624519471150199*^9, 
   3.6245215729601183`*^9, 3.624530817928175*^9, 3.6245363336930156`*^9, 
   3.624546045660555*^9, 3.6245500079000864`*^9, 3.624559317131779*^9, 
   3.6246064447294564`*^9, 3.6249676711721573`*^9, 3.6252072152759123`*^9, 
   3.6937484342623205`*^9, 3.6937592037468*^9, {3.693809167570298*^9, 
   3.6938091763238773`*^9}, 3.770619497219697*^9, 3.771960890836919*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
  RowBox[{
   SuperscriptBox["u", "4"], " ", 
   SuperscriptBox["\[Mu]", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["uh", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{"m2", " ", 
      RowBox[{"F", "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
     RowBox[{"u", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.624009773934681*^9, 3.6240097989983854`*^9}, 
   3.6240336633804893`*^9, 3.6240416376110015`*^9, 3.6240827296529646`*^9, 
   3.624110031754446*^9, 3.624110384099539*^9, 3.624215351451635*^9, {
   3.6243434521456633`*^9, 3.624343496694685*^9}, 3.624344695502412*^9, 
   3.624345065707741*^9, 3.62436243928583*^9, 3.6243765297010374`*^9, 
   3.624453087994402*^9, 3.6244732132509727`*^9, 3.624519471150199*^9, 
   3.6245215729601183`*^9, 3.624530817928175*^9, 3.6245363336930156`*^9, 
   3.624546045660555*^9, 3.6245500079000864`*^9, 3.624559317131779*^9, 
   3.6246064447294564`*^9, 3.6249676711721573`*^9, 3.6252072152759123`*^9, 
   3.6937484342623205`*^9, 3.6937592037468*^9, {3.693809167570298*^9, 
   3.6938091763238773`*^9}, 3.770619497219697*^9, 3.771960890840685*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
  RowBox[{
   SuperscriptBox["u", "4"], " ", 
   SuperscriptBox["\[Mu]", "2"]}], "-", 
  RowBox[{
   SuperscriptBox["uh", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "m2", " ", 
      RowBox[{"F", "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
     RowBox[{"u", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], "-", 
        RowBox[{"2", " ", "m2", " ", "u", " ", 
         SuperscriptBox["\[Alpha]", "2"], " ", 
         RowBox[{
          SuperscriptBox["F", "\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
        RowBox[{"u", " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.624009773934681*^9, 3.6240097989983854`*^9}, 
   3.6240336633804893`*^9, 3.6240416376110015`*^9, 3.6240827296529646`*^9, 
   3.624110031754446*^9, 3.624110384099539*^9, 3.624215351451635*^9, {
   3.6243434521456633`*^9, 3.624343496694685*^9}, 3.624344695502412*^9, 
   3.624345065707741*^9, 3.62436243928583*^9, 3.6243765297010374`*^9, 
   3.624453087994402*^9, 3.6244732132509727`*^9, 3.624519471150199*^9, 
   3.6245215729601183`*^9, 3.624530817928175*^9, 3.6245363336930156`*^9, 
   3.624546045660555*^9, 3.6245500079000864`*^9, 3.624559317131779*^9, 
   3.6246064447294564`*^9, 3.6249676711721573`*^9, 3.6252072152759123`*^9, 
   3.6937484342623205`*^9, 3.6937592037468*^9, {3.693809167570298*^9, 
   3.6938091763238773`*^9}, 3.770619497219697*^9, 3.771960891081753*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.624009773934681*^9, 3.6240097989983854`*^9}, 
   3.6240336633804893`*^9, 3.6240416376110015`*^9, 3.6240827296529646`*^9, 
   3.624110031754446*^9, 3.624110384099539*^9, 3.624215351451635*^9, {
   3.6243434521456633`*^9, 3.624343496694685*^9}, 3.624344695502412*^9, 
   3.624345065707741*^9, 3.62436243928583*^9, 3.6243765297010374`*^9, 
   3.624453087994402*^9, 3.6244732132509727`*^9, 3.624519471150199*^9, 
   3.6245215729601183`*^9, 3.624530817928175*^9, 3.6245363336930156`*^9, 
   3.624546045660555*^9, 3.6245500079000864`*^9, 3.624559317131779*^9, 
   3.6246064447294564`*^9, 3.6249676711721573`*^9, 3.6252072152759123`*^9, 
   3.6937484342623205`*^9, 3.6937592037468*^9, {3.693809167570298*^9, 
   3.6938091763238773`*^9}, 3.770619497219697*^9, 3.7719608910835896`*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["We solve the equation for the background and define \
some useful objects for later",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771960698624224*^9, 3.771960710675619*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
     RowBox[{
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["\[Mu]", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"f", "[", "u", "]"}]}], "+", 
        RowBox[{"m2", " ", 
         RowBox[{"F", "[", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
        RowBox[{"u", " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
    "\[Equal]", "0"}], ",", "f", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.624343574667194*^9, 3.624343579183038*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"f", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "u", "}"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{"C", "[", "1", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "1", "u"], 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
            RowBox[{"2", " ", "m2", " ", 
             SuperscriptBox["uh", "2"], " ", 
             RowBox[{"F", "[", 
              RowBox[{
               SuperscriptBox["\[Alpha]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"K", "[", "1", "]"}], "2"]}], "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"K", "[", "1", "]"}], "4"]}]}], 
           RowBox[{"2", " ", 
            SuperscriptBox["uh", "2"], " ", 
            SuperscriptBox[
             RowBox[{"K", "[", "1", "]"}], "4"]}]], 
          RowBox[{"\[DifferentialD]", 
           RowBox[{"K", "[", "1", "]"}]}]}]}]}]}]}], "]"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.624343587370926*^9, 3.6243447032371597`*^9, 
  3.6243450734893665`*^9, 3.6243624478078165`*^9, 3.624376537525215*^9, 
  3.6244530989793043`*^9, 3.6244732252000465`*^9, 3.6245194823538713`*^9, 
  3.624521581226143*^9, 3.6245308284599323`*^9, 3.624536344174491*^9, 
  3.624546055146852*^9, 3.6245500162644157`*^9, 3.6245593270480413`*^9, 
  3.6246064562769156`*^9, 3.624967679094425*^9, 3.6252072264327154`*^9, 
  3.693748459878287*^9, 3.6937592247786236`*^9, 3.7706195006425323`*^9, 
  3.7719608938554473`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fback", "=", 
   RowBox[{"{", 
    RowBox[{"f", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "u", "}"}], ",", 
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "uh", "u"], 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
            RowBox[{"2", " ", "m2", " ", 
             SuperscriptBox["uh", "2"], " ", 
             RowBox[{"F", "[", 
              RowBox[{
               SuperscriptBox["\[Alpha]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"K", "[", "1", "]"}], "2"]}], "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"K", "[", "1", "]"}], "4"]}]}], 
           RowBox[{"2", " ", 
            SuperscriptBox["uh", "2"], " ", 
            SuperscriptBox[
             RowBox[{"K", "[", "1", "]"}], "4"]}]], 
          RowBox[{"\[DifferentialD]", 
           RowBox[{"K", "[", "1", "]"}]}]}]}]}]}], "]"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6243436028560486`*^9, 3.6243436102314053`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f2ndback", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
       RowBox[{
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["\[Mu]", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["uh", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"f", "[", "u", "]"}]}], "+", 
          RowBox[{"2", " ", "m2", " ", 
           RowBox[{"F", "[", 
            RowBox[{
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              RowBox[{
               SuperscriptBox["f", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "-", 
             RowBox[{"2", " ", "m2", " ", "u", " ", 
              SuperscriptBox["\[Alpha]", "2"], " ", 
              RowBox[{
               SuperscriptBox["F", "\[Prime]",
                MultilineFunction->None], "[", 
               RowBox[{
                SuperscriptBox["u", "2"], " ", 
                SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
             RowBox[{"u", " ", 
              RowBox[{
               SuperscriptBox["f", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"f", "''"}], "[", "u", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6243436189193244`*^9, 3.6243436335294046`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
     RowBox[{
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["\[Mu]", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"f", "[", "u", "]"}]}], "-", 
     RowBox[{"2", " ", "m2", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"F", "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
     RowBox[{"4", " ", "u", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "m2", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["uh", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["uh", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.6243436243727093`*^9, 3.62434363429506*^9}, 
   3.624344703565302*^9, 3.624345073848759*^9, 3.6243624481393404`*^9, 
   3.6243765378372226`*^9, 3.6244530993699474`*^9, 3.624473225625693*^9, 
   3.624519482682002*^9, 3.624521581538659*^9, 3.6245308287568216`*^9, 
   3.624536344682829*^9, 3.6245460556161613`*^9, 3.624550016673689*^9, 
   3.6245593274181004`*^9, 3.624606456651904*^9, 3.6249676794069395`*^9, 
   3.625207226838977*^9, 3.69374846074303*^9, 3.693759225626522*^9, 
   3.69380919363346*^9, 3.7706195008280373`*^9, 3.7719608940073977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalLambda]back", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
       RowBox[{
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["\[Mu]", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["uh", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"f", "[", "u", "]"}]}], "+", 
          RowBox[{"m2", " ", 
           RowBox[{"F", "[", 
            RowBox[{
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
      "\[Equal]", "0"}], ",", "\[CapitalLambda]"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.624343641467285*^9, 3.6243436745470047`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[CapitalLambda]", "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["u", "4"]}], " ", 
      SuperscriptBox["\[Mu]", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"f", "[", "u", "]"}]}], "-", 
     RowBox[{"2", " ", "m2", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"F", "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["uh", "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.6243436662028513`*^9, 3.6243436750470257`*^9}, 
   3.624344703565302*^9, 3.6243450738643827`*^9, 3.624362448154972*^9, 
   3.6243765378612204`*^9, 3.624453099385573*^9, 3.6244732256576967`*^9, 
   3.624519482713267*^9, 3.624521581554284*^9, 3.62453082877245*^9, 
   3.62453634470084*^9, 3.6245460556421785`*^9, 3.6245500166846943`*^9, 
   3.6245593274181004`*^9, 3.624606456651904*^9, 3.6249676794069395`*^9, 
   3.625207226838977*^9, 3.6937484607830563`*^9, 3.693759225673399*^9, 
   3.6938091936959667`*^9, 3.7706195008519735`*^9, 3.771960894027285*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Closed]],

Cell[CellGroupData[{

Cell["Equations (safe way)", "Section",
 CellChangeTimes->{{3.7719607199806376`*^9, 3.771960724262961*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Phi]x", "=", 
   RowBox[{
    RowBox[{"\[Alpha]", " ", "x"}], " ", "+", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{"\[Delta]\[Phi]x", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]y", "=", 
   RowBox[{"\[Alpha]", " ", "y"}]}], " ", ";"}]}], "Input",
 CellChangeTimes->{{3.756543343824933*^9, 3.756543378499168*^9}, {
  3.7565455303492393`*^9, 3.7565455362519145`*^9}, {3.771960908103113*^9, 
  3.7719609545544205`*^9}, {3.771961106092139*^9, 3.7719611096590357`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Xdd", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "\[Phi]xd", ",", "\[Phi]xd"}], "]"}], "+", 
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "\[Phi]yd", ",", "\[Phi]yd"}], "]"}]}], "//", 
    "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FAdD", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"FAdd", ",", "2"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FF", "=", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"Outer", "[", 
      RowBox[{"Times", ",", "FAdd", ",", "FAdD"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7275117047387943`*^9, 3.7275119057486877`*^9}, {
   3.7275121537817135`*^9, 3.7275121582494507`*^9}, 3.727871932095058*^9, {
   3.7278720109961896`*^9, 3.727872031398452*^9}, {3.7310612517035923`*^9, 
   3.7310612954807105`*^9}, {3.7532889217005043`*^9, 3.753288948776705*^9}, {
   3.7532891239144673`*^9, 3.753289138160997*^9}, {3.7532892757484703`*^9, 
   3.753289275934801*^9}, {3.7532907659342947`*^9, 3.7532907688254957`*^9}, {
   3.7565433828425417`*^9, 3.7565434093875656`*^9}, {3.77196089905322*^9, 
   3.7719609038309956`*^9}, 3.7719609594519615`*^9, {3.77196107447657*^9, 
   3.7719610776877165`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Maxwell equation",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.727512476224573*^9, 3.7275124782181606`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSmaxwell", "=", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"Raise", "[", 
      RowBox[{
       RowBox[{"covD", "[", "FAdd", "]"}], ",", "3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.727888285779765*^9, 3.727888371760988*^9}, 
   3.727889357573536*^9, {3.7532889793211164`*^9, 3.753289010628629*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Scalars equation",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.727512476224573*^9, 3.7275124782181606`*^9}, {
  3.756545772599242*^9, 3.756545773240528*^9}, {3.7719608125711*^9, 
  3.771960813556839*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSaxions", "=", 
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"F", "'"}], "[", "X", "]"}], 
       RowBox[{"Raise", "[", 
        RowBox[{
         RowBox[{"covD", "[", "\[Phi]x", "]"}], ",", "1"}], "]"}]}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "+", 
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"F", "'"}], "[", "X", "]"}], 
       RowBox[{"Raise", "[", 
        RowBox[{
         RowBox[{"covD", "[", "\[Phi]y", "]"}], ",", "1"}], "]"}]}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7565459712191486`*^9, 3.756546004496971*^9}, {
  3.7578292126239815`*^9, 3.7578292164360957`*^9}, {3.771961207038547*^9, 
  3.7719612099969683`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Einstein equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.727512770322611*^9, 3.7275127725042496`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSeinstein", "=", 
   RowBox[{"Rdd", "-", 
    RowBox[{
     FractionBox["1", "2"], "gdd", 
     RowBox[{"(", 
      RowBox[{"R", "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "F2A"}], "-", 
       RowBox[{"2", " ", "m2", " ", 
        RowBox[{"F", "[", "X", "]"}]}], "-", 
       RowBox[{"2", "\[CapitalLambda]"}]}], ")"}]}], "-", "FF", "-", 
    RowBox[{"m2", " ", 
     RowBox[{
      RowBox[{"F", "'"}], "[", "X", "]"}], "Xdd"}]}]}], ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQfZFdeuaqo68d74rtWAqircRbTq8G0hJPlc6AaKGM
pEsg2iy84CaIrpFTuRV57LXjPA4zMC1TvP45iH7SdAxMN/2dxR4FpNlKmblA
9MmOXStBdI/WJTB94EfIOhCd53oBTK+ou34cRE8WP3oCRO8KuJqUAKQv6DwC
00vYdt1rAtIKt1mfgWgz7hBm3rOvHUPYtVhBtIhXyOEr31476ia9OgWixdYn
XgTRctzpl0D0r/z/ileB9BPDBUog+svbx/Ug2muidiOIfpU7MbL2/2vHZIHm
OBDtqJ/+olDqjWOryD0wPWFl63sQ7fP43EcQzV9w4DeIboiZ9QdEAwAOSrLE

  "]]
}, Closed]],

Cell[CellGroupData[{

Cell["Check we get the same equations", "Section",
 CellChangeTimes->{{3.7719609716606154`*^9, 3.7719609754582877`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQSmaxwell", "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQSaxions", "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQSeinstein", "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.771960995606763*^9, 3.7719610105223103`*^9}, {
  3.771961046311739*^9, 3.7719610550912957`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.771960997504943*^9, 3.771961055381294*^9}, 
   3.7719610859925284`*^9, {3.7719611181586533`*^9, 3.7719611202237463`*^9}, 
   3.7719611695984387`*^9, 3.771961237224883*^9, 3.771961319469386*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.771960997504943*^9, 3.771961055381294*^9}, 
   3.7719610859925284`*^9, {3.7719611181586533`*^9, 3.7719611202237463`*^9}, 
   3.7719611695984387`*^9, 3.771961237224883*^9, 3.771961319475004*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
          RowBox[{
           SuperscriptBox["u", "4"], " ", 
           SuperscriptBox["\[Mu]", "2"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["uh", "2"], " ", 
           RowBox[{"f", "[", "u", "]"}]}], "+", 
          RowBox[{"2", " ", "m2", " ", 
           SuperscriptBox["uh", "2"], " ", 
           RowBox[{"F", "[", 
            RowBox[{
             SuperscriptBox["u", "2"], " ", 
             SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
          RowBox[{"2", " ", "u", " ", 
           SuperscriptBox["uh", "2"], " ", 
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["uh", "2"]}]]}], ",", "0", ",", "0", ",", "0"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"f", "[", "u", "]"}]}], 
       SuperscriptBox["u", "2"]], "+", 
      FractionBox[
       RowBox[{"m2", " ", 
        RowBox[{"F", "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
       SuperscriptBox["u", "2"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[CapitalLambda]"}], 
          SuperscriptBox["u", "2"]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["uh", "2"]], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "u"], "-", 
         RowBox[{"2", " ", "m2", " ", 
          SuperscriptBox["\[Alpha]", "2"], " ", 
          RowBox[{
           SuperscriptBox["F", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], ",", "0", 
     ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"f", "[", "u", "]"}]}], 
       SuperscriptBox["u", "2"]], "+", 
      FractionBox[
       RowBox[{"m2", " ", 
        RowBox[{"F", "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
       SuperscriptBox["u", "2"]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "\[CapitalLambda]"}], 
          SuperscriptBox["u", "2"]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["\[Mu]", "2"]}], 
          SuperscriptBox["uh", "2"]], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["f", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "u"], "-", 
         RowBox[{"2", " ", "m2", " ", 
          SuperscriptBox["\[Alpha]", "2"], " ", 
          RowBox[{
           SuperscriptBox["F", "\[Prime]",
            MultilineFunction->None], "[", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
       RowBox[{
        SuperscriptBox["u", "4"], " ", 
        SuperscriptBox["\[Mu]", "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["uh", "2"], " ", 
        RowBox[{"f", "[", "u", "]"}]}], "+", 
       RowBox[{"2", " ", "m2", " ", 
        SuperscriptBox["uh", "2"], " ", 
        RowBox[{"F", "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
       RowBox[{"2", " ", "u", " ", 
        SuperscriptBox["uh", "2"], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["uh", "2"], " ", 
       RowBox[{"f", "[", "u", "]"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.771960997504943*^9, 3.771961055381294*^9}, 
   3.7719610859925284`*^9, {3.7719611181586533`*^9, 3.7719611202237463`*^9}, 
   3.7719611695984387`*^9, 3.771961237224883*^9, 3.771961319558706*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EQSeinstein", "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqat", "\[Equal]", "0"}], ",", 
       RowBox[{"eqax", "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "[", "u", "]"}], ",", 
       RowBox[{
        RowBox[{"f", "''"}], "[", "u", "]"}]}], "}"}]}], "]"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.7719611412427382`*^9, 3.771961146224061*^9}, {
  3.7719612491799736`*^9, 3.771961297894228*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7719611434875193`*^9, 3.7719611465435266`*^9}, 
   3.771961253219595*^9, {3.7719612923750334`*^9, 3.771961321229579*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["We get the same! It is highly suggested to use the \
safe method! It is easy to implement and we have control on everything.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719613268226814`*^9, 3.7719613491666937`*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations", "Chapter",
 CellChangeTimes->{{3.6240409311615105`*^9, 3.624040932755335*^9}}],

Cell[CellGroupData[{

Cell["EOMs", "Section",
 CellChangeTimes->{{3.6240412000362463`*^9, 3.6240412008956656`*^9}}],

Cell[TextData[StyleBox["For simplicity let us just use the lazy method, check \
you get the same with the other method!",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719613863817883`*^9, 3.771961401890727*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQtx", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"2", " ", 
           SuperscriptBox["uh", "2"], " ", 
           SqrtBox[
            RowBox[{"f", "[", "u", "]"}]]}]]}], "u", " ", "uh", 
        SqrtBox[
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           RowBox[{"f", "[", "u", "]"}]}]]], " "}]], 
      RowBox[{
       RowBox[{"EulerEquations", "[", 
        RowBox[{"ll2", ",", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", "\[CapitalLambda]back"}], "/.",
     "f2ndback"}], " ", "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxy", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", 
          SuperscriptBox["uh", "2"], " ", 
          SqrtBox[
           RowBox[{"f", "[", "u", "]"}]]}]], "u", " ", 
        SqrtBox[
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           RowBox[{"f", "[", "u", "]"}]}]]], " "}]], 
      RowBox[{
       RowBox[{"EulerEquations", "[", 
        RowBox[{"ll2", ",", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", "\[CapitalLambda]back"}], "/.",
     "f2ndback"}], " ", "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxu", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", 
          SuperscriptBox["uh", "2"]}]], "u", " ", 
        SqrtBox[
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           RowBox[{"f", "[", "u", "]"}]}]]], " ", 
        SqrtBox[
         RowBox[{"f", "[", "u", "]"}]], " "}]], 
      RowBox[{
       RowBox[{"EulerEquations", "[", 
        RowBox[{"ll2", ",", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", "\[CapitalLambda]back"}], "/.",
     "f2ndback"}], " ", "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ\[Phi]x", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"m2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{
            SuperscriptBox["u", "2"], " ", 
            RowBox[{"f", "[", "u", "]"}]}]], ")"}], 
         RowBox[{"3", "/", "2"}]], " ", 
        SqrtBox[
         RowBox[{"f", "[", "u", "]"}]], " "}]], 
      RowBox[{
       RowBox[{"EulerEquations", "[", 
        RowBox[{"ll2", ",", 
         RowBox[{"\[Delta]\[Phi]x", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", "\[CapitalLambda]back"}], "/.",
     "f2ndback"}], " ", "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQA", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"uh", " ", 
          SqrtBox[
           RowBox[{"f", "[", "u", "]"}]]}]], "u", " ", 
        SqrtBox[
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           RowBox[{"f", "[", "u", "]"}]}]]], " "}]], 
      RowBox[{
       RowBox[{"EulerEquations", "[", 
        RowBox[{"ll2", ",", 
         RowBox[{"\[Delta]Ax", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", "\[CapitalLambda]back"}], "/.",
     "f2ndback"}], " ", "//", "FS"}]}]}], "Input",
 CellChangeTimes->{{3.624040972943391*^9, 3.624041002323907*^9}, {
  3.6252077833037214`*^9, 3.625207788944619*^9}, {3.6252079115443697`*^9, 
  3.625207990767003*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uh", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "m2", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      RowBox[{"\[Delta]Gtx", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
     RowBox[{"2", " ", "m2", " ", "\[Alpha]", " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Delta]Gtx", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
        RowBox[{
         SuperscriptBox["\[Delta]Gxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "uh", " ", 
      RowBox[{"\[Delta]Gtx", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
     RowBox[{"u", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "u", " ", "\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Ax", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{"2", " ", "uh", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gtx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{"u", " ", "uh", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gtx", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
        RowBox[{"u", " ", "uh", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gxu", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252077897102757`*^9, {3.6252079405926623`*^9, 3.625207991329521*^9}, 
   3.6937484659965134`*^9, 3.6937592324367356`*^9, 3.693809201399454*^9, 
   3.770619524795515*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"f", "[", "u", "]"}]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]Gxy", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
        RowBox[{
         SuperscriptBox["u", "4"], " ", 
         SuperscriptBox["\[Mu]", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["uh", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m2", " ", 
            RowBox[{"F", "[", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
           RowBox[{"2", " ", "u", " ", 
            RowBox[{
             SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "+", 
           RowBox[{"m2", " ", 
            SuperscriptBox["u", "2"], " ", 
            SuperscriptBox["\[Alpha]", "2"], " ", 
            RowBox[{
             SuperscriptBox["F", "\[Prime]",
              MultilineFunction->None], "[", 
             RowBox[{
              SuperscriptBox["u", "2"], " ", 
              SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}]}], 
       ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "m2", " ", "\[Alpha]", " ", 
         RowBox[{
          SuperscriptBox["F", "\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Delta]\[Phi]x", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[Delta]Gxu", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["uh", "2"], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"\[Delta]Gxy", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
     RowBox[{"u", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
        RowBox[{"u", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gxu", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{"u", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gxy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
  "+", 
  RowBox[{
   SuperscriptBox["u", "2"], " ", 
   SuperscriptBox["uh", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Delta]Gtx", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
     RowBox[{
      SuperscriptBox["\[Delta]Gxy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252077897102757`*^9, {3.6252079405926623`*^9, 3.625207991329521*^9}, 
   3.6937484659965134`*^9, 3.6937592324367356`*^9, 3.693809201399454*^9, 
   3.7706195257689214`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "uh"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"uh", " ", 
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "m2", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
       RowBox[{"2", " ", "m2", " ", "\[Alpha]", " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Delta]\[Phi]x", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxu", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxy", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "u", " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["\[Delta]Ax", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
       RowBox[{"uh", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gtx", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
          RowBox[{"u", " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gtx", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
          RowBox[{"u", " ", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxu", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"2", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6252077897102757`*^9, {3.6252079405926623`*^9, 3.625207991329521*^9}, 
   3.6937484659965134`*^9, 3.6937592324367356`*^9, 3.693809201399454*^9, 
   3.770619526290653*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["u", "2"]}], " ", "\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Delta]Gxy", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]x", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["u", "4"], " ", 
      SuperscriptBox["\[Alpha]", "3"], " ", 
      RowBox[{"\[Delta]Gxu", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "3"]}], " ", "\[Alpha]", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Gxu", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]\[Phi]x", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{"u", " ", 
         RowBox[{
          SuperscriptBox["\[Delta]\[Phi]x", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
  "+", 
  RowBox[{"u", " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "2"], " ", "\[Alpha]", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]Gtx", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]x", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252077897102757`*^9, {3.6252079405926623`*^9, 3.625207991329521*^9}, 
   3.6937484659965134`*^9, 3.6937592324367356`*^9, 3.693809201399454*^9, 
   3.7706195267584043`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"uh", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Delta]Ax", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Ax", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Delta]Ax", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"u", " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{"u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SuperscriptBox["\[Delta]Gtx", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Delta]Gxu", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}], "-", 
  RowBox[{"uh", " ", 
   RowBox[{
    SuperscriptBox["\[Delta]Ax", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252077897102757`*^9, {3.6252079405926623`*^9, 3.625207991329521*^9}, 
   3.6937484659965134`*^9, 3.6937592324367356`*^9, 3.693809201399454*^9, 
   3.770619527009734*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gauge invariant combinations", "Section",
 CellChangeTimes->{{3.625207175852106*^9, 3.6252071794147797`*^9}}],

Cell[TextData[{
 StyleBox["The gauge invariant variables are",
  FontWeight->"Bold"],
 "\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "i"], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "2"], 
      SubscriptBox["h", 
       RowBox[{"ti", " "}]]}], "-", 
     FractionBox[
      RowBox[{
       SubscriptBox["\[PartialD]", "t"], 
       SubscriptBox["\[Phi]", "i"]}], "\[Alpha]"]}]}], TraditionalForm]],
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 StyleBox["\n",
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "i"], "=", " ", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], 
     RowBox[{"(", 
      SubscriptBox["h", "ui"]}]}]}], TraditionalForm]],
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 StyleBox["-",
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["\[PartialD]", "u"], 
     SubscriptBox["\[Phi]", "i"]}], 
    RowBox[{"\[Alpha]", " ", 
     SuperscriptBox["u", "2"]}]], ")"}]],
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 StyleBox["\n",
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["B", "i"], "=", 
    RowBox[{
     SubscriptBox["b", "i"], "-", 
     FractionBox[
      RowBox[{" ", 
       SubscriptBox["\[Phi]", "i"]}], "\[Alpha]"]}]}], TraditionalForm]],
  FontSize->18,
  Background->RGBColor[1, 0.85, 0.85]],
 "\n\n",
 StyleBox["and can be found in ",
  FontWeight->"Bold"],
 StyleBox["arXiv:1411.1003",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic",
  Background->RGBColor[0.87, 0.94, 1]]
}], "Text",
 CellChangeTimes->{{3.625210788200808*^9, 3.625210844578577*^9}, {
  3.625210880220924*^9, 3.6252110059770794`*^9}, {3.6937483056021996`*^9, 
  3.69374831549329*^9}, {3.69374837890392*^9, 3.69374837890392*^9}, {
  3.693759048739365*^9, 3.6937590649751773`*^9}, {3.6937591334838552`*^9, 
  3.6937591400779157`*^9}, {3.7719614104659815`*^9, 3.771961421091489*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gtx", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], "+", 
      RowBox[{
       FractionBox["1", "\[Alpha]"], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]x", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}], 
    RowBox[{
     SuperscriptBox["u", "2"], " "}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gxu", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{" ", 
      RowBox[{"U", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
     RowBox[{"f", "[", "u", "]"}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"\[Alpha]", " ", 
       SuperscriptBox["u", "2"]}]], " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]x", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gxy", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{" ", 
      SuperscriptBox["u", "2"]}]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"b", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", "y"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"B", "[", 
     RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "+", 
    RowBox[{
     FractionBox["1", "\[Alpha]"], " ", 
     RowBox[{"\[Delta]\[Phi]x", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"EQtx2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQtx", "/.", "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxy2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQxy", "/.", "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxu2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "uh"}]], "EQxu"}], "/.", 
     "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ\[Phi]x2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[Alpha]", " "}]], "EQ\[Phi]x"}], "/.",
      "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQA2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQA", "/.", "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Delta]Gtx", ",", "\[Delta]Gxu", ",", "\[Delta]Gxy", ",", "b"}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.625208470384223*^9, 3.6252085104643335`*^9}, {
  3.62520855699784*^9, 3.6252085770456934`*^9}, {3.6252086138287487`*^9, 
  3.625208614047528*^9}, {3.625208661909224*^9, 3.625208728240594*^9}, {
  3.625208761929743*^9, 3.6252088427930984`*^9}, {3.6252088758728223`*^9, 
  3.625208968439846*^9}, {3.625209015020258*^9, 3.625209035052482*^9}, {
  3.625209084773672*^9, 3.625209100586949*^9}, {3.6252091512300467`*^9, 
  3.6252091902007284`*^9}, {3.6252105531267834`*^9, 3.625210553783095*^9}, {
  3.6252106660854445`*^9, 3.625210666288578*^9}, {3.6937483815134172`*^9, 
  3.6937483873266807`*^9}, {3.6937590893377743`*^9, 3.6937591011947207`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "m2", " ", "uh", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"T", "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
  RowBox[{"uh", " ", 
   RowBox[{
    SuperscriptBox["T", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{"2", " ", "uh", " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["T", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "u"], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]Ax", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
  RowBox[{"uh", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["T", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "2"], " ", "uh", " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["U", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "-", 
  RowBox[{"uh", " ", 
   RowBox[{
    SuperscriptBox["B", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["u", "2"], " ", "uh", " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252085114643526`*^9, 3.6252086147194104`*^9, {3.62520866740949*^9, 
   3.6252087306313314`*^9}, {3.625208769914502*^9, 3.6252087971345873`*^9}, {
   3.625208827792337*^9, 3.625208847840193*^9}, {3.6252088810761957`*^9, 
   3.625208975565195*^9}, {3.625209026333305*^9, 3.625209035724389*^9}, 
   3.6252091015244856`*^9, {3.6252091528707485`*^9, 3.625209159730459*^9}, 
   3.625209191544516*^9, {3.6252105614553156`*^9, 3.625210578674909*^9}, 
   3.6252106670854864`*^9, 3.6937484808303394`*^9, 3.69375924298534*^9, 
   3.6938092377629037`*^9, 3.770619559682062*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["uh", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "m2", " ", 
         SuperscriptBox["\[Alpha]", "2"], " ", 
         RowBox[{
          SuperscriptBox["F", "\[Prime]",
           MultilineFunction->None], "[", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["B", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["B", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{
          SuperscriptBox["B", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{"u", " ", 
         RowBox[{
          SuperscriptBox["B", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"u", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["T", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], "-", 
        RowBox[{
         SuperscriptBox["B", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], 
  "u"]], "Output",
 CellChangeTimes->{
  3.6252085114643526`*^9, 3.6252086147194104`*^9, {3.62520866740949*^9, 
   3.6252087306313314`*^9}, {3.625208769914502*^9, 3.6252087971345873`*^9}, {
   3.625208827792337*^9, 3.625208847840193*^9}, {3.6252088810761957`*^9, 
   3.625208975565195*^9}, {3.625209026333305*^9, 3.625209035724389*^9}, 
   3.6252091015244856`*^9, {3.6252091528707485`*^9, 3.625209159730459*^9}, 
   3.625209191544516*^9, {3.6252105614553156`*^9, 3.625210578674909*^9}, 
   3.6252106670854864`*^9, 3.6937484808303394`*^9, 3.69375924298534*^9, 
   3.6938092377629037`*^9, 3.7706195598391495`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "m2", " ", 
   SuperscriptBox["u", "2"], " ", "uh", " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"U", "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "2"], " ", "uh", " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
  RowBox[{"4", " ", 
   SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
   RowBox[{
    SuperscriptBox["\[Delta]Ax", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
  RowBox[{"2", " ", "uh", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["B", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["T", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252085114643526`*^9, 3.6252086147194104`*^9, {3.62520866740949*^9, 
   3.6252087306313314`*^9}, {3.625208769914502*^9, 3.6252087971345873`*^9}, {
   3.625208827792337*^9, 3.625208847840193*^9}, {3.6252088810761957`*^9, 
   3.625208975565195*^9}, {3.625209026333305*^9, 3.625209035724389*^9}, 
   3.6252091015244856`*^9, {3.6252091528707485`*^9, 3.625209159730459*^9}, 
   3.625209191544516*^9, {3.6252105614553156`*^9, 3.625210578674909*^9}, 
   3.6252106670854864`*^9, 3.6937484808303394`*^9, 3.69375924298534*^9, 
   3.6938092377629037`*^9, 3.7706195601922455`*^9}],

Cell[BoxData[
 RowBox[{"2", " ", "u", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["u", "3"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"U", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["B", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}], "+", 
          RowBox[{
           SuperscriptBox["u", "2"], " ", 
           RowBox[{
            SuperscriptBox["U", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["F", "\[Prime]",
       MultilineFunction->None], "[", 
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["T", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6252085114643526`*^9, 3.6252086147194104`*^9, {3.62520866740949*^9, 
   3.6252087306313314`*^9}, {3.625208769914502*^9, 3.6252087971345873`*^9}, {
   3.625208827792337*^9, 3.625208847840193*^9}, {3.6252088810761957`*^9, 
   3.625208975565195*^9}, {3.625209026333305*^9, 3.625209035724389*^9}, 
   3.6252091015244856`*^9, {3.6252091528707485`*^9, 3.625209159730459*^9}, 
   3.625209191544516*^9, {3.6252105614553156`*^9, 3.625210578674909*^9}, 
   3.6252106670854864`*^9, 3.6937484808303394`*^9, 3.69375924298534*^9, 
   3.6938092377629037`*^9, 3.7706195602941923`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"uh", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]Ax", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{
       SuperscriptBox["T", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
     RowBox[{"uh", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]Ax", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"uh", " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]Ax", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
   RowBox[{
    SuperscriptBox["U", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "-", 
  RowBox[{"uh", " ", 
   RowBox[{
    SuperscriptBox["\[Delta]Ax", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252085114643526`*^9, 3.6252086147194104`*^9, {3.62520866740949*^9, 
   3.6252087306313314`*^9}, {3.625208769914502*^9, 3.6252087971345873`*^9}, {
   3.625208827792337*^9, 3.625208847840193*^9}, {3.6252088810761957`*^9, 
   3.625208975565195*^9}, {3.625209026333305*^9, 3.625209035724389*^9}, 
   3.6252091015244856`*^9, {3.6252091528707485`*^9, 3.625209159730459*^9}, 
   3.625209191544516*^9, {3.6252105614553156`*^9, 3.625210578674909*^9}, 
   3.6252106670854864`*^9, 3.6937484808303394`*^9, 3.69375924298534*^9, 
   3.6938092377629037`*^9, 3.7706195603580227`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Check: with these combinations all the other \
variables disappear. The combinations are correct.\nPS. You can try to \
implement a program that find for you all the gauge invariant combinations \
very generally ...",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.77061954472269*^9, 3.770619555809199*^9}, {
  3.771961447394334*^9, 3.7719614923847275`*^9}, {3.773392831163094*^9, 
  3.7733928375499506`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier decomposition", "Section",
 CellChangeTimes->{{3.625209202982583*^9, 3.6252092061858854`*^9}}],

Cell[TextData[StyleBox["Just going to Fourier space",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.771961502857339*^9, 3.7719615069820776`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Omega]", " ", "t"}], " ", "-", " ", 
       RowBox[{"k", " ", "y"}]}], ")"}]}]], 
   RowBox[{"T", "[", "u", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "[", 
   RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Omega]", " ", "t"}], " ", "-", " ", 
       RowBox[{"k", " ", "y"}]}], ")"}]}]], 
   RowBox[{"U", "[", "u", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B", "[", 
   RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Omega]", " ", "t"}], " ", "-", " ", 
       RowBox[{"k", " ", "y"}]}], ")"}]}]], 
   RowBox[{"B", "[", "u", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]Ax", "[", 
   RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Omega]", " ", "t"}], " ", "-", " ", 
       RowBox[{"k", " ", "y"}]}], ")"}]}]], 
   RowBox[{"aa", "[", "u", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EQtx3", "=", 
  RowBox[{
   RowBox[{
    FractionBox["u", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "y"}], "-", 
         RowBox[{"t", " ", "\[Omega]"}]}], ")"}]}]]], "EQtx2"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxy3", "=", 
  RowBox[{
   RowBox[{
    FractionBox["u", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "y"}], "-", 
         RowBox[{"t", " ", "\[Omega]"}]}], ")"}]}]]], "EQxy2"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxu3", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"k", " ", "y"}], "-", 
          RowBox[{"t", " ", "\[Omega]"}]}], ")"}]}]]}]], "EQxu2"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ\[Phi]x3", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"k", " ", "y"}], "-", 
          RowBox[{"t", " ", "\[Omega]"}]}], ")"}]}]]}]], "EQ\[Phi]x2"}], "//",
    "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQA3", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"k", " ", "y"}], "-", 
         RowBox[{"t", " ", "\[Omega]"}]}], ")"}]}]]], "EQA2"}], "//", 
   "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"T", ",", "U", ",", "B", ",", "\[Delta]Ax"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.6252092096235256`*^9, 3.6252093555369263`*^9}, {
  3.625209422633955*^9, 3.6252094394785323`*^9}, {3.625210571237049*^9, 
  3.625210571471439*^9}, {3.6252106218020473`*^9, 3.625210623005231*^9}, {
  3.6252106769297233`*^9, 3.6252106775078716`*^9}, {3.69374850498934*^9, 
  3.6937485272050495`*^9}, {3.6937592582650037`*^9, 3.693759261413103*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SuperscriptBox["k", "2"], " ", "u", " ", "uh", " ", "\[Omega]", " ", 
   RowBox[{"B", "[", "u", "]"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "3"], " ", "\[Mu]", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["aa", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["u", "3"], " ", "uh", " ", "\[Omega]", " ", 
    RowBox[{"U", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "-", 
  RowBox[{"u", " ", "uh", " ", 
   RowBox[{"T", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     RowBox[{"2", " ", "m2", " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", "uh", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["T", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["u", "3"], " ", "uh", " ", "\[Omega]", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "+", 
  RowBox[{"u", " ", "uh", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["T", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.6252092896274414`*^9, 3.625209356177574*^9}, 
   3.6252094401191826`*^9, 3.625210573534033*^9, {3.62521061423915*^9, 
   3.6252106239114985`*^9}, {3.6252106721638603`*^9, 
   3.6252106781016507`*^9}, {3.693748500810568*^9, 3.693748527714387*^9}, 
   3.6937592647775693`*^9, 3.693809245841407*^9, 3.770619564587734*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", 
  SuperscriptBox["uh", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "u", " ", "\[Omega]", " ", 
     RowBox[{"T", "[", "u", "]"}]}], "-", 
    RowBox[{"u", " ", 
     RowBox[{"B", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "-", 
       RowBox[{"2", " ", "m2", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["B", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{"u", " ", 
        RowBox[{
         SuperscriptBox["B", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{"u", " ", 
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["B", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.6252092896274414`*^9, 3.625209356177574*^9}, 
   3.6252094401191826`*^9, 3.625210573534033*^9, {3.62521061423915*^9, 
   3.6252106239114985`*^9}, {3.6252106721638603`*^9, 
   3.6252106781016507`*^9}, {3.693748500810568*^9, 3.693748527714387*^9}, 
   3.6937592647775693`*^9, 3.693809245841407*^9, 3.770619564802127*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["u", "2"], " ", "\[Mu]", " ", "\[Omega]", " ", 
   RowBox[{"aa", "[", "u", "]"}]}], "+", 
  FractionBox[
   RowBox[{"uh", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       RowBox[{"U", "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Omega]", "2"]}], "+", 
         RowBox[{
          RowBox[{"f", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["k", "2"], "+", 
            RowBox[{"2", " ", "m2", " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             RowBox[{
              SuperscriptBox["F", "\[Prime]",
               MultilineFunction->None], "[", 
              RowBox[{
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["k", "2"]}], " ", 
          RowBox[{"f", "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
          RowBox[{
           SuperscriptBox["T", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"f", "[", "u", "]"}]]}]], "Output",
 CellChangeTimes->{{3.6252092896274414`*^9, 3.625209356177574*^9}, 
   3.6252094401191826`*^9, 3.625210573534033*^9, {3.62521061423915*^9, 
   3.6252106239114985`*^9}, {3.6252106721638603`*^9, 
   3.6252106781016507`*^9}, {3.693748500810568*^9, 3.693748527714387*^9}, 
   3.6937592647775693`*^9, 3.693809245841407*^9, 3.7706195650524583`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["k", "2"]}], " ", 
      RowBox[{"B", "[", "u", "]"}], " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"T", "[", "u", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "4"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.6252092896274414`*^9, 3.625209356177574*^9}, 
   3.6252094401191826`*^9, 3.625210573534033*^9, {3.62521061423915*^9, 
   3.6252106239114985`*^9}, {3.6252106721638603`*^9, 
   3.6252106781016507`*^9}, {3.693748500810568*^9, 3.693748527714387*^9}, 
   3.6937592647775693`*^9, 3.693809245841407*^9, 3.7706195651222706`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uh", " ", 
   RowBox[{"aa", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], "-", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"f", "[", "u", "]"}]}]}], ")"}]}], "-", 
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["u", "2"], " ", "\[Mu]", " ", "\[Omega]", " ", 
   RowBox[{"U", "[", "u", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"uh", " ", 
      RowBox[{
       SuperscriptBox["aa", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{
       SuperscriptBox["T", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{"uh", " ", 
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["aa", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6252092896274414`*^9, 3.625209356177574*^9}, 
   3.6252094401191826`*^9, 3.625210573534033*^9, {3.62521061423915*^9, 
   3.6252106239114985`*^9}, {3.6252106721638603`*^9, 
   3.6252106781016507`*^9}, {3.693748500810568*^9, 3.693748527714387*^9}, 
   3.6937592647775693`*^9, 3.693809245841407*^9, 3.7706195652120323`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Indipendence of the equations", "Section",
 CellChangeTimes->{{3.6252094568075275`*^9, 3.6252094639641066`*^9}, {
  3.625209651426408*^9, 3.6252096553484716`*^9}}],

Cell[TextData[StyleBox["Not all these equations are necessary",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719615183556147`*^9, 3.771961528304695*^9}, {
  3.7733928627703476`*^9, 3.7733928629767957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"EQtx3", "\[IndentingNewLine]", "EQxy3", "\[IndentingNewLine]", \
"EQxu3", "\[IndentingNewLine]", "EQ\[Phi]x3"}], "Input",
 CellChangeTimes->{{3.62520947137074*^9, 3.62520947760542*^9}, {
  3.6252095793291225`*^9, 3.625209584110609*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SuperscriptBox["k", "2"], " ", "u", " ", "uh", " ", "\[Omega]", " ", 
   RowBox[{"B", "[", "u", "]"}]}], "-", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "3"], " ", "\[Mu]", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["aa", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["u", "3"], " ", "uh", " ", "\[Omega]", " ", 
    RowBox[{"U", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "-", 
  RowBox[{"u", " ", "uh", " ", 
   RowBox[{"T", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     RowBox[{"2", " ", "m2", " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", "uh", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["T", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["u", "3"], " ", "uh", " ", "\[Omega]", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "+", 
  RowBox[{"u", " ", "uh", " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["T", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252094779960365`*^9, {3.625209582063631*^9, 3.6252095844856224`*^9}, 
   3.6252106370996447`*^9, 3.6252106846800985`*^9, 3.6937485429554815`*^9, 
   3.693809250944848*^9, 3.7706195703591027`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", 
  SuperscriptBox["uh", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "u", " ", "\[Omega]", " ", 
     RowBox[{"T", "[", "u", "]"}]}], "-", 
    RowBox[{"u", " ", 
     RowBox[{"B", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Omega]", "2"], "-", 
       RowBox[{"2", " ", "m2", " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["B", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{"u", " ", 
        RowBox[{
         SuperscriptBox["B", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       RowBox[{"u", " ", 
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["B", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.6252094779960365`*^9, {3.625209582063631*^9, 3.6252095844856224`*^9}, 
   3.6252106370996447`*^9, 3.6252106846800985`*^9, 3.6937485429554815`*^9, 
   3.693809250944848*^9, 3.7706195703680105`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["u", "2"], " ", "\[Mu]", " ", "\[Omega]", " ", 
   RowBox[{"aa", "[", "u", "]"}]}], "+", 
  FractionBox[
   RowBox[{"uh", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "2"], " ", 
       RowBox[{"U", "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[Omega]", "2"]}], "+", 
         RowBox[{
          RowBox[{"f", "[", "u", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["k", "2"], "+", 
            RowBox[{"2", " ", "m2", " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             RowBox[{
              SuperscriptBox["F", "\[Prime]",
               MultilineFunction->None], "[", 
              RowBox[{
               SuperscriptBox["u", "2"], " ", 
               SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["k", "2"]}], " ", 
          RowBox[{"f", "[", "u", "]"}], " ", 
          RowBox[{
           SuperscriptBox["B", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
          RowBox[{
           SuperscriptBox["T", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"f", "[", "u", "]"}]]}]], "Output",
 CellChangeTimes->{
  3.6252094779960365`*^9, {3.625209582063631*^9, 3.6252095844856224`*^9}, 
   3.6252106370996447`*^9, 3.6252106846800985`*^9, 3.6937485429554815`*^9, 
   3.693809250944848*^9, 3.7706195703729973`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["k", "2"]}], " ", 
      RowBox[{"B", "[", "u", "]"}], " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
      RowBox[{"T", "[", "u", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "4"], " ", 
   SuperscriptBox["\[Alpha]", "2"], " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{
    SuperscriptBox["F", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", 
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.6252094779960365`*^9, {3.625209582063631*^9, 3.6252095844856224`*^9}, 
   3.6252106370996447`*^9, 3.6252106846800985`*^9, 3.6937485429554815`*^9, 
   3.693809250944848*^9, 3.7706195703769865`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{"EQxu3", ",", "u"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"EQtx3", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"T", "''"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"EQxy3", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"B", "''"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"EQ\[Phi]x3", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"U", "'"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%%%%", "/.", "%%%"}], "/.", "%%"}], "/.", "%"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"EQxu3", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"T", "'"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%%", "/.", "%"}], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.6252094838556976`*^9, 3.6252095533903637`*^9}, {
  3.6252095942829895`*^9, 3.6252096411446543`*^9}, {3.69375927291967*^9, 
  3.693759275982336*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.625209487433997*^9, 3.625209524482685*^9}, 
   3.62520955509356*^9, {3.6252096201436186`*^9, 3.625209642722849*^9}, 
   3.625210641115466*^9, 3.625210687633366*^9, 3.6937485495248375`*^9, 
   3.6937592789199524`*^9, 3.693809255635105*^9, 3.7706195712092805`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["One equation is redundant, lets forget about it",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770619576257559*^9, 3.770619580108528*^9}, {
  3.7719615349904284`*^9, 3.7719615376954565`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Remaining 4 Equations and massaging", "Section",
 CellChangeTimes->{{3.625209669536688*^9, 3.6252096744744043`*^9}, {
  3.6252102635501347`*^9, 3.625210263925136*^9}, {3.6252115770050297`*^9, 
  3.6252115789895215`*^9}}],

Cell["\<\
This is some massaging to make them nicer! Also the collect command can be \
useful\
\>", "Text",
 CellChangeTimes->{{3.7719615535681067`*^9, 3.771961574920102*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"order", "=", 
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"B", "''"}], "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"B", "'"}], "[", "u", "]"}], ",", 
        RowBox[{"B", "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"U", "''"}], "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"U", "'"}], "[", "u", "]"}], ",", 
        RowBox[{"U", "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"aa", "''"}], "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"aa", "'"}], "[", "u", "]"}], ",", 
        RowBox[{"aa", "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"T", "''"}], "[", "u", "]"}], ",", 
        RowBox[{
         RowBox[{"T", "'"}], "[", "u", "]"}], ",", 
        RowBox[{"T", "[", "u", "]"}]}], "}"}], ",", "Expand"}], "]"}], 
    "&"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.62520973132094*^9, 3.6252097677602253`*^9}, {
  3.625210235220603*^9, 3.6252102374394627`*^9}, {3.6252114815628786`*^9, 
  3.625211489391387*^9}, {3.6937592897968464`*^9, 3.6937593022829175`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "u", " ", "uh", " ", 
      RowBox[{"f", "[", "u", "]"}], " "}]], "EQtx3"}], "//", "order"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"exy", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"\[ImaginaryI]", " ", "k", "  ", "u", " ", 
      SuperscriptBox["uh", "2"], " ", 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"], " "}]], "EQxy3"}], "//", 
   "order"}]}], "\[IndentingNewLine]", 
 RowBox[{"exu", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{" ", 
      RowBox[{"\[ImaginaryI]", " ", "uh", " ", "\[Omega]"}]}]], "EQxu3"}], "//",
    "order"}]}], "\[IndentingNewLine]", 
 RowBox[{"e\[Phi]x", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]], "EQ\[Phi]x3"}], "//", 
   "order"}]}], "\[IndentingNewLine]", 
 RowBox[{"eA", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"uh", " ", 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"], " "}]], "EQA3"}], "//", 
   "order"}]}]}], "Input",
 CellChangeTimes->{{3.625209699335002*^9, 3.6252097008350954`*^9}, {
   3.625209769900956*^9, 3.625209842404505*^9}, {3.6252100072719593`*^9, 
   3.625210045086297*^9}, {3.6252102047191105`*^9, 3.6252102201729918`*^9}, {
   3.6252102527058573`*^9, 3.6252102535808716`*^9}, 3.6252106530066776`*^9, {
   3.625210706337414*^9, 3.625210706462415*^9}, 3.6252115690827675`*^9, {
   3.6937485802181616`*^9, 3.693748616975512*^9}, 3.6937593166259108`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
     RowBox[{"T", "[", "u", "]"}]}], 
    SuperscriptBox[
     RowBox[{"f", "[", "u", "]"}], "2"]]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["B", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "u"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"B", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", "m2", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "2"], " ", 
    RowBox[{
     SuperscriptBox["U", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "+", 
  RowBox[{
   SuperscriptBox["B", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}]}]], "Output",
 CellChangeTimes->{{3.625209683818611*^9, 3.6252097013663435`*^9}, {
   3.6252097711353827`*^9, 3.6252098427638907`*^9}, 3.6252100164598923`*^9, 
   3.6252100466332445`*^9, {3.625210207625497*^9, 3.625210254080899*^9}, {
   3.625210647553279*^9, 3.6252106534285684`*^9}, {3.6252106930086317`*^9, 
   3.625210706915563*^9}, 3.6252114927040215`*^9, 3.6252115696140404`*^9, {
   3.6937485636251717`*^9, 3.6937486174007893`*^9}, {3.693759312297573*^9, 
   3.693759317563444*^9}, 3.693809278228074*^9, 3.77061958711753*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
     RowBox[{"aa", "[", "u", "]"}]}], "uh"]}], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], "\[Omega]"], "+", 
  RowBox[{
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox["u", "2"]}], "\[Omega]"]}], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["u", "2"], " ", "\[Omega]"}], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "m2", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "\[Omega]"]}], ")"}]}], 
  "+", 
  RowBox[{
   SuperscriptBox["T", "\[Prime]",
    MultilineFunction->None], "[", "u", "]"}]}]], "Output",
 CellChangeTimes->{{3.625209683818611*^9, 3.6252097013663435`*^9}, {
   3.6252097711353827`*^9, 3.6252098427638907`*^9}, 3.6252100164598923`*^9, 
   3.6252100466332445`*^9, {3.625210207625497*^9, 3.625210254080899*^9}, {
   3.625210647553279*^9, 3.6252106534285684`*^9}, {3.6252106930086317`*^9, 
   3.625210706915563*^9}, 3.6252114927040215`*^9, 3.6252115696140404`*^9, {
   3.6937485636251717`*^9, 3.6937486174007893`*^9}, {3.693759312297573*^9, 
   3.693759317563444*^9}, 3.693809278228074*^9, 3.770619587126507*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"B", "[", "u", "]"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"f", "[", "u", "]"}]}]]}], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", 
    RowBox[{"T", "[", "u", "]"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"f", "[", "u", "]"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "2"], " ", 
    RowBox[{
     SuperscriptBox["U", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "3"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"U", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]]}]], "Output",
 CellChangeTimes->{{3.625209683818611*^9, 3.6252097013663435`*^9}, {
   3.6252097711353827`*^9, 3.6252098427638907`*^9}, 3.6252100164598923`*^9, 
   3.6252100466332445`*^9, {3.625210207625497*^9, 3.625210254080899*^9}, {
   3.625210647553279*^9, 3.6252106534285684`*^9}, {3.6252106930086317`*^9, 
   3.625210706915563*^9}, 3.6252114927040215`*^9, 3.6252115696140404`*^9, {
   3.6937485636251717`*^9, 3.6937486174007893`*^9}, {3.693759312297573*^9, 
   3.693759317563444*^9}, 3.693809278228074*^9, 3.7706195871344852`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "-", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["u", "2"], " ", "\[Mu]", " ", "\[Omega]", " ", 
    RowBox[{"U", "[", "u", "]"}]}], 
   RowBox[{"uh", " ", 
    SuperscriptBox[
     RowBox[{"f", "[", "u", "]"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "-", 
  FractionBox[
   RowBox[{"\[Mu]", " ", 
    RowBox[{
     SuperscriptBox["T", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"uh", " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "+", 
  RowBox[{
   SuperscriptBox["aa", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}]}]], "Output",
 CellChangeTimes->{{3.625209683818611*^9, 3.6252097013663435`*^9}, {
   3.6252097711353827`*^9, 3.6252098427638907`*^9}, 3.6252100164598923`*^9, 
   3.6252100466332445`*^9, {3.625210207625497*^9, 3.625210254080899*^9}, {
   3.625210647553279*^9, 3.6252106534285684`*^9}, {3.6252106930086317`*^9, 
   3.625210706915563*^9}, 3.6252114927040215`*^9, 3.6252115696140404`*^9, {
   3.6937485636251717`*^9, 3.6937486174007893`*^9}, {3.693759312297573*^9, 
   3.693759317563444*^9}, 3.693809278228074*^9, 3.7706195871404743`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"e\[Phi]x", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"U", "'"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"EqB", "=", 
  RowBox[{
   RowBox[{"exy", "/.", "%"}], "//", "order"}]}]}], "Input",
 CellChangeTimes->{{3.625211617772644*^9, 3.6252116508367662`*^9}, {
   3.625211995884905*^9, 3.6252119980568857`*^9}, {3.693748622503173*^9, 
   3.6937486396385174`*^9}, 3.693759329018524*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["B", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "u"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"B", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", "m2", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["B", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "3"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"U", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]]}]], "Output",
 CellChangeTimes->{
  3.625211651180529*^9, 3.625212006385412*^9, 3.6937486406241703`*^9, {
   3.6937593267371607`*^9, 3.693759329518546*^9}, 3.693809280900839*^9, 
   3.770619587244193*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"exu", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"T", "'"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"e\[Phi]x", "\[Equal]", "0"}], ",", 
      RowBox[{"T", "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"EqU", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"f", "[", "u", "]"}], 
         SuperscriptBox["u", "2"]], "2", 
        RowBox[{"D", "[", 
         RowBox[{"e\[Phi]x", ",", "u"}], "]"}]}], "/.", "%%"}], "/.", "%"}], "/.",
      "f2ndback"}], "/.", "\[CapitalLambda]back"}], "//", 
   "order"}]}]}], "Input",
 CellChangeTimes->{{3.6252117934687414`*^9, 3.6252118308611984`*^9}, {
  3.6252118736914263`*^9, 3.6252119081931124`*^9}, {3.625212001791438*^9, 
  3.625212003369646*^9}, {3.6937486487035265`*^9, 3.693748708087858*^9}, {
  3.693759332549951*^9, 3.6937593481276164`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Mu]", " ", "\[Omega]", " ", 
    RowBox[{"aa", "[", "u", "]"}]}], 
   RowBox[{"uh", " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"B", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{
    SuperscriptBox["u", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["2", "u"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]], "+", 
     FractionBox[
      RowBox[{"2", " ", "u", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}], "+", 
  RowBox[{
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", "m2", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"f", "[", "u", "]"}]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]], "+", 
     FractionBox[
      RowBox[{"2", " ", "u", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}], "2"]}], 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       RowBox[{
        SuperscriptBox["F", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6252117976095715`*^9, 3.62521183159561*^9}, {
   3.625211887035823*^9, 3.625211909115028*^9}, 3.625212008182377*^9, 
   3.6937487104143944`*^9, {3.693759334800044*^9, 3.693759348643258*^9}, 
   3.693809285925172*^9, 3.7706195874336853`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"exu", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"T", "'"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FS"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"EqA", "=", 
  RowBox[{
   RowBox[{"eA", "/.", "%"}], "//", "order"}]}]}], "Input",
 CellChangeTimes->{{3.625211959179983*^9, 3.6252119751807613`*^9}, {
   3.625212010104353*^9, 3.6252120116356754`*^9}, {3.6937487210574436`*^9, 
   3.6937487258546257`*^9}, 3.6937593511448326`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], 
      RowBox[{
       SuperscriptBox["uh", "2"], " ", 
       RowBox[{"f", "[", "u", "]"}]}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["k", "2"], " ", "\[Mu]", " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"uh", " ", "\[Omega]"}]], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "+", 
  RowBox[{
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox["u", "2"], " ", "\[Mu]"}], 
       RowBox[{"uh", " ", "\[Omega]", " ", 
        RowBox[{"f", "[", "u", "]"}]}]]}], "-", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "m2", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", "\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"uh", " ", "\[Omega]", " ", 
       RowBox[{"f", "[", "u", "]"}]}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["aa", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}]}]], "Output",
 CellChangeTimes->{{3.625211972727517*^9, 3.6252119756495357`*^9}, 
   3.625212012541966*^9, 3.693748726465025*^9, 3.6937593523167534`*^9, 
   3.6938092875382404`*^9, 3.7706195875244493`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Final 3 equations", "Section",
 CellChangeTimes->{{3.625211986150077*^9, 3.6252119906346707`*^9}}],

Cell[TextData[StyleBox["These are our final three equations",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7719621959345665`*^9, 3.7719622014458923`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQBfinal", "=", 
  RowBox[{"EqB", "/.", 
   RowBox[{"\[Mu]", "\[Rule]", 
    RowBox[{"\[Rho]", " ", "uh"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EQAfinal", "=", 
  RowBox[{"EqA", "/.", 
   RowBox[{"\[Mu]", "\[Rule]", 
    RowBox[{"\[Rho]", " ", "uh"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EQUfinal", "=", 
  RowBox[{"EqU", "/.", 
   RowBox[{"\[Mu]", "\[Rule]", 
    RowBox[{"\[Rho]", " ", "uh"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.6252120175578346`*^9, 3.6252120249800816`*^9}, {
  3.693748738101737*^9, 3.6937487977562475`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["B", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "u"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"B", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", "m2", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["B", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "3"], " ", 
    SuperscriptBox["\[Alpha]", "2"], " ", 
    RowBox[{"U", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]",
      MultilineFunction->None], "[", 
     RowBox[{
      SuperscriptBox["u", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]]}]], "Output",
 CellChangeTimes->{
  3.6937487613621435`*^9, {3.693748792802967*^9, 3.6937487981535063`*^9}, 
   3.6937593641454353`*^9, 3.6938092985071955`*^9, 3.7706195956058607`*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"aa", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Rho]", "2"]}], 
      RowBox[{"f", "[", "u", "]"}]]}], ")"}]}], "+", 
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["k", "2"], " ", "\[Rho]", " ", 
    RowBox[{
     SuperscriptBox["B", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], "\[Omega]"], "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["aa", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "+", 
  RowBox[{
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox["u", "2"], " ", "\[Rho]"}], 
       RowBox[{"\[Omega]", " ", 
        RowBox[{"f", "[", "u", "]"}]}]]}], "-", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "m2", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", "\[Rho]", " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"\[Omega]", " ", 
       RowBox[{"f", "[", "u", "]"}]}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["aa", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}]}]], "Output",
 CellChangeTimes->{
  3.6937487613621435`*^9, {3.693748792802967*^9, 3.6937487981535063`*^9}, 
   3.6937593641454353`*^9, 3.6938092985071955`*^9, 3.770619595618826*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Rho]", " ", "\[Omega]", " ", 
    RowBox[{"aa", "[", "u", "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"B", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], 
   RowBox[{
    SuperscriptBox["u", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["2", "u"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      RowBox[{"f", "[", "u", "]"}]], "+", 
     FractionBox[
      RowBox[{"2", " ", "u", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "u", "]"}], "+", 
  RowBox[{
   RowBox[{"U", "[", "u", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Omega]", "2"], 
      SuperscriptBox[
       RowBox[{"f", "[", "u", "]"}], "2"]], "-", 
     FractionBox[
      SuperscriptBox["k", "2"], 
      RowBox[{"f", "[", "u", "]"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", "m2", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{"f", "[", "u", "]"}]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]], "+", 
     FractionBox[
      RowBox[{"2", " ", "u", " ", 
       SuperscriptBox["\[Alpha]", "2"], " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}], "]"}], "2"]}], 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["F", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["u", "2"], " ", 
       SuperscriptBox["\[Alpha]", "4"], " ", 
       RowBox[{
        SuperscriptBox["F", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], 
      RowBox[{
       SuperscriptBox["F", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6937487613621435`*^9, {3.693748792802967*^9, 3.6937487981535063`*^9}, 
   3.6937593641454353`*^9, 3.6938092985071955`*^9, 3.7706195956337857`*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 1, 0]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Write them in compact form", "Section",
 CellChangeTimes->{{3.693750472010399*^9, 3.6937504773509364`*^9}, {
  3.6937511557002854`*^9, 3.693751156624693*^9}, {3.6937593961620145`*^9, 
  3.6937593965057755`*^9}, {3.7706196016947327`*^9, 3.770619604782525*^9}, {
  3.7719622058469443`*^9, 3.771962206396821*^9}, {3.773392905283146*^9, 
  3.7733929058487062`*^9}}],

Cell[TextData[{
 StyleBox["Write them as in ",
  FontWeight->"Bold"],
 StyleBox["arXiv:1411.1003",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic",
  Background->RGBColor[0.87, 0.94, 1]]
}], "Text",
 CellChangeTimes->{{3.771962211309744*^9, 3.771962221895834*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "u_", "]"}], "=", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"m2", " ", 
      RowBox[{
       RowBox[{"F", "'"}], "[", 
       RowBox[{
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["u", "2"], 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"f", "[", "u", "]"}], 
         SuperscriptBox["u", "2"]], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"B", "[", "u", "]"}], ",", "u"}], "]"}]}], ",", "u"}], 
      "]"}]}], "+", 
    RowBox[{
     RowBox[{"B", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"f", "[", "u", "]"}]], "-", 
       SuperscriptBox["k", "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"M", "[", "u", "]"}], "2"], 
     RowBox[{"B", "[", "u", "]"}]}], "+", 
    RowBox[{"2", 
     FractionBox[
      RowBox[{
       RowBox[{"M", "'"}], "[", "u", "]"}], 
      RowBox[{"M", "[", "u", "]"}]], 
     SuperscriptBox["u", "2"], 
     RowBox[{"U", "[", "u", "]"}]}]}], "//", "order"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "EQBfinal"}], "//", "order"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", "%%"}], "//", "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], 
       RowBox[{
        RowBox[{"aa", "'"}], "[", "u", "]"}]}], ",", "u"}], "]"}], "+", 
    RowBox[{
     RowBox[{"aa", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"f", "[", "u", "]"}]], "-", 
       SuperscriptBox["k", "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Rho]", "2"], 
     RowBox[{"aa", "[", "u", "]"}]}], "-", 
    RowBox[{"2", "I", " ", 
     SuperscriptBox[
      RowBox[{"M", "[", "u", "]"}], "2"], 
     FractionBox[
      RowBox[{"\[Rho]", " "}], "\[Omega]"], 
     SuperscriptBox["u", "2"], 
     RowBox[{"U", "[", "u", "]"}]}], "-", 
    RowBox[{"I", " ", 
     SuperscriptBox["k", "2"], 
     FractionBox[
      RowBox[{"\[Rho]", " ", 
       RowBox[{"f", "[", "u", "]"}]}], 
      RowBox[{" ", "\[Omega]"}]], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["u", "2"], 
         RowBox[{"f", "[", "u", "]"}]], 
        RowBox[{"U", "[", "u", "]"}]}], "-", 
       RowBox[{
        RowBox[{"B", "'"}], "[", "u", "]"}]}], ")"}]}]}], "//", "order"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "u", "]"}], "EQAfinal"}], "//", "order"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", "%%"}], "//", "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"f", "[", "u", "]"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["u", "2"]], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{"f", "[", "u", "]"}], 
              SuperscriptBox["u", "2"]}], 
             SuperscriptBox[
              RowBox[{"M", "[", "u", "]"}], "2"]], 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"M", "[", "u", "]"}], "2"], 
               RowBox[{"U", "[", "u", "]"}]}], ",", "u"}], "]"}]}], ",", 
           "u"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            SuperscriptBox["\[Omega]", "2"], 
            RowBox[{"f", "[", "u", "]"}]], "-", 
           SuperscriptBox["k", "2"]}], ")"}], 
         RowBox[{"U", "[", "u", "]"}]}], "-", 
        RowBox[{"2", 
         SuperscriptBox[
          RowBox[{"M", "[", "u", "]"}], "2"], 
         RowBox[{"U", "[", "u", "]"}]}], "+", 
        RowBox[{"2", "I", " ", "\[Rho]", " ", "\[Omega]", " ", 
         RowBox[{"aa", "[", "u", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["k", "2"], 
         RowBox[{"B", "[", "u", "]"}], " ", 
         FractionBox[
          RowBox[{
           RowBox[{"f", "'"}], "[", "u", "]"}], 
          RowBox[{" ", 
           SuperscriptBox["u", "2"]}]]}]}], ")"}]}], "/.", "f2ndback"}], "/.",
     "\[CapitalLambda]back"}], "//", "order"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EQUfinal", "/.", 
    RowBox[{"\[Mu]", "\[Rule]", 
     RowBox[{"\[Rho]", " ", "uh"}]}]}], "//", "order"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", "%%"}], "//", "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "M", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.693750589769395*^9, 3.6937506067936697`*^9}, {
  3.693759386536555*^9, 3.693759475741816*^9}, {3.6938093092303014`*^9, 
  3.6938093150581613`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.693750608269644*^9, {3.693759404211499*^9, 3.6937594761949625`*^9}, {
   3.6938093046032457`*^9, 3.6938093155925117`*^9}, 3.770619607221671*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.693750608269644*^9, {3.693759404211499*^9, 3.6937594761949625`*^9}, {
   3.6938093046032457`*^9, 3.6938093155925117`*^9}, 3.770619607224663*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.693750608269644*^9, {3.693759404211499*^9, 3.6937594761949625`*^9}, {
   3.6938093046032457`*^9, 3.6938093155925117`*^9}, 3.7706196072276545`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["u", "2"], 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"f", "[", "u", "]"}], 
         SuperscriptBox["u", "2"]], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"B", "[", "u", "]"}], ",", "u"}], "]"}]}], ",", "u"}], 
      "]"}]}], "+", 
    RowBox[{
     RowBox[{"B", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"f", "[", "u", "]"}]], "-", 
       SuperscriptBox["k", "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"M", "[", "u", "]"}], "2"], 
     RowBox[{"B", "[", "u", "]"}]}], "+", 
    RowBox[{"2", 
     FractionBox[
      RowBox[{
       RowBox[{"M", "'"}], "[", "u", "]"}], 
      RowBox[{"M", "[", "u", "]"}]], 
     SuperscriptBox["u", "2"], 
     RowBox[{"U", "[", "u", "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], 
       RowBox[{
        RowBox[{"aa", "'"}], "[", "u", "]"}]}], ",", "u"}], "]"}], "+", 
    RowBox[{
     RowBox[{"aa", "[", "u", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox["\[Omega]", "2"], 
        RowBox[{"f", "[", "u", "]"}]], "-", 
       SuperscriptBox["k", "2"]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["\[Rho]", "2"], 
     RowBox[{"aa", "[", "u", "]"}]}], "-", 
    RowBox[{"2", "I", " ", 
     SuperscriptBox[
      RowBox[{"M", "[", "u", "]"}], "2"], 
     FractionBox[
      RowBox[{"\[Rho]", " "}], "\[Omega]"], 
     SuperscriptBox["u", "2"], 
     RowBox[{"U", "[", "u", "]"}]}], "-", 
    RowBox[{"I", " ", 
     SuperscriptBox["k", "2"], 
     FractionBox[
      RowBox[{"\[Rho]", " ", 
       RowBox[{"f", "[", "u", "]"}]}], 
      RowBox[{" ", "\[Omega]"}]], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["u", "2"], 
         RowBox[{"f", "[", "u", "]"}]], 
        RowBox[{"U", "[", "u", "]"}]}], "-", 
       RowBox[{
        RowBox[{"B", "'"}], "[", "u", "]"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"f", "[", "u", "]"}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["u", "2"]], 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"f", "[", "u", "]"}], 
           SuperscriptBox["u", "2"]}], 
          SuperscriptBox[
           RowBox[{"M", "[", "u", "]"}], "2"]], 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"M", "[", "u", "]"}], "2"], 
            RowBox[{"U", "[", "u", "]"}]}], ",", "u"}], "]"}]}], ",", "u"}], 
       "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox["\[Omega]", "2"], 
         RowBox[{"f", "[", "u", "]"}]], "-", 
        SuperscriptBox["k", "2"]}], ")"}], 
      RowBox[{"U", "[", "u", "]"}]}], "-", 
     RowBox[{"2", 
      SuperscriptBox[
       RowBox[{"M", "[", "u", "]"}], "2"], 
      RowBox[{"U", "[", "u", "]"}]}], "+", 
     RowBox[{"2", "I", " ", "\[Rho]", " ", "\[Omega]", " ", 
      RowBox[{"aa", "[", "u", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["k", "2"], 
      RowBox[{"B", "[", "u", "]"}], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], "[", "u", "]"}], 
       RowBox[{" ", 
        SuperscriptBox["u", "2"]}]]}]}], ")"}]}]}],
  CellChangeTimes->{{3.693750589769395*^9, 3.6937506067936697`*^9}, {
   3.693759386536555*^9, 3.693759475741816*^9}, {3.6938093092303014`*^9, 
   3.6938093150581613`*^9}}]
}], "Text",
 CellChangeTimes->{{3.6937506215424385`*^9, 3.6937506336074295`*^9}, {
  3.6937594865235796`*^9, 3.693759504629386*^9}, {3.6938093241151605`*^9, 
  3.6938093412084813`*^9}, {3.6943394849952836`*^9, 3.694339514890081*^9}},
 FontSize->24,
 FontWeight->"Bold",
 Background->RGBColor[1, 1, 0]],

Cell[TextData[{
 StyleBox["Do you see the typo in ",
  FontWeight->"Bold"],
 StyleBox["arXiv:1411.1003",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic",
  Background->RGBColor[0.87, 0.94, 1]],
 StyleBox[" ?",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.7719622280725183`*^9, 3.7719622325573735`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1520, 781},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 297, 4, 139, "Title"],
Cell[880, 28, 627, 10, 161, "Text"],
Cell[1510, 40, 122, 2, 30, "Input"],
Cell[1635, 44, 147, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[1807, 51, 267, 5, 72, "Chapter"],
Cell[CellGroupData[{
Cell[2099, 60, 123, 3, 54, "Subsection"],
Cell[2225, 65, 187, 5, 31, "Input"],
Cell[2415, 72, 719, 23, 33, "Input"],
Cell[3137, 97, 661, 21, 52, "Input"],
Cell[3801, 120, 1735, 56, 92, "Input"],
Cell[5539, 178, 318, 10, 31, "Input"],
Cell[5860, 190, 327, 10, 31, "Input"],
Cell[6190, 202, 330, 10, 31, "Input"],
Cell[6523, 214, 321, 11, 31, "Input"],
Cell[6847, 227, 915, 28, 52, "Input"],
Cell[7765, 257, 1009, 35, 52, "Input"],
Cell[8777, 294, 1486, 43, 132, "Input"],
Cell[10266, 339, 1378, 41, 72, "Input"],
Cell[11647, 382, 167, 5, 31, "Input"],
Cell[11817, 389, 307, 9, 31, "Input"],
Cell[12127, 400, 1820, 52, 92, "Input"],
Cell[13950, 454, 1543, 44, 92, "Input"],
Cell[15496, 500, 359, 11, 31, "Input"],
Cell[15858, 513, 947, 25, 52, "Input"],
Cell[16808, 540, 325, 10, 31, "Input"],
Cell[17136, 552, 777, 24, 52, "Input"],
Cell[17916, 578, 46332, 1195, 3264, "Input"],
Cell[64251, 1775, 926, 27, 52, "Input"],
Cell[65180, 1804, 4515, 133, 152, "Input"],
Cell[69698, 1939, 2300, 78, 132, "Input"],
Cell[72001, 2019, 1034, 31, 72, "Input"],
Cell[73038, 2052, 494, 15, 31, "Input"],
Cell[73535, 2069, 494, 15, 31, "Input"],
Cell[74032, 2086, 2808, 78, 112, "Input"],
Cell[76843, 2166, 551, 19, 31, "Input"],
Cell[77397, 2187, 2389, 66, 92, "Input"],
Cell[79789, 2255, 2292, 64, 112, "Input"],
Cell[82084, 2321, 1181, 35, 72, "Input"],
Cell[83268, 2358, 424, 15, 31, "Input"],
Cell[83695, 2375, 2998, 85, 172, "Input"],
Cell[86696, 2462, 1453, 45, 72, "Input"],
Cell[88152, 2509, 188, 5, 31, "Input"],
Cell[88343, 2516, 9071, 232, 372, "Input"],
Cell[97417, 2750, 535, 17, 31, "Input"],
Cell[97955, 2769, 1725, 51, 72, "Input"],
Cell[99683, 2822, 2192, 66, 112, "Input"],
Cell[101878, 2890, 729, 21, 31, "Input"],
Cell[102610, 2913, 913, 27, 52, "Input"],
Cell[103526, 2942, 231, 7, 31, "Input"],
Cell[103760, 2951, 323, 10, 31, "Input"],
Cell[104086, 2963, 477, 9, 52, "Input"],
Cell[104566, 2974, 186, 5, 31, "Input"],
Cell[104755, 2981, 89, 1, 52, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[104893, 2988, 159, 2, 61, "Chapter"],
Cell[CellGroupData[{
Cell[105077, 2994, 106, 1, 70, "Section"],
Cell[105186, 2997, 167, 2, 30, "Text"],
Cell[105356, 3001, 4633, 86, 54, "Input"],
Cell[CellGroupData[{
Cell[110014, 3091, 90, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[110129, 3097, 3381, 72, 79, "Print"],
Cell[113513, 3171, 3031, 66, 24, "Print"],
Cell[116547, 3239, 42927, 922, 137, "Print"],
Cell[159477, 4163, 1010, 16, 22, "Print"],
Cell[160490, 4181, 1009, 16, 22, "Print"],
Cell[161502, 4199, 1025, 16, 22, "Print"],
Cell[162530, 4217, 997, 16, 22, "Print"],
Cell[163530, 4235, 1007, 16, 22, "Print"],
Cell[164540, 4253, 981, 16, 22, "Print"],
Cell[165524, 4271, 1016, 16, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[166567, 4291, 269, 4, 30, "Text"],
Cell[166839, 4297, 4891, 95, 74, "Input"],
Cell[CellGroupData[{
Cell[171755, 4396, 135, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[171915, 4403, 5637, 142, 81, "Print"],
Cell[177555, 4547, 3285, 75, 28, "Print"],
Cell[180843, 4624, 22647, 520, 141, "Print"],
Cell[203493, 5146, 321, 6, 22, "Print"],
Cell[203817, 5154, 322, 6, 22, "Print"],
Cell[204142, 5162, 336, 6, 22, "Print"],
Cell[204481, 5170, 339, 6, 22, "Print"],
Cell[204823, 5178, 320, 6, 22, "Print"],
Cell[205146, 5186, 321, 6, 22, "Print"],
Cell[205470, 5194, 326, 6, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[205823, 5204, 138, 2, 30, "Text"],
Cell[205964, 5208, 273, 9, 5, "Text"],
Cell[206240, 5219, 181, 3, 30, "Text"],
Cell[206424, 5224, 4678, 115, 283, "Input"],
Cell[211105, 5341, 273, 9, 5, "Text"],
Cell[211381, 5352, 148, 2, 30, "Text"],
Cell[211532, 5356, 1096, 30, 70, "Input"],
Cell[CellGroupData[{
Cell[212653, 5390, 732, 19, 73, "Input"],
Cell[213388, 5411, 3599, 96, 63, "Output"],
Cell[216990, 5509, 782, 11, 30, "Output"],
Cell[217775, 5522, 41724, 1062, 661, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[259548, 6590, 181, 2, 56, "Section"],
Cell[259732, 6594, 187, 3, 30, "Text"],
Cell[259922, 6599, 107, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[260054, 6605, 2767, 73, 157, "Input"],
Cell[262824, 6680, 2152, 53, 52, "Output"],
Cell[264979, 6735, 2599, 65, 52, "Output"],
Cell[267581, 6802, 3975, 102, 92, "Output"],
Cell[271559, 6906, 2224, 54, 30, "Output"]
}, Open  ]],
Cell[273798, 6963, 273, 9, 5, "Text"],
Cell[274074, 6974, 216, 3, 30, "Text"],
Cell[274293, 6979, 740, 24, 167, "Input"],
Cell[CellGroupData[{
Cell[275058, 7007, 1152, 35, 155, "Input"],
Cell[276213, 7044, 1465, 32, 34, "Output"],
Cell[277681, 7078, 1465, 32, 34, "Output"],
Cell[279149, 7112, 2076, 50, 34, "Output"],
Cell[281228, 7164, 827, 11, 30, "Output"]
}, Open  ]],
Cell[282070, 7178, 273, 9, 5, "Text"],
Cell[282346, 7189, 206, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[282577, 7196, 897, 26, 34, "Input"],
Cell[283477, 7224, 1829, 45, 52, "Output"]
}, Open  ]],
Cell[285321, 7272, 1276, 35, 56, "Input"],
Cell[CellGroupData[{
Cell[286622, 7311, 1769, 48, 34, "Input"],
Cell[288394, 7361, 1938, 48, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290369, 7414, 1046, 29, 34, "Input"],
Cell[291418, 7445, 1377, 32, 50, "Output"]
}, Open  ]],
Cell[292810, 7480, 273, 9, 5, "Text"],
Cell[293086, 7491, 273, 9, 5, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[293396, 7505, 107, 1, 56, "Section"],
Cell[293506, 7508, 583, 14, 50, "Input"],
Cell[294092, 7524, 1325, 29, 69, "Input"],
Cell[295420, 7555, 273, 9, 5, "Text"],
Cell[295696, 7566, 141, 2, 30, "Text"],
Cell[295840, 7570, 431, 11, 30, "Input"],
Cell[296274, 7583, 273, 9, 5, "Text"],
Cell[296550, 7594, 237, 4, 30, "Text"],
Cell[296790, 7600, 825, 24, 30, "Input"],
Cell[297618, 7626, 273, 9, 5, "Text"],
Cell[297894, 7637, 143, 2, 30, "Text"],
Cell[298040, 7641, 912, 24, 49, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[298989, 7670, 120, 1, 56, "Section"],
Cell[CellGroupData[{
Cell[299134, 7675, 516, 13, 69, "Input"],
Cell[299653, 7690, 309, 5, 30, "Output"],
Cell[299965, 7697, 244, 3, 30, "Output"],
Cell[300212, 7702, 5295, 149, 93, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305544, 7856, 633, 19, 30, "Input"],
Cell[306180, 7877, 548, 14, 30, "Output"]
}, Open  ]],
Cell[306743, 7894, 251, 3, 30, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[307043, 7903, 100, 1, 72, "Chapter"],
Cell[CellGroupData[{
Cell[307168, 7908, 93, 1, 70, "Section"],
Cell[307264, 7911, 220, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[307509, 7918, 4428, 132, 369, "Input"],
Cell[311940, 8052, 3557, 104, 57, "Output"],
Cell[315500, 8158, 5024, 149, 57, "Output"],
Cell[320527, 8309, 3976, 113, 57, "Output"],
Cell[324506, 8424, 5089, 154, 80, "Output"],
Cell[329598, 8580, 2652, 79, 34, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[332299, 8665, 115, 1, 56, "Section"],
Cell[332417, 8668, 2083, 72, 187, "Text"],
Cell[CellGroupData[{
Cell[334525, 8744, 3988, 119, 367, "Input"],
Cell[338516, 8865, 3196, 96, 51, "Output"],
Cell[341715, 8963, 3566, 101, 48, "Output"],
Cell[345284, 9066, 2607, 74, 51, "Output"],
Cell[347894, 9142, 2590, 70, 34, "Output"],
Cell[350487, 9214, 2554, 74, 34, "Output"]
}, Open  ]],
Cell[353056, 9291, 439, 7, 49, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[353532, 9303, 108, 1, 56, "Section"],
Cell[353643, 9306, 152, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[353820, 9312, 3769, 114, 318, "Input"],
Cell[357592, 9428, 2041, 52, 51, "Output"],
Cell[359636, 9482, 2027, 53, 34, "Output"],
Cell[361666, 9537, 1942, 51, 51, "Output"],
Cell[363611, 9590, 1462, 39, 34, "Output"],
Cell[365076, 9631, 1427, 37, 34, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[366552, 9674, 169, 2, 56, "Section"],
Cell[366724, 9678, 215, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[366964, 9685, 251, 3, 88, "Input"],
Cell[367218, 9690, 1921, 51, 51, "Output"],
Cell[369142, 9743, 1907, 52, 34, "Output"],
Cell[371052, 9797, 1820, 50, 51, "Output"],
Cell[372875, 9849, 1340, 38, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374252, 9892, 1634, 54, 145, "Input"],
Cell[375889, 9948, 313, 4, 30, "Output"]
}, Open  ]],
Cell[376217, 9955, 223, 3, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[376477, 9963, 226, 3, 56, "Section"],
Cell[376706, 9968, 175, 4, 30, "Text"],
Cell[376884, 9974, 1161, 31, 30, "Input"],
Cell[CellGroupData[{
Cell[378070, 10009, 1821, 51, 221, "Input"],
Cell[379894, 10062, 2003, 55, 52, "Output"],
Cell[381900, 10119, 1859, 47, 51, "Output"],
Cell[383762, 10168, 1760, 48, 52, "Output"],
Cell[385525, 10218, 1706, 45, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387268, 10268, 585, 16, 50, "Input"],
Cell[387856, 10286, 1976, 61, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[389869, 10352, 1225, 37, 89, "Input"],
Cell[391097, 10391, 4880, 143, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[396014, 10539, 583, 16, 50, "Input"],
Cell[396600, 10557, 2212, 64, 52, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[398861, 10627, 104, 1, 56, "Section"],
Cell[398968, 10630, 162, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[399155, 10636, 566, 14, 69, "Input"],
Cell[399724, 10652, 2009, 62, 72, "Output"],
Cell[401736, 10716, 2141, 63, 72, "Output"],
Cell[403880, 10781, 4816, 143, 72, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[408745, 10930, 367, 5, 56, "Section"],
Cell[409115, 10937, 276, 9, 35, "Text"],
Cell[CellGroupData[{
Cell[409416, 10950, 5276, 169, 308, "Input"],
Cell[414695, 11121, 197, 3, 30, "Output"],
Cell[414895, 11126, 197, 3, 30, "Output"],
Cell[415095, 11131, 199, 3, 30, "Output"]
}, Open  ]],
Cell[415309, 11137, 4228, 135, 282, "Text"],
Cell[419540, 11274, 325, 11, 35, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

