(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    282496,       7503]
NotebookOptionsPosition[    274506,       7269]
NotebookOutlinePosition[    274853,       7284]
CellTagsIndexPosition[    274810,       7281]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Section 4.4 : DC conductivities in V(X) model",
 FontSize->72]], "Title",
 CellChangeTimes->{{3.626785382235268*^9, 3.626785383688484*^9}, {
  3.626786008255689*^9, 3.626786020396877*^9}, {3.642741873338778*^9, 
  3.6427418763497696`*^9}, {3.644060938713873*^9, 3.6440609528692923`*^9}, {
  3.6453734325014534`*^9, 3.645373443429721*^9}, {3.7701191942601213`*^9, 
  3.7701191985378094`*^9}, {3.7733918399572964`*^9, 3.773391845749758*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6240094492315493`*^9, 3.6240094511847925`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FS", "=", "FullSimplify"}], ";"}]], "Input",
 CellChangeTimes->{{3.6240094529973536`*^9, 3.624009456528799*^9}}],

Cell[TextData[StyleBox["This notebook computes all the DC conductivities at \
zero magnetic field in the massive gravity model of arXiv:1411.1003.\nThe \
computations are explained in detail in section 4.4",
 FontSize->18,
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.7701192404090433`*^9, 3.7701192571348224`*^9}, {
  3.7733918512355013`*^9, 3.7733918602065263`*^9}}],

Cell[CellGroupData[{

Cell["Code for GR computation (do not ask too much, just run it)", "Chapter",
 CellChangeTimes->{{3.624009473685851*^9, 3.624009475529693*^9}, {
  3.644060995314535*^9, 3.644061000269838*^9}, {3.770119205944009*^9, 
  3.770119216978294*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 2  RG&TC-Code",
 FontWeight->"Bold"]], "Subsection",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrigRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]_", "]"}], "2"]}]}], "->", "x"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cot", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"y_.", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]_", "]"}], "2"]}]}], ":>", 
      RowBox[{"y", "/;", 
       RowBox[{
        RowBox[{"x", "+", "y"}], "===", "0"}]}]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FaSi", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FaSi", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FacSimp", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Equal", "]"}], ":=", 
   RowBox[{"Equal", "[", 
    RowBox[{
     RowBox[{"FacSimp", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"x", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Rule", "]"}], ":=", 
   RowBox[{"Rule", "[", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"coll", "[", "x", "]"}], "/.", "simpRules"}], ",", 
        "FormVars", ",", "Factor"}], "]"}], "/.", "simpRules"}], ")"}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroQ", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Normal", "[", "x", "]"}]}], "}"}], "]"}], "]"}], "===", 
    RowBox[{"{", "0", "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroL", "[", "x_", "]"}], ":=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroN", "[", "x_", "]"}], ":=", 
  RowBox[{"Length", "[", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"indepTerms", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"redPlus", "[", 
    RowBox[{"redTimes", "[", 
     RowBox[{
      RowBox[{"nonZeroL", "[", "x", "]"}], ",", "opt"}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"redTimes", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"opt_:", 
     RowBox[{"{", "}"}]}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tmp$", " ", "=", " ", 
       RowBox[{"Select", "[", 
        RowBox[{"x", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "#1", "]"}], " ", "===", " ", "Times"}], " ", 
          "&"}]}], "]"}]}], ",", " ", "rst$"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"rst$", " ", "=", " ", 
      RowBox[{"Complement", "[", 
       RowBox[{"x", ",", " ", "tmp$"}], "]"}]}], ";", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"rst$", ",", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"numb2", "[", 
           RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", "tmp$"}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"NumericQ", "[", "x", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{
     RowBox[{"x_", "^", "y_."}], ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{"opt", ",", "x"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", "x"}], ";", 
  RowBox[{
   RowBox[{"numb2", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Times", "@@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"numb1", "[", 
        RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", 
      RowBox[{"Level", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redPlus", "[", "x_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "#", "]"}], "===", "Plus"}], "&"}]}], 
         "]"}]}], ",", "rst$", ",", "i$", ",", "negi$"}], "}"}], ",", 
     RowBox[{
      RowBox[{"rst$", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"x", ",", "tmp$"}], "]"}]}], ";", 
      RowBox[{"i$", "=", "1"}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i$", "<", 
         RowBox[{"Length", "[", "tmp$", "]"}]}], ",", 
        RowBox[{
         RowBox[{"negi$", "=", 
          RowBox[{"Select", "[", 
           RowBox[{"tmp$", ",", 
            RowBox[{
             RowBox[{"#", "===", 
              RowBox[{"-", 
               RowBox[{"tmp$", "[", 
                RowBox[{"[", "i$", "]"}], "]"}]}]}], "&"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"negi$", "=!=", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"tmp$", "=", 
            RowBox[{"Complement", "[", 
             RowBox[{"tmp$", ",", "negi$"}], "]"}]}]}], "]"}], ";", 
         RowBox[{"i$", "=", 
          RowBox[{"i$", "+", "1"}]}]}]}], "]"}], ";", 
      RowBox[{"Union", "[", 
       RowBox[{"tmp$", ",", "rst$"}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RiemSym", "[", "h_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "a_", ",", "c_", ",", "d_"}], "]"}], "=", "0"}], 
     ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}], 
     ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"b", ",", "a", ",", "c", ",", "d"}], "]"}]}], "/;", 
       RowBox[{"a", ">", "b"}]}]}], ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"a", ",", "b", ",", "d", ",", "c"}], "]"}]}], "/;", 
       RowBox[{"c", ">", "d"}]}]}], ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"c", ",", "d", ",", "a", ",", "b"}], "]"}], "/;", 
       RowBox[{
        RowBox[{"a", ">", "c"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "===", "c"}], "&&", 
          RowBox[{"b", ">", "d"}]}], ")"}]}]}]}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"epsilon", "[", "a__", "]"}], ":=", 
   RowBox[{"Signature", "[", 
    RowBox[{"{", "a", "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroTensor", "[", "rnk_", "]"}], ":=", 
   RowBox[{"Fold", "[", 
    RowBox[{"Table", ",", "0", ",", 
     RowBox[{"List", "/@", 
      RowBox[{"Table", "[", 
       RowBox[{"Dim", ",", 
        RowBox[{"{", "rnk", "}"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"f_", "[", "y__", "]"}], ",", "g_", ",", 
    RowBox[{"ord_:", "2"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"FuncRepRules", "[", 
    RowBox[{
     RowBox[{"f", "[", "y", "]"}], ",", "g", ",", "ord"}], "]"}], "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "y", "]"}], "->", "g"}], "}"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"indexList", "[", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"{", "y", "}"}], "]"}], ",", "ord"}], "]"}]}]}], "}"}], 
     ",", "\n", "       ", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"indL", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "[", "f", "]"}], "[",
             "y", "]"}], " ", "->", " ", "\n", "            ", 
           RowBox[{"Expand", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"D", "[", 
              RowBox[{"g", ",", 
               RowBox[{"Sequence", "@@", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", "y", "}"}], ",", 
                   RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}]}], "]"}],
              "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "indL", "]"}]}], "}"}]}], "]"}], ";", 
      "tmp$"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"indexList", "[", 
   RowBox[{"varNo_", ",", "ord_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp$", ",", "indL"}], "}"}], ",", 
    RowBox[{
     RowBox[{"tmp$", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{"RotateRight", ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"varNo", "-", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"varNo", "-", "1"}]}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ord", ">", "1"}], ",", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"indL", "=", "tmp$"}], ";", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"tmp$", "=", 
             RowBox[{"Join", "[", 
              RowBox[{"tmp$", ",", 
               RowBox[{"Map", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Plus", "[", 
                   RowBox[{
                    RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], 
                 ",", "indL"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "varNo"}], "}"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ord", "-", "1"}], "}"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"Union", "[", "tmp$", "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"MatrixForm", "[", "x", "]"}], "/;", 
    RowBox[{"Dim", "<", "10"}]}]}], ";", 
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", "x"}], ";", 
  RowBox[{"DeclareForms", "[", 
   RowBox[{"1", ",", 
    RowBox[{"e", "[", "_", "]"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"stPrint", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"y_", ":", "Null"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"y", "===", "Null"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
        RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontSlant", "\[Rule]", "\"\<Italic\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"timePrint", "[", 
    RowBox[{"x_", ",", "sT_"}], "]"}], ":=", 
   RowBox[{"Print", "[", 
    RowBox[{
     RowBox[{"x", "<>", "\"\< computed in \>\""}], ",", 
     RowBox[{
      RowBox[{"TimeUsed", "[", "]"}], "-", "sT"}], ",", "\"\< sec\>\""}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"myCoef$", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_SeriesData", ",", "y__"}], "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "->", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"#", ",", "y"}], "]"}], "&"}], ",", 
        RowBox[{"x", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_", ",", "y__"}], "]"}], ":=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{"gIN_", ",", "xIN_", ",", "opt___"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"frameOpt", "=", "0"}], ",", "eIN", ",", 
       RowBox[{"Ropt", "=", "True"}], ",", 
       RowBox[{"Wopt", "=", "True"}], ",", "idMat", ",", "eFrame", ",", 
       "dxRul", ",", "Bmat", ",", "Amat", ",", 
       RowBox[{"NP$", "=", "False"}], ",", "de", ",", "a", ",", "b", ",", "c",
        ",", "id", ",", "k", ",", "StrCon", ",", "\[Gamma]Udd", ",", 
       "\[Gamma]ddd", ",", "gddd", ",", "Gamddd", ",", "rmn", ",", "tmp", ",",
        "RUd", ",", "Rg", ",", "gg", ",", "sT", ",", "Cflat", ",", "EinSp"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"Clear", "[", 
       RowBox[{
       "GUdd", ",", "\[Omega]Ud", ",", "RUddd", ",", "Rdd", ",", "EUd", ",", 
        "R", ",", "Wdddd", ",", "detg", ",", "rtAbsdetg", ",", "eta", ",", 
        "HStar", ",", "PS", ",", "PH"}], "]"}], ";", "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Transpose", "[", "gIN", "]"}], "=!=", "gIN"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"MatrixForm", "[", "gIN", "]"}], ",", 
           "\"\< is not a symmetric matrix\>\""}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", " ", 
      RowBox[{"Dim", "=", 
       RowBox[{"Length", "[", "xIN", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Dim", "=!=", 
         RowBox[{"Length", "[", "gIN", "]"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{
          "\"\<Metric and coordinate dimensions don't match\>\"", ",", "1"}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"gIN", "===", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"NP$", "=", "True"}]}], "]"}], ";", 
      RowBox[{"eFrame", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"e", ",", 
         RowBox[{"{", "Dim", "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"frameOpt", "=", 
         RowBox[{"0", " ", "=", 
          RowBox[{">", " ", "coordFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"1", " ", "=", 
          RowBox[{">", " ", "explicitFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"2", " ", "=", 
          RowBox[{">", " ", "implicitFrame"}]}]}]}], " ", "*)"}], "\n", 
      "\t\t", "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"{", "opt", "}"}], "]"}], ">", "0"}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", "opt", "}"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "e"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", "dxRuleList", "]"}], "===", "List"}], "&&", 
              RowBox[{
               RowBox[{"Head", "[", "deList", "]"}], "===", "List"}]}], ",", 
             RowBox[{
              RowBox[{"frameOpt", "=", "2"}], ";", 
              RowBox[{"eIN", "=", "eFrame"}]}], ",", 
             RowBox[{
              RowBox[{"stPrint", "[", 
               RowBox[{
               "\"\<dxRuleList and/or deList have not been defined!\>\"", ",",
                 "1"}], "]"}], ";", 
              RowBox[{"Return", "[", "]"}]}]}], "]"}]}], "]"}], ";", "\n", 
         "\t", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"!", 
             RowBox[{"IntegerQ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "opt", "}"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"d", "[", "0", "]"}], "=!=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<matrixEDCcode.nb must be evaluated before section 2 \
RG&TC-Code!\>\"", ",", "1"}], "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "2"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{
               RowBox[{"{", "opt", "}"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"frameOpt", "=!=", "2"}], ",", 
              RowBox[{
               RowBox[{"eIN", "=", 
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ";", 
               RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{"IntegerQ", "[", 
             RowBox[{"opt", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{"opt", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"frameOpt", "=!=", "2"}], ",", 
             RowBox[{
              RowBox[{"eIN", "=", "opt"}], ";", 
              RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ",", "\n", "\t", 
           "True", ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<Wrong optional arguments!\>\"", ",", "1"}], "]"}], 
            ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"FreeQ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"gIN", ",", "eIN", ",", 
             RowBox[{"{", "deList", "}"}]}], "}"}], ",", "SeriesData"}], 
          "]"}]}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{"gIN", ",", "eIN", ",", 
                 RowBox[{"{", "deList", "}"}]}], "}"}], "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "SeriesData"}], 
               "&"}]}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"xIN", ",", "tmp"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"de", "[", "1", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<d\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{
             RowBox[{"de", "[", "2", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<\[ScriptD]\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{"DeclareForms", "[", 
             RowBox[{"1", ",", 
              RowBox[{"\[ScriptD]", "[", "_", "]"}], ",", 
              RowBox[{"de", "[", "1", "]"}], ",", 
              RowBox[{"de", "[", "2", "]"}]}], "]"}], ";", 
            RowBox[{
             RowBox[{"d", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "1", "]"}]}], ";", 
            RowBox[{
             RowBox[{"\[ScriptD]", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "2", "]"}]}], ";", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"de", "[", "1", "]"}], "]"}], "=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"d", "[", "tmp", "]"}], "=", "0"}]}], "]"}]}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "1"}], ",", 
        RowBox[{
         RowBox[{"DeclareForms", "[", 
          RowBox[{"1", ",", 
           RowBox[{"\[ScriptD]", "[", "_", "]"}]}], "]"}], ";", 
         RowBox[{"origFRin$", "=", 
          RowBox[{"eIN", "/.", 
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"d", "/@", "xIN"}], ",", 
               RowBox[{"\[ScriptD]", "/@", "xIN"}]}], "}"}]}], "]"}]}]}], ";", 
         RowBox[{"eTO$dx", "=", 
          RowBox[{"MapThread", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"e", "/@", 
               RowBox[{"Range", "[", "Dim", "]"}]}], ",", "origFRin$"}], 
             "}"}]}], "]"}]}]}]}], "]"}], ";", "\n", "\t\t\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"frameOpt", ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Union", "[", 
             RowBox[{"FormDegree", "/@", "eIN"}], "]"}], "=!=", 
            RowBox[{"{", "1", "}"}]}], "||", 
           RowBox[{
            RowBox[{"Length", "[", "eIN", "]"}], "=!=", "Dim"}], "||", 
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"eIN", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"e", "[", "_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"y_", "|", 
                  RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
                 RowBox[{"0", "/;", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}],
              "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{"\"\<coframe has incorrect form\>\"", ",", "1"}], "]"}], 
         ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\t", "\n", "\t\t", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "Rule"}], "||", 
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "RuleDelayed"}]}], 
        ",", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "simpRules", "}"}]}]}], "]"}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "simpRules", "]"}], "=!=", "List"}], ",", " ", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "}"}]}]}], "]"}], ";", 
      RowBox[{"idMat", "=", 
       RowBox[{"IdentityMatrix", "[", "Dim", "]"}]}], ";", "\n", "\n", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Amat", "=", "idMat"}], ";", 
         RowBox[{"Bmat", "=", "idMat"}], ";", 
         RowBox[{"eIN", "=", 
          RowBox[{"d", "/@", "xIN"}]}], ";", 
         RowBox[{"dxRul", "=", 
          RowBox[{"{", "}"}]}]}], ",", "\n", 
        RowBox[{
         RowBox[{"frameOpt", "===", "1"}], "&&", 
         RowBox[{"zeroQ", "[", 
          RowBox[{"eIN", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
             RowBox[{
              RowBox[{"y_", "|", 
               RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
              RowBox[{"0", "/;", 
               RowBox[{"MemberQ", "[", 
                RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{"Bmat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"eIN", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"d", "[", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "b", "]"}], "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Det", "[", "Bmat", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sT", "=", 
             RowBox[{"TimeUsed", "[", "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ByteCount", "[", "eIN", "]"}], ">", 
               RowBox[{"1500", "*", "Dim"}]}], ",", 
              RowBox[{"stPrint", "[", 
               RowBox[{"\"\<Computing d[coframe]...\>\"", ",", "1"}], "]"}]}],
              "]"}], ";", 
            RowBox[{"Amat", "=", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Inverse", "[", "Bmat", "]"}], "]"}]}], ";", 
            RowBox[{"dxRul", "=", 
             RowBox[{"MapThread", "[", 
              RowBox[{"Rule", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"d", "[", "xIN", "]"}], ",", 
                 RowBox[{"Amat", ".", "eFrame"}]}], "}"}]}], "]"}]}], ";", 
            RowBox[{"de", "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"FreeQ", "[", 
                RowBox[{"eIN", ",", "SeriesData"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{
                 RowBox[{"d", "[", "eIN", "]"}], "/.", "dxRul"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{"Wedge", "[", 
                 RowBox[{
                  RowBox[{"FacSimp", "[", 
                   RowBox[{
                    RowBox[{"FacSimp", "[", 
                    RowBox[{"d", "[", "Bmat", "]"}], "]"}], "/.", "dxRul"}], 
                   "]"}], ",", 
                  RowBox[{
                   RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], "]"}], 
                "]"}]}], "]"}]}], ";", 
            RowBox[{"timePrint", "[", 
             RowBox[{"\"\<d[coframe]\>\"", ",", "sT"}], "]"}], ";", 
            RowBox[{"tmp", "=", 
             RowBox[{
              RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
            RowBox[{"MapThread", "[", 
             RowBox[{"Set", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], 
             "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<coframe does not span space!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}], ",", "\n", 
        RowBox[{"frameOpt", "===", "2"}], ",", 
        RowBox[{
         RowBox[{"de", "=", "deList"}], ";", 
         RowBox[{"dxRul", "=", "dxRuleList"}], ";", 
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
         RowBox[{"MapThread", "[", 
          RowBox[{"Set", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], "]"}], 
         ";", 
         RowBox[{"Amat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"tmp", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"eIN", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
      "\n", "\t\t", "\n", 
      RowBox[{"k", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "x_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "x_Symbol"}], ")"}], "b_."]}], "->", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["x", "2"]}], ")"}], "b"]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "-", "y_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "+", "y_Symbol"}], ")"}], "b_."]}], 
          "\[Rule]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "-", 
             SuperscriptBox["y", "2"]}], ")"}], "b"]}]}], "}"}]}], ";", 
      RowBox[{"gdd", "=", "gIN"}], ";", 
      RowBox[{"coordList", "=", "xIN"}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gdd = \>\"", ",", 
        RowBox[{"MF", "[", "gdd", "]"}]}], "]"}], ";", 
      RowBox[{"tmp", "=", 
       RowBox[{"eIN", ".", "gIN", ".", "eIN"}]}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = \>\"", ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "tmp", "]"}], "===", "SeriesData"}], ",", 
           RowBox[{"FacSimp", "[", "tmp", "]"}], ",", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Expand", "[", "tmp", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], 
                RowBox[{"d", "[", "b_", "]"}]}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], 
                RowBox[{"e", "[", "b_", "]"}]}]}], "}"}], ",", "Factor"}], 
            "]"}]}], "]"}], "//.", "k"}]}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"gUU", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Inverse", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      RowBox[{"detg", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Det", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      "\n", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gUU = \>\"", ",", 
        RowBox[{"MF", "[", "gUU", "]"}]}], "]"}], ";", 
      RowBox[{"Clear", "[", "k", "]"}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<gUU\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"rtAbsdetg", "=", 
       RowBox[{"PowerExpand", "[", 
        RowBox[{"Power", "[", 
         RowBox[{
          RowBox[{"Factor", "[", 
           RowBox[{"detg", "^", "2"}], "]"}], ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"SetAttributes", "[", 
       RowBox[{"HStar", ",", 
        RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", 
        RowBox[{"rtAbsdetg", "=", "I"}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_SeriesData", "]"}], ":=", 
       RowBox[{"x", "/.", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "->", 
         RowBox[{"HStar", "/@", 
          RowBox[{"x", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}]}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Plus", "]"}], ":=", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Plus", "@@", 
         RowBox[{"HStar", "/@", "x"}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_", "*", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"HStar", "[", "y", "]"}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Wedge", "@@", 
          RowBox[{"e", "/@", 
           RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Wedge", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", "/", "detg"}], "/;", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], "===", "Dim"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_Wedge", "|", "x_e"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"HStar", "[", "x", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"FacSimp", "[", 
          RowBox[{"inn", "[", 
           RowBox[{"x", ",", 
            RowBox[{"Wedge", "@@", 
             RowBox[{"e", "/@", 
              RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "]"}], "]"}]}]}]}], 
      ";", "\t\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Array", "[", 
          RowBox[{"epsilon", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", "Dim", "}"}]}], "]"}]}], "]"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "a__", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "a", "]"}], "=", 
        RowBox[{"Raise", "[", 
         RowBox[{
          RowBox[{"eta", "[", "]"}], ",", "a"}], "]"}]}]}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"e", "[", "a_", "]"}], "]"}], ":=", 
          RowBox[{"de", "[", 
           RowBox[{"[", "a", "]"}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "a_"}], "]"}], "=", "0"}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"StrCon", "[", 
             RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{"-", 
           RowBox[{"myCoef$", "[", 
            RowBox[{
             RowBox[{"de", "[", 
              RowBox[{"[", "c", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"e", "[", "a", "]"}], "\[Wedge]", 
              RowBox[{"e", "[", "b", "]"}]}]}], "]"}]}]}], ";", "\n", 
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"StrCon", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", 
          RowBox[{"gdd", ".", "\[Gamma]Udd"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"zeroTensor", "[", "3", "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", "\[Gamma]Udd"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"(*", 
       RowBox[{"*", " ", "Tests"}], " ", "**)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "[", "gdd", "]"}], "/.", "dxRul"}], ")"}], "/.", 
           RowBox[{
            RowBox[{"e", "[", "_", "]"}], "->", "0"}]}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<Warning: d[] on some symbols not defined!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Print", "[", 
             RowBox[{"indepTerms", "[", 
              RowBox[{"FacSimp", "[", "tmp", "]"}], "]"}], "]"}]}]}], "]"}], 
         ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"frameOpt", "===", "2"}], "&&", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ByteCount", "[", "deList", "]"}], "+", 
                RowBox[{"ByteCount", "[", "dxRuleList", "]"}]}], ")"}], "/", 
              "Dim"}], "<", "6000"}]}], ",", 
           RowBox[{
            RowBox[{"tmp", "=", 
             RowBox[{"FacSimp", "[", 
              RowBox[{"d", "[", "deList", "]"}], "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
              RowBox[{
               RowBox[{"stPrint", "[", 
                RowBox[{
                "\"\<Warning: deList not closed! d[deList]=\>\"", ",", "1"}], 
                "]"}], ";", 
               RowBox[{"Print", "[", "tmp", "]"}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"!", 
                  RowBox[{"zeroQ", "[", 
                   RowBox[{"tmp", "/.", 
                    RowBox[{
                    RowBox[{"d", "[", "_", "]"}], "->", "0"}]}], "]"}]}], ",", 
                 RowBox[{"Return", "[", "]"}]}], "]"}]}]}], "]"}]}]}], 
          "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "pD", "]"}], ";", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"pD", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Amat", "===", "idMat"}], ",", 
          RowBox[{"D", "[", 
           RowBox[{"x", ",", 
            RowBox[{"coordList", "[", 
             RowBox[{"[", "y", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "y"}], "]"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"x", ",", 
               RowBox[{"coordList", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}]}], "]"}]}]}], ";", 
      "\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "c"}], "]"}], "]"}], ",", "b"}], "]"}], "+", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"b", ",", "c"}], "]"}], "]"}], ",", "a"}], "]"}], "-", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "b"}], "]"}], "]"}], ",", "c"}], "]"}]}], 
           ")"}], "/", "2"}], "]"}]}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"gddd", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"Clear", "[", "tmp", "]"}], ";", 
         RowBox[{"k", "=", 
          RowBox[{"gUU", ".", "Gamddd"}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"k", "[", 
             RowBox[{"[", 
              RowBox[{"c", ",", "a", ",", "b"}], "]"}], "]"}], "]"}]}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}]}], ",",
         "\n", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{
            RowBox[{"Array", "[", 
             RowBox[{"gddd", ",", 
              RowBox[{"{", 
               RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Gamma]ddd", "+", 
               RowBox[{"Transpose", "[", "\[Gamma]ddd", "]"}], "-", 
               RowBox[{"Transpose", "[", 
                RowBox[{"\[Gamma]ddd", ",", 
                 RowBox[{"{", 
                  RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], "]"}]}], ")"}], 
             "/", "2"}]}], "]"}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Union", "[", 
               RowBox[{"NumericQ", "/@", 
                RowBox[{"Flatten", "[", "gUU", "]"}]}], "]"}], "===", 
              RowBox[{"{", "True", "}"}]}], "&&", 
             RowBox[{
              RowBox[{"nonZeroN", "[", "gUU", "]"}], "===", "Dim"}]}], ",", 
            RowBox[{"gUU", ".", "Gamddd"}], ",", 
            RowBox[{"FaSi", "[", 
             RowBox[{"gUU", ".", "Gamddd"}], "]"}]}], "]"}]}]}]}], "]"}], ";",
       "\n", "\t\t", "\n", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Gamma\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{"\[Omega]Ud", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], 
              RowBox[{"e", "[", "k", "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"a", ",", "Dim"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
      RowBox[{
       RowBox[{"rmn", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"rmn", "[", 
         RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "id", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "c", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"\[Gamma]Udd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "id"}], "]"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdddd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"rmn", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
        "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Riemann(dddd)\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdddd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Flat Space!\>\"", "]"}], ";", 
         RowBox[{"Clear", "[", 
          RowBox[{"Rdd", ",", "EUd", ",", "R", ",", "Wdddd"}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Rg", "=", 
       RowBox[{"gUU", ".", "Rdddd"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{"Ropt", ",", 
        RowBox[{
         RowBox[{"Clear", "[", "rmn", "]"}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}],
          ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"rmn", "[", 
             RowBox[{"a", ",", "b", ",", "id", ",", "c"}], "]"}]}], "/;", 
           RowBox[{"c", ">", "id"}]}]}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"rmn", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"Rg", "[", 
             RowBox[{"[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "]"}], 
            "]"}]}]}], ";", 
         RowBox[{"RUddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"rmn", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Riemann(Uddd)\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"Rg", "=", "RUddd"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<RUddd not computed\>\"", ",", "1"}], "]"}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "tmp", "]"}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Rg", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "a", ",", "k", ",", "b"}], "]"}], "]"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", 
      "\t\t\t\t", "\n", 
      RowBox[{"RUd", "=", 
       RowBox[{"gUU", ".", "Rdd"}]}], ";", 
      RowBox[{"R", "=", 
       RowBox[{"FaSi", "[", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"RUd", "[", 
           RowBox[{"[", 
            RowBox[{"a", ",", "a"}], "]"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"a", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Ricci\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Wopt", "||", 
         RowBox[{"Dim", "<", "4"}]}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"Dim", ">", "3"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
             RowBox[{"Wdddd", "=", "Rdddd"}], ",", "\n", "\t", 
             RowBox[{
              RowBox[{"gg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "gdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"gg", "=", 
               RowBox[{"gg", "-", 
                RowBox[{"Transpose", "[", "gg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "Rdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", "Rg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"Rg", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}]}], 
                 "]"}]}]}], ";", "\n", 
              RowBox[{"Clear", "[", "rmn", "]"}], ";", 
              RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
              RowBox[{
               RowBox[{"rmn", "[", 
                RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
               RowBox[{
                RowBox[{"rmn", "[", 
                 RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
                RowBox[{"FaSi", "[", 
                 RowBox[{
                  RowBox[{"Rdddd", "[", 
                   RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                   "]"}], "-", 
                  RowBox[{
                   RowBox[{"Rg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], "+", 
                  RowBox[{"R", " ", 
                   RowBox[{
                    RowBox[{"gg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], ")"}]}]}]}], 
                 "]"}]}]}], ";", 
              RowBox[{"Wdddd", "=", 
               RowBox[{"Array", "[", 
                RowBox[{"rmn", ",", 
                 RowBox[{"{", 
                  RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], 
                  "}"}]}], "]"}]}]}]}], "]"}], ",", 
           RowBox[{"Wdddd", "=", 
            RowBox[{"zeroTensor", "[", "4", "]"}]}]}], "]"}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Weyl\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", "Wdddd", "]"}], ",", 
           RowBox[{
            RowBox[{"Cflat", "=", "True"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dim", "=!=", "3"}], "||", 
               RowBox[{"zeroQ", "[", "CF3d", "]"}]}], ",", 
              RowBox[{"stPrint", "[", "\"\<Conformally Flat\>\"", "]"}]}], 
             "]"}]}]}], "]"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<Weyl tensor not computed\>\"", ",", "1"}], "]"}]}], 
       "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Ricci Flat\>\"", "]"}], ";", 
         RowBox[{"EUd", "=", "Rdd"}]}], ",", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"EUd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{"RUd", " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], " ", "R", "*", "idMat"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Einstein\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", 
            RowBox[{"EUd", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "-", 
                RowBox[{"1", "/", "Dim"}]}], ")"}], "R", "*", "idMat"}]}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", "\"\<Einstein Space\>\"", "]"}], ";", 
            RowBox[{"EinSp", "=", "True"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", ">", "2"}], "&&", "Cflat", "&&", "EinSp"}], ")"}], "||", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", "===", "2"}], "&&", 
           RowBox[{"zeroQ", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"covD", "[", "R", "]"}], "]"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
        "stPrint", "[", "\"\<Space of Constant Curvature!\>\"", "]"}]}], 
       "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", "NPdefs"}], "]"}], ";"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CF3d", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"stPrint", "[", 
      RowBox[{"\"\<Testing for 3-dim conformal flatness...\>\"", ",", "1"}], 
      "]"}], ";", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tmp$", "=", 
         RowBox[{
          RowBox[{"covD", "[", "Rdd", "]"}], "-", 
          RowBox[{"Outer", "[", 
           RowBox[{"Times", ",", "gdd", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"covD", "[", "R", "]"}], "/", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{"Dim", "-", "1"}], ")"}]}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"FaSi", "[", 
        RowBox[{"tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], 
      "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NPdefs", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "4"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{"FaSi", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ")"}], "/", "4"}], 
       "]"}]}], ";", 
     RowBox[{"\[CapitalLambda]", "=", 
      RowBox[{
       RowBox[{"-", "R"}], "/", 
       RowBox[{"2", "4"}]}]}], ";", 
     RowBox[{
     "tmp$", " ", "=", " ", 
      "\"\<NP variables PH[i,j], \[CapitalLambda] \>\""}], ";", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "Wdddd", "]"}], " ", "=!=", " ", "Symbol"}], ",",
        " ", 
       RowBox[{
        RowBox[{
         RowBox[{"PS", "[", "0", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "2", ",", "4"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "1", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4", ",", "2", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "2", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "3", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "4", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{"tmp$", " ", "=", " ", 
         RowBox[{"StringJoin", "[", 
          RowBox[{"tmp$", ",", " ", "\"\<and PS[i] \>\""}], "]"}]}]}]}], 
      "]"}], ";", " ", 
     RowBox[{"stPrint", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"tmp$", ",", " ", "\"\<defined.\>\""}], "]"}], ",", " ", 
       "1"}], "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{"y_Wedge", ",", "x_"}], "]"}], ":=", 
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"Rest", "[", "y", "]"}], ",", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"First", "[", "y", "]"}], ",", "x"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "+", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "x"}], "]"}], "+", 
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "*", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "*", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_"}], "]"}], ":=", 
   RowBox[{"0", "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_Wedge"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", 
       RowBox[{"First", "[", "x", "]"}]}], "]"}], "*", 
     RowBox[{"Rest", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", 
      RowBox[{"FormDegree", "[", 
       RowBox[{"First", "[", "x", "]"}], "]"}]}], "*", 
     RowBox[{
      RowBox[{"First", "[", "x", "]"}], "\[Wedge]", 
      RowBox[{"inn", "[", 
       RowBox[{
        RowBox[{"e", "[", "a", "]"}], ",", 
        RowBox[{"Rest", "[", "x", "]"}]}], "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"e", "[", "b_", "]"}]}], "]"}], ":=", 
   RowBox[{"gUU", "[", 
    RowBox[{"[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MoveIndex", "[", 
    RowBox[{"x_", ",", "i_", ",", "g_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "indL"}], "}"}], ",", 
     "\n", "    ", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"i", "===", "1"}], ",", 
       RowBox[{"g", ".", "x"}], ",", 
       RowBox[{"i", "===", "rnk1"}], ",", 
       RowBox[{"x", ".", "g"}], ",", "True", ",", 
       RowBox[{
        RowBox[{"indL", "=", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "->", "1"}], ",", 
            RowBox[{"1", "->", "i"}]}], "}"}]}]}], ";", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"g", ".", 
           RowBox[{"Transpose", "[", 
            RowBox[{"x", ",", "indL"}], "]"}]}], ",", "indL"}], "]"}]}]}], 
      "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lower", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gdd"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Raise", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gUU"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"multiDot", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"rnk2", "=", 
        RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Sort", "/@", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", "indPr", "}"}], "]"}]}]}], ",", 
       RowBox[{"ordPr", "=", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}], "||", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk2"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ordPr", "]"}], "===", "1"}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotOne", "[", 
          RowBox[{"x", ",", "y", ",", "indPr"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"rnk1", "===", "rnk2"}], "&&", 
         RowBox[{"rnk1", "===", 
          RowBox[{"Length", "[", "ordPr", "]"}]}]}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotAll", "[", 
          RowBox[{"x", ",", "y", ",", "ordPr"}], "]"}], "]"}], ",", "True", 
        ",", 
        RowBox[{"OKindCon", "[", 
         RowBox[{
          RowBox[{"dotOne", "[", 
           RowBox[{"x", ",", "y", ",", 
            RowBox[{"ordPr", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"renumb", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"ordPr", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], "/@", 
           RowBox[{"Rest", "[", "ordPr", "]"}]}]}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"renumb", "[", 
     RowBox[{"rnk_", ",", "j_"}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_"}], "}"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"j", ">", "b"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "2"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dotOne", "[", 
   RowBox[{"x_", ",", "y_", ",", 
    RowBox[{"{", 
     RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rnk1", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
      RowBox[{"rnk2", "=", 
       RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
      RowBox[{"tmp$", "=", 
       RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmp$", "===", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
       RowBox[{"tmp$", "=", "Wedge"}], ",", 
       RowBox[{"tmp$", "=", "Dot"}]}], "]"}], ";", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{"tmp$", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"x", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk1", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rnk1", "\[Rule]", "i"}], ",", 
              RowBox[{"i", "\[Rule]", "rnk1"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk2", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"j", "\[Rule]", "1"}], ",", 
              RowBox[{"1", "\[Rule]", "j"}]}], "}"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"rnk1", "+", "j", "-", "2"}]}], "]"}], ",", "1"}], "]"}],
          ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"rnk1", "+", "j", "-", "1"}], ",", 
           RowBox[{"rnk1", "+", "rnk2", "-", "2"}]}], "]"}]}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dotAll", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s$", ",", "allInd", ",", "sumInd", ",", 
       RowBox[{"tmp$", "=", 
        RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"allInd", "=", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{"s$", ",", 
          RowBox[{"Transpose", "[", "indPr", "]"}], ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], "/.", 
        RowBox[{
         RowBox[{"s$", "[", "i_", "]"}], ":>", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<s$\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
      RowBox[{"sumInd", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"allInd", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", 
              RowBox[{"allInd", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}]}], "}"}],
         "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tmp$", "===", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
        RowBox[{"tmp$", "=", "Wedge"}], ",", 
        RowBox[{"tmp$", "=", "Times"}]}], "]"}], ";", 
      RowBox[{"Sum", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Unevaluated", "[", 
          RowBox[{"tmp$", "[", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
            RowBox[{"y", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
          "]"}], ",", 
         RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"x_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Union", "[", "indL", "]"}], "]"}], "<", 
         RowBox[{"Length", "[", "indL", "]"}]}], "||", 
        RowBox[{
         RowBox[{"Length", "[", "indL", "]"}], ">", "rnk1"}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Sort", "[", "indL", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}]}], ",", 
       RowBox[{"errWarn", ";", 
        RowBox[{"Return", "[", "]"}]}], ",", 
       RowBox[{"OKindCon", "[", 
        RowBox[{"x", ",", 
         RowBox[{"Sort", "[", 
          RowBox[{"Sort", "/@", 
           RowBox[{"{", "indPr", "}"}]}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"newPrList", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Rest", "[", "x", "]"}], "-", "1"}], "/.", 
    RowBox[{"k_", ":>", 
     RowBox[{
      RowBox[{"k", "-", "1"}], "/;", 
      RowBox[{"k", ">", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", "1"}]}]}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"FacSimp", "[", 
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", "indPr", "]"}], "===", "1"}]}]}], ";", 
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s$", ",", "allInd", ",", "sumInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"TensorRank", "[", "x", "]"}], "]"}], "/.", 
          RowBox[{"Apply", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"Apply", "[", 
             RowBox[{"Sequence", ",", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Transpose", "[", 
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{
                    RowBox[{"s$", "[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}], "]"}], "&"}], 
                ",", "indPr"}], "]"}], ",", "1"}], "]"}], ",", "1"}], "]"}]}],
          "/.", 
         RowBox[{
          RowBox[{"s$", "[", "i_", "]"}], ":>", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<s$\>\"", "<>", 
            RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
       RowBox[{"sumInd", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Union", "[", "allInd", "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "allInd", "]"}], "/", "2"}], "}"}]}], 
            "]"}]}], "}"}], "]"}]}], ";", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Sum", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Unevaluated", "[", 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], "]"}], ",", 
           RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}], "]"}]}]}], "]"}], 
    "/;", 
    RowBox[{
     RowBox[{"TensorRank", "[", "x", "]"}], "===", 
     RowBox[{"2", 
      RowBox[{"Length", "[", "indPr", "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"OKindCon", "[", 
    RowBox[{
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"newPrList", "[", "indPr", "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ConOne", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "tr1List", ",", 
       "tr2List"}], "}"}], ",", 
     RowBox[{
      RowBox[{"tr1List", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"j", "->", "i"}], "}"}]}], ")"}], "/.", 
        RowBox[{"k_", ":>", 
         RowBox[{
          RowBox[{"k", "-", "1"}], "/;", 
          RowBox[{"k", ">", "j"}]}]}]}]}], ";", 
      RowBox[{"tr2List", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}]}], 
        "]"}]}], ";", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"x", ",", "tr1List"}], "]"}], ",", "tr2List"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"rnk1", "-", "2"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"errWarn", ":=", 
   RowBox[{"stPrint", "[", 
    RowBox[{"\"\<Wrong tensor rank or number(s) of indices!\>\"", ",", "1"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covDiv", "[", 
    RowBox[{"x_", ",", "UpList_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{"x", ",", "UpList"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k", "=", 
         RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "divInd", ",", 
        "allInd", ",", "freeInd", ",", "hhD", ",", "s", ",", "lt", ",", 
        "aInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{
            RowBox[{"Sort", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{"Head", "[", "x", "]"}], "=!=", "List"}]}], ",", 
         RowBox[{"errWarn", ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "1"}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"Select", "[", 
             RowBox[{"UpList", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "List"}], "&"}]}], 
             "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", "UpList", "}"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"aInd", "/@", 
           RowBox[{"Range", "[", "k", "]"}]}], ")"}], "/.", 
         RowBox[{
          RowBox[{"aInd", "[", "divInd", "]"}], "->", "s"}]}]}], ";", 
       RowBox[{"freeInd", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"allInd", ",", 
          RowBox[{
           RowBox[{"#", "=!=", "s"}], "&"}]}], "]"}]}], ";", 
       RowBox[{"Off", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"lt", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$VersionNumber", "<", "3.5"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"hhD", "[", 
                RowBox[{
                 RowBox[{"x", "[", 
                  RowBox[{"[", 
                   RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                 "s"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "+", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], "]"}],
                  ",", 
                 RowBox[{
                  RowBox[{"GUdd", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "Dim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Unevaluated", "[", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"hhD", "[", 
                 RowBox[{
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                  "s"}], "]"}], "+", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], 
                    "]"}], ",", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "]"}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"k", " ", ">", "1"}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{"Table", "@@", "lt"}]}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"pD", "[", 
              RowBox[{
               RowBox[{"x", "[", 
                RowBox[{"[", "s$", "]"}], "]"}], ",", "s$"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"s$", ",", "s$", ",", "j"}], "]"}], "]"}], 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "Dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
       RowBox[{"On", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       RowBox[{"Return", "[", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"lt", "/.", 
           RowBox[{"hhD", "->", "pD"}]}], "]"}], "]"}], "]"}]}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"c$D", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_", ",", "y_List"}], "]"}], ":=", "errWarn"}], ";", 
  RowBox[{
   RowBox[{"covD", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", "x", "]"}], "=", 
    RowBox[{"c$D", "[", "x", "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c$D", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"UpList_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
           RowBox[{
            RowBox[{
             RowBox[{"Sort", "[", 
              RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], 
             "\[LeftDoubleBracket]", 
             RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ">", "k"}]}], 
          ")"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "x", "]"}], "===", "List"}], ",", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{"cDcomp", "[", 
           RowBox[{"x", ",", "k", ",", "UpList"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"k", "+", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"pD", "[", 
            RowBox[{"x", ",", "i"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cDcomp", "[", 
     RowBox[{"x_", ",", "rnk_", ",", 
      RowBox[{"UpList_:", 
       RowBox[{"{", "}"}]}]}], "]"}], "[", "y__", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y$", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"{", "y", "}"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ",", 
       RowBox[{"z$", "=", 
        RowBox[{
         RowBox[{"{", "y", "}"}], "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", "y$"}], "]"}], "]"}], ",", "z$"}], "]"}],
        "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"UpList", ",", "i"}], "]"}], ",", 
           RowBox[{
            RowBox[{"GUdd", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"y$", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "z$", ",", "j"}], "]"}], 
             "]"}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}], 
           ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "z$", ",", 
                RowBox[{"y$", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}]}],
           "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "Dim"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "rnk"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "0", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdddd", "]"}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{"indepTerms", "[", 
       RowBox[{"tmp$", "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}]}], 
         "]"}], "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "5", ",", "3", ",", "4"}], "}"}]}], 
         "]"}]}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "1", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdd", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "RUddd", "]"}], "===", "Symbol"}], ",", 
        RowBox[{"RUddd", "=", 
         RowBox[{"Raise", "[", 
          RowBox[{"Rdddd", ",", "1"}], "]"}]}]}], "]"}], ";", 
      RowBox[{"FaSi", "[", 
       RowBox[{"indepTerms", "[", 
        RowBox[{
         RowBox[{"covDiv", "[", 
          RowBox[{"RUddd", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}], "+", "tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "2", "]"}], ":=", 
   RowBox[{"indepTerms", "[", 
    RowBox[{"covDiv", "[", 
     RowBox[{"EUd", ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PrePrint", "=", " ", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ByteCount", "[", "#", "]"}], " ", ">", " ", "200000"}], ",", 
      RowBox[{"Short", "[", 
       RowBox[{"#", ",", "100"}], "]"}], ",", " ", "#"}], "]"}], "&"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{
   "cDcomp", ",", "CF3d", ",", "ConOne", ",", "c$D", ",", "dotAll", ",", 
    "dotOne", ",", "epsilon", ",", "errWarn", ",", "FacSimp", ",", "FaSi", 
    ",", "indexList", ",", "inn", ",", "MF", ",", "MoveIndex", ",", 
    "newPrList", ",", "NPdefs", ",", "numb1", ",", "numb2", ",", "OKindCon", 
    ",", "redPlus", ",", "redTimes", ",", "renumb", ",", "RiemSym", ",", 
    "zeroTensor"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.6205808502542887`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Routine", "Chapter",
 CellChangeTimes->{{3.645379401072316*^9, 3.6453794064168777`*^9}, {
  3.7701192975345683`*^9, 3.7701192985818377`*^9}}],

Cell[CellGroupData[{

Cell["Background", "Subchapter",
 CellChangeTimes->{{3.624040920155903*^9, 3.6240409216247253`*^9}}],

Cell[TextData[StyleBox["Here we find the EOMs for the background (cheating \
and using the variational principle) and the solution for the background",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770119325098953*^9, 3.7701193493306985`*^9}}],

Cell[CellGroupData[{

Cell["Model and lagrangian", "Section",
 CellChangeTimes->{{3.62400950390606*^9, 3.6240095065468335`*^9}}],

Cell[TextData[StyleBox["u is the radial direction between 0 (boundary) and uh \
(horizon)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701193554450436`*^9, 3.770119369008662*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "u"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "2"]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", 
       RowBox[{"NN", "[", "u", "]"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.570167330426721*^9, {3.570167711460515*^9, 3.5701677604433165`*^9}, {
   3.5701875806651926`*^9, 3.570187583672364*^9}, {3.5701876605677624`*^9, 
   3.5701876639509563`*^9}, {3.570187735649057*^9, 3.570187745717633*^9}, {
   3.5701886532425404`*^9, 3.5701886590188704`*^9}, {3.5710344839574785`*^9, 
   3.5710345490622025`*^9}, {3.5710565998820677`*^9, 3.571056609206601*^9}, {
   3.571056688575141*^9, 3.5710566960055656`*^9}, {3.571057753245036*^9, 
   3.5710577696369743`*^9}, {3.5710584597704477`*^9, 3.571058487839053*^9}, {
   3.571162597044566*^9, 3.571162634373329*^9}, {3.572352151919235*^9, 
   3.5723521744285226`*^9}, {3.5723527649783*^9, 3.572352805412613*^9}, {
   3.5723544810774555`*^9, 3.572354481370472*^9}, {3.572783907767783*^9, 
   3.572783910698951*^9}, {3.5727852817183685`*^9, 3.5727852851825666`*^9}, {
   3.572847181580718*^9, 3.572847187575061*^9}, {3.5728479839206095`*^9, 
   3.572848013493301*^9}, {3.5728683898720317`*^9, 3.5728684127023373`*^9}, {
   3.5768411793242626`*^9, 3.5768411960782213`*^9}, {3.576841393342504*^9, 
   3.576841400301902*^9}, {3.588570366786084*^9, 3.588570605641746*^9}, {
   3.588676297756776*^9, 3.588676313015649*^9}, {3.588679147362764*^9, 
   3.588679147494772*^9}, {3.589176462654968*^9, 3.5891764682232866`*^9}, {
   3.5891765005721364`*^9, 3.5891765490069065`*^9}, {3.5891765827008343`*^9, 
   3.5891766018889313`*^9}, {3.589176698654466*^9, 3.5891767473842535`*^9}, {
   3.5891781666334295`*^9, 3.5891781823983316`*^9}, {3.5892026584710283`*^9, 
   3.58920267756212*^9}, {3.5892027244858036`*^9, 3.589202733565323*^9}, {
   3.5892038518332844`*^9, 3.589203878423805*^9}, {3.5892057669598236`*^9, 
   3.5892057873969927`*^9}, {3.58920631763332*^9, 3.589206320231469*^9}, {
   3.589207357322787*^9, 3.589207393252842*^9}, {3.5896209102385693`*^9, 
   3.5896209119556675`*^9}, {3.5896210590570817`*^9, 3.589621064654402*^9}, {
   3.5907551876956787`*^9, 3.5907552091219044`*^9}, {3.5907566716935587`*^9, 
   3.5907566860873823`*^9}, {3.592217073930195*^9, 3.5922171581900144`*^9}, {
   3.59256777152232*^9, 3.592567782218931*^9}, {3.5927224828902206`*^9, 
   3.5927225021913247`*^9}, {3.592755344267173*^9, 3.592755345044217*^9}, {
   3.5927555533841333`*^9, 3.592755559335474*^9}, 3.592755679146327*^9, {
   3.592914201124915*^9, 3.5929142298985605`*^9}, {3.592914325799046*^9, 
   3.5929143259670553`*^9}, {3.5931684118583736`*^9, 3.593168433449609*^9}, {
   3.593168691672378*^9, 3.593168692003397*^9}, {3.593177947440778*^9, 
   3.5931779569343204`*^9}, {3.5932379656937857`*^9, 
   3.5932379657697897`*^9}, {3.5939694634234915`*^9, 
   3.5939694642905407`*^9}, {3.612679384297059*^9, 3.6126794442260604`*^9}, 
   3.612891633755241*^9, {3.6128925243427753`*^9, 3.6128925729956837`*^9}, {
   3.6128930187745657`*^9, 3.6128930511441402`*^9}, {3.612902044032016*^9, 
   3.612902045532769*^9}, {3.619853651851103*^9, 3.619853652299033*^9}, {
   3.62002395456089*^9, 3.6200239553877697`*^9}, {3.620378552850563*^9, 
   3.62037858294659*^9}, {3.620378635267205*^9, 3.620378639328519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g", ",", "xCoord"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "2"]}], 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "0", "0"},
       {
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]},
       {"0", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], "0"},
       {"0", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "0", 
        RowBox[{"NN", "[", "u", "]"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-$CellContext`at[$CellContext`u]^2, $CellContext`\[Epsilon] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y], 0, 
      0}, {$CellContext`\[Epsilon] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y], $CellContext`ax[$CellContext`u]^2, \
$CellContext`\[Epsilon] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y], $CellContext`\[Epsilon] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, {
     0, $CellContext`\[Epsilon] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y], $CellContext`ax[$CellContext`u]^2, 0}, {
     0, $CellContext`\[Epsilon] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y], 0, 
      $CellContext`NN[$CellContext`u]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.7701220496723337`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(ds\\), \\(2\\)]\\) = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox[
       RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "x", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "y", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "u", "]"}], "2"], " ", 
     RowBox[{"NN", "[", "u", "]"}]}], "+", 
    RowBox[{"2", " ", "\[Epsilon]", " ", 
     RowBox[{"d", "[", "t", "]"}], " ", 
     RowBox[{"d", "[", "x", "]"}], " ", 
     RowBox[{"\[Delta]Gtx", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[Epsilon]", " ", 
     RowBox[{"d", "[", "u", "]"}], " ", 
     RowBox[{"d", "[", "x", "]"}], " ", 
     RowBox[{"\[Delta]Gxu", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
    RowBox[{"2", " ", "\[Epsilon]", " ", 
     RowBox[{"d", "[", "x", "]"}], " ", 
     RowBox[{"d", "[", "y", "]"}], " ", 
     RowBox[{"\[Delta]Gxy", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}],
  SequenceForm[
  "\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = ", \
-$CellContext`at[$CellContext`u]^2 $CellContext`d[$CellContext`t]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`x]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`y]^2 + \
$CellContext`d[$CellContext`u]^2 $CellContext`NN[$CellContext`u] + 
   2 $CellContext`\[Epsilon] $CellContext`d[$CellContext`t] \
$CellContext`d[$CellContext`x] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] + 
   2 $CellContext`\[Epsilon] $CellContext`d[$CellContext`u] \
$CellContext`d[$CellContext`x] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] + 
   2 $CellContext`\[Epsilon] $CellContext`d[$CellContext`x] \
$CellContext`d[$CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.7701220496763234`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gtx", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}]},
       {
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gtx", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gxy", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"\[Delta]Gxu", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          RowBox[{"NN", "[", "u", "]"}], " ", 
          RowBox[{"\[Delta]Gxy", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}]},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{"\[Epsilon]", " ", 
          SuperscriptBox[
           RowBox[{"at", "[", "u", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
          RowBox[{"\[Delta]Gxu", "[", 
           RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            RowBox[{"NN", "[", "u", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
           RowBox[{"NN", "[", "u", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"at", "[", "u", "]"}], "2"], " ", 
           RowBox[{"NN", "[", "u", "]"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{-($CellContext`ax[$CellContext`u]^4 \
$CellContext`NN[$CellContext`u] - $CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}, {$CellContext`\[Epsilon] \
$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}, {-$CellContext`\[Epsilon]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), ($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`NN[$CellContext`u] $CellContext`\
\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y]^2 - $CellContext`\
\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]^2)/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}, {-$CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), $CellContext`\[Epsilon] \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), -$CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]/(-$CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] - \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 + $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2), ($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 + $CellContext`\[Epsilon]^2 \
$CellContext`ax[$CellContext`u]^2 $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)/($CellContext`at[$CellContext`u]^2 \
$CellContext`ax[$CellContext`u]^4 $CellContext`NN[$CellContext`u] + \
$CellContext`\[Epsilon]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2 - $CellContext`\[Epsilon]^2 \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 - \
$CellContext`\[Epsilon]^2 $CellContext`at[$CellContext`u]^2 \
$CellContext`NN[$CellContext`u] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]^2)}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.770122049821932*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.03100000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.03100000000000014, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.7701220498428764`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.09399999999999986`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.09399999999999986, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.770122049861826*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.5619999999999998`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.5619999999999998, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.7701220505973682`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "8.766000000000002`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 8.766000000000002, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.7701220592774267`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "3.4220000000000006`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 3.4220000000000006`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.770122063028681*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "19.702999999999996`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 19.702999999999996`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.770122083745163*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "17.547000000000004`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 17.547000000000004`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.77011976134247*^9, 3.7701201991636295`*^9, 
  3.77012210220033*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["A trick to make faster:",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701193852571507`*^9, 3.7701193883158417`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "u"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "2"]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gtx", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxy", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "2"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"\[Epsilon]", "*", 
        RowBox[{"\[Delta]Gxu", "[", 
         RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", 
       RowBox[{"NN", "[", "u", "]"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"RGtensors", "[", 
  RowBox[{"g2", ",", "xCoord"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.570167330426721*^9, {3.570167711460515*^9, 3.5701677604433165`*^9}, {
   3.5701875806651926`*^9, 3.570187583672364*^9}, {3.5701876605677624`*^9, 
   3.5701876639509563`*^9}, {3.570187735649057*^9, 3.570187745717633*^9}, {
   3.5701886532425404`*^9, 3.5701886590188704`*^9}, {3.5710344839574785`*^9, 
   3.5710345490622025`*^9}, {3.5710565998820677`*^9, 3.571056609206601*^9}, {
   3.571056688575141*^9, 3.5710566960055656`*^9}, {3.571057753245036*^9, 
   3.5710577696369743`*^9}, {3.5710584597704477`*^9, 3.571058487839053*^9}, {
   3.571162597044566*^9, 3.571162634373329*^9}, {3.572352151919235*^9, 
   3.5723521744285226`*^9}, {3.5723527649783*^9, 3.572352805412613*^9}, {
   3.5723544810774555`*^9, 3.572354481370472*^9}, {3.572783907767783*^9, 
   3.572783910698951*^9}, {3.5727852817183685`*^9, 3.5727852851825666`*^9}, {
   3.572847181580718*^9, 3.572847187575061*^9}, {3.5728479839206095`*^9, 
   3.572848013493301*^9}, {3.5728683898720317`*^9, 3.5728684127023373`*^9}, {
   3.5768411793242626`*^9, 3.5768411960782213`*^9}, {3.576841393342504*^9, 
   3.576841400301902*^9}, {3.588570366786084*^9, 3.588570605641746*^9}, {
   3.588676297756776*^9, 3.588676313015649*^9}, {3.588679147362764*^9, 
   3.588679147494772*^9}, {3.589176462654968*^9, 3.5891764682232866`*^9}, {
   3.5891765005721364`*^9, 3.5891765490069065`*^9}, {3.5891765827008343`*^9, 
   3.5891766018889313`*^9}, {3.589176698654466*^9, 3.5891767473842535`*^9}, {
   3.5891781666334295`*^9, 3.5891781823983316`*^9}, {3.5892026584710283`*^9, 
   3.58920267756212*^9}, {3.5892027244858036`*^9, 3.589202733565323*^9}, {
   3.5892038518332844`*^9, 3.589203878423805*^9}, {3.5892057669598236`*^9, 
   3.5892057873969927`*^9}, {3.58920631763332*^9, 3.589206320231469*^9}, {
   3.589207357322787*^9, 3.589207393252842*^9}, {3.5896209102385693`*^9, 
   3.5896209119556675`*^9}, {3.5896210590570817`*^9, 3.589621064654402*^9}, {
   3.5907551876956787`*^9, 3.5907552091219044`*^9}, {3.5907566716935587`*^9, 
   3.5907566860873823`*^9}, {3.592217073930195*^9, 3.5922171581900144`*^9}, {
   3.59256777152232*^9, 3.592567782218931*^9}, {3.5927224828902206`*^9, 
   3.5927225021913247`*^9}, {3.592755344267173*^9, 3.592755345044217*^9}, {
   3.5927555533841333`*^9, 3.592755559335474*^9}, 3.592755679146327*^9, {
   3.592914201124915*^9, 3.5929142298985605`*^9}, {3.592914325799046*^9, 
   3.5929143259670553`*^9}, {3.5931684118583736`*^9, 3.593168433449609*^9}, {
   3.593168691672378*^9, 3.593168692003397*^9}, {3.593177947440778*^9, 
   3.5931779569343204`*^9}, {3.5932379656937857`*^9, 
   3.5932379657697897`*^9}, {3.5939694634234915`*^9, 
   3.5939694642905407`*^9}, {3.612679384297059*^9, 3.6126794442260604`*^9}, 
   3.612891633755241*^9, {3.6128925243427753`*^9, 3.6128925729956837`*^9}, {
   3.6128930187745657`*^9, 3.6128930511441402`*^9}, {3.612902044032016*^9, 
   3.612902045532769*^9}, {3.619853651851103*^9, 3.619853652299033*^9}, {
   3.62002395456089*^9, 3.6200239553877697`*^9}, {3.620378552850563*^9, 
   3.62037858294659*^9}, {3.620378635267205*^9, 3.620378639328519*^9}, {
   3.7701194009066734`*^9, 3.770119418000766*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "2"]}], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], "0", "0"},
       {
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gtx", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False]},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxy", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], 
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]Gxu", "[", 
            RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
          "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 0, {
           $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1],
         Editable->False], "0", 
        RowBox[{"NN", "[", "u", "]"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-$CellContext`at[$CellContext`u]^2, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], 0, 0}, {
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], $CellContext`ax[$CellContext`u]^2, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1]}, {0, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], $CellContext`ax[$CellContext`u]^2, 0}, {0, 
      SeriesData[$CellContext`\[Epsilon], 0, {
        $CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, \
$CellContext`y]}, 1, 3, 1], 0, 
      $CellContext`NN[$CellContext`u]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221023035755`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(ds\\), \\(2\\)]\\) = \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "x", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "u", "]"}], "2"], " ", 
        RowBox[{"NN", "[", "u", "]"}]}]}], ")"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"d", "[", "x", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"d", "[", "t", "]"}], " ", 
         RowBox[{"\[Delta]Gtx", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"d", "[", "u", "]"}], " ", 
         RowBox[{"\[Delta]Gxu", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"d", "[", "y", "]"}], " ", 
         RowBox[{"\[Delta]Gxy", "[", 
          RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}], ")"}], " ", 
      "\[Epsilon]"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
      SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 3, 1],
      Editable->False]}],
    SeriesData[$CellContext`\[Epsilon], 
     0, {-$CellContext`at[$CellContext`u]^2 $CellContext`d[$CellContext`t]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`x]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`y]^2 + \
$CellContext`d[$CellContext`u]^2 $CellContext`NN[$CellContext`u], 
      2 $CellContext`d[$CellContext`x] ($CellContext`d[$CellContext`t] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] + \
$CellContext`d[$CellContext`u] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] + $CellContext`d[$CellContext`y] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y])}, 0,
      3, 1],
    Editable->False]}],
  SequenceForm["\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = ", 
   SeriesData[$CellContext`\[Epsilon], 
    0, {-$CellContext`at[$CellContext`u]^2 $CellContext`d[$CellContext`t]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`x]^2 + \
$CellContext`ax[$CellContext`u]^2 $CellContext`d[$CellContext`y]^2 + \
$CellContext`d[$CellContext`u]^2 $CellContext`NN[$CellContext`u], 
     2 $CellContext`d[$CellContext`x] ($CellContext`d[$CellContext`t] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] + \
$CellContext`d[$CellContext`u] $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] + $CellContext`d[$CellContext`y] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y])}, 0,
     3, 1]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221023135366`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"]]}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "4"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {(-1) $CellContext`at[$CellContext`u]^(-2), 
           0, $CellContext`at[$CellContext`u]^(-4) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "4"]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
          4, 1],
         Editable->False]},
       {
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gtx", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox[
                 RowBox[{"ax", "[", "u", "]"}], "2"]}], " ", 
               RowBox[{"NN", "[", "u", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Delta]Gtx", "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"at", "[", "u", "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Delta]Gxu", "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"at", "[", "u", "]"}], "2"], " ", 
               RowBox[{"NN", "[", "u", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Delta]Gxy", "[", 
                 RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"]}]}], ")"}], 
            " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"at", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "6"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-2), 
           0, $CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-6) $CellContext`NN[$CellContext`u]^(-1) \
(-$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2)}, 
          0, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
          3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False]},
       {
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "4"]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
          3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "2"]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Delta]Gxy", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           SuperscriptBox[
            RowBox[{"ax", "[", "u", "]"}], "6"]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-2), 
           0, $CellContext`ax[$CellContext`u]^(-6) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2}, 
          0, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False]},
       {
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gtx", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
             SuperscriptBox["\[Epsilon]", "2"]}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"at", "[", "u", "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
          4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", "\[Epsilon]"}], 
            RowBox[{
             SuperscriptBox[
              RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
             RowBox[{"NN", "[", "u", "]"}]}]]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "3"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 1, 3, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"\[Delta]Gxu", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            RowBox[{"\[Delta]Gxy", "[", 
             RowBox[{"t", ",", "u", ",", "y"}], "]"}], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
            RowBox[{"NN", "[", "u", "]"}]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 2, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1],
         Editable->False], 
        InterpretationBox[
         RowBox[{
          FractionBox["1", 
           RowBox[{"NN", "[", "u", "]"}]], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"\[Delta]Gxu", "[", 
              RowBox[{"t", ",", "u", ",", "y"}], "]"}], "2"], " ", 
            SuperscriptBox["\[Epsilon]", "2"]}], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"NN", "[", "u", "]"}], "2"]}]], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", "\[Epsilon]", "]"}], "4"],
           SeriesData[$CellContext`\[Epsilon], 0, {}, 0, 4, 1],
           Editable->False]}],
         SeriesData[$CellContext`\[Epsilon], 
          0, {$CellContext`NN[$CellContext`u]^(-1), 
           0, $CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-2) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1],
         Editable->False]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
      SeriesData[$CellContext`\[Epsilon], 
       0, {(-1) $CellContext`at[$CellContext`u]^(-2), 
        0, $CellContext`at[$CellContext`u]^(-4) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
       4, 1]}, {
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-2), 
        0, $CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-6) $CellContext`NN[$CellContext`u]^(-1) \
(-$CellContext`ax[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`ax[$CellContext`u]^2 \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]^2 + \
$CellContext`at[$CellContext`u]^2 $CellContext`NN[$CellContext`u] \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2)}, 
       0, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
       3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1]}, {
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-4) $CellContext`\[Delta]Gtx[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]}, 1, 
       3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-2), 
        0, $CellContext`ax[$CellContext`u]^(-6) \
$CellContext`\[Delta]Gxy[$CellContext`t, $CellContext`u, $CellContext`y]^2}, 
       0, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1]}, {
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`at[$CellContext`u]^(-2) \
$CellContext`ax[$CellContext`u]^(-2) $CellContext`NN[$CellContext`u]^(-1) \
$CellContext`\[Delta]Gtx[$CellContext`t, $CellContext`u, $CellContext`y] \
$CellContext`\[Delta]Gxu[$CellContext`t, $CellContext`u, $CellContext`y]}, 2, 
       4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {-$CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 1, 3, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`ax[$CellContext`u]^(-4) \
$CellContext`NN[$CellContext`u]^(-1) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y] $CellContext`\[Delta]Gxy[$CellContext`t, \
$CellContext`u, $CellContext`y]}, 2, 4, 1], 
      SeriesData[$CellContext`\[Epsilon], 
       0, {$CellContext`NN[$CellContext`u]^(-1), 
        0, $CellContext`ax[$CellContext`u]^(-2) \
$CellContext`NN[$CellContext`u]^(-2) $CellContext`\[Delta]Gxu[$CellContext`t, \
$CellContext`u, $CellContext`y]^2}, 0, 4, 1]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221023384695`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.015999999999998238`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.015999999999998238`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221023494406`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.04700000000000415`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.04700000000000415, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221023564224`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.20299999999999585`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.20299999999999585`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.770122102553895*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "1.8130000000000024`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 1.8130000000000024`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221043587246`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.5779999999999959`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.5779999999999959, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.770122104960625*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "1.5930000000000035`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 1.5930000000000035`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221065603743`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.39099999999999824`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.39099999999999824`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7701198118599453`*^9, 3.77012026696865*^9, 
  3.7701221069662886`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[StyleBox["Huge difference if you do more complicated stuff !!",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701194713424625`*^9, 3.7701194794284687`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Ansatz for matter fields",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701194508262987`*^9, 3.7701194551289864`*^9}, {
  3.7733919044526453`*^9, 3.7733919049365463`*^9}}],

Cell[BoxData[{
 RowBox[{"Ad", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"At", "[", "u", "]"}], ",", 
    RowBox[{"\[Epsilon]", "*", 
     RowBox[{"\[Delta]Ax", "[", 
      RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", "0", ",", "0"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"AD", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"Ad", ",", "1"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Add", ":=", 
  RowBox[{"covD", "[", "Ad", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FAdd", ":=", 
  RowBox[{
   RowBox[{"covD", "[", "Ad", "]"}], "-", 
   RowBox[{"Transpose", "[", 
    RowBox[{"covD", "[", "Ad", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"FADd", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"FAdd", ",", "1"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FADD", ":=", 
  RowBox[{"Raise", "[", 
   RowBox[{"FAdd", ",", "1", ",", "2"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"F2A", ":=", 
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{"Outer", "[", 
     RowBox[{"Times", ",", "FAdd", ",", "FADD"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]\[Alpha]", "[", "u_", "]"}], ":=", "1"}], "\n", 
 RowBox[{
  RowBox[{"\[Phi]xd", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
     RowBox[{"\[Alpha]\[Alpha]", "[", "u", "]"}], ",", 
     RowBox[{"\[Epsilon]", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]x", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]\[Alpha]", "'"}], "[", "u", "]"}], "x"}], " ", "+", 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]x", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "u", ",", "y"}], "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]yd", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"\[Alpha]\[Alpha]", "[", "u", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Alpha]\[Alpha]", "'"}], "[", "u", "]"}], " ", "y"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]xU", "=", 
   RowBox[{"Raise", "[", 
    RowBox[{"\[Phi]xd", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]yU", "=", 
   RowBox[{"Raise", "[", 
    RowBox[{"\[Phi]yd", ",", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Phi]xU", ".", "\[Phi]xd"}], "+", 
     RowBox[{"\[Phi]yU", ".", "\[Phi]yd"}]}], "2"]}], ";"}]}], "Input",
 CellChangeTimes->{{3.572867901441095*^9, 3.572867909621563*^9}, {
   3.572867947587734*^9, 3.572867964232686*^9}, 3.572868004770005*^9, {
   3.5728681548565893`*^9, 3.572868160515913*^9}, {3.5885706227857265`*^9, 
   3.5885706335743437`*^9}, {3.5886763282075176`*^9, 3.588676328686545*^9}, {
   3.588679161875594*^9, 3.588679162435626*^9}, {3.589176613958622*^9, 
   3.5891766403151293`*^9}, {3.5891781868285847`*^9, 
   3.5891781889057035`*^9}, {3.589202741782793*^9, 3.5892027467890797`*^9}, {
   3.5892580858651075`*^9, 3.58925808817824*^9}, {3.5892581726700726`*^9, 
   3.58925817297509*^9}, {3.59211606757362*^9, 3.5921160700067587`*^9}, {
   3.5922171668125076`*^9, 3.592217179860254*^9}, {3.592567787601239*^9, 
   3.5925677879202576`*^9}, {3.59256795073757*^9, 3.592567951300602*^9}, {
   3.592722473010656*^9, 3.592722473486683*^9}, {3.592914712905187*^9, 
   3.5929147138212395`*^9}, {3.593168440243997*^9, 3.5931684552968583`*^9}, {
   3.61267945371039*^9, 3.612679459666366*^9}, {3.6126801788663993`*^9, 
   3.612680193122916*^9}, {3.6128928336151857`*^9, 3.612892840685255*^9}, {
   3.6128936214712353`*^9, 3.6128936261751757`*^9}, {3.612901670067477*^9, 
   3.6129016848401947`*^9}, {3.6199304511005983`*^9, 3.619930456673005*^9}, 
   3.620025645677609*^9, 3.620033153563682*^9, {3.6203787248857403`*^9, 
   3.6203787252081413`*^9}, {3.624009548298813*^9, 3.624009568424783*^9}, {
   3.6240096075360465`*^9, 3.6240096081454506`*^9}, {3.6427418995561266`*^9, 
   3.6427419063085957`*^9}, {3.642742108843665*^9, 3.642742110713902*^9}, {
   3.6440610763844852`*^9, 3.644061104103932*^9}, {3.6441478118823595`*^9, 
   3.644147820232916*^9}, {3.6453784957744927`*^9, 3.6453785017864933`*^9}, {
   3.645379441627304*^9, 3.6453794424688697`*^9}, {3.7701194343771877`*^9, 
   3.7701194348648825`*^9}, {3.7701197318046637`*^9, 
   3.7701197318854437`*^9}, {3.7701199584222336`*^9, 3.7701199591567974`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[{
 "The lagrangian is : Sqrt[detg](R-2\[CapitalLambda] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["F", "2"], "2"]}], "-", 
     RowBox[{"2", 
      SuperscriptBox["m", "2"], 
      RowBox[{"V", "(", "X", ")"}]}]}], " ", ")"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.64406121437044*^9, 3.644061245514166*^9}, {
  3.6453734884346733`*^9, 3.645373490439005*^9}, {3.7733919166250744`*^9, 
  3.773391927016426*^9}},
 FontSize->18,
 FontWeight->"Bold",
 Background->RGBColor[1, 1, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ll", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    SqrtBox[
     FractionBox["detg", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"at", "[", "u", "]"}], "2"]}], " ", 
       SuperscriptBox[
        RowBox[{"ax", "[", "u", "]"}], "4"], " ", 
       RowBox[{"NN", "[", "u", "]"}]}]]], 
    RowBox[{"at", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"ax", "[", "u", "]"}], "2"], " ", 
    SqrtBox[
     RowBox[{"NN", "[", "u", "]"}]], 
    RowBox[{"(", 
     RowBox[{"R", "-", 
      RowBox[{"2", "\[CapitalLambda]"}], "+", 
      RowBox[{"-", 
       FractionBox["F2A", "2"]}], "-", " ", 
      RowBox[{"2", " ", "m2", " ", 
       RowBox[{"V", "[", "X", "]"}]}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6200341676054163`*^9, 3.620034215743165*^9}, {
   3.620034458244574*^9, 3.6200344612821217`*^9}, {3.620378776150002*^9, 
   3.620378781381852*^9}, {3.621336515409584*^9, 3.6213365267986593`*^9}, {
   3.62235246555513*^9, 3.6223524737692547`*^9}, {3.626786168919361*^9, 
   3.6267861778572745`*^9}, 3.639302325386151*^9, {3.6453734988155828`*^9, 
   3.645373501123119*^9}, {3.645378749807555*^9, 3.6453787504229574`*^9}, {
   3.7701194930964537`*^9, 3.770119501704841*^9}, {3.770120180306583*^9, 
   3.770120180691066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ll0", "=", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"ll", ",", "0"}], "]"}], "//", "FS"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ll1", "=", 
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"ll", ",", "1"}], "]"}], "//", "FS"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ll2", "=", 
   RowBox[{
    RowBox[{"SeriesCoefficient", "[", 
     RowBox[{"ll", ",", "2"}], "]"}], "//", "FS"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.620034237198539*^9, 3.62003425835084*^9}, {
  3.62003429885275*^9, 3.620034350132928*^9}, {3.6200344361985683`*^9, 
  3.6200344468218403`*^9}, {3.644061116901449*^9, 3.644061118898778*^9}, {
  3.7701195045012293`*^9, 3.770119535096839*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6240096364749346`*^9, 3.624033643152733*^9, 3.62404084033712*^9, 
   3.624082688479106*^9, 3.6241100289574356`*^9, 3.6241103813181553`*^9, 
   3.6242153475139446`*^9, 3.6247888384278493`*^9, 3.6249477340865545`*^9, 
   3.6249489951001115`*^9, 3.6249727425983667`*^9, 3.625139536693277*^9, 
   3.6252934982595854`*^9, 3.625305461228637*^9, 3.6253072060484614`*^9, 
   3.6253371226924047`*^9, 3.625380284340048*^9, 3.6254677230872693`*^9, 
   3.6255512129718947`*^9, 3.625574276388364*^9, 3.625659596591069*^9, 
   3.6256791780639105`*^9, 3.6257430464871454`*^9, 3.625751271036156*^9, 
   3.625986204713917*^9, 3.6267862695021267`*^9, 3.6267871446362915`*^9, 
   3.626806430724227*^9, 3.6270378358877463`*^9, 3.6270603904877496`*^9, 
   3.6271137791254773`*^9, 3.62714241106964*^9, 3.6272070695976315`*^9, 
   3.6272071922751737`*^9, 3.6272365744651837`*^9, 3.6272377772240467`*^9, 
   3.62728102733982*^9, 3.627302214214661*^9, 3.627304856715891*^9, 
   3.6273152617974167`*^9, 3.6273185821207542`*^9, 3.6273671789153576`*^9, 
   3.627395928934292*^9, 3.6274938674557657`*^9, 3.627914383021388*^9, 
   3.6280006949656944`*^9, 3.6286211666323442`*^9, 3.639302396968732*^9, 
   3.639917136266388*^9, 3.6427420748871884`*^9, 3.6427421223956313`*^9, 
   3.6440612730434866`*^9, 3.64413359815007*^9, 3.6441480111553164`*^9, {
   3.6453738555907516`*^9, 3.6453738815950556`*^9}, 3.6453787802117853`*^9, 
   3.6453796638269916`*^9, 3.6454270339819307`*^9, {3.770119523935339*^9, 
   3.7701195355830774`*^9}, 3.770119741350311*^9, 3.7701199811737523`*^9, 
   3.770120273710557*^9, 3.7701221088517776`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Equations of motion", "Section",
 CellChangeTimes->{{3.6240096569759517`*^9, 3.6240096602104826`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "VariationalMethods`"}]], "Input",
 CellChangeTimes->{3.5919628000845413`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqN", "=", 
   RowBox[{
    RowBox[{"8", " ", 
     RowBox[{"at", "[", "u", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"NN", "[", "u", "]"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{
      RowBox[{"EulerEquations", "[", 
       RowBox[{"ll0", ",", 
        RowBox[{"NN", "[", "u", "]"}], ",", 
        RowBox[{"{", "u", "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqat", "=", 
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"at", "[", "u", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"NN", "[", "u", "]"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{
      RowBox[{"EulerEquations", "[", 
       RowBox[{"ll0", ",", 
        RowBox[{"at", "[", "u", "]"}], ",", 
        RowBox[{"{", "u", "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqax", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      FractionBox["1", 
       RowBox[{"2", " ", 
        RowBox[{"ax", "[", "u", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"NN", "[", "u", "]"}], 
         RowBox[{"3", "/", "2"}]]}]]], 
     RowBox[{
      RowBox[{"EulerEquations", "[", 
       RowBox[{"ll0", ",", 
        RowBox[{"ax", "[", "u", "]"}], ",", 
        RowBox[{"{", "u", "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqAt", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"at", "[", "u", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"NN", "[", "u", "]"}], 
          RowBox[{"5", "/", "2"}]]}]], 
       RowBox[{"ax", "[", "u", "]"}]}]], 
     RowBox[{
      RowBox[{"EulerEquations", "[", 
       RowBox[{"ll0", ",", 
        RowBox[{"At", "[", "u", "]"}], ",", 
        RowBox[{"{", "u", "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//", "FS"}]}], ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQXfLwkh7P61eOGrtuGYDoHNcZ/iDa4NTWUBCd7rbC
TwBI16Qe9gfRj7y75oJop7pVYLr9Lsubqh+vHDfNzwDTdzIyZauB9Cr+vwog
+vOT9TnLgPSzasFcEB2UFpy4AkjfspRIBtGbmG3jVwHpUONSMD0hhltgNZAu
WRUJpqfob41V/f3KkWftfTB9ie9xIoju/eOcCqLzVy+arQakv71cA6Y1zwqs
A9EhOcpg2udo2S97hteOahce/gXR0ZZv1/1Sfu1YZHRoPYi+5tRtwKT52tFr
4QMwveXisjIQvW/9ajA97WX6+ndibxxfXn4NpgFv8KYG
  "]],

Cell[TextData[StyleBox["BE CAREFUL! I do this here because I already know the \
results",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770119558216744*^9, 3.7701195688181963`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["Ansatz for the metric and the Gauge field",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701195779180164`*^9, 3.7701195828056393`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"at", "[", "u_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "u"], 
   SqrtBox[
    RowBox[{"f", "[", "u", "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ax", "[", "u_", "]"}], ":=", 
  FractionBox["1", "u"]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NN", "[", "u_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["u", "2"]], 
   FractionBox["1", 
    RowBox[{"f", "[", "u", "]"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"At", "[", "u_", "]"}], "=", 
   RowBox[{"\[Mu]", "-", 
    RowBox[{"\[Rho]", " ", "u"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"\[Mu]", "/", "uh"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["u", "6"]}], "eqN"}], "//", "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"-", " ", 
    SuperscriptBox["u", 
     RowBox[{"8", " "}]]}], 
   RowBox[{"f", "[", "u", "]"}], "eqat"}], "//", 
  "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"-", " ", 
    SuperscriptBox["u", "7"]}], " ", 
   SuperscriptBox[
    RowBox[{"f", "[", "u", "]"}], 
    RowBox[{"3", "/", "2"}]], "eqax"}], "//", "FS"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["1", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox[
        FractionBox["1", 
         RowBox[{
          SuperscriptBox["u", "2"], " ", 
          RowBox[{"f", "[", "u", "]"}]}]]], " "}], 
      SuperscriptBox["u", "10"]]}]], "eqAt"}], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.6240099221762233`*^9, 3.6240099971173306`*^9}, {
   3.6240411235638123`*^9, 3.6240411239075785`*^9}, {3.624082738887782*^9, 
   3.6240827403566036`*^9}, {3.626786333380085*^9, 3.626786348474547*^9}, 
   3.6267864925749445`*^9, 3.64274220274082*^9, {3.645373946556288*^9, 
   3.6453739513164573`*^9}, {3.7701195892230463`*^9, 3.7701195988815784`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "\[CapitalLambda]"}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "4"], " ", 
    SuperscriptBox["\[Mu]", "2"]}], 
   SuperscriptBox["uh", "2"]], "+", 
  RowBox[{"12", " ", 
   RowBox[{"f", "[", "u", "]"}]}], "+", 
  RowBox[{"4", " ", "m2", " ", 
   RowBox[{"V", "[", 
    SuperscriptBox["u", "2"], "]"}]}], "-", 
  RowBox[{"4", " ", "u", " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.6267863344426255`*^9, 3.6267863492245593`*^9}, 
   3.6267864930124493`*^9, 3.6267871656685133`*^9, 3.6268064349470215`*^9, 
   3.6270378403933425`*^9, 3.6270603941739197`*^9, 3.6271137827975216`*^9, 
   3.627142415908752*^9, 3.6272070848795867`*^9, 3.6272072982331905`*^9, 
   3.627236580682451*^9, 3.6272377816491995`*^9, 3.627281031933813*^9, 
   3.6273022181211205`*^9, 3.6273048602317047`*^9, 3.6273152663206887`*^9, 
   3.6273185869850116`*^9, 3.627367182524929*^9, 3.6273959349653234`*^9, 
   3.627493871967763*^9, 3.6279143876694794`*^9, 3.628000700295241*^9, 
   3.628621170913803*^9, 3.639302413294588*^9, 3.6399171400048914`*^9, {
   3.642742196160463*^9, 3.6427422033972497`*^9}, 3.6427433670655193`*^9, 
   3.6440613164033384`*^9, 3.6441336117130957`*^9, {3.6441480168150787`*^9, 
   3.6441480208087406`*^9}, 3.644148106695032*^9, {3.6453739424695673`*^9, 
   3.6453739528975077`*^9}, 3.6453789640213428`*^9, 3.645379714581415*^9, 
   3.6454270399318895`*^9, 3.770119602949752*^9, 3.7701199933270197`*^9, 
   3.7701202795071425`*^9, 3.7701221153470993`*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 0.85, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "\[CapitalLambda]"}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "4"], " ", 
    SuperscriptBox["\[Mu]", "2"]}], 
   SuperscriptBox["uh", "2"]], "+", 
  RowBox[{"12", " ", 
   RowBox[{"f", "[", "u", "]"}]}], "+", 
  RowBox[{"4", " ", "m2", " ", 
   RowBox[{"V", "[", 
    SuperscriptBox["u", "2"], "]"}]}], "-", 
  RowBox[{"4", " ", "u", " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.6267863344426255`*^9, 3.6267863492245593`*^9}, 
   3.6267864930124493`*^9, 3.6267871656685133`*^9, 3.6268064349470215`*^9, 
   3.6270378403933425`*^9, 3.6270603941739197`*^9, 3.6271137827975216`*^9, 
   3.627142415908752*^9, 3.6272070848795867`*^9, 3.6272072982331905`*^9, 
   3.627236580682451*^9, 3.6272377816491995`*^9, 3.627281031933813*^9, 
   3.6273022181211205`*^9, 3.6273048602317047`*^9, 3.6273152663206887`*^9, 
   3.6273185869850116`*^9, 3.627367182524929*^9, 3.6273959349653234`*^9, 
   3.627493871967763*^9, 3.6279143876694794`*^9, 3.628000700295241*^9, 
   3.628621170913803*^9, 3.639302413294588*^9, 3.6399171400048914`*^9, {
   3.642742196160463*^9, 3.6427422033972497`*^9}, 3.6427433670655193`*^9, 
   3.6440613164033384`*^9, 3.6441336117130957`*^9, {3.6441480168150787`*^9, 
   3.6441480208087406`*^9}, 3.644148106695032*^9, {3.6453739424695673`*^9, 
   3.6453739528975077`*^9}, 3.6453789640213428`*^9, 3.645379714581415*^9, 
   3.6454270399318895`*^9, 3.770119602949752*^9, 3.7701199933270197`*^9, 
   3.7701202795071425`*^9, 3.7701221153520856`*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 0.85, 0.85]],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "\[CapitalLambda]"}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "4"], " ", 
    SuperscriptBox["\[Mu]", "2"]}], 
   SuperscriptBox["uh", "2"]], "+", 
  RowBox[{"12", " ", 
   RowBox[{"f", "[", "u", "]"}]}], "+", 
  RowBox[{"4", " ", "m2", " ", 
   RowBox[{"V", "[", 
    SuperscriptBox["u", "2"], "]"}]}], "+", 
  RowBox[{"2", " ", "u", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     RowBox[{"2", " ", "m2", " ", "u", " ", 
      RowBox[{
       SuperscriptBox["V", "\[Prime]",
        MultilineFunction->None], "[", 
       SuperscriptBox["u", "2"], "]"}]}], "+", 
     RowBox[{"u", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.6267863344426255`*^9, 3.6267863492245593`*^9}, 
   3.6267864930124493`*^9, 3.6267871656685133`*^9, 3.6268064349470215`*^9, 
   3.6270378403933425`*^9, 3.6270603941739197`*^9, 3.6271137827975216`*^9, 
   3.627142415908752*^9, 3.6272070848795867`*^9, 3.6272072982331905`*^9, 
   3.627236580682451*^9, 3.6272377816491995`*^9, 3.627281031933813*^9, 
   3.6273022181211205`*^9, 3.6273048602317047`*^9, 3.6273152663206887`*^9, 
   3.6273185869850116`*^9, 3.627367182524929*^9, 3.6273959349653234`*^9, 
   3.627493871967763*^9, 3.6279143876694794`*^9, 3.628000700295241*^9, 
   3.628621170913803*^9, 3.639302413294588*^9, 3.6399171400048914`*^9, {
   3.642742196160463*^9, 3.6427422033972497`*^9}, 3.6427433670655193`*^9, 
   3.6440613164033384`*^9, 3.6441336117130957`*^9, {3.6441480168150787`*^9, 
   3.6441480208087406`*^9}, 3.644148106695032*^9, {3.6453739424695673`*^9, 
   3.6453739528975077`*^9}, 3.6453789640213428`*^9, 3.645379714581415*^9, 
   3.6454270399318895`*^9, 3.770119602949752*^9, 3.7701199933270197`*^9, 
   3.7701202795071425`*^9, 3.7701221157490263`*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 0.85, 0.85]],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.6267863344426255`*^9, 3.6267863492245593`*^9}, 
   3.6267864930124493`*^9, 3.6267871656685133`*^9, 3.6268064349470215`*^9, 
   3.6270378403933425`*^9, 3.6270603941739197`*^9, 3.6271137827975216`*^9, 
   3.627142415908752*^9, 3.6272070848795867`*^9, 3.6272072982331905`*^9, 
   3.627236580682451*^9, 3.6272377816491995`*^9, 3.627281031933813*^9, 
   3.6273022181211205`*^9, 3.6273048602317047`*^9, 3.6273152663206887`*^9, 
   3.6273185869850116`*^9, 3.627367182524929*^9, 3.6273959349653234`*^9, 
   3.627493871967763*^9, 3.6279143876694794`*^9, 3.628000700295241*^9, 
   3.628621170913803*^9, 3.639302413294588*^9, 3.6399171400048914`*^9, {
   3.642742196160463*^9, 3.6427422033972497`*^9}, 3.6427433670655193`*^9, 
   3.6440613164033384`*^9, 3.6441336117130957`*^9, {3.6441480168150787`*^9, 
   3.6441480208087406`*^9}, 3.644148106695032*^9, {3.6453739424695673`*^9, 
   3.6453739528975077`*^9}, 3.6453789640213428`*^9, 3.645379714581415*^9, 
   3.6454270399318895`*^9, 3.770119602949752*^9, 3.7701199933270197`*^9, 
   3.7701202795071425`*^9, 3.7701221157520185`*^9},
 FontWeight->"Bold",
 Background->RGBColor[1, 0.85, 0.85]]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", "\[CapitalLambda]"}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["u", "4"], " ", 
       SuperscriptBox["\[Mu]", "2"]}], 
      SuperscriptBox["uh", "2"]], "+", 
     RowBox[{"12", " ", 
      RowBox[{"f", "[", "u", "]"}]}], "+", 
     RowBox[{"4", " ", "m2", " ", 
      RowBox[{"V", "[", 
       SuperscriptBox["u", "2"], "]"}]}], "-", 
     RowBox[{"4", " ", "u", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", "0"}], ",",
    "f", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.6453739783244286`*^9, 3.645373986715012*^9}, 
   3.645378970862894*^9, {3.6453797219303064`*^9, 3.645379722273535*^9}, {
   3.7701196143612986`*^9, 3.770119614645538*^9}, {3.770120000070887*^9, 
   3.7701200003172016`*^9}, {3.770120253871769*^9, 3.770120254442521*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"f", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "u", "}"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{"C", "[", "1", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["u", "3"], " ", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "1", "u"], 
         RowBox[{
          FractionBox[
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"K", "[", "1", "]"}], "4"]}], "+", 
            RowBox[{"2", " ", "m2", " ", 
             SuperscriptBox["uh", "2"], " ", 
             RowBox[{"V", "[", 
              SuperscriptBox[
               RowBox[{"K", "[", "1", "]"}], "2"], "]"}]}]}], 
           RowBox[{"2", " ", 
            SuperscriptBox["uh", "2"], " ", 
            SuperscriptBox[
             RowBox[{"K", "[", "1", "]"}], "4"]}]], 
          RowBox[{"\[DifferentialD]", 
           RowBox[{"K", "[", "1", "]"}]}]}]}]}]}]}], "]"}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6453740121679535`*^9, 3.64537899991623*^9, 
  3.6453797463035307`*^9, 3.6454270627550793`*^9, 3.7701196179369698`*^9, 
  3.7701200037597523`*^9, 3.770120282641285*^9, 3.7701221181680775`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Here it is your metric! Fix the integration constants \
to have it zero at uh and always check it reduces to what you know!",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701196227395983`*^9, 3.7701196696589246`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fback", "[", "u_", "]"}], "=", 
   RowBox[{
    SuperscriptBox["u", "3"], 
    RowBox[{"Integrate", "[", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["uh", "2"], " ", "\[CapitalLambda]"}], "+", 
        RowBox[{"2", " ", "m2", " ", 
         SuperscriptBox["uh", "2"], " ", 
         RowBox[{"V", "[", 
          SuperscriptBox[
           RowBox[{"K", "[", "1", "]"}], "2"], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"K", "[", "1", "]"}], "4"]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["uh", "2"], " ", 
        SuperscriptBox[
         RowBox[{"K", "[", "1", "]"}], "4"]}]], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"K", "[", "1", "]"}], ",", "uh", ",", "u"}], "}"}], ",", 
      RowBox[{"GenerateConditions", "\[Rule]", "False"}]}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.770119672546792*^9, 3.7701196962832146`*^9}, {
  3.770120003640072*^9, 3.77012002707836*^9}, {3.770120257142707*^9, 
  3.770120257679143*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"fback", "[", "u", "]"}], "/.", 
    RowBox[{"m2", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"\[CapitalLambda]", "\[Rule]", 
    RowBox[{"-", "3"}]}]}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.770119700131668*^9, 3.7701197049309797`*^9}, {
  3.7701200120506167`*^9, 3.7701200200820055`*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   SuperscriptBox["u", "3"], 
   SuperscriptBox["uh", "3"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "4"], " ", 
    SuperscriptBox["\[Mu]", "2"]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["uh", "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "3"], " ", 
    SuperscriptBox["\[Mu]", "2"]}], 
   RowBox[{"2", " ", "uh"}]]}]], "Output",
 CellChangeTimes->{{3.7701200095397053`*^9, 3.770120031739463*^9}, 
   3.77012028315423*^9, 3.7701221186418085`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"-", 
    RowBox[{
     RowBox[{"fback", "'"}], "[", "uh", "]"}]}], 
   RowBox[{"4", "\[Pi]"}]], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.7701200897400217`*^9, 3.770120097006749*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["\[CapitalLambda]", 
    RowBox[{"4", " ", "\[Pi]", " ", "uh"}]]}], "-", 
  FractionBox[
   RowBox[{"uh", " ", 
    SuperscriptBox["\[Mu]", "2"]}], 
   RowBox[{"8", " ", "\[Pi]"}]], "-", 
  FractionBox[
   RowBox[{"m2", " ", 
    RowBox[{"V", "[", 
     SuperscriptBox["uh", "2"], "]"}]}], 
   RowBox[{"4", " ", "\[Pi]", " ", "uh"}]]}]], "Output",
 CellChangeTimes->{3.770120097429618*^9, 3.770120283314802*^9, 
  3.7701221187874517`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["This will be useful later:",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770120080333251*^9, 3.770120085732142*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f2ndback", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"4", " ", "\[CapitalLambda]"}], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["uh", "2"]], "+", 
        RowBox[{"12", " ", 
         RowBox[{"f", "[", "u", "]"}]}], "+", 
        RowBox[{"4", " ", "m2", " ", 
         RowBox[{"V", "[", 
          SuperscriptBox["u", "2"], "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", 
            RowBox[{
             SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "-", 
           RowBox[{"2", " ", "m2", " ", "u", " ", 
            RowBox[{
             SuperscriptBox["V", "\[Prime]",
              MultilineFunction->None], "[", 
             SuperscriptBox["u", "2"], "]"}]}], "+", 
           RowBox[{"u", " ", 
            RowBox[{
             SuperscriptBox["f", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"f", "''"}], "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]back", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"4", " ", "\[CapitalLambda]"}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["u", "4"], " ", 
          SuperscriptBox["\[Mu]", "2"]}], 
         SuperscriptBox["uh", "2"]], "+", 
        RowBox[{"12", " ", 
         RowBox[{"f", "[", "u", "]"}]}], "+", 
        RowBox[{"4", " ", "m2", " ", 
         RowBox[{"V", "[", 
          SuperscriptBox["u", "2"], "]"}]}], "-", 
        RowBox[{"4", " ", "u", " ", 
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], "\[Equal]", "0"}], 
      ",", "\[CapitalLambda]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.642744562973133*^9, 3.642744642446736*^9}, {
  3.6453739963824463`*^9, 3.6453740204081097`*^9}, {3.645378973172429*^9, 
  3.645378974735471*^9}, {3.6453797281154222`*^9, 3.6453797343735867`*^9}, {
  3.770120067361971*^9, 3.7701200731060476`*^9}, {3.770120261540117*^9, 
  3.7701202714647703`*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations ", "Subchapter",
 CellChangeTimes->{{3.6252936726118774`*^9, 3.6252936743307095`*^9}, {
   3.6272098788595643`*^9, 3.6272098839847994`*^9}, 3.63930227689192*^9}],

Cell[CellGroupData[{

Cell["EOMs ", "Section",
 CellChangeTimes->{{3.6240412000362463`*^9, 3.6240412008956656`*^9}, {
  3.6252937087230186`*^9, 3.6252937147701907`*^9}, {3.6252944486342354`*^9, 
  3.625294448759241*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQtx", "=", 
   RowBox[{
    RowBox[{"EulerEquations", "[", 
     RowBox[{"ll2", ",", 
      RowBox[{"\[Delta]Gtx", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQxy", "=", 
   RowBox[{
    RowBox[{"EulerEquations", "[", 
     RowBox[{"ll2", ",", 
      RowBox[{"\[Delta]Gxy", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQxu", "=", 
   RowBox[{
    RowBox[{"EulerEquations", "[", 
     RowBox[{"ll2", ",", 
      RowBox[{"\[Delta]Gxu", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ\[Phi]x", "=", 
   RowBox[{
    RowBox[{"EulerEquations", "[", 
     RowBox[{"ll2", ",", 
      RowBox[{"\[Delta]\[Phi]x", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQAx", "=", 
   RowBox[{
    RowBox[{"EulerEquations", "[", 
     RowBox[{"ll2", ",", 
      RowBox[{"\[Delta]Ax", "[", 
       RowBox[{"t", ",", "u", ",", "y"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "u", ",", "y"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.624040972943391*^9, 3.624041002323907*^9}, {
  3.644148125181332*^9, 3.644148134707675*^9}, {3.64537975064563*^9, 
  3.6453797508137417`*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrical sourced ansatz", "Subchapter",
 CellChangeTimes->{{3.645377831293042*^9, 3.645377834018862*^9}, {
  3.645426860767684*^9, 3.6454268616372614`*^9}, {3.6454283618220005`*^9, 
  3.6454283738159776`*^9}, {3.7701203677251854`*^9, 3.77012036779101*^9}}],

Cell["We source the BH with an external electric field", "Text",
 CellChangeTimes->{{3.770120390662243*^9, 3.770120396691387*^9}, {
  3.773391984603877*^9, 3.773391985857956*^9}},
 FontWeight->"Bold"],

Cell["The relevant equations are:", "Text",
 CellChangeTimes->{{3.770120407418556*^9, 3.7701204115961127`*^9}},
 FontWeight->"Bold"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F2\[Epsilon]", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{"F2A", ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
     SuperscriptBox["\[Epsilon]", "2"]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6453801369018507`*^9, 3.6453801775619106`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gtx", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{"htx", "[", "u", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gxy", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gxu", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{"hxu", "[", "u", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]\[Phi]x", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{"\[Chi]", "[", "u", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Ax", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Ex"}], " ", "t"}], " ", "+", 
    RowBox[{"\[Delta]Ax", "[", "u", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EQtxelectric", "=", 
  RowBox[{
   RowBox[{"EQtx", "/.", "\[CapitalLambda]back"}], "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
    "&"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EQxy", "//", 
  RowBox[{
   RowBox[{"FS", "[", 
    RowBox[{"#", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
       RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
   "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQconstraint", "=", 
  RowBox[{
   RowBox[{"EQxu", "/.", "\[CapitalLambda]back"}], "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
    "&"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ\[Chi]electric", "=", 
  RowBox[{"EQ\[Phi]x", "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
    "&"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"EQmaxwell", "=", 
  RowBox[{"EQAx", "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
    "&"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"F2electric", "=", 
  RowBox[{"F2\[Epsilon]", "//", "Expand"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[Delta]Gtx", ",", "\[Delta]Gxy", ",", "\[Delta]Gxu", ",", 
    "\[Delta]\[Phi]x", ",", "\[Delta]Ax", ",", "\[Delta]Ay"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.645377840122924*^9, 3.6453779079800816`*^9}, {
   3.6453780878788013`*^9, 3.6453781318480606`*^9}, {3.6453783571972723`*^9, 
   3.6453783878076425`*^9}, {3.645379167578806*^9, 3.6453791993329325`*^9}, {
   3.6453798081699066`*^9, 3.6453798142819777`*^9}, {3.6453798680917883`*^9, 
   3.645379868483048*^9}, {3.645379940963278*^9, 3.6453800084862175`*^9}, {
   3.645380181166312*^9, 3.6453802070175123`*^9}, {3.6454269899636335`*^9, 
   3.6454270008909054`*^9}, 3.6454270809813385`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"htx", "[", "u", "]"}], "-", 
  RowBox[{"u", " ", 
   RowBox[{
    SuperscriptBox["htx", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "+", 
  FractionBox[
   RowBox[{"m2", " ", 
    SuperscriptBox["u", "2"], " ", 
    RowBox[{"htx", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", 
     SuperscriptBox["u", "2"], "]"}]}], 
   RowBox[{"f", "[", "u", "]"}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
    RowBox[{
     SuperscriptBox["\[Delta]Ax", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], "uh"], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["u", "2"], " ", 
   RowBox[{
    SuperscriptBox["htx", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.645378132627581*^9, 3.6453782200007267`*^9, {3.645378352134904*^9, 
   3.645378391729258*^9}, 3.6453790570852733`*^9, 3.6453792058152514`*^9, 
   3.645379816079171*^9, 3.6453798695957885`*^9, 3.645379953825838*^9, 
   3.645380009283744*^9, {3.6453801881479545`*^9, 3.6453802078260503`*^9}, {
   3.645427072637781*^9, 3.645427081949978*^9}, 3.7701203848429456`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.645378132627581*^9, 3.6453782200007267`*^9, {3.645378352134904*^9, 
   3.645378391729258*^9}, 3.6453790570852733`*^9, 3.6453792058152514`*^9, 
   3.645379816079171*^9, 3.6453798695957885`*^9, 3.645379953825838*^9, 
   3.645380009283744*^9, {3.6453801881479545`*^9, 3.6453802078260503`*^9}, {
   3.645427072637781*^9, 3.645427081949978*^9}, 3.7701203848479333`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Ex", " ", 
    SuperscriptBox["u", "2"], " ", "\[Mu]"}], "+", 
   RowBox[{"m2", " ", "uh", " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", 
     SuperscriptBox["u", "2"], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["u", "2"]}], " ", 
       RowBox[{"hxu", "[", "u", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Chi]", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
  "uh"]], "Output",
 CellChangeTimes->{
  3.645378132627581*^9, 3.6453782200007267`*^9, {3.645378352134904*^9, 
   3.645378391729258*^9}, 3.6453790570852733`*^9, 3.6453792058152514`*^9, 
   3.645379816079171*^9, 3.6453798695957885`*^9, 3.645379953825838*^9, 
   3.645380009283744*^9, {3.6453801881479545`*^9, 3.6453802078260503`*^9}, {
   3.645427072637781*^9, 3.645427081949978*^9}, 3.7701203849232397`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"m2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"u", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["V", "\[Prime]",
        MultilineFunction->None], "[", 
       SuperscriptBox["u", "2"], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Chi]", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["u", "3"], " ", 
      RowBox[{"hxu", "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["f", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["V", "\[Prime]",
           MultilineFunction->None], "[", 
          SuperscriptBox["u", "2"], "]"}]}], "+", 
        RowBox[{"2", " ", "u", " ", 
         RowBox[{"f", "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["V", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          SuperscriptBox["u", "2"], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["u", "3"]}], " ", 
         RowBox[{
          SuperscriptBox["hxu", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["V", "\[Prime]",
           MultilineFunction->None], "[", 
          SuperscriptBox["u", "2"], "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["u", "2"], " ", 
         RowBox[{
          SuperscriptBox["\[Chi]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}], " ", 
         RowBox[{
          SuperscriptBox["V", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", 
          SuperscriptBox["u", "2"], "]"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["V", "\[Prime]",
           MultilineFunction->None], "[", 
          SuperscriptBox["u", "2"], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             SuperscriptBox["\[Chi]", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "+", 
           RowBox[{"u", " ", 
            RowBox[{
             SuperscriptBox["\[Chi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
       ")"}]}]}], ")"}]}], 
  SuperscriptBox["u", "3"]]], "Output",
 CellChangeTimes->{
  3.645378132627581*^9, 3.6453782200007267`*^9, {3.645378352134904*^9, 
   3.645378391729258*^9}, 3.6453790570852733`*^9, 3.6453792058152514`*^9, 
   3.645379816079171*^9, 3.6453798695957885`*^9, 3.645379953825838*^9, 
   3.645380009283744*^9, {3.6453801881479545`*^9, 3.6453802078260503`*^9}, {
   3.645427072637781*^9, 3.645427081949978*^9}, 3.770120385191523*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "u"}], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"htx", "[", "u", "]"}]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{
        SuperscriptBox["htx", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
   RowBox[{"uh", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]Ax", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]Ax", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
  "uh"]], "Output",
 CellChangeTimes->{
  3.645378132627581*^9, 3.6453782200007267`*^9, {3.645378352134904*^9, 
   3.645378391729258*^9}, 3.6453790570852733`*^9, 3.6453792058152514`*^9, 
   3.645379816079171*^9, 3.6453798695957885`*^9, 3.645379953825838*^9, 
   3.645380009283744*^9, {3.6453801881479545`*^9, 3.6453802078260503`*^9}, {
   3.645427072637781*^9, 3.645427081949978*^9}, 3.7701203852713118`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["Ex", "2"], " ", 
     SuperscriptBox["u", "4"]}], 
    RowBox[{"f", "[", "u", "]"}]]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "8"], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    SuperscriptBox[
     RowBox[{"htx", "[", "u", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["uh", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", "Ex", " ", 
    SuperscriptBox["u", "6"], " ", "\[Mu]", " ", 
    RowBox[{"hxu", "[", "u", "]"}]}], "uh"], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "8"], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"hxu", "[", "u", "]"}], "2"]}], 
   SuperscriptBox["uh", "2"]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["u", "6"], " ", "\[Mu]", " ", 
    RowBox[{"htx", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Delta]Ax", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], "uh"], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "4"], " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Delta]Ax", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.645378132627581*^9, 3.6453782200007267`*^9, {3.645378352134904*^9, 
   3.645378391729258*^9}, 3.6453790570852733`*^9, 3.6453792058152514`*^9, 
   3.645379816079171*^9, 3.6453798695957885`*^9, 3.645379953825838*^9, 
   3.645380009283744*^9, {3.6453801881479545`*^9, 3.6453802078260503`*^9}, {
   3.645427072637781*^9, 3.645427081949978*^9}, 3.770120385277295*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[TextData[StyleBox["The Maxwell equation is simply the radial \
conservation of a current, which at the boundary is the electric current we \
want",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701204269966307`*^9, 3.7701204681614337`*^9}, 
   3.773391997602088*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], 
      RowBox[{
       RowBox[{"\[Delta]Ax", "'"}], "[", "u", "]"}]}], "-", 
     RowBox[{
      FractionBox["\[Mu]", "uh"], " ", 
      SuperscriptBox["u", "2"], 
      RowBox[{"htx", "[", "u", "]"}]}]}], ",", "u"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "-", "EQmaxwell"}], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.645379830312643*^9, 3.645379849924698*^9}, {
  3.6453799554179015`*^9, 3.645379958872198*^9}, {3.7701204700992827`*^9, 
  3.7701204827676573`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.6453798437956185`*^9, 3.645379959313491*^9, 3.6454270737425203`*^9, {
   3.7701204761245775`*^9, 3.770120483102763*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["Let us solve the constraint for hxu close to the \
horizon where f(uh)=0",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701204904805794`*^9, 3.770120495114523*^9}, {
  3.7733920103432255`*^9, 3.7733920156742024`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"EQconstraint", "\[Equal]", "0"}], ",", 
    RowBox[{"hxu", "[", "u", "]"}]}], "]"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"hxu", "[", "u", "]"}], "/.", "%"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "u", "]"}], ",", "0", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.645379963703416*^9, 3.6453799712444296`*^9}, {
  3.645380100733782*^9, 3.6453801019375873`*^9}, {3.770120706745113*^9, 
  3.770120719923438*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hxu", "[", "u", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"Ex", " ", "\[Mu]"}], 
      RowBox[{"m2", " ", "uh", " ", 
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["V", "\[Prime]",
         MultilineFunction->None], "[", 
        SuperscriptBox["u", "2"], "]"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Chi]", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], 
      SuperscriptBox["u", "2"]]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.645379972100004*^9, 3.6453800261009407`*^9, 
  3.6453801022377834`*^9, 3.6454270737675343`*^9, 3.770120497178157*^9, 
  3.7701207206778803`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  InterpretationBox[
   RowBox[{
    FractionBox[
     RowBox[{"Ex", " ", "\[Mu]"}], 
     RowBox[{"m2", " ", "uh", " ", 
      RowBox[{
       SuperscriptBox["V", "\[Prime]",
        MultilineFunction->None], "[", 
       SuperscriptBox["u", "2"], "]"}], " ", 
      RowBox[{"f", "[", "u", "]"}]}]], "+", 
    InterpretationBox[
     SuperscriptBox[
      RowBox[{"O", "[", 
       RowBox[{"f", "[", "u", "]"}], "]"}], "0"],
     SeriesData[
      $CellContext`f[$CellContext`u], 0, {}, -1, 0, 1],
     Editable->False]}],
   SeriesData[
    $CellContext`f[$CellContext`u], 
    0, {$CellContext`Ex $CellContext`m2^(-1) $CellContext`uh^(-1) \
$CellContext`\[Mu]/Derivative[1][$CellContext`V][$CellContext`u^2]}, -1, 0, 1],
   Editable->False], "}"}]], "Output",
 CellChangeTimes->{3.645379972100004*^9, 3.6453800261009407`*^9, 
  3.6453801022377834`*^9, 3.6454270737675343`*^9, 3.770120497178157*^9, 
  3.7701207206826935`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["An alternative way to see the constraints at the \
horizons (see theory)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701206266337233`*^9, 3.7701206369286027`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"F2electric", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["u", "4"], " ", 
       RowBox[{"f", "[", "u", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Delta]Ax", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}], "2"]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["Ex", "2"], " ", 
        SuperscriptBox["u", "4"]}], 
       RowBox[{"f", "[", "u", "]"}]]}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Delta]Ax", "'"}], "[", "u", "]"}]}], "]"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%%", "/.", "%"}], "//", "FS"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"htx", "[", "u", "]"}], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{"hxu", "[", "u", "]"}]}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"htx", "[", "u", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6453802113854237`*^9, 3.6453802398873916`*^9}, {
  3.6453802821345015`*^9, 3.6453802853616533`*^9}, {3.645380327972005*^9, 
  3.645380367405247*^9}, {3.770120500976819*^9, 3.7701205297214594`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["Ex", "2"], " ", 
     SuperscriptBox["u", "4"]}], 
    RowBox[{"f", "[", "u", "]"}]]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "8"], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    SuperscriptBox[
     RowBox[{"htx", "[", "u", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["uh", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "-", 
  FractionBox[
   RowBox[{"4", " ", "Ex", " ", 
    SuperscriptBox["u", "6"], " ", "\[Mu]", " ", 
    RowBox[{"hxu", "[", "u", "]"}]}], "uh"], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "8"], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"hxu", "[", "u", "]"}], "2"]}], 
   SuperscriptBox["uh", "2"]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["u", "6"], " ", "\[Mu]", " ", 
    RowBox[{"htx", "[", "u", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Delta]Ax", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}]}], "uh"], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "4"], " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Delta]Ax", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.6453802222996826`*^9, 3.6453802402966633`*^9}, 
   3.645380285817952*^9, {3.645380337692478*^9, 3.645380367730468*^9}, 
   3.6454270738445845`*^9, 3.7701205015566483`*^9, 3.770120561947426*^9, 
   3.7701206407653303`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Delta]Ax", "\[Prime]",
     MultilineFunction->None], "[", "u", "]"}], "\[Rule]", 
   FractionBox["Ex", 
    RowBox[{"f", "[", "u", "]"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.6453802222996826`*^9, 3.6453802402966633`*^9}, 
   3.645380285817952*^9, {3.645380337692478*^9, 3.645380367730468*^9}, 
   3.6454270738445845`*^9, 3.7701205015566483`*^9, 3.770120561947426*^9, 
   3.7701206408321514`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"htx", "[", "u", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"f", "[", "u", "]"}]}], " ", 
    RowBox[{"hxu", "[", "u", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6453802222996826`*^9, 3.6453802402966633`*^9}, 
   3.645380285817952*^9, {3.645380337692478*^9, 3.645380367730468*^9}, 
   3.6454270738445845`*^9, 3.7701205015566483`*^9, 3.770120561947426*^9, 
   3.7701206408361406`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], 
       RowBox[{
        RowBox[{"\[Delta]Ax", "'"}], "[", "u", "]"}]}], "-", 
      RowBox[{
       FractionBox["\[Mu]", "uh"], " ", 
       SuperscriptBox["u", "2"], 
       RowBox[{"htx", "[", "u", "]"}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"htx", "[", "u", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"f", "[", "u", "]"}]}], " ", 
        RowBox[{"hxu", "[", "u", "]"}]}]}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Delta]Ax", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "\[Rule]", 
      FractionBox["Ex", 
       RowBox[{"f", "[", "u", "]"}]]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"hxu", "[", "u", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"Ex", " ", "\[Mu]"}], 
      RowBox[{"m2", " ", "uh", " ", 
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["V", "\[Prime]",
         MultilineFunction->None], "[", 
        SuperscriptBox["u", "2"], "]"}]}]]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["%", "Ex"], "/.", 
   RowBox[{"u", "\[Rule]", "uh"}]}], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.6453803790630054`*^9, 3.6453804098434887`*^9}, {
  3.7701206466242514`*^9, 3.7701206687350955`*^9}, {3.770120726492516*^9, 
  3.7701207331229134`*^9}}],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   SuperscriptBox["\[Mu]", "2"], 
   RowBox[{"m2", " ", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", 
     SuperscriptBox["uh", "2"], "]"}]}]]}]], "Output",
 CellChangeTimes->{{3.645380380173744*^9, 3.6453804103188095`*^9}, 
   3.645427074106758*^9, 3.7701206697158194`*^9, {3.770120726993704*^9, 
   3.770120733798214*^9}},
 FontSize->24,
 FontWeight->"Bold",
 Background->RGBColor[1, 1, 0]]
}, Open  ]],

Cell[TextData[StyleBox["Here it is eq.310 !",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.773392042266297*^9, 3.7733920517468867`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Thermal sourced ansatz and Seebek", "Subchapter",
 CellChangeTimes->{{3.6453804411653337`*^9, 3.645380451071926*^9}, {
  3.645426864653267*^9, 3.645426899428102*^9}, {3.645427356935976*^9, 
  3.6454273572501855`*^9}, {3.6454283698823614`*^9, 3.6454283719267263`*^9}, {
  3.7701203641745787`*^9, 3.7701203647326202`*^9}, {3.7701209488179016`*^9, 
  3.7701209514045286`*^9}}],

Cell[TextData[StyleBox["\[Zeta] is the thermal gradient",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770121082552895*^9, 3.7701210887198973`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gtx", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Zeta]"}], " ", 
       FractionBox[
        RowBox[{"f", "[", "u", "]"}], 
        SuperscriptBox["u", "2"]]}], ")"}]}], "+", 
    RowBox[{"htx", "[", "u", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gxy", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Gxu", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   FractionBox[
    RowBox[{"hxu", "[", "u", "]"}], 
    SuperscriptBox["u", "2"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]\[Phi]x", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{"\[Chi]", "[", "u", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]Ax", "[", 
    RowBox[{"t_", ",", "u_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "Ex"}], "+", 
       RowBox[{"\[Zeta]", " ", 
        RowBox[{"At", "[", "u", "]"}]}]}], ")"}]}], " ", "+", 
    RowBox[{"\[Delta]Ax", "[", "u", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EQtx", "/.", "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"EQxy", ";"}], "\[IndentingNewLine]", 
 RowBox[{"consT", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQxu", "/.", "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
    "&"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EQ\[Phi]x", "/.", "\[CapitalLambda]back"}], "/.", "f2ndback"}], "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"maxT", "=", 
  RowBox[{"EQmaxwell", "//", 
   RowBox[{
    RowBox[{"FS", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "u", "]"}], ">", "0"}], ",", 
        RowBox[{"u", ">", "0"}]}], "}"}]}], "]"}], 
    "&"}]}]}], "\[IndentingNewLine]", "F2\[Epsilon]", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[Delta]Gtx", ",", "\[Delta]Gxy", ",", "\[Delta]Gxu", ",", 
    "\[Delta]\[Phi]x", ",", "\[Delta]Ax", ",", "\[Delta]Ay"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.6469296985274925`*^9, 3.646929747061717*^9}, {
   3.6469298064771633`*^9, 3.646929846393664*^9}, {3.646930474067725*^9, 
   3.6469304893248544`*^9}, {3.6469305203164296`*^9, 
   3.6469305416215744`*^9}, {3.646930657519515*^9, 3.646930658525182*^9}, 
   3.6469307928093395`*^9, 3.646931079964978*^9, 3.646932606950169*^9, {
   3.7701209982342477`*^9, 3.7701209992192984`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Ex", " ", "uh"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"u", "-", "uh"}], ")"}], " ", "\[Zeta]", " ", "\[Mu]"}]}], 
     ")"}]}], "-", 
   RowBox[{
    SuperscriptBox["uh", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Zeta]", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "+", 
      RowBox[{"2", " ", "m2", " ", 
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["V", "\[Prime]",
         MultilineFunction->None], "[", 
        SuperscriptBox["u", "2"], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"hxu", "[", "u", "]"}], "-", 
         RowBox[{
          SuperscriptBox["\[Chi]", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], ")"}]}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["uh", "2"]}]]], "Output",
 CellChangeTimes->{
  3.646929749223156*^9, {3.6469298081582737`*^9, 3.6469298478636355`*^9}, 
   3.646930668566849*^9, 3.646930797481439*^9, 3.6469310841067276`*^9, 
   3.6469326134805007`*^9, 3.6470636065977316`*^9, 3.64706549743999*^9, {
   3.7701209803198853`*^9, 3.7701210026295824`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "u"}], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"htx", "[", "u", "]"}]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{
        SuperscriptBox["htx", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], "+", 
   RowBox[{"uh", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]Ax", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}], "+", 
      RowBox[{
       RowBox[{"f", "[", "u", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]Ax", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
  "uh"]], "Output",
 CellChangeTimes->{
  3.646929749223156*^9, {3.6469298081582737`*^9, 3.6469298478636355`*^9}, 
   3.646930668566849*^9, 3.646930797481439*^9, 3.6469310841067276`*^9, 
   3.6469326134805007`*^9, 3.6470636065977316`*^9, 3.64706549743999*^9, {
   3.7701209803198853`*^9, 3.770121002826056*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["u", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Ex"}], "+", 
        RowBox[{"\[Zeta]", " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "-", 
           FractionBox[
            RowBox[{"u", " ", "\[Mu]"}], "uh"]}], ")"}]}]}], ")"}], "2"]}], 
    RowBox[{"f", "[", "u", "]"}]]}], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "8"], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"t", " ", "\[Zeta]", " ", 
          RowBox[{"f", "[", "u", "]"}]}], 
         SuperscriptBox["u", "2"]]}], "+", 
       RowBox[{"htx", "[", "u", "]"}]}], ")"}], "2"]}], 
   RowBox[{
    SuperscriptBox["uh", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}]}]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["u", "4"], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "Ex"}], "+", 
      RowBox[{"\[Zeta]", " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "-", 
         FractionBox[
          RowBox[{"u", " ", "\[Mu]"}], "uh"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"hxu", "[", "u", "]"}]}], "uh"], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["u", "4"], " ", 
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"f", "[", "u", "]"}], " ", 
    SuperscriptBox[
     RowBox[{"hxu", "[", "u", "]"}], "2"]}], 
   SuperscriptBox["uh", "2"]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["u", "6"], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", "\[Zeta]", " ", 
         RowBox[{"f", "[", "u", "]"}]}], 
        SuperscriptBox["u", "2"]]}], "+", 
      RowBox[{"htx", "[", "u", "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", "\[Zeta]", " ", "\[Mu]"}], "uh"]}], "+", 
      RowBox[{
       SuperscriptBox["\[Delta]Ax", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], ")"}]}], "uh"], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["u", "4"], " ", 
   RowBox[{"f", "[", "u", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", "\[Zeta]", " ", "\[Mu]"}], "uh"]}], "+", 
      RowBox[{
       SuperscriptBox["\[Delta]Ax", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], ")"}], 
    "2"]}]}]], "Output",
 CellChangeTimes->{
  3.646929749223156*^9, {3.6469298081582737`*^9, 3.6469298478636355`*^9}, 
   3.646930668566849*^9, 3.646930797481439*^9, 3.6469310841067276`*^9, 
   3.6469326134805007`*^9, 3.6470636065977316`*^9, 3.64706549743999*^9, {
   3.7701209803198853`*^9, 3.770121002836028*^9}}]
}, Open  ]],

Cell[TextData[StyleBox["The Maxwell equation is again",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701210168561897`*^9, 3.7701210214647307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]Ax", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
       RowBox[{"htx", "[", "u", "]"}]}], "uh"]}], ",", "u"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"maxT", "-", "%"}], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.6469298900866723`*^9, 3.646929911240716*^9}, {
  3.6469299766594925`*^9, 3.6469300235025926`*^9}, {3.6469306780781636`*^9, 
  3.646930678258289*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.646929895800461*^9, 3.6469299117430487`*^9}, {
   3.646929978246546*^9, 3.646930023992915*^9}, 3.6469306788857036`*^9, 
   3.6469330959780135`*^9, 3.6470636109686375`*^9, 3.647065502094079*^9, 
   3.770121023375308*^9}]
}, Open  ]],

Cell[TextData[StyleBox["We can solve the constraint",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7701210323331475`*^9, 3.7701210353029876`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"consT", "\[Equal]", "0"}], ",", 
      RowBox[{"hxu", "[", "u", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Chi]", "'"}], "[", "u", "]"}], "\[Rule]", "0"}]}], "//", 
  RowBox[{
   RowBox[{"Collect", "[", 
    RowBox[{"#", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Chi]", "'"}], "[", "u", "]"}], "}"}], ",", "FS"}], "]"}], 
   "&"}]}]], "Input",
 CellChangeTimes->{{3.6469301173318853`*^9, 3.646930161282065*^9}, {
  3.646930685400029*^9, 3.6469306861765404`*^9}, {3.646931450569869*^9, 
  3.646931466341339*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"hxu", "[", "u", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Ex", " ", "uh"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", "-", "uh"}], ")"}], " ", "\[Zeta]", " ", "\[Mu]"}]}], 
       ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["uh", "2"], " ", "\[Zeta]", " ", 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], 
    RowBox[{"2", " ", "m2", " ", 
     SuperscriptBox["uh", "2"], " ", 
     RowBox[{"f", "[", "u", "]"}], " ", 
     RowBox[{
      SuperscriptBox["V", "\[Prime]",
       MultilineFunction->None], "[", 
      SuperscriptBox["u", "2"], "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.646930123592037*^9, 3.6469301617733893`*^9}, 
   3.6469306869200387`*^9, {3.6469314614961243`*^9, 3.646931466647544*^9}, 
   3.647063611316868*^9, 3.6470655025293665`*^9, 3.770121039188846*^9}]
}, Open  ]],

Cell["The Seebeck coefficient is  dJ/d\[Zeta] 1/T :", "Text",
 CellChangeTimes->{{3.64693166773405*^9, 3.6469316854518127`*^9}, {
  3.7701210976197667`*^9, 3.7701211073453827`*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "u", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Delta]Ax", "\[Prime]",
          MultilineFunction->None], "[", "u", "]"}]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
         RowBox[{"htx", "[", "u", "]"}]}], "uh"]}], ")"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Delta]Ax", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}], "\[Rule]", 
      RowBox[{"-", 
       FractionBox["Ex", 
        RowBox[{"f", "[", "u", "]"}]]}]}], "}"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"htx", "[", "u", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox[
       RowBox[{"f", "[", "u", "]"}], 
       SuperscriptBox["uh", "2"]], " ", 
      RowBox[{"hxu", "[", "u", "]"}]}]}], "}"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"hxu", "[", "u", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Ex", " ", "uh"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"u", "-", "uh"}], ")"}], " ", "\[Zeta]", " ", "\[Mu]"}]}], 
        ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["uh", "2"], " ", "\[Zeta]", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], 
     RowBox[{"2", " ", "m2", " ", 
      SuperscriptBox["uh", "2"], " ", 
      RowBox[{"f", "[", "u", "]"}], " ", 
      RowBox[{
       SuperscriptBox["V", "\[Prime]",
        MultilineFunction->None], "[", 
       SuperscriptBox["u", "2"], "]"}]}]]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], 
    FractionBox[
     RowBox[{"\[Pi]", " "}], 
     RowBox[{
      RowBox[{"f", "'"}], "[", "u", "]"}]], 
    RowBox[{"D", "[", 
     RowBox[{"%", ",", "\[Zeta]"}], "]"}]}], "/.", 
   RowBox[{"u", "\[Rule]", "uh"}]}], "//", "FS"}]}], "Input",
 CellChangeTimes->{{3.646931435056574*^9, 3.646931484211208*^9}, {
   3.6469315491142926`*^9, 3.6469316066364865`*^9}, {3.6469317813024483`*^9, 
   3.6469317883571324`*^9}, {3.6469319085139027`*^9, 
   3.6469319100509243`*^9}, {3.646932806343544*^9, 3.6469328079866385`*^9}, {
   3.7701211318433976`*^9, 3.7701211367778244`*^9}, 3.770123691705371*^9}],

Cell[BoxData[
 RowBox[{"Ex", "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["u", "2"], " ", "\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Ex", " ", "uh"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"u", "-", "uh"}], ")"}], " ", "\[Zeta]", " ", "\[Mu]"}]}], 
        ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["uh", "2"], " ", "\[Zeta]", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}], 
   RowBox[{"2", " ", "m2", " ", 
    SuperscriptBox["uh", "5"], " ", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", 
     SuperscriptBox["u", "2"], "]"}]}]]}]], "Output",
 CellChangeTimes->{3.7701236920636168`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "\[Pi]", " ", "\[Mu]"}], 
  RowBox[{"m2", " ", "uh", " ", 
   RowBox[{
    SuperscriptBox["V", "\[Prime]",
     MultilineFunction->None], "[", 
    SuperscriptBox["uh", "2"], "]"}]}]]], "Output",
 CellChangeTimes->{3.770123692067607*^9}]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  FractionBox[
   RowBox[{"2", " ", "\[Pi]", " ", "\[Mu]"}], 
   RowBox[{"m2", " ", "uh", " ", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", 
     SuperscriptBox["uh", "2"], "]"}]}]],
  FontSize->18,
  Background->RGBColor[1, 1, 0]]], "Input",
 CellChangeTimes->{3.7701211566688757`*^9}],

Cell[TextData[StyleBox["This is eq.319",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7733920895443835`*^9, 3.773392098612735*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1520, 781},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 463, 6, 139, "Title"],
Cell[1046, 30, 122, 2, 30, "Input"],
Cell[1171, 34, 147, 3, 30, "Input"],
Cell[1321, 39, 393, 6, 59, "Text"],
Cell[CellGroupData[{
Cell[1739, 49, 241, 3, 72, "Chapter"],
Cell[CellGroupData[{
Cell[2005, 56, 123, 3, 54, "Subsection"],
Cell[2131, 61, 187, 5, 31, "Input"],
Cell[2321, 68, 719, 23, 33, "Input"],
Cell[3043, 93, 661, 21, 52, "Input"],
Cell[3707, 116, 1735, 56, 92, "Input"],
Cell[5445, 174, 318, 10, 31, "Input"],
Cell[5766, 186, 327, 10, 31, "Input"],
Cell[6096, 198, 330, 10, 31, "Input"],
Cell[6429, 210, 321, 11, 31, "Input"],
Cell[6753, 223, 915, 28, 52, "Input"],
Cell[7671, 253, 1009, 35, 52, "Input"],
Cell[8683, 290, 1486, 43, 132, "Input"],
Cell[10172, 335, 1378, 41, 72, "Input"],
Cell[11553, 378, 167, 5, 31, "Input"],
Cell[11723, 385, 307, 9, 31, "Input"],
Cell[12033, 396, 1820, 52, 92, "Input"],
Cell[13856, 450, 1543, 44, 92, "Input"],
Cell[15402, 496, 359, 11, 31, "Input"],
Cell[15764, 509, 947, 25, 52, "Input"],
Cell[16714, 536, 325, 10, 31, "Input"],
Cell[17042, 548, 777, 24, 52, "Input"],
Cell[17822, 574, 46332, 1195, 3264, "Input"],
Cell[64157, 1771, 926, 27, 52, "Input"],
Cell[65086, 1800, 4515, 133, 152, "Input"],
Cell[69604, 1935, 2300, 78, 132, "Input"],
Cell[71907, 2015, 1034, 31, 72, "Input"],
Cell[72944, 2048, 494, 15, 31, "Input"],
Cell[73441, 2065, 494, 15, 31, "Input"],
Cell[73938, 2082, 2808, 78, 112, "Input"],
Cell[76749, 2162, 551, 19, 31, "Input"],
Cell[77303, 2183, 2389, 66, 92, "Input"],
Cell[79695, 2251, 2292, 64, 112, "Input"],
Cell[81990, 2317, 1181, 35, 72, "Input"],
Cell[83174, 2354, 424, 15, 31, "Input"],
Cell[83601, 2371, 2998, 85, 172, "Input"],
Cell[86602, 2458, 1453, 45, 72, "Input"],
Cell[88058, 2505, 188, 5, 31, "Input"],
Cell[88249, 2512, 9071, 232, 372, "Input"],
Cell[97323, 2746, 535, 17, 31, "Input"],
Cell[97861, 2765, 1725, 51, 72, "Input"],
Cell[99589, 2818, 2192, 66, 112, "Input"],
Cell[101784, 2886, 729, 21, 31, "Input"],
Cell[102516, 2909, 913, 27, 52, "Input"],
Cell[103432, 2938, 231, 7, 31, "Input"],
Cell[103666, 2947, 323, 10, 31, "Input"],
Cell[103992, 2959, 477, 9, 52, "Input"],
Cell[104472, 2970, 186, 5, 31, "Input"],
Cell[104661, 2977, 89, 1, 52, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[104799, 2984, 147, 2, 61, "Chapter"],
Cell[CellGroupData[{
Cell[104971, 2990, 100, 1, 67, "Subchapter"],
Cell[105074, 2993, 250, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[105349, 3000, 106, 1, 70, "Section"],
Cell[105458, 3003, 190, 3, 30, "Text"],
Cell[105651, 3008, 4633, 86, 54, "Input"],
Cell[CellGroupData[{
Cell[110309, 3098, 90, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[110424, 3104, 2720, 63, 79, "Print"],
Cell[113147, 3169, 2372, 57, 24, "Print"],
Cell[115522, 3228, 42264, 913, 137, "Print"],
Cell[157789, 4143, 346, 7, 22, "Print"],
Cell[158138, 4152, 348, 7, 22, "Print"],
Cell[158489, 4161, 364, 7, 22, "Print"],
Cell[158856, 4170, 362, 7, 22, "Print"],
Cell[159221, 4179, 347, 7, 22, "Print"],
Cell[159571, 4188, 345, 7, 22, "Print"],
Cell[159919, 4197, 352, 7, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[160298, 4208, 150, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[160473, 4214, 4983, 97, 93, "Input"],
Cell[CellGroupData[{
Cell[165481, 4315, 5663, 143, 81, "Print"],
Cell[171147, 4460, 3311, 76, 28, "Print"],
Cell[174461, 4538, 22675, 521, 141, "Print"],
Cell[197139, 5061, 349, 7, 22, "Print"],
Cell[197491, 5070, 350, 7, 22, "Print"],
Cell[197844, 5079, 365, 7, 22, "Print"],
Cell[198212, 5088, 365, 7, 22, "Print"],
Cell[198580, 5097, 346, 7, 22, "Print"],
Cell[198929, 5106, 347, 7, 22, "Print"],
Cell[199279, 5115, 357, 7, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[199663, 5126, 178, 2, 30, "Text"],
Cell[199844, 5130, 273, 9, 5, "Text"],
Cell[200120, 5141, 204, 3, 30, "Text"],
Cell[200327, 5146, 5135, 121, 283, "Input"],
Cell[205465, 5269, 273, 9, 5, "Text"],
Cell[205741, 5280, 577, 18, 68, "Text"],
Cell[206321, 5300, 1319, 33, 70, "Input"],
Cell[CellGroupData[{
Cell[207665, 5337, 753, 19, 69, "Input"],
Cell[208421, 5358, 1649, 23, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[210119, 5387, 108, 1, 56, "Section"],
Cell[210230, 5390, 107, 2, 30, "Input"],
Cell[210340, 5394, 2544, 77, 157, "Input"],
Cell[212887, 5473, 188, 3, 30, "Text"],
Cell[213078, 5478, 273, 9, 5, "Text"],
Cell[213354, 5489, 273, 9, 5, "Text"],
Cell[213630, 5500, 168, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[213823, 5506, 1941, 59, 308, "Input"],
Cell[215767, 5567, 1673, 33, 69, "Output"],
Cell[217443, 5602, 1673, 33, 69, "Output"],
Cell[219119, 5637, 2101, 46, 69, "Output"],
Cell[221223, 5685, 1179, 17, 46, "Output"]
}, Open  ]],
Cell[222417, 5705, 273, 9, 5, "Text"],
Cell[222693, 5716, 273, 9, 5, "Text"],
Cell[CellGroupData[{
Cell[222991, 5729, 961, 24, 53, "Input"],
Cell[223955, 5755, 1430, 38, 52, "Output"]
}, Open  ]],
Cell[225400, 5796, 250, 3, 30, "Text"],
Cell[225653, 5801, 1142, 32, 56, "Input"],
Cell[CellGroupData[{
Cell[226820, 5837, 356, 9, 30, "Input"],
Cell[227179, 5848, 537, 17, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227753, 5870, 242, 7, 51, "Input"],
Cell[227998, 5879, 493, 15, 49, "Output"]
}, Open  ]],
Cell[228506, 5897, 149, 2, 30, "Text"],
Cell[228658, 5901, 2551, 68, 96, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[231258, 5975, 181, 2, 67, "Subchapter"],
Cell[CellGroupData[{
Cell[231464, 5981, 198, 3, 70, "Section"],
Cell[231665, 5986, 1929, 53, 107, "Input"],
Cell[233597, 6041, 273, 9, 5, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[233919, 6056, 264, 3, 67, "Subchapter"],
Cell[234186, 6061, 200, 3, 30, "Text"],
Cell[234389, 6066, 132, 2, 30, "Text"],
Cell[234524, 6070, 389, 10, 34, "Input"],
Cell[CellGroupData[{
Cell[234938, 6084, 3401, 99, 240, "Input"],
Cell[238342, 6185, 1263, 33, 51, "Output"],
Cell[239608, 6220, 417, 6, 30, "Output"],
Cell[240028, 6228, 1009, 26, 48, "Output"],
Cell[241040, 6256, 2999, 81, 49, "Output"],
Cell[244042, 6339, 1269, 34, 46, "Output"],
Cell[245314, 6375, 1751, 48, 52, "Output"]
}, Open  ]],
Cell[247080, 6426, 273, 9, 5, "Text"],
Cell[247356, 6437, 279, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[247660, 6446, 619, 18, 67, "Input"],
Cell[248282, 6466, 173, 3, 30, "Output"]
}, Open  ]],
Cell[248470, 6472, 250, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[248745, 6480, 610, 17, 50, "Input"],
Cell[249358, 6499, 756, 21, 50, "Output"],
Cell[250117, 6522, 957, 26, 49, "Output"]
}, Open  ]],
Cell[251089, 6551, 199, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[251313, 6558, 1370, 37, 115, "Input"],
Cell[252686, 6597, 1608, 46, 52, "Output"],
Cell[254297, 6645, 477, 11, 48, "Output"],
Cell[254777, 6658, 461, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255275, 6674, 1505, 46, 93, "Input"],
Cell[256783, 6722, 484, 14, 106, "Output"]
}, Open  ]],
Cell[257282, 6739, 144, 2, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[257463, 6746, 379, 5, 51, "Subchapter"],
Cell[257845, 6753, 156, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[258026, 6759, 3496, 105, 284, "Input"],
Cell[261525, 6866, 1352, 38, 50, "Output"],
Cell[262880, 6906, 1172, 33, 46, "Output"],
Cell[264055, 6941, 2878, 88, 60, "Output"]
}, Open  ]],
Cell[266948, 7032, 156, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[267129, 7038, 674, 19, 73, "Input"],
Cell[267806, 7059, 270, 4, 30, "Output"]
}, Open  ]],
Cell[268091, 7066, 154, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[268270, 7072, 693, 21, 30, "Input"],
Cell[268966, 7095, 1069, 29, 52, "Output"]
}, Open  ]],
Cell[270050, 7127, 202, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[270277, 7134, 2493, 73, 97, "Input"],
Cell[272773, 7209, 894, 27, 52, "Output"],
Cell[273670, 7238, 285, 8, 49, "Output"]
}, Open  ]],
Cell[273970, 7249, 354, 11, 71, "Input"],
Cell[274327, 7262, 139, 2, 30, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

