(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    102049,       2704]
NotebookOptionsPosition[     97692,       2559]
NotebookOutlinePosition[     98039,       2574]
CellTagsIndexPosition[     97996,       2571]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Section 4.5 : A taste of QNMs",
 FontSize->72]], "Title",
 CellChangeTimes->{{3.7699685353302555`*^9, 3.7699685391383286`*^9}, {
  3.773391402519706*^9, 3.773391407626175*^9}}],

Cell[TextData[StyleBox["In this notebook :\n1) we show how to solve \
perturbatively an holographic equation to obtain the QNMs at low \
momentum/frequency\n2) we show a simple method to get the QNM numerically for \
a decoupled equation\n\nThe relevant equations and results are contained in \
section 4.5 of the notes and they are taken from arXiv:1905.09164 ",
 FontSize->18,
 Background->RGBColor[0.87, 0.94, 1]]], "Text",
 CellChangeTimes->{{3.769968552932876*^9, 3.7699685601299033`*^9}, {
  3.771963159357607*^9, 3.771963193463833*^9}, {3.771963317540942*^9, 
  3.7719633403821306`*^9}, {3.7733914210554743`*^9, 3.7733914436482115`*^9}}],

Cell[CellGroupData[{

Cell["Analytics", "Chapter",
 CellChangeTimes->{{3.7699689846914635`*^9, 3.7699689858907785`*^9}}],

Cell[CellGroupData[{

Cell["Equation and perturbative expansion", "Section",
 CellChangeTimes->{{3.7700362309346867`*^9, 3.7700362359114275`*^9}}],

Cell[TextData[StyleBox["Derive the equations order by order",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7700363209629993`*^9, 3.770036326225243*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["k", "2"]}], " ", "NN", " ", "u"}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", "NN"}], ")"}], " ", "w"}]}], ")"}], " ", 
     RowBox[{"\[Phi]", "[", "u", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", "NN"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["u", "3"]}], ")"}]}], "+", 
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "w"}]}], ")"}]}]}], ")"}], 
     " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "+", 
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["u", "3"]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769768481818246*^9, 3.7697684849269342`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "[", "u_", "]"}], "=", 
   RowBox[{
    RowBox[{"F0", "[", "u", "]"}], "+", 
    RowBox[{"w", " ", 
     RowBox[{"F1", "[", "u", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], 
     RowBox[{"F2", "[", "u", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"eq", ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0", ",", "2"}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq0", "=", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq1", "=", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq2", "=", 
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{"%%%", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\[Phi]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.769838401628874*^9, 3.769838441348693*^9}, {
  3.7700362435421314`*^9, 3.7700362995356016`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           SuperscriptBox["u", "3"], "-", 
           RowBox[{"2", " ", "NN", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["u", "3"]}], ")"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["F0", "\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}], "-", 
        RowBox[{"u", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["u", "3"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["F0", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "u", "]"}]}]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "NN"}], " ", "u", " ", 
          RowBox[{"F0", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"2", " ", "NN"}], "+", 
            SuperscriptBox["u", "3"], "-", 
            RowBox[{"2", " ", "NN", " ", 
             SuperscriptBox["u", "3"]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["F2", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{"u", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["u", "3"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["F2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}], " ", 
       SuperscriptBox["k", "2"]}], "+", 
      InterpretationBox[
       SuperscriptBox[
        RowBox[{"O", "[", "k", "]"}], "3"],
       SeriesData[$CellContext`k, 0, {}, 0, 3, 1],
       Editable->False]}],
     SeriesData[$CellContext`k, 
      0, {(-4 + $CellContext`u^3 - 2 $CellContext`NN (-1 + $CellContext`u^3)) 
        Derivative[
         1][$CellContext`F0][$CellContext`u] - $CellContext`u (-1 + \
$CellContext`u^3) Derivative[2][$CellContext`F0][$CellContext`u], 
       0, -$CellContext`NN $CellContext`u $CellContext`F0[$CellContext`u] + \
(-4 + 2 $CellContext`NN + $CellContext`u^3 - 
         2 $CellContext`NN $CellContext`u^3) 
        Derivative[
         1][$CellContext`F2][$CellContext`u] - $CellContext`u (-1 + \
$CellContext`u^3) Derivative[2][$CellContext`F2][$CellContext`u]}, 0, 3, 1],
     Editable->False], ")"}], "+", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "NN"}], ")"}], " ", 
          RowBox[{"F0", "[", "u", "]"}]}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "u", " ", 
          RowBox[{
           SuperscriptBox["F0", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{
           SuperscriptBox["F1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{"2", " ", "NN", " ", 
          RowBox[{
           SuperscriptBox["F1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["u", "3"], " ", 
          RowBox[{
           SuperscriptBox["F1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{"2", " ", "NN", " ", 
          SuperscriptBox["u", "3"], " ", 
          RowBox[{
           SuperscriptBox["F1", "\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "+", 
         RowBox[{"u", " ", 
          RowBox[{
           SuperscriptBox["F1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["u", "4"], " ", 
          RowBox[{
           SuperscriptBox["F1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "u", "]"}]}]}], ")"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "NN"}], " ", "u", " ", 
           RowBox[{"F1", "[", "u", "]"}]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "NN"}], ")"}], " ", 
              RowBox[{"F2", "[", "u", "]"}]}], "+", 
             RowBox[{"u", " ", 
              RowBox[{
               SuperscriptBox["F2", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}], 
         ")"}], " ", 
        SuperscriptBox["k", "2"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", "k", "]"}], "3"],
        SeriesData[$CellContext`k, 0, {}, 0, 3, 1],
        Editable->False]}],
      SeriesData[$CellContext`k, 0, {
       Complex[0, 2] (-2 + $CellContext`NN) $CellContext`F0[$CellContext`u] + 
        Complex[0, 2] $CellContext`u 
         Derivative[1][$CellContext`F0][$CellContext`u] - 4 
        Derivative[1][$CellContext`F1][$CellContext`u] + 
        2 $CellContext`NN 
         Derivative[1][$CellContext`F1][$CellContext`u] + $CellContext`u^3 
         Derivative[1][$CellContext`F1][$CellContext`u] - 
        2 $CellContext`NN $CellContext`u^3 
        Derivative[1][$CellContext`F1][$CellContext`u] + $CellContext`u 
         Derivative[2][$CellContext`F1][$CellContext`u] - $CellContext`u^4 
        Derivative[2][$CellContext`F1][$CellContext`u], 
        0, -$CellContext`NN $CellContext`u $CellContext`F1[$CellContext`u] + 
        Complex[0, 
           2] ((-2 + $CellContext`NN) $CellContext`F2[$CellContext`u] + \
$CellContext`u Derivative[1][$CellContext`F2][$CellContext`u])}, 0, 3, 1],
      Editable->False], ")"}], " ", "w"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "w", "]"}], "2"],
    SeriesData[$CellContext`w, 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`w, 0, {
    SeriesData[$CellContext`k, 
     0, {(-4 + $CellContext`u^3 - 2 $CellContext`NN (-1 + $CellContext`u^3)) 
       Derivative[
        1][$CellContext`F0][$CellContext`u] - $CellContext`u (-1 + \
$CellContext`u^3) Derivative[2][$CellContext`F0][$CellContext`u], 
      0, -$CellContext`NN $CellContext`u $CellContext`F0[$CellContext`u] + \
(-4 + 2 $CellContext`NN + $CellContext`u^3 - 
        2 $CellContext`NN $CellContext`u^3) 
       Derivative[
        1][$CellContext`F2][$CellContext`u] - $CellContext`u (-1 + \
$CellContext`u^3) Derivative[2][$CellContext`F2][$CellContext`u]}, 0, 3, 1], 
    SeriesData[$CellContext`k, 0, {
     Complex[0, 2] (-2 + $CellContext`NN) $CellContext`F0[$CellContext`u] + 
      Complex[0, 2] $CellContext`u 
       Derivative[1][$CellContext`F0][$CellContext`u] - 4 
      Derivative[1][$CellContext`F1][$CellContext`u] + 
      2 $CellContext`NN 
       Derivative[1][$CellContext`F1][$CellContext`u] + $CellContext`u^3 
       Derivative[1][$CellContext`F1][$CellContext`u] - 
      2 $CellContext`NN $CellContext`u^3 
      Derivative[1][$CellContext`F1][$CellContext`u] + $CellContext`u 
       Derivative[2][$CellContext`F1][$CellContext`u] - $CellContext`u^4 
      Derivative[2][$CellContext`F1][$CellContext`u], 
      0, -$CellContext`NN $CellContext`u $CellContext`F1[$CellContext`u] + 
      Complex[0, 
         2] ((-2 + $CellContext`NN) $CellContext`F2[$CellContext`u] + \
$CellContext`u Derivative[1][$CellContext`F2][$CellContext`u])}, 0, 3, 1]}, 0,
    2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7700362419783897`*^9, 3.7700363000799055`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving it perturbatively", "Section",
 CellChangeTimes->{{3.7700363122053547`*^9, 3.770036316042366*^9}}],

Cell[TextData[StyleBox["Solve them assuming regularity at the horizon uh=1",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.770036333422263*^9, 3.7700363394454746`*^9}, 
   3.7733914712104473`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"eq0", "/.", 
       RowBox[{"NN", "\[Rule]", "3"}]}], ")"}], "\[Equal]", "0"}], ",", "F0", 
    ",", "u"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F0", "[", "u", "]"}], "/.", 
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]0sol", "[", "u_", "]"}], "=", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", "1"}]}]}]}], "Input",
 CellChangeTimes->{{3.7700363680131607`*^9, 3.7700363734970827`*^9}, {
   3.7700364418573112`*^9, 3.770036465645708*^9}, 3.7700365581233735`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"C", "[", "2", "]"}], "+", 
  RowBox[{
   RowBox[{"C", "[", "1", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "u"]}], "-", 
     FractionBox[
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "u"}]}], 
        SqrtBox["3"]], "]"}], 
      SqrtBox["3"]], "-", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", "u"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", "u", "+", 
        SuperscriptBox["u", "2"]}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.77003637396725*^9, {3.7700364449422116`*^9, 3.7700364666812396`*^9}, 
   3.770036558546218*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.77003637396725*^9, {3.7700364449422116`*^9, 3.7700364666812396`*^9}, 
   3.770036558558714*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"eq2", "/.", 
         RowBox[{"NN", "\[Rule]", "3"}]}], "/.", 
        RowBox[{"F0", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"x", ",", 
           RowBox[{"\[Phi]0sol", "[", "x", "]"}]}], "]"}]}]}], "//", 
       "Simplify"}], ")"}], "\[Equal]", "0"}], ",", "F2", ",", "u"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F2", "[", "u", "]"}], "/.", 
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2sol", "[", "u_", "]"}], "=", 
  RowBox[{"%%", "/.", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"%", ",", 
         RowBox[{"Log", "[", 
          RowBox[{"1", "-", "u"}], "]"}]}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"C", "[", "1", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.770036390329838*^9, 3.770036427799264*^9}, {
  3.770036469114292*^9, 3.770036552243383*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], "u"]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "u"}]}], 
      SqrtBox["3"]], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"C", "[", "1", "]"}]}], ")"}]}], 
   SqrtBox["3"]], "+", 
  RowBox[{"C", "[", "2", "]"}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "u"}], "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", "u", "+", 
     SuperscriptBox["u", "2"]}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.770036424510353*^9, 3.770036428194207*^9}, {
  3.7700364724979916`*^9, 3.770036552681855*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "3"]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "u"}], "]"}]}], "+", 
  RowBox[{"(", 
   InterpretationBox[
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox["3"], " ", "\[Pi]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"C", "[", "1", "]"}]}], ")"}]}], "+", 
        RowBox[{"18", " ", 
         RowBox[{"C", "[", "2", "]"}]}], "+", 
        RowBox[{
         RowBox[{"C", "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "18"}], "+", 
           RowBox[{"Log", "[", "27", "]"}]}], ")"}]}], "+", 
        RowBox[{"Log", "[", "27", "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"u", "-", "1"}], ")"}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        RowBox[{"u", "-", "1"}], "]"}], "2"],
      SeriesData[$CellContext`u, 1, {}, 0, 2, 1],
      Editable->False]}],
    SeriesData[$CellContext`u, 1, {
     Rational[1, 18] ((-2) 3^Rational[1, 2] Pi (1 + C[1]) + 18 C[2] + 
       C[1] (-18 + Log[27]) + Log[27]), 
      C[1]}, 0, 2, 1],
    Editable->False], ")"}]}]], "Output",
 CellChangeTimes->{{3.770036424510353*^9, 3.770036428194207*^9}, {
  3.7700364724979916`*^9, 3.7700365526968155`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "u"], "+", 
  RowBox[{"C", "[", "2", "]"}]}]], "Output",
 CellChangeTimes->{{3.770036424510353*^9, 3.770036428194207*^9}, {
  3.7700364724979916`*^9, 3.770036552699813*^9}}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"eq1", "/.", 
         RowBox[{"NN", "\[Rule]", "3"}]}], "/.", 
        RowBox[{"F0", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{"x", ",", 
           RowBox[{"\[Phi]0sol", "[", "x", "]"}]}], "]"}]}]}], "//", 
       "Simplify"}], ")"}], "\[Equal]", "0"}], ",", "F1", ",", "u"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F1", "[", "u", "]"}], "/.", 
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]1sol", "[", "u_", "]"}], "=", 
  RowBox[{
   RowBox[{"%%", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{"%", ",", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "-", "u"}], "]"}]}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"C", "[", "1", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
    RowBox[{"C", "[", "3", "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.7700365751645374`*^9, 3.770036606994933*^9}, {
  3.7700366432806206`*^9, 3.7700366485015445`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"C", "[", "2", "]"}], "+", 
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"C", "[", "1", "]"}]}], "u"], "+", 
     RowBox[{
      FractionBox["1", "3"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{"1", "+", 
         RowBox[{"2", " ", "u"}]}], 
        SqrtBox["3"]], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "3"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "+", 
        RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", "u"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "6"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "+", 
        RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", "u", "+", 
        SuperscriptBox["u", "2"]}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.770036583541834*^9, 3.7700366077302446`*^9}, 
   3.7700366489139805`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "3"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], "+", 
        RowBox[{"C", "[", "1", "]"}]}], ")"}]}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "u"}], "]"}]}], "+", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{
       RowBox[{
        FractionBox["1", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SqrtBox["3"], " ", "\[Pi]", " ", 
           RowBox[{"(", 
            RowBox[{"\[ImaginaryI]", "+", 
             RowBox[{"C", "[", "1", "]"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              RowBox[{"C", "[", "2", "]"}]}], "+", 
             RowBox[{
              RowBox[{"C", "[", "1", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "6"}], "+", 
                RowBox[{"Log", "[", "3", "]"}]}], ")"}]}], "-", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"Log", "[", "3", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"C", "[", "1", "]"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "-", "1"}], ")"}]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          RowBox[{"u", "-", "1"}], "]"}], "2"],
        SeriesData[$CellContext`u, 1, {}, 0, 2, 1],
        Editable->False]}],
      SeriesData[$CellContext`u, 1, {
       Rational[1, 6] ((-2) 3^Rational[1, 2] Pi (Complex[0, 1] + C[1]) + 
         3 (6 C[2] + C[1] (-6 + Log[3]) + Complex[0, -1] Log[3])), 
        Complex[0, -1] + 3 C[1]}, 0, 2, 1],
      Editable->False], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.770036583541834*^9, 3.7700366077302446`*^9}, 
   3.770036648928917*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "u"]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "u"}]}], 
         SqrtBox["3"]], "]"}]}], 
      SqrtBox["3"]]}], ")"}]}], "+", 
  RowBox[{"C", "[", "3", "]"}]}]], "Output",
 CellChangeTimes->{{3.770036583541834*^9, 3.7700366077302446`*^9}, 
   3.770036648935893*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Read the QNM", "Section",
 CellChangeTimes->{{3.7700363457583637`*^9, 3.770036347491216*^9}}],

Cell[TextData[StyleBox["Expanding the perturbative solution at the boundary \
u=0 and read the zero of the leading term",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7700366940397367`*^9, 3.770036704861427*^9}, {
  3.773391507177301*^9, 3.77339150802534*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "[", "u_", "]"}], "=", 
   RowBox[{
    RowBox[{"\[Phi]0sol", "[", "u", "]"}], "+", 
    RowBox[{"w", " ", 
     RowBox[{"(", 
      RowBox[{"\[Phi]1sol", "[", "u", "]"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], 
     RowBox[{"(", 
      RowBox[{"\[Phi]2sol", "[", "u", "]"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "0"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SeriesCoefficient", "[", 
      RowBox[{"%", ",", 
       RowBox[{"-", "1"}]}], "]"}], "\[Equal]", "0"}], ",", "w"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\[Phi]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.770036629722601*^9, 3.7700366812829046`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], "-", 
     RowBox[{"\[ImaginaryI]", " ", "w"}]}], "u"], "+", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "w"}], 
      RowBox[{"3", " ", 
       SqrtBox["3"]}]], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"C", "[", "2", "]"}]}], "+", 
     RowBox[{"w", " ", 
      RowBox[{"C", "[", "3", "]"}]}]}], ")"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "u", "]"}], "1"],
    SeriesData[$CellContext`u, 0, {}, -1, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`u, 
   0, {$CellContext`k^2 + Complex[0, -1] $CellContext`w, 1 + ((Complex[0, 
         Rational[-1, 3]] 3^Rational[-1, 2]) 
      Pi) $CellContext`w + $CellContext`k^2 C[2] + $CellContext`w C[3]}, -1, 
   1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7700366520516148`*^9, 3.770036681582841*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"w", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "\[ImaginaryI]"}], " ", 
    SuperscriptBox["k", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7700366520516148`*^9, 3.7700366815918*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerics", "Chapter",
 CellChangeTimes->{{3.7699685282376266`*^9, 3.769968529351636*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.770036209667468*^9, 3.770036210717761*^9}}],

Cell[CellGroupData[{

Cell["Equation", "Section",
 CellChangeTimes->{{3.769762131701007*^9, 3.769762133708793*^9}}],

Cell[TextData[StyleBox["Defining the equation in EF coordinates and read the \
boundary powers",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.769968570753481*^9, 3.769968574999468*^9}, {
  3.7699686849871287`*^9, 3.7699686881918726`*^9}, {3.7733915292067375`*^9, 
  3.7733915294839644`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqNN", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["k", "2"]}], " ", "NN", " ", "u"}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", "NN"}], ")"}], " ", "w"}]}], ")"}], " ", 
     RowBox[{"\[Phi]", "[", "u", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "-", "NN"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["u", "3"]}], ")"}]}], "+", 
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["u", "2"]}], "+", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "w"}]}], ")"}]}]}], ")"}], 
     " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}], "+", 
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["u", "3"]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "u", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7699676595573344`*^9, 3.769967665355286*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqNN", "/.", 
   RowBox[{"\[Phi]", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"z", ",", 
      SuperscriptBox["z", "pp"]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "0"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "5"}], " ", "pp"}], "+", 
     RowBox[{"2", " ", "NN", " ", "pp"}], "+", 
     SuperscriptBox["pp", "2"]}], "\[Equal]", "0"}], ",", "pp"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7697622787374177`*^9, 3.7697623134547997`*^9}, {
  3.7699676444782305`*^9, 3.769967644754181*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["u", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "pp"}]], " ", 
  RowBox[{"(", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "pp"}], "+", 
       RowBox[{"2", " ", "NN", " ", "pp"}], "+", 
       SuperscriptBox["pp", "2"]}], ")"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "u", "]"}], "1"],
      SeriesData[$CellContext`u, 0, {}, 0, 1, 1],
      Editable->False]}],
    SeriesData[$CellContext`u, 
     0, {(-5) $CellContext`pp + 
      2 $CellContext`NN $CellContext`pp + $CellContext`pp^2}, 0, 1, 1],
    Editable->False], ")"}]}]], "Output",
 CellChangeTimes->{{3.7697623019584465`*^9, 3.769762315646475*^9}, 
   3.769762362894758*^9, 3.7697650508820715`*^9, {3.7697659707942905`*^9, 
   3.769765987511101*^9}, {3.7699676452907686`*^9, 3.769967669493452*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"pp", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"pp", "\[Rule]", 
     RowBox[{"5", "-", 
      RowBox[{"2", " ", "NN"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7697623019584465`*^9, 3.769762315646475*^9}, 
   3.769762362894758*^9, 3.7697650508820715`*^9, {3.7697659707942905`*^9, 
   3.769765987511101*^9}, {3.7699676452907686`*^9, 3.7699676694965267`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["UV expansion", "Section",
 CellChangeTimes->{{3.76976347373752*^9, 3.769763473937502*^9}, {
  3.7699677629644966`*^9, 3.769967765005585*^9}}],

Cell[TextData[StyleBox["We start the expansion from a constant; doing that we \
directly impose the boundary condition corresponding to zero source, which is \
crucial to find the QNMs of the corresponding Green function. The numerical \
value of the constant is meaningless because it can always be rescaled away \
(so we set it to 1).",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699686134854994`*^9, 3.769968680120641*^9}, {
  3.773391545408869*^9, 3.773391575271699*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "[", "u_", "]"}], "=", 
   RowBox[{"1", "+", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"c", "[", "i", "]"}], 
       SuperscriptBox["u", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UVexp", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"eqNN", ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "0", ",", "11"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UVsol", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "6"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "7"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "8"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "9"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"UVexp", ",", "10"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c", "[", "1", "]"}], ",", 
       RowBox[{"c", "[", "2", "]"}], ",", 
       RowBox[{"c", "[", "3", "]"}], ",", 
       RowBox[{"c", "[", "4", "]"}], ",", 
       RowBox[{"c", "[", "5", "]"}], ",", 
       RowBox[{"c", "[", "6", "]"}], ",", 
       RowBox[{"c", "[", "7", "]"}], ",", 
       RowBox[{"c", "[", "8", "]"}], ",", 
       RowBox[{"c", "[", "9", "]"}], ",", 
       RowBox[{"c", "[", "10", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]UV", "[", 
    RowBox[{"u_", ",", "k_", ",", "w_", ",", "NN_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "u", "]"}], "/.", 
    RowBox[{"UVsol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]UVp", "[", 
    RowBox[{"u_", ",", "k_", ",", "w_", ",", "NN_"}], "]"}], "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[Phi]UV", "[", 
      RowBox[{"u", ",", "k", ",", "w", ",", "NN"}], "]"}], ",", "u"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\[Phi]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7697635007604837`*^9, 3.769763660802585*^9}, {
  3.7697650414455795`*^9, 3.7697651982459702`*^9}, {3.769967830824715*^9, 
  3.7699678311528807`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["IR expansion", "Section",
 CellChangeTimes->{{3.7299246069432096`*^9, 3.729924607100892*^9}, {
  3.769967773955117*^9, 3.769967775144838*^9}}],

Cell[TextData[StyleBox["At the horizon we simply impose regularity",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699686948271785`*^9, 3.769968700074127*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "[", "u_", "]"}], "=", 
   RowBox[{"\[Phi]0", "+", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ch", "[", "i", "]"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "u"}], ")"}], "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IRexp", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{"eqNN", ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", "1", ",", "10"}], "}"}]}], "]"}], "//", 
    "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IRsol", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "0"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "6"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "7"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "8"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{"IRexp", ",", "9"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ch", "[", "1", "]"}], ",", 
       RowBox[{"ch", "[", "2", "]"}], ",", 
       RowBox[{"ch", "[", "3", "]"}], ",", 
       RowBox[{"ch", "[", "4", "]"}], ",", 
       RowBox[{"ch", "[", "5", "]"}], ",", 
       RowBox[{"ch", "[", "6", "]"}], ",", 
       RowBox[{"ch", "[", "7", "]"}], ",", 
       RowBox[{"ch", "[", "8", "]"}], ",", 
       RowBox[{"ch", "[", "9", "]"}], ",", 
       RowBox[{"ch", "[", "10", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]IR", "[", 
    RowBox[{"u_", ",", "k_", ",", "w_", ",", "NN_", ",", "\[Phi]0_"}], "]"}], 
   "=", 
   RowBox[{
    RowBox[{"\[Phi]", "[", "u", "]"}], "/.", 
    RowBox[{"IRsol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]IRp", "[", 
    RowBox[{"u_", ",", "k_", ",", "w_", ",", "NN_", ",", "\[Phi]0_"}], "]"}], 
   "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"\[Phi]IR", "[", 
      RowBox[{"u", ",", "k", ",", "w", ",", "NN", ",", "\[Phi]0"}], "]"}], 
     ",", "u"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", "\[Phi]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7299250970526633`*^9, 3.7299251271161866`*^9}, {
   3.729925455775958*^9, 3.7299255556434546`*^9}, 3.7299255947630177`*^9, {
   3.769763715939847*^9, 3.7697637743159533`*^9}, {3.7697638691290264`*^9, 
   3.7697638706288614`*^9}, {3.769765221649457*^9, 3.769765226891121*^9}, {
   3.76996783982664*^9, 3.7699678401846867`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrations", "Section",
 CellChangeTimes->{{3.729925658762398*^9, 3.729925661066369*^9}, 
   3.7299312767975254`*^9}],

Cell[TextData[StyleBox["We integrate from the horizon and the boundary to an \
intermediate point zf.\nSince we know already that the lowest mode is purely \
imaginary we cheat a bit and we define w=-i \[CapitalGamma]",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699687072131557`*^9, 3.7699687176138744`*^9}, {
  3.773391601845502*^9, 3.7733916226777086`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"zf", "=", 
   RowBox[{"1", "/", "2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7299313871834383`*^9, 3.7299313892086296`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EQnum", "[", 
    RowBox[{"u_", ",", "k_", ",", "w_", ",", "NN_"}], "]"}], "=", "eqNN"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.729931321647625*^9, 3.7299313477419434`*^9}, {
   3.76976379880272*^9, 3.7697638057711725`*^9}, 3.7697652497102036`*^9, {
   3.7697653272651553`*^9, 3.7697653289563203`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Epsilon]", "=", 
   RowBox[{"1", "/", "100000"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.729931302700248*^9, 3.7299313065592194`*^9}, {
  3.7300880127416587`*^9, 3.7300880159973927`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NumUV", "[", 
   RowBox[{
    RowBox[{"k_", "?", "NumericQ"}], ",", 
    RowBox[{"\[CapitalGamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"NN_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"SetPrecision", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"EQnum", "[", 
          RowBox[{"u", ",", "k", ",", 
           RowBox[{
            RowBox[{"-", "I"}], " ", "\[CapitalGamma]"}], ",", "NN"}], "]"}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "\[Epsilon]", "]"}], "\[Equal]", 
         RowBox[{"\[Phi]UV", "[", 
          RowBox[{"\[Epsilon]", ",", "k", ",", 
           RowBox[{
            RowBox[{"-", "I"}], " ", "\[CapitalGamma]"}], ",", "NN"}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "\[Epsilon]", "]"}], "\[Equal]", 
         RowBox[{"\[Phi]UVp", "[", 
          RowBox[{"\[Epsilon]", ",", "k", ",", 
           RowBox[{
            RowBox[{"-", "I"}], " ", "\[CapitalGamma]"}], ",", "NN"}], 
          "]"}]}]}], "}"}], ",", "40"}], "]"}], ",", 
    RowBox[{"{", "\[Phi]", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "\[Epsilon]", ",", "zf"}], "}"}], ",", 
    RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729931308378282*^9, 3.7299313133962736`*^9}, {
  3.72993135126584*^9, 3.729931393985156*^9}, {3.7299314380287185`*^9, 
  3.7299314740335016`*^9}, {3.730087952378787*^9, 3.7300879695139465`*^9}, {
  3.7697638096992598`*^9, 3.769763839855793*^9}, {3.769763900322982*^9, 
  3.769763900534417*^9}, {3.7697643383401656`*^9, 3.769764353022388*^9}, {
  3.769765258764781*^9, 3.7697652625633535`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NumIR", "[", 
   RowBox[{
    RowBox[{"k_", "?", "NumericQ"}], ",", 
    RowBox[{"\[CapitalGamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"NN_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Phi]0_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"SetPrecision", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"EQnum", "[", 
          RowBox[{"u", ",", "k", ",", 
           RowBox[{
            RowBox[{"-", "I"}], " ", "\[CapitalGamma]"}], ",", "NN"}], "]"}], 
         "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]", "[", 
          RowBox[{"1", "-", "\[Epsilon]"}], "]"}], "\[Equal]", 
         RowBox[{"\[Phi]IR", "[", 
          RowBox[{
           RowBox[{"1", "-", "\[Epsilon]"}], ",", "k", ",", 
           RowBox[{
            RowBox[{"-", "I"}], " ", "\[CapitalGamma]"}], ",", "NN", ",", 
           "\[Phi]0"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", 
          RowBox[{"1", "-", "\[Epsilon]"}], "]"}], "\[Equal]", 
         RowBox[{"\[Phi]IRp", "[", 
          RowBox[{
           RowBox[{"1", "-", "\[Epsilon]"}], ",", "k", ",", 
           RowBox[{
            RowBox[{"-", "I"}], " ", "\[CapitalGamma]"}], ",", "NN", ",", 
           "\[Phi]0"}], "]"}]}]}], "}"}], ",", "40"}], "]"}], ",", 
    RowBox[{"{", "\[Phi]", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", 
      RowBox[{"1", "-", "\[Epsilon]"}], ",", "zf"}], "}"}], ",", 
    RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.729931492518588*^9, 3.729931499416688*^9}, {
  3.729931531184428*^9, 3.7299315478795266`*^9}, {3.7299397912391787`*^9, 
  3.729939798807726*^9}, {3.729939954370406*^9, 3.7299399567704334`*^9}, {
  3.7300879717148027`*^9, 3.730087988595297*^9}, {3.769763854861205*^9, 
  3.769763902558855*^9}, {3.769764355903263*^9, 3.7697643671229935`*^9}, {
  3.7697652657754073`*^9, 3.769765269907043*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["The solutions", "Section",
 CellChangeTimes->{{3.7697640931437345`*^9, 3.7697640939180994`*^9}, {
  3.7699687279230433`*^9, 3.7699687309801702`*^9}}],

Cell[TextData[StyleBox["This is how the solutions look like for a random \
choice of parameters",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.769968735760793*^9, 3.769968744454664*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]", "=", " ", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NN", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]0", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"DiscretePlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"\[Phi]", "[", "xx", "]"}], "]"}], "/.", 
        RowBox[{"NumUV", "[", 
         RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN"}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"xx", ",", "\[Epsilon]", ",", "zf", ",", "0.01"}], "}"}], ",", 
      RowBox[{"Filling", "\[Rule]", "False"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Phi]\",
FontSize->16]\)\!\(\*
StyleBox[\"(\",
FontSize->16]\)\!\(\*
StyleBox[\"u\",
FontSize->16]\)\!\(\*
StyleBox[\")\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", " ", "12"}], "]"}]}]}], "]"}], ",", "xx"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"DiscretePlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"\[Phi]", "[", "xx", "]"}], "]"}], "/.", 
        RowBox[{"NumIR", "[", 
         RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"xx", ",", "zf", ",", 
        RowBox[{"1", "-", "\[Epsilon]"}], ",", "0.01"}], "}"}], ",", 
      RowBox[{"Filling", "\[Rule]", "False"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Phi]\",
FontSize->16]\)\!\(\*
StyleBox[\"(\",
FontSize->16]\)\!\(\*
StyleBox[\"u\",
FontSize->16]\)\!\(\*
StyleBox[\")\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
      RowBox[{"AxesStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Black", ",", " ", "12"}], "]"}]}]}], "]"}], ",", "xx"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7697640967408066`*^9, 3.7697641582369795`*^9}, {
  3.769764376317506*^9, 3.7697645209626017`*^9}, {3.7697653412615995`*^9, 
  3.769765341975401*^9}, {3.769967905767171*^9, 3.7699679656373158`*^9}, {
  3.769968002866852*^9, 3.769968013013073*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0, 0, 1], PointSize[0.009166666666666668], Thickness[Large]}, 
    {RGBColor[0, 0, 1], PointSize[0.009166666666666668], Thickness[Large], 
     LineBox[CompressedData["
1:eJwBNQPK/CFib1JlAwAAAAEAAAAyAAAAAgAAAPFo44i1+OQ+ttbjswwA8D9V
TRB1H4CEPwDJpp/S1+8/6DBfXoB9lD9iDsD4e7DvPyU7NgLxup4/D34fozWK
7z+yogbTMHykP3CK6QT8ZO8/0SfyJOmaqT9yaeWKy0DvP++s3Xahua4/TmZI
q6Ad7z8HmWTkLOyxPwGWIud3++4/lltaDYl7tD/zypLLTdruPyUeUDblCrc/
UhLj8h667j+14EVfQZq5P6T6lAXomu4/RKM7iJ0pvD+rLWC7pXzuP9NlMbH5
uL4/ZMAk3FRf7j8ylBPtKqTAP25G0kDyQu4/enWOAdnrwT+Hm0TUeifuP8FW
CRaHM8M/JU8XlOsM7j8JOIQqNXvEP46ecJFB8+0/URn/PuPCxT/U7MTxedrt
P5j6eVORCsc/oqyT75HC7T/g2/RnP1LIP960HtuGq+0/KL1vfO2ZyT+f/hwb
VpXtP2+e6pCb4co/KtFpLf1/7T+3f2WlSSnMPzJnsad5a+0//2DgufdwzT/u
Hxw4yVftP0ZCW86luM4/z1b5pelE7T/HEWvxKQDQP6wFa9LYMu0/a4Ko+wCk
0D+mXxO5lCHtPw/z5QXYR9E/vp7FcBsR7T+zYyMQr+vRP2xLOyxrAe0/VtRg
GoaP0j/FVM86gvLsP/pEniRdM9M/IWFACV/k7D+etdsuNNfTP+HSeyIA1+w/
QiYZOQt71D/NE3MwZMrsP+aWVkPiHtU/9dL8/Im+7D+KB5RNucLVP7L+w3Jw
s+w/LnjRV5Bm1j+bZUaeFqnsP9HoDmJnCtc/mA/lrnuf7D91WUxsPq7XP4iL
CPieluw/GcqJdhVS2D+gn1vyf47sP706x4Ds9dg/1gIfPR6H7D9hqwSLw5nZ
Pz4GmZ95gOw/BRxClZo92j9VXqQKknrsP6iMf59x4do/SpBhmmd17D9M/byp
SIXbP67mDpj6cOw/8G36sx8p3D/CPgt8S23sP5TeN772zNw/23wI8Fpq7D84
T3XIzXDdP1sGc9EpaOw/3L+y0qQU3j8MRRQ0uWbsP38w8Nx7uN4/Lvb2ZApm
7D8joS3nUlzfPy7jlO0eZuw/gdWdIw==
      "]], {}, {}}}, {
    {RGBColor[1, 0, 0], PointSize[0.009166666666666668], Thickness[Large]}, 
    {RGBColor[1, 0, 0], PointSize[0.009166666666666668], Thickness[Large], 
     LineBox[CompressedData["
1:eJw10VtI02EYx/GlpjkoKVYrmi2vTCRxWaCB/So7soo2tQubFKZTL9qWTTIH
RbLSkDLtRmeBlZBGm5oaCl3UEIOYWmxzm5u28/mAeSihVtvftwfe2y/P834y
KsT8qkQajbYh9g7EXgLt/1gR3XWOqRG5wB/bcz/As4I35JO2eZzolRTSDa+s
WC0SCWVCJ1b3CdrUK1bskH88lRtw4IytkaE6bYNfGB4trXdA0RUfG/JGOsJd
SQ4EefGgDebh1v1DnXYcidUkhXZM/VRnlXLsiMViRTvWBrcrTkzbsJ6zo5s3
+Pm4ONahxgFPQ202k2FDbLlY0IGkkJHx6IMV8Rrd4ACHtbXsZo0VWfH19jmh
Ld+Y9oxphSyea3Ti62Rr89jT75jSxMeJEnl/OzO6ADYVdKFv2LKYKlrAjfi5
EhdGuMK0s455UOupXSioqezvKJ8HlWO4kT8zIe+zWCCkxo3z1dyMi1ctoL5v
zI30t2tSvtcM6ly6B+8Z+UqZ1AxqPYEHhzV5K4okM6icyoNroh9HmzrnsO7h
Rc7yG1Zy7hzx8KLFEr3754uJeHihSB/vPVZrIh5eqAY/WZV0E/HwYXrydxN7
wEg8fHBHte/qLxmJhw/t0hx+O81IPPzYe/KlrURpwBPqYD9aLgwIewUG2CkP
P1IeGIqrthhwkPIIoO/K9bo76lniEcA98fKUoWGWeAQgHV/qKePMEo8ginez
ihYDeuIRRMT9emdzn554BLEt09y0qVpPPELoznv8rSJTD+pcSQiybNUhuU9H
PEJIVfWMXFbqiEcY4onbLFOdjniEMSFY/hUs0BGPMG4lsx+2JOiIRwSbZwZG
n2u0xCMCLmcphd2pJR4RFCRyX/yt1OIfawSY6w==
      "]], {}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->16]\\)\"", 
     TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"\[Phi]\\\",\\nFontSize->16]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->16]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->16]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->16]\\)\"", 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{
   "MessagesHead" -> DiscretePlot, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05]},
  PlotRange->{{0, 1}, {0, 1.1}},
  PlotRangePadding->{{Automatic, Automatic}, {Automatic, Automatic}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.769764133146338*^9, 3.769764161981831*^9}, {
   3.7697643912395916`*^9, 3.76976452620969*^9}, 3.769765352195563*^9, 
   3.76996789985127*^9, 3.7699679791101017`*^9, 3.769968030292979*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Find root routine", "Section",
 CellChangeTimes->{{3.729939979044938*^9, 3.7299399812478633`*^9}, {
  3.730088449538637*^9, 3.73008845360294*^9}, {3.7697653915007095`*^9, 
  3.769765391650274*^9}, {3.769968338813876*^9, 3.7699683426031427`*^9}}],

Cell[TextData[StyleBox["Here it is how a very simple FindRoot routine works \
(if you brave you can automatize it)\n(always remember to check, do not trust \
mathematica!)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699687682168145`*^9, 3.769968805563196*^9}, {
  3.7733916467384205`*^9, 3.773391648337164*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NN", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{
          "k", ",", " ", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", " ", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{
          "k", ",", " ", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Phi]0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CapitalGamma]", ",", "1.4"}], "}"}], ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "8"}], ",", 
    RowBox[{"PrecisionGoal", "\[Rule]", "10"}]}], "]"}], "//", 
  "Quiet"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", " ", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}]}], "}"}], "/.", "%"}], "//", "Quiet"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "NN"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7300487869547224`*^9, 3.7300487912920284`*^9}, {
  3.7300497203461666`*^9, 3.730049766047846*^9}, {3.7697641877427607`*^9, 
  3.769764327535749*^9}, {3.769764531001012*^9, 3.7697646227862263`*^9}, {
  3.769764664993348*^9, 3.769764669859388*^9}, {3.7697653690878158`*^9, 
  3.76976538717203*^9}, {3.76976545048575*^9, 3.769765589407467*^9}, {
  3.769766108236293*^9, 3.769766313928344*^9}, {3.7697663576117115`*^9, 
  3.7697663584238763`*^9}, {3.76996834487783*^9, 3.769968345406143*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Phi]0", "\[Rule]", "0.8520180094680673`"}], ",", 
   RowBox[{"\[CapitalGamma]", "\[Rule]", "0.267841079479841`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.730048795202829*^9, {3.730049743323803*^9, 3.7300497711735973`*^9}, {
   3.7697642678718987`*^9, 3.7697643280663266`*^9}, {3.769764585045331*^9, 
   3.7697646066581664`*^9}, 3.769764662297619*^9, 3.769764693945323*^9, 
   3.7697653941978617`*^9, {3.7697654600610905`*^9, 3.7697655985166073`*^9}, {
   3.769766119769065*^9, 3.7697663052554407`*^9}, {3.7697663554929075`*^9, 
   3.7697663819877515`*^9}, 3.7699683614755*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "{", "2.96957015127776890681391028280301387799506`22.88341128961807*^-17", 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "-", "6.03655894281866776583358323413240498878672`20.366756527480213*^-\
17"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.730048795202829*^9, {3.730049743323803*^9, 3.7300497711735973`*^9}, {
   3.7697642678718987`*^9, 3.7697643280663266`*^9}, {3.769764585045331*^9, 
   3.7697646066581664`*^9}, 3.769764662297619*^9, 3.769764693945323*^9, 
   3.7697653941978617`*^9, {3.7697654600610905`*^9, 3.7697655985166073`*^9}, {
   3.769766119769065*^9, 3.7697663052554407`*^9}, {3.7697663554929075`*^9, 
   3.7697663819877515`*^9}, 3.7699683618275604`*^9}]
}, Open  ]],

Cell[TextData[StyleBox["Try to play moving the matching point and the seeds \
for the FindRoot...",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699688284028015`*^9, 3.7699688390739985`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Data N=3", "Section",
 CellChangeTimes->{{3.769765425761427*^9, 3.769765429584091*^9}, {
  3.7697655980868735`*^9, 3.769765598815687*^9}, {3.769968366292918*^9, 
  3.769968369271857*^9}, {3.769968973803895*^9, 3.769968974067027*^9}}],

Cell[TextData[StyleBox["Collecting manually the data for N=3 (you can easily \
automatize it, I am lazy)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.769968846811309*^9, 3.769968852661252*^9}, {
  3.7733916722254515`*^9, 3.7733916795346923`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.00010000257577525192`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", "0.010025412770812972`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "0.04041216056022905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.09213551293608103`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.4", ",", "0.16698082662340588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "0.2678410794798416`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6", ",", "0.3992866120430983`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7", ",", "0.5686892364288846`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8", ",", "0.788617999099683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9", ",", "1.0825403958541808`"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769765436730014*^9, 3.76976560530466*^9}, {
  3.7697661179484186`*^9, 3.7697663119173937`*^9}, {3.7697663855872564`*^9, 
  3.769766386297996*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data3short", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.1`", ",", "0.010025412770812972`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2`", ",", "0.04041216056022905`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3`", ",", "0.09213551293608103`"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7697664506308255`*^9, 3.76976645892017*^9}}],

Cell[TextData[StyleBox["Comparing with the known diffusion constant D= \
N/(2N-3)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699689043532996`*^9, 3.769968920694254*^9}, {
  3.7733916884215155`*^9, 3.7733916902801647`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"data3", ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"1", 
     SuperscriptBox["x", "2"]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<k\>\"", ",", "\"\<|Im[\[Omega]]|\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.769765591852936*^9, 3.769765670413838*^9}, {
  3.7697663988145227`*^9, 3.7697663990818124`*^9}, {3.7697664294947968`*^9, 
  3.7697664639386177`*^9}, {3.769968400171335*^9, 3.7699684165981216`*^9}, {
  3.7699688658635545`*^9, 3.7699688819044914`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6], 
       LineBox[{{0.01, 0.00010000257577525192`}, {0.1, 
        0.010025412770812972`}, {0.2, 0.04041216056022905}, {0.3, 
        0.09213551293608103}, {0.4, 0.16698082662340588`}, {0.5, 
        0.2678410794798416}, {0.6, 0.3992866120430983}, {0.7, 
        0.5686892364288846}, {0.8, 0.788617999099683}, {0.9, 
        1.0825403958541808`}}]}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[6], 
       AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->8.96], {0., 0.}], {{{0.01, 0.00010000257577525192`}}, {{
        0.1, 0.010025412770812972`}}, {{0.2, 0.04041216056022905}}, {{0.3, 
        0.09213551293608103}}, {{0.4, 0.16698082662340588`}}, {{0.5, 
        0.2678410794798416}}, {{0.6, 0.3992866120430983}}, {{0.7, 
        0.5686892364288846}}, {{0.8, 0.788617999099683}}, {{0.9, 
        1.0825403958541808`}}}]}, {}}}, {}, {}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlWk01AsYxm2VVBNaNBNX2UppUtlS5rGVLSpbiSayJHUZJUo3jIxSRF2X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        "]]},
      Annotation[#, "Charting`Private`Tag$8761#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"k\"", TraditionalForm], 
    FormBox["\"|Im[\[Omega]]|\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.9}, {0, 1.0825403958541808`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7697656073883514`*^9, 3.769765670831722*^9}, 
   3.769766218818548*^9, {3.7697663883853908`*^9, 3.7697663996562977`*^9}, 
   3.7697664327804594`*^9, 3.769766464517078*^9, {3.7699684054362984`*^9, 
   3.7699684173231974`*^9}, {3.769968866779644*^9, 3.7699688824948645`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data N=5", "Section",
 CellChangeTimes->{{3.769765425761427*^9, 3.769765429584091*^9}, {
  3.7697655980868735`*^9, 3.769765598815687*^9}, {3.769766504128772*^9, 
  3.7697665042640743`*^9}}],

Cell[TextData[StyleBox["Same for N=5",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699689043532996`*^9, 3.7699689343903723`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"k", "=", "0.9"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NN", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{
          "k", ",", " ", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", " ", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{
          "k", ",", " ", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "\[Equal]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Phi]0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[CapitalGamma]", ",", "0.4"}], "}"}], ",", 
    RowBox[{"AccuracyGoal", "\[Rule]", "8"}], ",", 
    RowBox[{"PrecisionGoal", "\[Rule]", "10"}]}], "]"}], "//", 
  "Quiet"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"\[Phi]", "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", " ", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumIR", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN", ",", "\[Phi]0"}], 
          "]"}]}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           RowBox[{"\[Phi]", "'"}], "[", "zf", "]"}], "]"}], "/.", 
         RowBox[{"NumUV", "[", 
          RowBox[{"k", ",", "\[CapitalGamma]", ",", "NN"}], "]"}]}], 
        ")"}]}]}], "}"}], "/.", "%"}], "//", "Quiet"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"k", ",", "NN"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7697665078591614`*^9, 3.769766602668326*^9}, {
  3.769766633914657*^9, 3.7697666812904997`*^9}, {3.7697667780659757`*^9, 
  3.76976681459268*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Phi]0", "\[Rule]", "0.6921998910922964`"}], ",", 
   RowBox[{"\[CapitalGamma]", "\[Rule]", "0.616227122319391`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7697665229253364`*^9, 3.769766610824244*^9}, {
  3.769766642197939*^9, 3.7697666931668153`*^9}, {3.7697667875146456`*^9, 
  3.7697668213513603`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "-", "1.4336874994704272998063306194049615986202284`24.58706490189526*^-\
15"}], "}"}], ",", 
   RowBox[{
   "{", "1.53811992239333656963792542808984756981660714`22.729900877502992*^-\
14", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7697665229253364`*^9, 3.769766610824244*^9}, {
  3.769766642197939*^9, 3.7697666931668153`*^9}, {3.7697667875146456`*^9, 
  3.7697668216695123`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"data5", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.00007142908983287521`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", "0.0017860383806660941`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", "0.007148047281040472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.15", ",", "0.01609774271853924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "0.028654767822581587`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.25", ",", "0.04484686969394908`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.06471015148875221`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.4", ",", "0.11563852541577668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "0.1819106654795495`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6", ",", "0.2641620128177804`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7", ",", "0.363218427963782`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8", ",", "0.4801315956617181`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9", ",", "0.616227122319391`"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769765436730014*^9, 3.76976560530466*^9}, {
  3.7697661179484186`*^9, 3.7697663119173937`*^9}, {3.7697663855872564`*^9, 
  3.769766386297996*^9}, {3.769766518696854*^9, 3.7697667008401146`*^9}, {
  3.769766795087579*^9, 3.7697668275993967`*^9}}],

Cell[TextData[StyleBox["Comparing with the known diffusion constant D= \
N/(2N-3)",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7699689043532996`*^9, 3.769968920694254*^9}, {
  3.773391702258196*^9, 3.7733917038028536`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"data5", ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     FractionBox["5", "7"], " ", 
     SuperscriptBox["x", "2"]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%", ",", "%", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<k\>\"", ",", "\"\<|Im[\[Omega]]|\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.769765591852936*^9, 3.769765670413838*^9}, {
  3.7697663988145227`*^9, 3.7697663990818124`*^9}, {3.7697664294947968`*^9, 
  3.7697664639386177`*^9}, {3.7697666181775465`*^9, 3.7697666246739244`*^9}, {
  3.7699684314026747`*^9, 3.769968453845626*^9}, {3.76996889091926*^9, 
  3.769968891267324*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{{}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6], 
       LineBox[{{0.01, 0.00007142908983287521}, {0.05, 
        0.0017860383806660941`}, {0.1, 0.007148047281040472}, {0.15, 
        0.01609774271853924}, {0.2, 0.028654767822581587`}, {0.25, 
        0.04484686969394908}, {0.3, 0.06471015148875221}, {0.4, 
        0.11563852541577668`}, {0.5, 0.1819106654795495}, {0.6, 
        0.2641620128177804}, {0.7, 0.363218427963782}, {0.8, 
        0.4801315956617181}, {0.9, 0.616227122319391}}]}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[6], 
       AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->8.96], {0., 0.}], {{{0.01, 0.00007142908983287521}}, {{
        0.05, 0.0017860383806660941`}}, {{0.1, 0.007148047281040472}}, {{0.15,
         0.01609774271853924}}, {{0.2, 0.028654767822581587`}}, {{0.25, 
        0.04484686969394908}}, {{0.3, 0.06471015148875221}}, {{0.4, 
        0.11563852541577668`}}, {{0.5, 0.1819106654795495}}, {{0.6, 
        0.2641620128177804}}, {{0.7, 0.363218427963782}}, {{0.8, 
        0.4801315956617181}}, {{0.9, 
        0.616227122319391}}}]}, {}}}, {}, {}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
       Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0vk/1IkDx3EkVyLHbkuOaEyrNFFIYd5JJToxiWjctZQrJSk0QpFrc6Sc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        "]]},
      Annotation[#, "Charting`Private`Tag$8853#1"]& ]}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"k\"", TraditionalForm], 
    FormBox["\"|Im[\[Omega]]|\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 0.9}, {0, 0.616227122319391}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7697656073883514`*^9, 3.769765670831722*^9}, 
   3.769766218818548*^9, {3.7697663883853908`*^9, 3.7697663996562977`*^9}, 
   3.7697664327804594`*^9, 3.769766464517078*^9, 3.769766831257126*^9, {
   3.7699684378344584`*^9, 3.7699684543064995`*^9}, 3.7699689380845885`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Happy end (cf. fig.27)", "Section",
 CellChangeTimes->{{3.769766855613843*^9, 3.769766856024104*^9}, {
  3.7699689440521994`*^9, 3.7699689489118156`*^9}, {3.773391783245081*^9, 
  3.7733917898187447`*^9}}],

Cell[TextData[StyleBox["Collect the results and plot them",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.773391732863874*^9, 3.7733917377162385`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"data5", ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "14"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", " ", 
   RowBox[{
    SuperscriptBox["x", "2"], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uno", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"%%", ",", "%"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{"data3", ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotMarkers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "14"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindFit", "[", 
   RowBox[{"data3short", ",", 
    RowBox[{"a", " ", 
     SuperscriptBox["x", "2"]}], ",", 
    RowBox[{"{", "a", "}"}], ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     FractionBox["5", "7"], 
     SuperscriptBox["x", "2"]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Black", ",", "Dashed"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"due", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"%%%", ",", "%"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7697668709128237`*^9, 3.769766926984541*^9}, {
  3.769853026789513*^9, 3.7698530764415874`*^9}, {3.7698531251520996`*^9, 
  3.7698532228318624`*^9}, {3.7699684781850324`*^9, 3.7699684801115875`*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"uno", ",", "due", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0.9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.9"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<k\>\"", ",", "\"\<|Im[\[Omega]]|\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "->", 
    RowBox[{"Directive", "[", 
     RowBox[{"Bold", ",", " ", "Medium", ",", "Black"}], "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", "Black"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7697669318068275`*^9, 3.7697670039606395`*^9}, {
  3.7699652425714636`*^9, 3.7699652530887947`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {
      {RGBColor[0, 0, 1], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->14], {0., 0.}], {{{0.01, 0.00007142908983287521}}, {{0.05,
         0.0017860383806660941`}}, {{0.1, 0.007148047281040472}}, {{0.15, 
        0.01609774271853924}}, {{0.2, 0.028654767822581587`}}, {{0.25, 
        0.04484686969394908}}, {{0.3, 0.06471015148875221}}, {{0.4, 
        0.11563852541577668`}}, {{0.5, 0.1819106654795495}}, {{0.6, 
        0.2641620128177804}}, {{0.7, 0.363218427963782}}, {{0.8, 
        0.4801315956617181}}, {{0.9, 
        0.616227122319391}}}]}, {}}, {}, {}, {{}, {}}}, {{{}, {}, 
      TagBox[
       {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlWk01AsYxm2VVBNaNBNX2UppUtlS5rGVLSpbiSayJHUZJUo3jIxSRF2X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         "]]},
       Annotation[#, "Charting`Private`Tag$1215#1"]& ]}, {}, {}}}, {{{}, {
      {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
       GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->14], {0., 0.}], {{{0.01, 0.00010000257577525192`}}, {{0.1,
         0.010025412770812972`}}, {{0.2, 0.04041216056022905}}, {{0.3, 
        0.09213551293608103}}, {{0.4, 0.16698082662340588`}}, {{0.5, 
        0.2678410794798416}}, {{0.6, 0.3992866120430983}}, {{0.7, 
        0.5686892364288846}}, {{0.8, 0.788617999099683}}, {{0.9, 
        1.0825403958541808`}}}]}, {}}, {}, {}, {{}, {}}}, {{{}, {}, 
      TagBox[
       {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0vk/1IkDx3EkVyLHbkuOaEyrNFFIYd5JJToxiWjctZQrJSk0QpFrc6Sc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         "]]},
       Annotation[#, "Charting`Private`Tag$1296#1"]& ]}, {}, {}}}, InsetBox[
    StyleBox[Cell[TextData[StyleBox["D T = 0.243",
      FontSize->24,
      FontColor->RGBColor[1, 0, 0]]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     FontSize->36,
     FontWeight->Bold,
     FontSlant->"Italic",
     FontOpacity->0.85,
     Background->GrayLevel[1.]], {0.10350115745991958, 0.74709941557586}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["D T = 0.171",
      FontSize->24,
      FontColor->RGBColor[0, 0, 1]]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     FontSize->36,
     FontWeight->Bold,
     FontSlant->"Italic",
     FontOpacity->0.85,
     Background->GrayLevel[1.]], {0.09782986136448152, 0.5055541984964351}, {
    Left, Baseline},
    Alignment->{Left, Top}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"k\"", TraditionalForm], 
    FormBox["\"|Im[\[Omega]]|\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->GrayLevel[0],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{13.387755, 16.}, {14.913408, 21.}},
  LabelStyle->Directive[Bold, Medium, 
    GrayLevel[0]],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.018750000000000003`, 
   0.9187500000000001}, {-0.019354838709677424`, 0.9483870967741936}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.7699652657746897`*^9, 3.769965273987094*^9}}],

Cell[TextData[StyleBox["Here you have fig.27 in the notes.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.773391766196464*^9, 3.7733917716954374`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1520, 781},
WindowMargins->{{-9, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 200, 3, 139, "Title"],
Cell[783, 27, 644, 9, 131, "Text"],
Cell[CellGroupData[{
Cell[1452, 40, 98, 1, 72, "Chapter"],
Cell[CellGroupData[{
Cell[1575, 45, 124, 1, 70, "Section"],
Cell[1702, 48, 160, 2, 30, "Text"],
Cell[1865, 52, 1357, 42, 34, "Input"],
Cell[CellGroupData[{
Cell[3247, 98, 1339, 40, 126, "Input"],
Cell[4589, 140, 7863, 191, 57, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12501, 337, 112, 1, 56, "Section"],
Cell[12616, 340, 203, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[12844, 347, 779, 22, 69, "Input"],
Cell[13626, 371, 811, 27, 72, "Output"],
Cell[14440, 400, 148, 3, 30, "Output"]
}, Open  ]],
Cell[14603, 406, 273, 9, 5, "Text"],
Cell[CellGroupData[{
Cell[14901, 419, 1352, 41, 88, "Input"],
Cell[16256, 462, 1006, 34, 64, "Output"],
Cell[17265, 498, 1571, 48, 46, "Output"],
Cell[18839, 548, 216, 5, 45, "Output"]
}, Open  ]],
Cell[19070, 556, 273, 9, 5, "Text"],
Cell[CellGroupData[{
Cell[19368, 569, 1483, 45, 88, "Input"],
Cell[20854, 616, 1375, 41, 54, "Output"],
Cell[22232, 659, 2051, 59, 46, "Output"],
Cell[24286, 720, 514, 17, 72, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24849, 743, 99, 1, 56, "Section"],
Cell[24951, 746, 268, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[25244, 754, 941, 28, 88, "Input"],
Cell[26188, 784, 1004, 29, 54, "Output"],
Cell[27195, 815, 227, 6, 34, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27483, 828, 95, 1, 72, "Chapter"],
Cell[27581, 831, 118, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[27724, 837, 93, 1, 70, "Section"],
Cell[27820, 840, 299, 5, 30, "Text"],
Cell[28122, 847, 1359, 42, 34, "Input"],
Cell[CellGroupData[{
Cell[29506, 893, 730, 21, 73, "Input"],
Cell[30239, 916, 911, 25, 34, "Output"],
Cell[31153, 943, 459, 11, 30, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[31661, 960, 147, 2, 56, "Section"],
Cell[31811, 964, 486, 7, 49, "Text"],
Cell[32300, 973, 3289, 90, 170, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[35626, 1068, 148, 2, 56, "Section"],
Cell[35777, 1072, 167, 2, 30, "Text"],
Cell[35947, 1076, 3638, 97, 170, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[39622, 1178, 125, 2, 56, "Section"],
Cell[39750, 1182, 371, 5, 49, "Text"],
Cell[40124, 1189, 162, 4, 30, "Input"],
Cell[40289, 1195, 353, 8, 30, "Input"],
Cell[40645, 1205, 226, 5, 30, "Input"],
Cell[40874, 1212, 1789, 43, 30, "Input"],
Cell[42666, 1257, 2024, 49, 50, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[44727, 1311, 155, 2, 56, "Section"],
Cell[44885, 1315, 194, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[45104, 1322, 3934, 111, 202, "Input"],
Cell[49041, 1435, 5349, 118, 257, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[54439, 1559, 251, 3, 56, "Section"],
Cell[54693, 1564, 323, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[55041, 1573, 3590, 98, 126, "Input"],
Cell[58634, 1673, 638, 12, 30, "Output"],
Cell[59275, 1687, 739, 16, 34, "Output"]
}, Open  ]],
Cell[60029, 1706, 200, 3, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[60266, 1714, 239, 3, 56, "Section"],
Cell[60508, 1719, 256, 4, 30, "Text"],
Cell[60767, 1725, 1111, 28, 50, "Input"],
Cell[61881, 1755, 431, 12, 30, "Input"],
Cell[62315, 1769, 235, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[62575, 1777, 1068, 28, 74, "Input"],
Cell[63646, 1807, 6182, 114, 254, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[69877, 1927, 195, 3, 56, "Section"],
Cell[70075, 1932, 139, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[70239, 1938, 3248, 94, 126, "Input"],
Cell[73490, 2034, 363, 8, 30, "Output"],
Cell[73856, 2044, 462, 12, 34, "Output"]
}, Open  ]],
Cell[74333, 2059, 1467, 35, 69, "Input"],
Cell[75803, 2096, 233, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[76061, 2104, 1145, 30, 89, "Input"],
Cell[77209, 2136, 6391, 117, 254, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[83649, 2259, 211, 3, 56, "Section"],
Cell[83863, 2264, 158, 2, 30, "Text"],
Cell[84024, 2268, 1972, 57, 175, "Input"],
Cell[85999, 2327, 735, 18, 30, "Input"],
Cell[86737, 2347, 10753, 203, 255, "Input"],
Cell[97493, 2552, 159, 2, 30, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

