(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    209072,       4612]
NotebookOptionsPosition[    205966,       4506]
NotebookOutlinePosition[    206313,       4521]
CellTagsIndexPosition[    206270,       4518]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Section 5.3 : numerical RG flows", "Title",
 CellChangeTimes->{{3.6327401341379185`*^9, 3.632740141118559*^9}, {
  3.777808164268839*^9, 3.7778081653222346`*^9}, {3.7778765592858543`*^9, 
  3.7778765648948913`*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.6327401540721664`*^9, 3.632740155131873*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FS", "=", "FullSimplify"}], ";"}]], "Input",
 CellChangeTimes->{{3.6327401568770313`*^9, 3.632740162527787*^9}}],

Cell["\<\
In this notebook we construct numerically holographic flows between AdS and \
Lifshitz geometries discussed in section 5.3
The original work can be found in https://arxiv.org/abs/1108.3067\
\>", "Text",
 CellChangeTimes->{{3.777876571145134*^9, 3.7778766204781857`*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["Theory", "Chapter",
 CellChangeTimes->{{3.632740149932416*^9, 3.6327401521148653`*^9}, {
  3.777876637177518*^9, 3.777876639744656*^9}}],

Cell[CellGroupData[{

Cell["Equations", "Section",
 CellChangeTimes->{{3.613892245567933*^9, 3.6138922504511642`*^9}, {
  3.6327402249572897`*^9, 3.632740227000641*^9}, {3.7778082693073444`*^9, 
  3.7778082694757056`*^9}}],

Cell["\<\
We consider the theory in 5 dimensions, which corresponds in the notations of \
the nb. to n=3
We also consider a simple potential with only a mass term for the vector.
In the notations of the notes the relevant equations of motion are:\
\>", "Text",
 CellChangeTimes->{{3.7778766471468544`*^9, 3.777876674147644*^9}, {
  3.7778767196510253`*^9, 3.7778767342908773`*^9}},
 FontWeight->"Bold"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "z_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "n"}], 
     RowBox[{"(", 
      RowBox[{"n", "+", "1"}], ")"}]}], "+", 
    RowBox[{"2", "M2", " ", "z"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.777808197352126*^9, 3.777808204796604*^9}, {
  3.7778085904225655`*^9, 3.777808590570135*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"GenEQ", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"NN", "[", "u", "]"}], "\[Equal]", 
       FractionBox[
        SqrtBox[
         RowBox[{
          RowBox[{"n", " ", 
           RowBox[{"ww", "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"ww", "[", "u", "]"}], "-", 
             RowBox[{"n", " ", 
              RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
              RowBox[{
               SuperscriptBox["\[Beta]t", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], ")"}], "2"]}]}]], 
        SqrtBox[
         RowBox[{"V", "[", 
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}]]]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["NN", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "\[Equal]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"n", " ", 
          SuperscriptBox[
           RowBox[{"V", "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], 
           RowBox[{"3", "/", "2"}]]}]], 
        SqrtBox[
         RowBox[{
          RowBox[{"n", " ", 
           RowBox[{"ww", "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"ww", "[", "u", "]"}], "-", 
             RowBox[{"n", " ", 
              RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
              RowBox[{
               SuperscriptBox["\[Beta]t", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], ")"}], "2"]}]}]],
         " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"n", " ", 
           RowBox[{"V", "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"ww", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "n", "+", 
                RowBox[{"ww", "[", "u", "]"}], "-", 
                RowBox[{"n", " ", 
                 RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["\[Beta]t", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}]}], ")"}], 
               "2"]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Beta]t", "[", "u", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["V", "\[Prime]",
             MultilineFunction->None], "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"n", " ", 
              RowBox[{"ww", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
                 RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["\[Beta]t", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}]}], ")"}], 
               "2"]}]}], ")"}]}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Beta]t", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "\[Equal]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", "n", " ", 
          RowBox[{"V", "[", 
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["V", "\[Prime]",
             MultilineFunction->None], "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "n"}], "+", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
              RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                RowBox[{
                 SuperscriptBox["\[Beta]t", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
            ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"n", " ", 
              RowBox[{"ww", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
                 RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["\[Beta]t", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}]}], ")"}], 
               "2"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "n", " ", 
           RowBox[{"V", "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"\[Beta]t", "[", "u", "]"}], "3"]}], "+", 
             RowBox[{
              RowBox[{"ww", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
                 RowBox[{"ww", "[", "u", "]"}]}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["\[Beta]t", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               RowBox[{"\[Beta]t", "[", "u", "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox["\[Beta]t", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Beta]t", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}], "3"]}], "+", 
             RowBox[{
              RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 RowBox[{"ww", "[", "u", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"2", "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
                    RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Beta]t", "\[Prime]",
                    MultilineFunction->None], "[", "u", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["ww", "\[Prime]",
         MultilineFunction->None], "[", "u", "]"}], "\[Equal]", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"n", " ", 
          RowBox[{"V", "[", 
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}]}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
              RowBox[{"ww", "[", "u", "]"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Beta]t", "[", "u", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["V", "\[Prime]",
             MultilineFunction->None], "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "n", " ", 
              RowBox[{"ww", "[", "u", "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", "n", " ", 
              SuperscriptBox[
               RowBox[{"ww", "[", "u", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["\[Beta]t", "\[Prime]",
                   MultilineFunction->None], "[", "u", "]"}]}], ")"}], 
               "2"]}]}], ")"}]}], "+", 
          RowBox[{"n", " ", 
           RowBox[{"V", "[", 
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}], "]"}], " ", 
           RowBox[{"ww", "[", "u", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"ww", "[", "u", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "n", "+", 
                RowBox[{"ww", "[", "u", "]"}], "-", 
                RowBox[{"n", " ", 
                 RowBox[{"ww", "[", "u", "]"}]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                RowBox[{
                 SuperscriptBox["\[Beta]t", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
                RowBox[{
                 SuperscriptBox["\[Beta]t", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}]}], "}"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.633432475610566*^9, 3.633432503885337*^9}, {
  3.6334325518171635`*^9, 3.6334325545049467`*^9}, {3.6334326722481184`*^9, 
  3.633432681956564*^9}, {3.7778082096417203`*^9, 3.7778082098691072`*^9}, {
  3.7778082436781235`*^9, 3.777808263073081*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}],

Cell["\<\
You can verify them as an exercise using the action and the ansatz defined in \
section 5.3\
\>", "Text",
 CellChangeTimes->{{3.777876741031802*^9, 3.777876747522442*^9}, {
  3.778028735346204*^9, 3.778028744320425*^9}},
 FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lifshitz fixed points", "Section",
 CellChangeTimes->{{3.6327402681369853`*^9, 3.6327402790702515`*^9}, {
  3.777876772258323*^9, 3.7778767729724283`*^9}}],

Cell["\<\
Fixed points are characterized by the functions of the ansatz being \
constant(see lectures). We define by z the lifshitz scaling exponent and we \
find the Lifshitz fixed points of the system.\
\>", "Text",
 CellChangeTimes->{{3.777876857881273*^9, 3.777876890443178*^9}, {
  3.7780287816000004`*^9, 3.7780287886537294`*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]t", "[", "u_", "]"}], "=", "\[Beta]0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ww", "[", "u_", "]"}], "=", 
   FractionBox["1", "z"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NN", "[", "u_", "]"}], "=", "N0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GenEQ", "//", "FS"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Lif", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"\[Beta]0", ",", "N0", ",", "M2"}], "}"}]}], "]"}], "//", 
    "FunctionExpand"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[Alpha]", ",", "\[Beta]", ",", "ww", ",", "NN", ",", "\[Beta]t"}], "]"}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.632740284246694*^9, 3.63274030745512*^9}, {
   3.632740369402523*^9, 3.632740411971821*^9}, {3.63274044625661*^9, 
   3.632740492968663*^9}, {3.632740734132262*^9, 3.63274073428036*^9}, {
   3.6327409676484795`*^9, 3.6327409682618866`*^9}, {3.6334327121646194`*^9, 
   3.633432989933028*^9}, {3.7778082804219685`*^9, 3.7778082868522983`*^9}, {
   3.777808331217667*^9, 3.7778083771075153`*^9}, 3.777876779070073*^9, {
   3.7778867683679037`*^9, 3.7778867690647416`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Beta]0", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", "z"}], "z"]], 
        SqrtBox["2"]]}]}], ",", 
     RowBox[{"N0", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", "+", 
           RowBox[{"5", " ", "z"}], "+", 
           SuperscriptBox["z", "2"]}], 
          SuperscriptBox["z", "2"]]}]], 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", "+", 
            RowBox[{"5", " ", "z"}], "+", 
            SuperscriptBox["z", "2"]}], 
           RowBox[{"9", "+", 
            RowBox[{"2", " ", "z"}], "+", 
            SuperscriptBox["z", "2"]}]]}]]}]]}], ",", 
     RowBox[{"M2", "\[Rule]", 
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Beta]0", "\[Rule]", 
      FractionBox[
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], "z"]], 
       SqrtBox["2"]]}], ",", 
     RowBox[{"N0", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{"-", 
         FractionBox[
          RowBox[{"6", "+", 
           RowBox[{"5", " ", "z"}], "+", 
           SuperscriptBox["z", "2"]}], 
          SuperscriptBox["z", "2"]]}]], 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", 
        SqrtBox[
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", "+", 
            RowBox[{"5", " ", "z"}], "+", 
            SuperscriptBox["z", "2"]}], 
           RowBox[{"9", "+", 
            RowBox[{"2", " ", "z"}], "+", 
            SuperscriptBox["z", "2"]}]]}]]}]]}], ",", 
     RowBox[{"M2", "\[Rule]", 
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6327403447489114`*^9, 3.6327403781033087`*^9}, {
   3.632740443937067*^9, 3.632740493347909*^9}, 3.632740739205634*^9, 
   3.6327409721734858`*^9, 3.632765908572359*^9, 3.6334316160689096`*^9, {
   3.633432725814683*^9, 3.633432777744152*^9}, {3.6334328116566687`*^9, 
   3.633432990792596*^9}, 3.633434707309306*^9, 3.633434780202591*^9, 
   3.6335480369659166`*^9, 3.633603791951027*^9, 3.641776695400893*^9, 
   3.641777338262594*^9, 3.641809838377158*^9, 3.6418136634057517`*^9, 
   3.6419000556505547`*^9, 3.6419753698301525`*^9, 3.6420266936936026`*^9, 
   3.6423134244333076`*^9, 3.6951419048505783`*^9, 3.7778082917338867`*^9, {
   3.777808342624008*^9, 3.777808377617152*^9}, 3.7778084405478687`*^9, 
   3.7778085969920874`*^9, 3.7778867710284967`*^9, 3.777887516274542*^9, 
   3.7780297998317766`*^9}]
}, Open  ]],

Cell["\<\
We can plot the phase space of the solutions in function of the vector mass \
(blue are the lifshitz ones and red the ads one)\
\>", "Text",
 CellChangeTimes->{{3.777876897063507*^9, 3.777876900864311*^9}, {
  3.777877268744452*^9, 3.777877294232646*^9}, {3.7780287996912346`*^9, 
  3.7780288126336374`*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]], ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "1", ",", "20"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\!\(\*SuperscriptBox[\(m\), \(2\)]\)\>\"", ",", "\"\<z\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}], ",", 
    RowBox[{"GridLinesStyle", "->", 
     RowBox[{"Directive", "[", 
      RowBox[{"Red", ",", "Thick"}], "]"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Blue", ",", "Thick"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.632733561560153*^9, 3.6327336235208006`*^9}, {
  3.632733875489129*^9, 3.6327338949574847`*^9}, {3.632740697069631*^9, 
  3.632740716575595*^9}, {3.777808450550211*^9, 3.7778084546931777`*^9}, {
  3.7778086077060337`*^9, 3.777808608064064*^9}, {3.777876799407671*^9, 
  3.7778768411260824`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   TagBox[
    {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], FaceForm[Opacity[0.3]],
      LineBox[CompressedData["
1:eJwl1wk0VVsfAHAudzJcd6cMUclMPMNtRJ1/SiGRMYSGZ4yS8SEJcaNoJlMl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      "]]},
    Annotation[#, "Charting`Private`Tag$3213#1"]& ]},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*SuperscriptBox[\\(m\\), \\(2\\)]\\)\"", TraditionalForm], 
    FormBox["\"z\"", TraditionalForm]},
  AxesOrigin->{1.6035634743875278`, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{}, {1}},
  GridLinesStyle->Directive[
    RGBColor[1, 0, 0], 
    Thickness[Large]],
  ImageSize->{305., Automatic},
  LabelStyle->Directive[
    GrayLevel[0], Bold, Medium],
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{1.6035634743875278`, 4.499998838526334}, {0., 20.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7778768003431635`*^9, 3.7778768414143157`*^9}, 
   3.7780297999255123`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations", "Section",
 CellChangeTimes->{{3.6334330335930185`*^9, 3.6334330351530523`*^9}}],

Cell[TextData[StyleBox["Lets check the linear perturbations around ads to see \
the relevant/irrelevant deformations.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.7778864234548783`*^9, 3.7778864319014187`*^9}, {
  3.778028830334116*^9, 3.7780288724235244`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]t", "[", "u_", "]"}], "=", 
   RowBox[{"0", "+", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{"\[Delta]\[Beta]", "[", "u", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ww", "[", "u_", "]"}], "=", 
   RowBox[{"1", "+", 
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], 
     RowBox[{"\[Delta]w", "[", "u", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Drop", "[", 
    RowBox[{"GenEQ", ",", "2"}], "]"}], "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"GenEQ", ",", "2"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "Normal"}], "\[IndentingNewLine]", 
 RowBox[{"DSolve", "[", 
  RowBox[{"%", ",", "\[Delta]\[Beta]", ",", "u"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Beta]t", ",", "ww", ",", "\[Alpha]"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6334330444952555`*^9, 3.6334331951592813`*^9}, {
  3.7778086249842653`*^9, 3.7778086754224586`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Beta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "u", "]"}]}], "\[Equal]", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{"\[Delta]\[Beta]", "[", "u", "]"}]}], "+", 
     RowBox[{"M2", " ", 
      RowBox[{"\[Delta]\[Beta]", "[", "u", "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Beta]", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.63343313484023*^9, 3.6334331506036973`*^9}, {
   3.63343318172836*^9, 3.6334331955005035`*^9}, 3.6334347093663673`*^9, 
   3.6334347823636265`*^9, 3.6335480434740715`*^9, 3.6336037971387844`*^9, 
   3.6417773407627125`*^9, 3.6418098431673403`*^9, 3.641813666220624*^9, 
   3.6419000636278505`*^9, 3.641975375267918*^9, 3.64202670240139*^9, 
   3.642313433660434*^9, 3.695141915741796*^9, {3.7778086278047543`*^9, 
   3.777808639527669*^9}, {3.777808670246931*^9, 3.7778086759973445`*^9}, 
   3.778029799963271*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Delta]\[Beta]", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "u", "}"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "-", 
            SqrtBox[
             RowBox[{"1", "+", "M2"}]]}], ")"}], " ", "u"}]], " ", 
        RowBox[{"C", "[", "1", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            SqrtBox[
             RowBox[{"1", "+", "M2"}]]}], ")"}], " ", "u"}]], " ", 
        RowBox[{"C", "[", "2", "]"}]}]}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.63343313484023*^9, 3.6334331506036973`*^9}, {
   3.63343318172836*^9, 3.6334331955005035`*^9}, 3.6334347093663673`*^9, 
   3.6334347823636265`*^9, 3.6335480434740715`*^9, 3.6336037971387844`*^9, 
   3.6417773407627125`*^9, 3.6418098431673403`*^9, 3.641813666220624*^9, 
   3.6419000636278505`*^9, 3.641975375267918*^9, 3.64202670240139*^9, 
   3.642313433660434*^9, 3.695141915741796*^9, {3.7778086278047543`*^9, 
   3.777808639527669*^9}, {3.777808670246931*^9, 3.7778086759973445`*^9}, 
   3.7780298000322685`*^9}]
}, Open  ]],

Cell["\<\
Here we plot the dimension of the vector deformation (which breaks lorentz \
invariance) around the AdS fixed point.\
\>", "Text",
 CellChangeTimes->{{3.7780288801011286`*^9, 3.778028901510296*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"1", "+", "M2"}]]}], ",", 
     RowBox[{"2", "-", 
      SqrtBox[
       RowBox[{"1", "+", "M2"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"M2", ",", 
     RowBox[{"-", "2"}], ",", "5"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<\!\(\*
StyleBox[SuperscriptBox[\"m\", \"2\"],
FontSize->16]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[CapitalDelta]\",
FontSize->16]\)\>\""}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
   RowBox[{"AxesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"-", "1"}], "}"}], ",", 
      RowBox[{"{", "3", "}"}]}], "}"}]}], ",", 
   RowBox[{"GridLinesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Gray", ",", " ", "Dashed"}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7778864397306585`*^9, 3.777886513908633*^9}, {
  3.777886583840118*^9, 3.7778866041600733`*^9}, {3.777886638551868*^9, 
  3.7778866387224846`*^9}, {3.778028916038067*^9, 3.7780289370859227`*^9}, {
  3.778028974610723*^9, 3.7780289771005898`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVzHs01HkfB/C5uYaZn5/7436podzpxDK/T1jstmuRlFZrjWy0qTkRHvTo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       "]]},
     Annotation[#, "Charting`Private`Tag$3261#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], Thickness[Large], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVkHs8FPgaxifUUBKG0lVEiwol+0ku788lqXZtlN1snBq6WXU4pZIKq2hb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       "]]},
     Annotation[#, "Charting`Private`Tag$3261#2"]& ]}, {}, {}},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"m\\\", \
\\\"2\\\"],\\nFontSize->16]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"\[CapitalDelta]\\\",\\nFontSize->16]\\)\"", 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  AxesStyle->Directive[
    GrayLevel[0], 12],
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{-1}, {3}},
  GridLinesStyle->Directive[
    GrayLevel[0.5], 
    Dashing[{Small, Small}]],
  ImagePadding->All,
  LabelStyle->Directive[
    GrayLevel[0], Bold, Medium],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-2, 5}, {-0.4494897136225857, 4.449489713622586}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7778864529605336`*^9, 3.777886514215582*^9}, {
   3.777886592163349*^9, 3.7778866046377172`*^9}, 3.777886639139681*^9, {
   3.7780289274860487`*^9, 3.778028937518696*^9}, {3.778028977401148*^9, 
   3.778028996278093*^9}, 3.7780298000791407`*^9}]
}, Open  ]],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 0.5}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 3}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations for the numerics", "Section",
 CellChangeTimes->{{3.7778091059230604`*^9, 3.777809109061142*^9}}],

Cell["\<\
Setting the numerical equations for the integration.
We ignore those for NN(u) since NN(u) is determined completely by \[Beta]t \
and ww\
\>", "Text",
 CellChangeTimes->{{3.7780290108558855`*^9, 3.778029037971176*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eqnum", "=", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{"GenEQ", ",", "2"}], "]"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7778091326931367`*^9, 3.7778091559352202`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Beta]t", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "\[Equal]", 
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{"6", "+", 
          RowBox[{"M2", " ", 
           SuperscriptBox[
            RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M2", " ", 
         RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
              RowBox[{
               SuperscriptBox["\[Beta]t", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], ")"}]}]}], ")"}],
          " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"ww", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"ww", "[", "u", "]"}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
               RowBox[{
                SuperscriptBox["\[Beta]t", "\[Prime]",
                 MultilineFunction->None], "[", "u", "]"}]}], ")"}], "2"]}]}],
           ")"}]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"M2", " ", 
            SuperscriptBox[
             RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"\[Beta]t", "[", "u", "]"}], "3"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"ww", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"ww", "[", "u", "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Beta]t", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             RowBox[{"\[Beta]t", "[", "u", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["\[Beta]t", "\[Prime]",
              MultilineFunction->None], "[", "u", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Beta]t", "\[Prime]",
               MultilineFunction->None], "[", "u", "]"}], "3"]}], "+", 
           RowBox[{
            RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"ww", "[", "u", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"ww", "[", "u", "]"}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Beta]t", "\[Prime]",
                  MultilineFunction->None], "[", "u", "]"}], "2"]}]}], 
             ")"}]}]}], ")"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["ww", "\[Prime]",
      MultilineFunction->None], "[", "u", "]"}], "\[Equal]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"12", " ", 
        RowBox[{"ww", "[", "u", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"6", "+", 
          RowBox[{"M2", " ", 
           SuperscriptBox[
            RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox[
           RowBox[{"ww", "[", "u", "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[Beta]t", "[", "u", "]"}], "2"], "+", 
          RowBox[{"2", " ", 
           RowBox[{"\[Beta]t", "[", "u", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Beta]t", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Beta]t", "\[Prime]",
             MultilineFunction->None], "[", "u", "]"}], "2"]}], ")"}]}], "+", 
       RowBox[{"2", " ", "M2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           RowBox[{"ww", "[", "u", "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"\[Beta]t", "[", "u", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"ww", "[", "u", "]"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{"ww", "[", "u", "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Beta]t", "[", "u", "]"}], "+", 
              RowBox[{
               SuperscriptBox["\[Beta]t", "\[Prime]",
                MultilineFunction->None], "[", "u", "]"}]}], ")"}], "2"]}]}], 
         ")"}]}]}], 
      RowBox[{"6", " ", 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         RowBox[{"M2", " ", 
          SuperscriptBox[
           RowBox[{"\[Beta]t", "[", "u", "]"}], "2"]}]}], ")"}]}]]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.777809133793621*^9, 3.777809156415271*^9}, 
   3.7778091957436085`*^9, 3.7778875291954575`*^9, 3.778029800094761*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerics", "Chapter",
 CellChangeTimes->{{3.632740830895581*^9, 3.632740832604718*^9}, {
   3.6334343475523634`*^9, 3.633434348658098*^9}, 3.777808689788455*^9}],

Cell[CellGroupData[{

Cell["Numerical flows", "Section",
 CellChangeTimes->{{3.6334333655764227`*^9, 3.6334333683812866`*^9}, {
  3.633434064305315*^9, 3.633434070411363*^9}, {3.633434334354603*^9, 
  3.6334343455380216`*^9}, {3.7780290582706084`*^9, 3.7780290584557014`*^9}}],

Cell[CellGroupData[{

Cell["Example with zUV=2 to zIR=1: Lifshitz ----> AdS", "Subsection",
 CellChangeTimes->{{3.6334350533225203`*^9, 3.6334350582868214`*^9}, {
  3.633548807292162*^9, 3.633548811304269*^9}, {3.7780297312517977`*^9, 
  3.7780297313676567`*^9}, {3.7780299658150296`*^9, 3.7780299715603485`*^9}}],

Cell[TextData[{
 "Let us first visualize the flow. We will choose ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["m", "2"], "=", 
    RowBox[{"72", "/", "17.", " "}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "From the previous analysis we can see that the vector deformation is \
irrelevant around \nthe AdS fixed point. Therefore in this case the ads fixed \
point is the IR attractive one. We can check from the results in the notes \
that for this value of the mass the deformation is relevant in the lifshitz \
fixed point on the lower branch (z=2). Therefore we will have a flow from \
zUV=2 to zIR=1."
}], "Text",
 CellChangeTimes->{{3.7780295551980567`*^9, 3.778029729377617*^9}},
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"36", " ", "z"}], 
    RowBox[{"9", "+", 
     RowBox[{"2", " ", "z"}], "+", 
     SuperscriptBox["z", "2"]}]], "\[Equal]", 
   RowBox[{"72", "/", "17"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.778029488687745*^9, 3.77802950809962*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", 
     FractionBox["9", "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7780295085696535`*^9, 3.7780298001325407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]], ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "8"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[SuperscriptBox[\"m\", \"2\"],
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Blue"}], "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox["72", "17"], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["72", "17"], ",", "1"}], "}"}]}], "}"}], ",", 
    RowBox[{"PlotMarkers", "->", 
     RowBox[{"Style", "[", 
      RowBox[{"Red", ",", "Thick", ",", "Small"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLinePlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox["72", "17"], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["72", "17"], ",", "1"}], "}"}]}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Dashed", ",", "Purple", ",", 
       RowBox[{"Thickness", "[", "0.006", "]"}]}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%%", ",", "%%", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.633435937751695*^9, 3.6334361475187674`*^9}, {
  3.641776736465396*^9, 3.6417768408610787`*^9}, {3.7778087714677935`*^9, 
  3.777808774987445*^9}, {3.777808844522649*^9, 3.777808941151536*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[0.01], Opacity[1.], FaceForm[Opacity[0.3]],
       LineBox[CompressedData["
1:eJxd2Hk8VN/7AHCGWQ3mkr1MVEKFKELcJy2WqEQ7skdlyV5RkiTJ7pOEyq4s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       "]]},
     Annotation[#, "Charting`Private`Tag$4611#1"]& ]}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[6], 
      AbsoluteThickness[1.6], GeometricTransformationBox[InsetBox[
        StyleBox[
         InterpretationBox[
          ButtonBox[
           TooltipBox[
            GraphicsBox[{
              {GrayLevel[0], RectangleBox[{0, 0}]}, 
              {GrayLevel[0], RectangleBox[{1, -1}]}, 
              {RGBColor[1, 0, 0], RectangleBox[{0, -1}, {2, 1}]}},
             AspectRatio->1,
             Frame->True,
             FrameStyle->RGBColor[0.6666666666666666, 0., 0.],
             FrameTicks->None,
             
             ImageSize->
              Dynamic[{
               Automatic, 
                1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}],
             PlotRangePadding->None],
            "RGBColor[1, 0, 0]"],
           Appearance->None,
           BaseStyle->{},
           BaselinePosition->Baseline,
           ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
             If[
              Not[
               AbsoluteCurrentValue["Deployed"]], 
              SelectionMove[Typeset`box$, All, Expression]; 
              FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
              FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[1, 0, 0]; 
              FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
              MathLink`CallFrontEnd[
                FrontEnd`AttachCell[Typeset`box$, 
                 FrontEndResource["RGBColorValueSelector"], {
                 0, {Left, Bottom}}, {Left, Top}, 
                 "ClosingActions" -> {
                  "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
           DefaultBaseStyle->{},
           Evaluator->Automatic,
           Method->"Preemptive"],
          RGBColor[1, 0, 0],
          Editable->False,
          Selectable->False],
         StripOnInput->False,
         Thickness->Large,
         FontSize->Small], {0., 0.}], {{{4.235294117647059, 2.}}, {{
       4.235294117647059, 1.}}}]}, {}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.5, 0, 0.5], PointSize[0.019444444444444445`], Thickness[
      0.006], Dashing[{Small, Small}], 
      LineBox[{{4.235294117647059, 2.}, {4.235294117647059, 
       1.}}]}}, {}, {}, {{}, {}}}, 
   StyleBox[InsetBox[Cell[TextData[Cell[BoxData[
      FormBox[
       StyleBox[
        SubscriptBox["z", "UV"],
        FontWeight->"Bold"], TraditionalForm]],
      FontSize->18]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left], {3.861434929423685, 2.364465890465393}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    StripOnInput->False,
    FontSize->18], 
   StyleBox[InsetBox[Cell[TextData[Cell[BoxData[
      FormBox[
       StyleBox[
        SubscriptBox["z", "IR"],
        FontWeight->"Bold"], TraditionalForm]],
      FontSize->18]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left], {3.8869363881408208, 0.4076911893579327}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    StripOnInput->False,
    FontSize->18]},
  AspectRatio->1,
  Axes->{True, True},
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"m\\\", \
\\\"2\\\"],\\nFontSize->24]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"z\\\",\\nFontSize->24]\\)\"", 
     TraditionalForm]},
  AxesOrigin->{1.5807437459578235`, 0},
  AxesStyle->Directive[
    GrayLevel[0], 15],
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{}, {1}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{2.016422, 40.}, {6.100821, 24.}},
  LabelStyle->Directive[
    GrayLevel[0], Bold, Medium],
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{1.418562854477058, 4.662180684092368}, {-0.4444444444444445, 
   8.444444444444445}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.778029800426831*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uIR", "=", 
   RowBox[{"-", "10"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uUV", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M2", "=", 
   FractionBox["72", "17"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zsol", "=", 
   RowBox[{"z", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"36", " ", "z"}], 
        RowBox[{"9", "+", 
         RowBox[{"2", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}]], "\[Equal]", "M2"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "1"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Eqnum", ",", 
       RowBox[{
        RowBox[{"\[Beta]t", "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{"0", "+", 
         SuperscriptBox["10", 
          RowBox[{"-", "4"}]]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Beta]t", "'"}], "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{"0", "+", 
         RowBox[{"0.4", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "4"}]]}]}]}], ",", 
       RowBox[{
        RowBox[{"ww", "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{"1", "-", 
         SuperscriptBox["10", 
          RowBox[{"-", "5"}]]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ww", ",", "\[Beta]t"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "uIR", ",", "uUV"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]t", "[", "x", "]"}], "/.", "sol"}], ",", 
      FractionBox[
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "zsol"}], "zsol"]], 
       SqrtBox["2"]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "uIR", ",", "uUV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.012", "]"}], ",", "Orange"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Beta]\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"u\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.6"}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"ww", "[", "x", "]"}]}], "/.", "sol"}], ",", "zsol", ",", 
      "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "uIR", ",", "uUV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.012", "]"}], ",", "Green"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"u\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0.7", ",", "2.2"}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "12"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"%%", ",", "%"}], "}"}], "}"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "uIR", ",", "uUV", ",", "M2", ",", "\[Gamma]", ",", "n", ",", "zsol"}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.63343384395302*^9, 3.6334343066011696`*^9}, {
  3.6334343654492435`*^9, 3.633434547626192*^9}, {3.6334346167791033`*^9, 
  3.6334346175986443`*^9}, {3.633434881048145*^9, 3.6334349026364784`*^9}, {
  3.6334358287243123`*^9, 3.6334358353427057`*^9}, {3.6417773601386557`*^9, 
  3.641777517090923*^9}, {3.6417775698747396`*^9, 3.6417776082974567`*^9}, {
  3.69514202809621*^9, 3.6951420297843246`*^9}, {3.777808981742732*^9, 
  3.7778090075307407`*^9}, {3.7778091722130055`*^9, 3.777809313740203*^9}, {
  3.778029764212345*^9, 3.7780297836472096`*^9}, {3.7780298223979597`*^9, 
  3.778029847254302*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[1, 0.5, 0], Thickness[0.012], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV1nc8V98fB3CUygjZK5vs+bHH+23LKGWXSkJChKKMSiEKIYlUFPkaJWRE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           "]]},
         Annotation[#, "Charting`Private`Tag$3874#1"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXbbt5bX//5UPXPgPAvftd8cqPmq4pATnM7BGvmVc
qgjny8St0Z2uJwfn5wss7jmXKQnnv5q8IPTHHhE4/9ac4s6kUH443/fcvHqZ
e6xw/oLbTC0vzb/vh/Glfkm1y84+AefXeEx9opz73h7Gv/C0pU6Vm8kBxhfe
+/r1zl5uOJ+lctEhkwIhOL88xjjzb504nL/p4XFmJXMZOP9zuMKe6FUKcH5l
WKSjrq4ynP9EdcqBNS2qcP5pyYNrnvBpwPnT772fdCpXC86/f1zgWcZ/HTh/
soceC1+rPpwvdlatb8N7AzhfoWN9gJmZEZw/R9tSQDjdGM4/J+Vo+nmiCZxv
J3Nogv41Uzhfkc3l5SEWczjficm+YpOPBZwv6bUjZ2mfJZyfVGUU936XFZz/
co9q21QGGzj/0XPJ1ZMMbOH8SXE9ppOj7OD8hufl397PtYfzC3SMbl1MdYDz
7d+lXInkdITz3VUkfHkXIfhaDV0Vh8yd4HydVMv9qrcQ/PR9GS1bCp3h/IML
rqR8FHWB87+t+P9dfzuCn6q6mnOWrysiPrUmm236gODvWvL74dcONzg/xkXZ
wVrOHc6XzW3fqXcAwRfnytnoG+4B59+ynnx52WoEf17urq///yP4AMl/IeY=

           "]]},
         Annotation[#, "Charting`Private`Tag$3874#2"]& ]}, {}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"\[Beta]\\\",\\nFontSize->24]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm]},
      AxesOrigin->{0, 0},
      AxesStyle->Directive[
        GrayLevel[0], 15],
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      LabelStyle->Directive[
        GrayLevel[0], Bold, Medium],
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-9.999998775510203, 49.99999877551021}, {0, 0.6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {192., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], Thickness[0.012], Opacity[1.], 
          LineBox[CompressedData["
1:eJwl13k8lF8XAHD7voXs28zYshPZ3WMflIpIRYuQqPwUaU8lUVREkYoKCWVN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           "]]},
         Annotation[#, "Charting`Private`Tag$3916#1"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXbbt5bX//5UPzP8PBva7YxUfNVxSgvMZWCPfMi5V
hPNl4tboTteTg/PzBRb3nMuUhPNfTV4Q+mOPCJx/a05xZ1IoP5zve25evcw9
Vjh/wW2mlpfm3/fD+FK/pNplZ5+A82s8pj5Rzn1vD+NfeNpSp8rN5ADjC+99
/XpnLzecz1K56JBJgRCcXx5jnPm3ThzO3/TwOLOSuQyc/zlcYU/0KgU4vzIs
0lFXVxnOf6I65cCaFlU4/7TkwTVP+DTg/On33k86lasF598/LvAs478OnD/Z
Q4+Fr1Ufzhc7q9a34b0BnK/QsT7AzMwIzp+jbSkgnG4M55+TcjT9PNEEzreT
OTRB/5opnK/I5vLyEIs5nO/EZF+xyccCzpf02pGztM8Szk+qMop7v8sKzn+5
R7VtKoMNnP/oueTqSQa2cP6kuB7TyVF2cH7D8/Jv7+faw/kFOka3LqY6wPn2
71KuRHI6wvnuKhK+vIsQfK2GropD5k5wvk6q5X7VWwh++r6Mli2FznD+wQVX
Uj6KusD531b8/66/HcFPVV3NOcvXFRGfWpPNNn1A8Hct+f3wa4cbnB/jouxg
LecO58vmtu/UO4Dgi3PlbPQN94Dzb1lPvrxsNYI/L3fX1///EXwABbQecg==

           "]]},
         Annotation[#, "Charting`Private`Tag$3916#2"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQXbbt5bX//5UPMIDBB/vdsYqPGi4pwfkMrJFvGZcq
wvkycWt0p+vJwfn5Aot7zmVKwvmvJi8I/bFHBM6/Nae4MymUH873PTevXuYe
K5y/4DZTy0vz7/thfKlfUu2ys0/A+TUeU58o5763h/EvPG2pU+VmcoDxhfe+
fr2zlxvOZ6lcdMikQAjOL48xzvxbJw7nb3p4nFnJXAbO/xyusCd6lQKcXxkW
6airqwznP1GdcmBNiyqcf1ry4JonfBpw/vR77yedytWC8+8fF3iW8V8Hzp/s
ocfC16oP54udVevb8N4AzlfoWB9gZmYE58/RthQQTjeG889JOZp+nmgC59vJ
HJqgf80Uzldkc3l5iMUczndisq/Y5GMB50t67chZ2mcJ5ydVGcW932UF57/c
o9o2lcEGzn/0XHL1JANbOH9SXI/p5Cg7OL/hefm393Pt4fwCHaNbF1Md4Hz7
dylXIjkd4Xx3FQlf3kUIvlZDV8Uhcyc4XyfVcr/qLQQ/fV9Gy5ZCZzj/4IIr
KR9FXeD8byv+f9ffjuCnqq7mnOXrCud/1ppstukDgr9rye+HXzvc4PwYF2UH
azl3OF82t32n3gEEX5wrZ6NvuAecf8t68uVlqxH8ebm7vv7/j+ADALyM+AA=

           "]]},
         Annotation[#, "Charting`Private`Tag$3916#3"]& ]}, {}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"z\\\",\\nFontSize->24]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm]},
      AxesOrigin->{0, 0.7},
      AxesStyle->Directive[
        GrayLevel[0], 12],
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      LabelStyle->Directive[
        GrayLevel[0], Bold, Medium],
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-9.999998775510203, 49.99999877551021}, {0.7, 2.2}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {576., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}]}, 
   {Arrowheads[0.023442288153199226`], EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{681.4495637458961, -191.54523522316032`}, {
     485.98565699352775`, -191.5452352231602}}]}, InsetBox[
    StyleBox[Cell[TextData[StyleBox["UV",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {670.7406510518069, -182.57056672872503}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["IR",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {485.86248480244114, -180.77563307581863}, {
    Left, Baseline},
    Alignment->{Left, Top}], 
   {Arrowheads[0.023442288153199226`], EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{294.5930305106906, -197.68274187538123`}, {
     99.12912375832244, -197.6827418753811}}]}, InsetBox[
    StyleBox[Cell[TextData[StyleBox["UV",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {291.11218346209, -187.9553676874443}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["IR",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {97.70808236141863, -187.95536768744452}, {
    Left, Baseline},
    Alignment->{Left, Top}]},
  ContentSelectable->True,
  ImagePadding->{{193.879032, 194.879032}, {1., 0.}},
  ImageSize->{830., Automatic},
  PlotRange->{{186., 582.}, {-383., 5.}},
  PlotRangePadding->Automatic]], "Input",
 CellChangeTimes->{{3.7780298823183804`*^9, 3.7780299446390667`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lifshitz to lifshitz", "Subsection",
 CellChangeTimes->{{3.633435900140727*^9, 3.633435905014963*^9}, {
  3.633548548578061*^9, 3.633548554786209*^9}, {3.633548813880323*^9, 
  3.6335488180564213`*^9}, {3.7778094282262793`*^9, 3.777809429693622*^9}}],

Cell[TextData[StyleBox["Now we consider the flow between two lifshitz fixed \
points. Verify by yourselves that the dimension of the operator in the two \
fixed points is what expected.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.778030089249432*^9, 3.7780301291672835`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uIR", "=", 
   RowBox[{"-", "10"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uUV", "=", "60"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M2", "=", 
   FractionBox["72", "17"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zsol", "=", 
   RowBox[{"z", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"36", " ", "z"}], 
        RowBox[{"9", "+", 
         RowBox[{"2", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}]], "\[Equal]", "M2"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "5"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zsol2", "=", 
   RowBox[{"z", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"36", " ", "z"}], 
        RowBox[{"9", "+", 
         RowBox[{"2", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}]], "\[Equal]", "M2"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "2"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Eqnum", ",", 
       RowBox[{
        RowBox[{"\[Beta]t", "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox[
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", "zsol"}], "zsol"]], 
          SqrtBox["2"]], "-", 
         SuperscriptBox["10", 
          RowBox[{"-", "5"}]]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Beta]t", "'"}], "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{"0", "-", 
         SuperscriptBox["10", 
          RowBox[{"-", "5"}]]}]}], ",", 
       RowBox[{
        RowBox[{"ww", "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "zsol"], "+", 
         SuperscriptBox["10", 
          RowBox[{"-", "5"}]]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ww", ",", "\[Beta]t"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "uIR", ",", "uUV"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]t", "[", "x", "]"}], "/.", "sol"}], ",", 
      FractionBox[
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "zsol"}], "zsol"]], 
       SqrtBox["2"]], ",", 
      FractionBox[
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "zsol2"}], "zsol2"]], 
       SqrtBox["2"]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "uIR", ",", "uUV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.012", "]"}], ",", "Orange"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Beta]\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"u\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0.45", ",", "0.65"}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"ww", "[", "x", "]"}]}], "/.", "sol"}], ",", "zsol", ",", 
      "zsol2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "uIR", ",", "uUV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.012", "]"}], ",", "Green"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"u\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"%%", ",", "%"}], "}"}], "}"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "uIR", ",", "uUV", ",", "M2", ",", "\[Gamma]", ",", "n", ",", "zsol"}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6335480790789194`*^9, 3.6335482838117666`*^9}, {
  3.633548375713952*^9, 3.6335485362937484`*^9}, {3.641813680600169*^9, 
  3.641813784406086*^9}, {3.777809437899868*^9, 3.777809451676341*^9}, {
  3.7778094828148184`*^9, 3.777809581519506*^9}, {3.7780300640070095`*^9, 
  3.7780300753311467`*^9}, {3.77803014355746*^9, 3.778030158992584*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[1, 0.5, 0], Thickness[0.012], Opacity[1.], 
          LineBox[CompressedData["
1:eJwd13k8FW8XAHCyVnayb9cle9ZUtjmWa+fVYo1UIpTsopQWURHSYkmRVEgh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           "]]},
         Annotation[#, "Charting`Private`Tag$4129#1"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbbpK4ML//8oHbl2ZxT3ny2N7thkX2R0XKMH511on
2Tc5KML5yoc/x2/oloHzW15k/Cz4LQbn24Vb71RsF4Tzw3s2fv1kwQ7nC/YU
XZke/WM/jH9CoEG78OcsOF8zbeFGbpHv9jB+addqpav1bA4w/naDChNtQ0E4
31Pvi1z4XjE4v/mR0ONJujJwvov35kvCXIpwftC7zuuXTynD+W6C1dEHjqnB
+b39tme2bNGE8+9fW/NArkAHzhefZ1ayNU0fztedvu1qgqghnO8of9/g7xQj
OP9/SEHTXF4TON/p/fWlP3JM4fyKk2c4Xr00g/ONOWbYTvO1gPNnfDmd4bbK
Es7/oNB7uUfFGs4/t1FFoK/VBs6f3+TZo8piB+dLMV7/d6DaHs7nLZq7kDvX
Ac5vZ572mFHbERFexyv7Qu8g+NceTjTR7nKC8xPnFPw67eYM5+t3Wmme+obg
fxM9XT55qwucz3DVTX9XuisiPF99e5gk5oaIzwW5W65dRvAvdZx/v7zFHc5/
LvDDy8XFA86/+D5kYRKDJ5z/l2Fuwr31CL7yptX2qnlecH731KXtJ+W94fwT
5y+fen8Wwf+/8oTuwy4fOL9y24qf+ta+iPRUcO3b9LkIfq8Wy5f//xF8AN8K
yQc=
           "]]},
         Annotation[#, "Charting`Private`Tag$4129#2"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbbpK4ML//8oHGMDggT3bjIvsjguU4PxrrZPsmxwU
4Xzlw5/jN3TLwPktLzJ+FvwWg/Ptwq13KrYLwvnhPRu/frJgh/MFe4quTI/+
sR/GPyHQoF34cxacr5m2cCO3yHd7GL+0a7XS1Xo2Bxh/u0GFibahIJzvqfdF
LnyvGJzf/Ejo8SRdGTjfxXvzJWEuRTg/6F3n9cunlOF8N8Hq6APH1OD83n7b
M1u2aML596+teSBXoAPni88zK9mapg/n607fdjVB1BDOd5S/b/B3ihGc/z+k
oGkurwmc7/T++tIfOaZwfsXJMxyvXprB+cYcM2yn+VrA+TO+nM5wW2UJ539Q
6L3co2IN55/bqCLQ12oD589v8uxRZbGD86UYr/87UG0P5/MWzV3InesA57cz
T3vMqO2ICK/jlX2hdxD8aw8nmmh3OcH5iXMKfp12c4bz9TutNE99Q/C/iZ4u
n7zVBc5nuOqmvyvdFRGer749TBJzg/O3L8jdcu0ygn+p4/z75S3ucP5zgR9e
Li4ecP7F9yELkxg84fy/DHMT7q1H8JU3rbZXzfOC87unLm0/Ke8N5584f/nU
+7MI/v+VJ3QfdvnA+ZXbVvzUt/aF85sLrn2bPhfB79Vi+fL/P4IPAEtt/kA=

           "]]},
         Annotation[#, "Charting`Private`Tag$4129#3"]& ]}, {}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"\[Beta]\\\",\\nFontSize->24]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm]},
      AxesOrigin->{0, 0.45},
      AxesStyle->Directive[
        GrayLevel[0], 15],
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      LabelStyle->Directive[
        GrayLevel[0], Bold, Medium],
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-9.999998571428572, 59.99999857142857}, {0.45, 0.65}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {192., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], Thickness[0.012], Opacity[1.], 
          LineBox[CompressedData["
1:eJwV13c8ld8fAPDn2kLutaLslWySPT7GvbhcWRFRKEpSyIyKsglJ1reBlllG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           "]]},
         Annotation[#, "Charting`Private`Tag$4172#1"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbbpK4ML//8oH/oOBoAPbjIvsjguU4PxrrZPsmxwU
4Xzlw5/jN3TLwPktLzJ+FvwWg/Ptwq13KrYLwvnhPRu/frJgh/MFe4quTI/+
sR/GPyHQoF34cxacr5m2cCO3yHd7GL+0a7XS1Xo2Bxh/u0GFibahIJzvqfdF
LnyvGJzf/Ejo8SRdGTjfxXvzJWEuRTg/6F3n9cunlOF8N8Hq6APH1OD83n7b
M1u2aML596+teSBXoAPni88zK9mapg/n607fdjVB1BDOd5S/b/B3ihGc/z+k
oGkurwmc7/T++tIfOaZwfsXJMxyvXprB+cYcM2yn+VrA+TO+nM5wW2UJ539Q
6L3co2IN55/bqCLQ12oD589v8uxRZbGD86UYr/87UG0P5/MWzV3InesA57cz
T3vMqO2ICK/jlX2hdxD8aw8nmmh3OcH5iXMKfp12c4bz9TutNE99Q/C/iZ4u
n7zVBc5nuOqmvyvdFRGer749TBJzQ8Tngtwt1y4j+Jc6zr9f3uIO5z8X+OHl
4uIB5198H7IwicETzv/LMDfh3noEX3nTanvVPC84v3vq0vaT8t5w/onzl0+9
P4vg/195Qvdhlw+cX7ltxU99a19Eeiq49m36XAS/V4vly///CD4AXNILTg==

           "]]},
         Annotation[#, "Charting`Private`Tag$4172#2"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQbbpK4ML//8oHGCDAgW3GRXbHBUpw/rXWSfZNDopw
vvLhz/EbumXg/JYXGT8LfovB+Xbh1jsV2wXh/PCejV8/WbDD+YI9RVemR//Y
D+OfEGjQLvw5C87XTFu4kVvkuz2MX9q1WulqPZsDjL/doMJE21AQzvfU+yIX
vlcMzm9+JPR4kq4MnO/ivfmSMJcinB/0rvP65VPKcL6bYHX0gWNqcH5vv+2Z
LVs04fz719Y8kCvQgfPF55mVbE3Th/N1p2+7miBqCOc7yt83+DvFCM7/H1LQ
NJfXBM53en996Y8cUzi/4uQZjlcvzeB8Y44ZttN8LeD8GV9OZ7itsoTzPyj0
Xu5RsYbzz21UEehrtYHz5zd59qiy2MH5UozX/x2otofzeYvmLuTOdYDz25mn
PWbUdkSE1/HKvtA7CP61hxNNtLuc4PzEOQW/Trs5w/n6nVaap74h+N9ET5dP
3uoC5zNcddPfle6KCM9X3x4mibnB+dsX5G65dhnBv9Rx/v3yFnc4/7nADy8X
Fw84/+L7kIVJDJ5w/l+GuQn31iP4yptW26vmecH53VOXtp+U94bzT5y/fOr9
WQT//8oTug+7fOD8ym0rfupb+8L5zQXXvk2fi+D3arF8+f8fwQcAuzrQ9A==

           "]]},
         Annotation[#, "Charting`Private`Tag$4172#3"]& ]}, {}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"z\\\",\\nFontSize->24]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm]},
      AxesOrigin->{0, 1},
      AxesStyle->Directive[
        GrayLevel[0], 15],
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      LabelStyle->Directive[
        GrayLevel[0], Bold, Medium],
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-9.999998571428572, 59.99999857142857}, {1, 5}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {576., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}]}, 
   {Arrowheads[0.023442288153199226`], EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{303.01198640941703`, -188.20680824034483`}, {
     107.54807965704867`, -188.2068082403447}}]}, 
   {Arrowheads[0.023442288153199226`], EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{685.128179411829, -190.7766542480604}, {
     489.6642726594606, -190.77665424806028`}}]}, InsetBox[
    StyleBox[Cell[TextData[StyleBox["UV",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {293.4140914302344, -180.5154516276051}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["UV",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {673.2311496973731, -179.5957977334958}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["IR",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {97.98763893200925, -179.59579773349586}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["IR",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {486.0815822461317, -180.51545162760507}, {
    Left, Baseline},
    Alignment->{Left, Top}]},
  ContentSelectable->True,
  ImagePadding->{{189.201613, 190.201613}, {190.151468, 190.288978}},
  ImageSize->{810., Automatic},
  PlotRange->{{186., 582.}, {-195.04611602856346`, -184.}},
  PlotRangePadding->Automatic]], "Input",
 CellChangeTimes->{{3.7780301636736307`*^9, 3.778030204545043*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["AdS UV -----> Lifshitz IR (zIR=12)", "Subsection",
 CellChangeTimes->{{3.633435900140727*^9, 3.633435905014963*^9}, {
  3.633548548578061*^9, 3.633548554786209*^9}, {3.6335488237165556`*^9, 
  3.633548833576785*^9}, {3.633548978428214*^9, 3.633548978916231*^9}, {
  3.7780302856649103`*^9, 3.7780303324168744`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"36", " ", "z"}], 
   RowBox[{"9", "+", 
    RowBox[{"2", " ", "z"}], "+", 
    SuperscriptBox["z", "2"]}]], "/.", 
  RowBox[{"z", "\[Rule]", "12"}]}]], "Input",
 CellChangeTimes->{{3.777809631849474*^9, 3.7778096335233555`*^9}}],

Cell[BoxData[
 FractionBox["144", "59"]], "Output",
 CellChangeTimes->{3.777809633878161*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"uIR", "=", 
   RowBox[{"-", "30"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uUV", "=", "50"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M2", "=", 
   FractionBox["144", "59"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zsol", "=", 
   RowBox[{"z", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"36", " ", "z"}], 
        RowBox[{"9", "+", 
         RowBox[{"2", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}]], "\[Equal]", "M2"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "15"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Eqnum", ",", 
       RowBox[{
        RowBox[{"\[Beta]t", "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox[
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"-", "1"}], "+", "zsol"}], "zsol"]], 
          SqrtBox["2"]], "-", 
         SuperscriptBox["10", 
          RowBox[{"-", "7"}]]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Beta]t", "'"}], "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{"0", "-", 
         SuperscriptBox["10", 
          RowBox[{"-", "7"}]]}]}], ",", 
       RowBox[{
        RowBox[{"ww", "[", "uIR", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "zsol"], "+", 
         SuperscriptBox["10", 
          RowBox[{"-", "7"}]]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"ww", ",", "\[Beta]t"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", "uIR", ",", "uUV"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Beta]t", "[", "x", "]"}], "/.", "sol"}], ",", 
      FractionBox[
       SqrtBox[
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "zsol"}], "zsol"]], 
       SqrtBox["2"]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "uIR", ",", "uUV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.012", "]"}], ",", "Orange"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"\[Beta]\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"u\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.8"}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"ww", "[", "x", "]"}]}], "/.", "sol"}], ",", "zsol", ",", 
      "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "uIR", ",", "uUV"}], "}"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.012", "]"}], ",", "Green"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", "Black", ",", "Thick"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"u\",
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\!\(\*
StyleBox[\"(\",
FontSize->24]\)\!\(\*
StyleBox[\"u\",
FontSize->24]\)\!\(\*
StyleBox[\")\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30"}], ",", "20"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "13"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"%%", ",", "%"}], "}"}], "}"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "uIR", ",", "uUV", ",", "M2", ",", "\[Gamma]", ",", "n", ",", "zsol"}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6335480790789194`*^9, 3.6335482838117666`*^9}, {
  3.633548375713952*^9, 3.6335485362937484`*^9}, {3.633548589106995*^9, 
  3.6335486902134113`*^9}, {3.6335487607750607`*^9, 3.6335487696352687`*^9}, {
  3.6335488790378714`*^9, 3.633548968183976*^9}, {3.641813971404237*^9, 
  3.641814067829255*^9}, {3.7778096376267056`*^9, 3.7778097274794736`*^9}, {
  3.7778875404515324`*^9, 3.777887587675934*^9}, {3.7780303119496555`*^9, 
  3.7780303271998057`*^9}, {3.7780304813118825`*^9, 3.7780304971792493`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[1, 0.5, 0], Thickness[0.012], Opacity[1.], 
          LineBox[CompressedData["
1:eJwd13c8Vf8fB3BEdrL33ntd1/b52NeqSAgRIZUoFZGMhGQlJZkho6xkZMWn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           "]]},
         Annotation[#, "Charting`Private`Tag$4512#1"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/evc7Cf//9se2OU1by7Tqqf2Gi8PTGMwR/DDmZ95
MObZwPncp/pSjHZZwflqG7pvuihbwvlL20yPB00xh/Or39vmTHhsCufvKJ+V
td7fBM73mxSq8G+mEZzvPnevn8cbA4R8/+c1z7fpwfn7ODS15wVqw/l/D7DF
iKtpwPmMUXZ17VyqcP5WcWP+8NWKcH6BxoKll7hl4fxrWSFc2yzF4PzuuxWL
+fj54fzlD17+2T2RCeH/W7auc8Sf7IfxJz5cbtdT/c4exu+5sq5UP4jVAca/
IKbGfSFJEM7f46ryjWmlOJzvob2CubxMDs6fffLtVaMMJTj/7Jy1FsatqnC+
v/cGnStPNeB8pt1ceZt4dOB8VrYVDobl+nC+4o6vE+5kGML5N32dNex/GsH5
loFGHEWrTeB8Q9OzfYcdzOD84xq750ieM0eY3+X12b7WEs6/fbr1Qwu/NZwf
WZ1kNuuwDZxfwP1a6VyUHZyvvPrYNLZX9nC+w52FK9vPOsD5VsFm0bOnO8L5
HI3ShtOLnOD8pWarvKZ6OsP5fXf6tisJucD53pZHPGa8RvBD2vx1525zhfN1
oltCl9S6wfk3nnEumhzqjoivpKeOQvIecL7aUkmpzn4Ev/a576f//xF8ALR5
i7w=
           "]]},
         Annotation[#, "Charting`Private`Tag$4512#2"]& ]}, {}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"\[Beta]\\\",\\nFontSize->24]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm]},
      AxesOrigin->{0, 0},
      AxesStyle->Directive[
        GrayLevel[0], 15],
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      LabelStyle->Directive[
        GrayLevel[0], Bold, Medium],
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-29.99999836734694, 49.99999836734694}, {0, 0.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {0, 0}},
      Ticks->{Automatic, Automatic}], {192., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0, 1, 0], Thickness[0.012], Opacity[1.], 
          LineBox[CompressedData["
1:eJwl13c8ld8fAHB7j+y9x7X3Xs+xR3airBBKWWkRZaaQBlLISGRHhURxikJK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           "]]},
         Annotation[#, "Charting`Private`Tag$4554#1"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/evc7Cf//9se+PcfBNQdNF4emMZgjuCHMz/zYMyz
gfO5T/WlGO2ygvPVNnTfdFG2hPOXtpkeD5piDudXv7fNmfDYFM7fUT4ra72/
CZzvNylU4d9MIzjffe5eP483Bgj5/s9rnm/Tg/P3cWhqzwvUhvP/HmCLEVfT
gPMZo+zq2rlU4fyt4sb84asV4fwCjQVLL3HLwvnXskK4tlmKwfnddysW8/Hz
w/nLH7z8s3siE8L/t2xd54g/2Q/jT3y43K6n+p09jN9zZV2pfhCrA4x/QUyN
+0KSIJy/x1XlG9NKcTjfQ3sFc3mZHJw/++Tbq0YZSnD+2TlrLYxbVeF8f+8N
OleeasD5TLu58jbx6MD5rGwrHAzL9eF8xR1fJ9zJMITzb/o6a9j/NILzLQON
OIpWm8D5hqZn+w47mMH5xzV2z5E8Z44wv8vrs32tJZx/+3TrhxZ+azg/sjrJ
bNZhGzi/gPu10rkoOzhfefWxaWyv7OF8hzsLV7afdYDzrYLNomdPd4TzORql
DacXOcH5S81WeU31dIbz++70bVcScoHzvS2PeMx4jeCHtPnrzt3mCufrRLeE
Lql1g/NvPONcNDnUHRFfSU8dheQ94Hy1pZJSnf0Ifu1z30///yP4ALbCBD8=

           "]]},
         Annotation[#, "Charting`Private`Tag$4554#2"]& ], 
        TagBox[
         {GrayLevel[0], Thickness[Large], Opacity[1.], 
          Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/evc7Cf//9seYACDD/YaLw9MYzBH8MOZn3kw5tnA
+dyn+lKMdlnB+Wobum+6KFvC+UvbTI8HTTGH86vf2+ZMeGwK5+8on5W13t8E
zvebFKrwb6YRnO8+d6+fxxsDhHz/5zXPt+nB+fs4NLXnBWrD+X8PsMWIq2nA
+YxRdnXtXKpw/lZxY/7w1YpwfoHGgqWXuGXh/GtZIVzbLMXg/O67FYv5+Pnh
/OUPXv7ZPZEJ4f9btq5zxJ/sh/EnPlxu11P9zh7G77myrlQ/iNUBxr8gpsZ9
IUkQzt/jqvKNaaU4nO+hvYK5vEwOzp998u1VowwlOP/snLUWxq2qcL6/9wad
K0814Hym3Vx5m3h04HxWthUOhuX6cL7ijq8T7mQYwvk3fZ017H8awfmWgUYc
RatN4HxD07N9hx3M4PzjGrvnSJ4zR5jf5fXZvtYSzr99uvVDC781nB9ZnWQ2
67ANnF/A/VrpXJQdnK+8+tg0tlf2cL7DnYUr2886wPlWwWbRs6c7wvkcjdKG
04uc4PylZqu8pno6w/l9d/q2Kwm5wPnelkc8ZrxG8EPa/HXnbnOF83WiW0KX
1LrB+TeecS6aHOoO519IeuooJO8B56stlZTq7Efwa5/7fvr/H8EHAAYe9i0=

           "]]},
         Annotation[#, "Charting`Private`Tag$4554#3"]& ]}, {}, {}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"u\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"z\\\",\\nFontSize->24]\\)\\!\\(\\*\\\
nStyleBox[\\\"(\\\",\\nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\"u\\\",\\\
nFontSize->24]\\)\\!\\(\\*\\nStyleBox[\\\")\\\",\\nFontSize->24]\\)\"", 
         TraditionalForm]},
      AxesOrigin->{0, 0},
      AxesStyle->Directive[
        GrayLevel[0], 15],
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      LabelStyle->Directive[
        GrayLevel[0], Bold, Medium],
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
             Part[#, 1]], 
            (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{-30, 20}, {0, 13}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], {576., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}]}, 
   {Arrowheads[0.023442288153199226`], EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{263.0328766131472, -219.70867985463397`}, {
     67.5689698607789, -219.70867985463386`}}]}, 
   {Arrowheads[0.023442288153199226`], EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{667.3705801212279, -186.95915841946666`}, {
     471.90667336885963`, -186.95915841946655`}}]}, InsetBox[
    StyleBox[Cell[TextData[StyleBox["IR",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {64.24970006606299, -209.51380569679327}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["IR",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {463.49099635229146, -175.5738297261519}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["UV",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {257.6182473724802, -212.19327748394915}, {
    Left, Baseline},
    Alignment->{Left, Top}], InsetBox[
    StyleBox[Cell[TextData[StyleBox["UV",
      FontSize->16]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline,
      TextAlignment->Left],
     TextAlignment->Center,
     FontSize->12,
     FontWeight->Bold,
     Background->GrayLevel[1.]], {661.3253299706352, -179.1464587756931}, {
    Left, Baseline},
    Alignment->{Left, Top}]},
  ContentSelectable->True,
  ImagePadding->{{194.814516, 195.814516}, {196.93414, 195.316304}},
  ImageSize->{834., Automatic},
  PlotRange->{{186., 582.}, {-194., -183.44817567114836`}},
  PlotRangePadding->Automatic]], "Input",
 CellChangeTimes->{{3.778030530454534*^9, 3.778030571541685*^9}}],

Cell[" ", "Text",
 Editable->False,
 Selectable->False,
 CellFrame->{{0, 0}, {0, 2}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{Inherited, 4}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flows diagram", "Section",
 CellChangeTimes->{{3.777887389204545*^9, 3.777887391007705*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]], ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[SuperscriptBox[\"m\", \"2\"],
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.006", "]"}], ",", "Blue"}], "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]], ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "3", ",", "13"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[SuperscriptBox[\"m\", \"2\"],
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.006", "]"}], ",", "Orange"}], "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       RowBox[{"36", " ", "z"}], 
       RowBox[{"9", "+", 
        RowBox[{"2", " ", "z"}], "+", 
        SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "13"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[SuperscriptBox[\"m\", \"2\"],
FontSize->24]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"z\",
FontSize->24]\)\>\""}], "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", "Bold", ",", " ", "Medium"}], "]"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Black", ",", " ", "15"}], "]"}]}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"{", "1", "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Thickness", "[", "0.006", "]"}], ",", "Green"}], "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", "%%%", ",", "%%", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "4.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "13"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "0.8"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.777887110214346*^9, 3.7778871922095623`*^9}, {
  3.777887226764601*^9, 3.7778872459138746`*^9}, {3.7778872783984566`*^9, 
  3.777887359250949*^9}, {3.7784171791548605`*^9, 3.7784173661557045`*^9}, {
  3.7784174013497705`*^9, 3.7784174584654093`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0, 1, 0], Thickness[0.006], Opacity[1.], FaceForm[Opacity[
      0.3]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQjQo+2HfZi6xau+W+PYwveeG0559N7+D8Zf9KJjvN
/gvn1/1p1Zb2Z3GA8QvcmI/yruOA89e/r1WuSuKB8/3kfzhN+c8H5//a4D31
VLsAnC8gyKKZYykI5/twlnsvXILg2/v4OiQ8Q/CZTi7gSPyG4F/keqXb8A/B
Lwo7NGvrfwT/7+Zvt9l+I/gfOxytn95H8NmWtn95uRXBj0yPtX5bheCHO5S0
iJsj+HUm3jv7PyLc7zA96HbjQgR//+VN1xhCEPzntkuZt//hR7g3Md3KKxjB
X1zyO65vKyJ8Lq2SMhXmQfAVWTj0JAp44fzggOmcd24iwnen7V+VMCsE/+wy
lnUsK7nhfNaQystz+BF8zw8PdnnUcsH5grKcl9b+4ES4/4VPtFwugh9tfo/j
7DtE/G7V0k5aVIbga/1seuXygx3Ov2fokyTQhuD/OXi2WI8PwZ+mx/P6wkI2
ON+2NcD7shWCb1DyasbCc6xwPp/PxLgbOQi+fcO6MGs2BL/zxNJ9B5cg0mNJ
i0LMYh8Ev7rW8BLnB2Y4vycuy8phDoI/65SifLMPgj/PQNx82g8mOJ99bunP
2WsQfJfG/na1ZgQ/CgwQfAAY9+0k
       "]]},
     Annotation[#, "Charting`Private`Tag$3302#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[0, 0, 1], Thickness[0.006], Opacity[1.], FaceForm[Opacity[
      0.3]], LineBox[CompressedData["
1:eJw11gs0lVkbB/DjcN6NDs5rdB2KLnKrMVFfE3kfh4zRDVHD8CGpRLmWUonE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       "]]},
     Annotation[#, "Charting`Private`Tag$3254#1"]& ]}, {{}, {}, 
    TagBox[
     {RGBColor[1, 0.5, 0], Thickness[0.006], Opacity[1.], FaceForm[Opacity[
      0.3]], LineBox[CompressedData["
1:eJwt1nlYzdkfB/B82773dnPvN2nRtN5SX/kV7US9h2lDqWyhsrVRRJORpDRa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       "]]},
     Annotation[#, "Charting`Private`Tag$3278#1"]& ]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], FaceForm[{Hue[0.2611111111111111, 0.4594594594594595, 1.], Opacity[
    0.28]}], 
    RectangleBox[{3.013364233770632, 0.02322314532630898}, \
{0.7744850189909016, 13.664607542504378}]}, 
   {EdgeForm[Opacity[1.]], EdgeForm[None], 
    ArrowBox[{{2.3990694629562235`, 1.3676633444075321`}, {2.383288732102825, 
     11.670727214168295`}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{2.0628654970760234`, 1.504177109440267}, {
     2.056367771280052, 13.088693957115009`}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{1.6600064977257962`, 1.4740090968161148`}, {
     1.6600064977257962`, 13.239534020235773`}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{1.2701429499675114`, 1.4740090968161148`}, {
     1.2896361273554255`, 13.752390234846374`}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{2.673651721897336, 1.413673071567807}, {
     2.673651721897336, 10.07189269469971}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], FaceForm[Opacity[0.05]], 
    RectangleBox[{3.0180311890838207, 13.661886196973915}, \
{4.519005847953217, -0.06455954701569233}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{3.115957692971343, 1.3830699572356777`}, {
     3.1282571877617253`, 8.110564976000479}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{3.38190383365822, 1.715353197809339}, {3.38190383365822,
      6.964587394411955}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{3.6353151397011048`, 2.0472013366750197`}, {
     3.6353151397011048`, 5.938874965190752}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{3.9212150747238472`, 2.167873387171632}, {
     3.914717348927876, 4.943330548593707}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{4.181124106562704, 2.288545437668244}, {
     4.181124106562704, 4.098626195117422}}]}, 
   {Arrowheads[{{0.022908676527677727`, 1.}}], EdgeForm[{GrayLevel[0.], 
    Opacity[1.], AbsoluteThickness[1]}], EdgeForm[None], 
    ArrowBox[{{4.4410331384015596`, 2.318713450292396}, {4.4410331384015596`, 
     1.1485602333555514`}}]}, 
   {Arrowheads[{{0.020796966871036958`, 1.}}], EdgeForm[{GrayLevel[0.], 
    Opacity[1.], AbsoluteThickness[1]}], EdgeForm[None], 
    ArrowBox[{{4.265594541910332, 1.7756892230576433`}, {4.265594541910332, 
     1.1723289705745827`}}]}, 
   {Arrowheads[{{0.020044720273651614`, 1.}}], EdgeForm[{GrayLevel[0.], 
    Opacity[1.], AbsoluteThickness[1]}], EdgeForm[None], 
    ArrowBox[{{4.064165042235218, 1.5645131346885748`}, {4.064165042235218, 
     1.0818249327021263`}}]}, 
   {EdgeForm[{GrayLevel[0.], Opacity[1.], AbsoluteThickness[1]}], EdgeForm[
    None], ArrowBox[{{4.337069525666018, 2.529889538661468}, {
     4.337069525666018, 3.5857699805068215`}}]}, 
   {Thickness[0.004216965034285823], 
    LineBox[{{3.0115334632878494`, 0.9913208948296663}, {4.506010396361274, 
     0.9913208948296663}}]}, 
   {Arrowheads[{{0.020044720273651614`, 1.}}], EdgeForm[{GrayLevel[0.], 
    Opacity[1.], AbsoluteThickness[1]}], EdgeForm[None], 
    ArrowBox[{{3.866313636117412, 1.4287570778798866`}, {3.866313636117412, 
     0.9460688758934381}}]}, 
   StyleBox[InsetBox[
     StyleBox[Cell["LIFSHITZ IR",
       GeneratedCell->False,
       CellAutoOverwrite->False,
       CellBaseline->Baseline,
       TextAlignment->Left],
      FontWeight->"Bold",
      FontOpacity->1.], {3.24545159194282, 8.774668151861134}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    FontSize->18,
    FontColor->Hue[0.0722222222222222, 1., 0.9484557066141633],
    Background->RGBColor[1., 1., 1., 0.02]], 
   StyleBox[InsetBox[
     StyleBox[Cell[TextData[StyleBox["LIFSHITZ UV",
       FontColor->RGBColor[0, 0, 1]]],
       GeneratedCell->False,
       CellAutoOverwrite->False,
       CellBaseline->Baseline,
       TextAlignment->Left],
      FontWeight->"Bold",
      FontOpacity->1.], {3.424139051332034, 2.0924533556112497}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    FontSize->18,
    FontColor->Hue[0.0722222222222222, 1., 0.9484557066141633],
    Background->RGBColor[1., 1., 1., 0.02]], 
   StyleBox[InsetBox[
     StyleBox[Cell[TextData[StyleBox["ADS UV",
       FontColor->RGBColor[0, 1, 0]]],
       GeneratedCell->False,
       CellAutoOverwrite->False,
       CellBaseline->Baseline,
       TextAlignment->Left],
      FontWeight->"Bold",
      FontOpacity->1.], {1.5657894736842104, 0.34270862341037756}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    FontSize->18,
    FontColor->Hue[0.0722222222222222, 1., 0.9484557066141633],
    Background->RGBColor[1., 1., 1., 0.02]], 
   StyleBox[InsetBox[
     StyleBox[Cell[TextData[StyleBox["ADS IR",
       FontColor->GrayLevel[0]]],
       GeneratedCell->False,
       CellAutoOverwrite->False,
       CellBaseline->Baseline,
       TextAlignment->Left],
      FontWeight->"Bold",
      FontOpacity->1.], {3.5670890188434052, 0.2823725981620697}, {
     Left, Baseline},
     Alignment->{Left, Top}],
    FontSize->18,
    FontColor->Hue[0.0722222222222222, 1., 0.9484557066141633],
    Background->RGBColor[1., 1., 1., 0.02]]},
  AspectRatio->0.8,
  Axes->{True, True},
  AxesLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[SuperscriptBox[\\\"m\\\", \
\\\"2\\\"],\\nFontSize->24]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"z\\\",\\nFontSize->24]\\)\"", 
     TraditionalForm]},
  AxesOrigin->{1, 0},
  AxesStyle->Directive[
    GrayLevel[0], 15],
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{{}, {1}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{0.5, 40.}, {1.5, 24.}},
  ImageSize->{639., Automatic},
  LabelStyle->Directive[
    GrayLevel[0], Bold, Medium],
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{0.8055555555555556, 4.694444444444445}, {-0.7222222222222223, 
   13.722222222222221`}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic,
  Ticks->{Automatic, Automatic}]], "Input",
 CellChangeTimes->{{3.77841747486017*^9, 3.778417527904747*^9}, {
  3.7784177337447944`*^9, 3.7784177651987534`*^9}, {3.7784178276043563`*^9, 
  3.7784178308536215`*^9}, {3.7784178908726172`*^9, 3.778417917009447*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1520, 781},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 221, 3, 101, "Title"],
Cell[804, 27, 120, 2, 30, "Input"],
Cell[927, 31, 147, 3, 30, "Input"],
Cell[1077, 36, 301, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[1403, 46, 142, 2, 72, "Chapter"],
Cell[CellGroupData[{
Cell[1570, 52, 200, 3, 70, "Section"],
Cell[1773, 57, 402, 8, 68, "Text"],
Cell[2178, 67, 433, 13, 50, "Input"],
Cell[2614, 82, 11918, 314, 330, "Input"],
Cell[14535, 398, 273, 9, 5, "Text"],
Cell[14811, 409, 251, 6, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15099, 420, 161, 2, 70, "Section"],
Cell[15263, 424, 357, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[15645, 435, 1324, 33, 146, "Input"],
Cell[16972, 470, 3005, 85, 101, "Output"]
}, Open  ]],
Cell[19992, 558, 339, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[20356, 569, 1581, 41, 101, "Input"],
Cell[21940, 612, 6160, 118, 317, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28149, 736, 102, 1, 70, "Section"],
Cell[28254, 739, 271, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[28550, 747, 1304, 38, 145, "Input"],
Cell[29857, 787, 1139, 25, 30, "Output"],
Cell[30999, 814, 1341, 33, 45, "Output"]
}, Open  ]],
Cell[32355, 850, 208, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[32588, 858, 1569, 42, 71, "Input"],
Cell[34160, 902, 7061, 138, 367, "Output"]
}, Open  ]],
Cell[41236, 1043, 273, 9, 5, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41546, 1057, 113, 1, 70, "Section"],
Cell[41662, 1060, 249, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[41936, 1070, 241, 6, 30, "Input"],
Cell[42180, 1078, 5671, 155, 114, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47912, 1240, 167, 2, 72, "Chapter"],
Cell[CellGroupData[{
Cell[48104, 1246, 254, 3, 70, "Section"],
Cell[CellGroupData[{
Cell[48383, 1253, 291, 3, 49, "Subsection"],
Cell[48677, 1258, 736, 16, 70, "Text"],
Cell[CellGroupData[{
Cell[49438, 1278, 315, 9, 51, "Input"],
Cell[49756, 1289, 275, 8, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50068, 1302, 2455, 72, 181, "Input"],
Cell[52526, 1376, 10225, 211, 363, "Output"]
}, Open  ]],
Cell[62766, 1590, 5410, 161, 364, "Input"],
Cell[68179, 1753, 34440, 627, 448, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102656, 2385, 256, 3, 49, "Subsection"],
Cell[102915, 2390, 286, 4, 30, "Text"],
Cell[103204, 2396, 5987, 185, 466, "Input"],
Cell[109194, 2583, 32383, 595, 407, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141614, 3183, 321, 4, 49, "Subsection"],
Cell[CellGroupData[{
Cell[141960, 3191, 279, 8, 51, "Input"],
Cell[142242, 3201, 93, 2, 45, "Output"]
}, Open  ]],
Cell[142350, 3206, 5695, 172, 425, "Input"],
Cell[148048, 3380, 39032, 701, 419, "Input"],
Cell[187083, 4083, 271, 9, 8, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[187403, 4098, 98, 1, 70, "Section"],
Cell[187504, 4101, 4379, 125, 251, "Input"],
Cell[191886, 4228, 14040, 273, 519, InheritFromParent]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

