(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    739598,      23588]
NotebookOptionsPosition[    698591,      22392]
NotebookOutlinePosition[    699551,      22430]
CellTagsIndexPosition[    699451,      22424]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["\n",
  FontSize->12],
 "\t\t\n",
 StyleBox["RIEMANNIAN GEOMETRY & TENSOR CALCULUS\n",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["A set of functions for tensor calculations in Riemannian Geometry \
and General Relativity\n",
  FontSize->16]
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontColor->RGBColor[0, 0, 1]],

Cell["version 2.8.4- November 2002", "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Times",
 FontSize->14,
 FontSlant->"Italic"],

Cell[TextData[{
 StyleBox["\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ButtonBox["S. Bonanos",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/SB.html"], None}],
 StyleBox["\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Bold"],
 StyleBox["Institute of Nuclear Physics, ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[ButtonBox["NCSR \"Demokritos\"",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.demokritos.gr/"], None}],
  FontSlant->"Italic"],
 StyleBox[", \nAghia Paraskevi 15310, Greece. ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Bold"],
 "Please send comments, suggestions, bug reports to:  ",
 ButtonBox["sbonano@mail.ariadne-t.gr",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:sbonano@mail.ariadne-t.gr"], None}],
 StyleBox[" \t",
  FontWeight->"Bold"]
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Times",
 FontSize->16]
}, Open  ]],

Cell[TextData[{
 "\[CapitalDelta]\[Omega]\[Rho]\[Epsilon]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "`"],
   FontFamily->"Times"]]],
 "\[Nu] \[Epsilon]\[Lambda]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "'"],
   FontFamily->"Times"]]],
 "\[Beta]\[Epsilon]\[Tau]\[Epsilon], \[Delta]\[Omega]\[Rho]\[Epsilon]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "`"],
   FontFamily->"Times"]]],
 "\[Nu] \[Delta]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["o", "'"],
   FontFamily->"Times"]]],
 "\[Tau]\[Epsilon]."
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Helvetica",
 FontSize->24,
 FontColor->GrayLevel[1]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 1  Instructions ",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Section",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["  1.1  ",
  FontWeight->"Bold"],
 "Basic Input /Output & Notation"
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "This package allows calculations in Riemannian Geometry by defining all \
basic tensors and tensor operations. Tensors are represented as nested lists. \
To define the geometry, begin by computing all basic Riemannian Geometry \
tensors for a particular metric. To do this:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "(0) Evaluate section ",
 StyleBox["2 RG&TC-Code",
  FontWeight->"Bold"]
}], "Text",
 FontSize->16],

Cell["Open a new notebook and", "Text",
 FontSize->16],

Cell[TextData[{
 "\t(1) Define a list symbols (coordinate names) - ",
 StyleBox["xIN",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t(2) Define a symmetric matrix (list of lists) of functions of the \
coordinates (the metric) - ",
 StyleBox["gIN",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t(3) Assign appropriate simplification rules to the global list ",
 StyleBox["simpRules",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"],
 " --- as needed (see Examples and Usage Tips)"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t(4) Evaluate ",
 StyleBox["RGtensors[gIN,xIN]\n",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 "  computes all common Riemannian Geometry tensors, printing messages along \
the way. It also tests if the space is ",
 StyleBox["Flat,",
  FontSlant->"Italic"],
 " ",
 StyleBox["Conformally Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Ricci Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " or ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 " and, if yes, prints corresponding messages. When it is finished, the \
following \"tensors\" - nested lists - are stored in memory and can be used \
in further calculations (the letters U, d  in the tensor names serve as \
mnemonic devices for the position - ",
 StyleBox["Up",
  FontSlant->"Italic"],
 " or ",
 StyleBox["down",
  FontSlant->"Italic"],
 " - of the relevant indices) :"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["gdd",
  FontFamily->"Courier"],
 " (covariant form of the metric tensor), with components gdd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["g", "ab"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["gUU",
  FontFamily->"Courier"],
 " (contravariant form of the metric tensor), with components gUU[[a,b]] = ",
 Cell[BoxData[
  SuperscriptBox["g", "ab"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["GUdd",
  FontFamily->"Courier"],
 " (Christoffel symbols of the 2nd kind), with components GUdd[[a,b,c]] = ",
 Cell[BoxData[
  TagBox[
   SubsuperscriptBox["\[CapitalGamma]", "bc", "a"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Rdddd",
  FontFamily->"Courier"],
 " (covariant form of the Riemann tensor), with components Rdddd[[a,b,c,d]] = \
",
 Cell[BoxData[
  TagBox[
   SubscriptBox["R", "abcd"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["RUddd",
  FontFamily->"Courier"],
 " (mixed form of the Riemann tensor), with components RUddd[[a,b,c,d]] = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "bcd"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Rdd",
  FontFamily->"Courier"],
 " (covariant form of the Ricci tensor), with components Rdd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["R", "ab"]]],
 " \[Congruent] ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "s"], "asb"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["EUd",
  FontFamily->"Courier"],
 " (mixed form of the Einstein tensor), with components EUd[[a,b]] = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["E", "a"], "b"],
   DisplayForm]]],
 " \[Congruent] ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "b"],
   DisplayForm]]],
 "- ",
 StyleBox["R/2",
  FontFamily->"Courier"],
 " ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Delta]", "a"], "b"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["R",
  FontFamily->"Courier"],
 " is the curvature scalar "
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Wdddd",
  FontFamily->"Courier"],
 " (covariant form of the Weyl tensor), with components Wdddd[[a,b,c,d]] = ",
 Cell[BoxData[
  SubscriptBox["W", "abcd"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tFinally, ",
 StyleBox["coordList",
  FontFamily->"Courier"],
 " contains the coordinates defined in (1) above, ",
 StyleBox["detg",
  FontFamily->"Courier"],
 " is the determinant of the metric and ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " stores the dimension of the space. Tensor components refer to the \
coordinate frame and are numbered ",
 StyleBox["1,...,Dim",
  FontFamily->"Courier"],
 ", rather than ",
 StyleBox["0,...,Dim-1",
  FontFamily->"Courier"],
 ". See section 5 \"",
 StyleBox["Calculating Tensor Components in an Arbitrary Frame",
  FontSlant->"Italic"],
 "\" below on how to do calculations in an arbitrary frame. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": One can choose to skip the most time consuming computations: RUddd and/or \
Wdddd. This can be achieved by calling ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 "  with an optional extra argument - a list of two numbers ",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 ". When the first number is 0, RUddd is not computed and when the second \
number is 0 Wdddd is not computed. Thus ",
 StyleBox["RGtensors[gIN,xIN,{1,0}]",
  FontFamily->"Courier"],
 "  will compute RUddd but not Wdddd. (See Examples 7 and 8)"
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\t  1.1.1  : Totally antisymmetric symbol / tensor", "Subsubsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t Definitions for the totally antisymmetric symbol ",
 Cell[BoxData[
  SubscriptBox["\[CurlyEpsilon]", 
   RowBox[{
    RowBox[{"a1", "..."}], "an"}]]]],
 " and tensor  ",
 Cell[BoxData[
  SubscriptBox["\[Eta]", 
   RowBox[{
    RowBox[{"a1", "..."}], "an"}]]]],
 " are provided, but the tensor is not evaluated unless called by the user. \
As the number of indices on these objects equals the dimension of the \
mannifold, the U/d notation cannot be used. Instead, the following global \
names are used:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t ",
 StyleBox["epsilon",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a ",
 StyleBox["function",
  FontSlant->"Italic"],
 " that takes ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " integers as arguments and returns one of { 0, 1, -1} - the sign of the \
permutation of the arguments. For example, in 5 dimensions,"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["epsilon[1,2,3,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns 1,  ",
 StyleBox["epsilon[1,3,2,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns -1, and  ",
 StyleBox["epsilon[1,2,2,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns 0."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["eta[]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " can take 0 to ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " arguments and returns the ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "-rank antisymmetric tensor with raised indices at the position(s) indicated \
by the argument(s). Thus ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " is the totally covariant antisymmetric tensor, with components"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["eta[][[a1,a2,...,an]]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], ")"}], 
   
   RowBox[{"1", "/", "2"}]]]],
 StyleBox["epsilon[a1,a2,...,an]",
  FontFamily->"Courier"],
 ", "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "while"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["eta[2,3][[a1,a2,...,an]]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], ")"}], 
    RowBox[{"1", "/", "2"}]], 
   SuperscriptBox["g", 
    RowBox[{"a2", " ", "b2"}]]}]]],
 Cell[BoxData[
  SuperscriptBox["g", 
   RowBox[{"a3", " ", "b3"}]]]],
 StyleBox["epsilon[a1,b2,b3,..,an]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Warning",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": The evaluation of ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " tensors (",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "-fold nested lists) is ",
 StyleBox["very",
  FontSlant->"Italic"],
 " time consuming in high dimensions as the number of components grows as ",
 Cell[BoxData[
  SuperscriptBox["Dim", "Dim"]]],
 ". It also requires large amounts of memory. For example, for the simple \
case of a conformally flat metric, the {Time, Storage} requirements for \
computing ",
 StyleBox["each",
  FontSlant->"Italic"],
 " ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " grow as follows: ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "{~2 sec, <1 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=6, {~35 sec, ~7 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=7, and {> 10 min, >120 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=8! Thus, calculations with ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " should not be attempted if ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 ">7. Fortunately, for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=4 the requirements are quite modest, even for complicated metrics."
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tNow that the basic tensors have been computed, one can use the functions \
defined in the following sections to perform further calculations."
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "  ",
 StyleBox["1.2  Manipulation of tensor indices & tensor products",
  FontWeight->"Bold"]
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 "\tThe ",
 StyleBox["first",
  FontSlant->"Italic"],
 " or ",
 StyleBox["last",
  FontSlant->"Italic"],
 " index of a tensor can be raised / lowered by inner (",
 StyleBox["Dot",
  FontWeight->"Bold"],
 ") multiplication with gUU / gdd:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t     ",
 StyleBox["Edd=gdd.EUd",
  FontFamily->"Courier"],
 " has components Edd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["E", "ab"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t     ",
 StyleBox["WdddU=Wdddd.gUU",
  FontFamily->"Courier"],
 " has components WdddU[[a,b,c,d]] = ",
 Cell[BoxData[
  TagBox[
   SuperscriptBox[
    SubscriptBox["W", "abc"], "d"],
   DisplayForm]]],
 ".",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tTo manipulate other indices the following functions have been defined:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["Lower[x_,ni__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: lowers the index(indices) at position(s) ",
 StyleBox["ni",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (assumed U) of the nested list ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " using the matrix  gdd."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["Raise[x_,ni__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: raises the index(indices) at position(s) ",
 StyleBox["ni",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (assumed d) of the nested list ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " using the matrix  gUU."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tFor example, the mixed Riemann tensor with  components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox[
    SubscriptBox[
     SuperscriptBox["R", "a"], "b"], "c"], "d"]]],
 "  is  ",
 StyleBox["RUdUd=Raise[RUddd,3]",
  FontFamily->"Courier"],
 ", ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "while  RUUUd",
 StyleBox["=Raise[RUddd,2,3]",
  FontFamily->"Courier"],
 "  has components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "abc"], "d"]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["Raise",
  FontWeight->"Bold"],
 " / ",
 StyleBox["Lower",
  FontWeight->"Bold"],
 " apply the rules in ",
 StyleBox["simpRules",
  FontWeight->"Bold"],
 " and factor the expressions obtained. Thus ",
 StyleBox["Raise[RUddd,4]",
  FontFamily->"Courier"],
 " is equivalent but not identical to ",
 StyleBox["RUddd.gUU",
  FontFamily->"Courier"],
 ". "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tTensor products are obtained by using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Outer",
  FontWeight->"Bold"],
 ". For example,"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["gg=Outer[Times,gdd,gdd];",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 4th rank (d-type) tensor with components ",
 StyleBox["gg[[a,b,c,d]]=",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["g", "ab"]}]],
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "cd"]],
  FontWeight->"Bold"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tUsing the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Transpose",
  FontWeight->"Bold"],
 ",  we can then define the tensor: ",
 StyleBox["gxg",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "=",
 StyleBox["gg-Transpose[gg,{1,3,2,4}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[",",
  FontVariations->{"CompatibilityType"->0}],
 " ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "which has components  ",
 StyleBox["gxg[[a,b,c,d]]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" = ",
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "ab"]],
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", 
   RowBox[{"cd", " "}]]],
  FontWeight->"Bold"],
 StyleBox["-",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["g", "ac"]}]],
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "bd"]],
  FontWeight->"Bold"],
 ".\n"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "  ",
 StyleBox["1.3  Contraction of tensor indices",
  FontWeight->"Bold"]
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 "\tThe function  ",
 StyleBox["Contract[x_,{i1_,j1_},{i2_,j2_},..]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  takes as arguments an nth rank tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", and one or more lists of  pairs of numbers, indicating the positions of \
the indices to be contracted. It returns  a tensor of rank ",
 StyleBox["n-2k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of lists. It is assumed that the two numbers in each list \
refer to one U and one d type index, in any order.  Examples (the Einstein \
summation convention holds):"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(a) ",
 StyleBox["Contract[GUdd,{1,3}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  gives a d-type vector with components ",
 Cell[BoxData[
  TagBox[
   SubsuperscriptBox["\[CapitalGamma]", "ba", "a"],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(b) ",
 StyleBox["Contract[RUddd,{1,3}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  gives Rdd."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(c) ",
 StyleBox["Contract[Outer[Times,RUddd,RUddd],{1,7},{4,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  produces a dddd tensor with components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "s"], "abt"]]],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "t"], "csd"]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Note1",
  FontSlant->"Italic"],
 ": Even though the last result can be obtained by calling ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 " twice, each time with a single pair of indices, it is ",
 StyleBox["much",
  FontSlant->"Italic"],
 " more efficient to perform multiple contractions simultaneously, as \
above.",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Note2",
  FontSlant->"Italic"],
 ": The result of (c) can also be obtained as  ",
 StyleBox["Contract[RUddd.RUddd,{1,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", since the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Dot",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " performs the ",
 StyleBox["{4,5}",
  FontFamily->"Courier"],
 " contraction of the outer product (last index of first tensor with first \
index of second tensor) giving a 6th rank tensor.",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tThe function ",
 StyleBox["multiDot[x_,y_,{i1_,j1_},{i2_,j2_},..]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is similar to ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 ", and generalizes the built-in function ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 ".  It takes as arguments ",
 StyleBox["two",
  FontSlant->"Italic"],
 " tensors - ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " - and one or more lists of  pairs of numbers.  For each pair of numbers ",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 ", it contracts the ",
 StyleBox["i",
  FontWeight->"Bold"],
 "th index of the ",
 StyleBox["first",
  FontSlant->"Italic"],
 " tensor (",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ") with the ",
 StyleBox["j",
  FontWeight->"Bold"],
 "th index of the ",
 StyleBox["second",
  FontSlant->"Italic"],
 " tensor (",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "),  returning a tensor of rank ",
 StyleBox["m+n-2k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["m",
  FontSlant->"Italic"],
 ", ",
 StyleBox["n",
  FontSlant->"Italic"],
 " are the ranks of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of index pairs. Again, it is assumed that the indices at ",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 " are of opposite (U/d) types. Using ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 ", the result of example (c) above can also be obtained as  ",
 StyleBox["multiDot[RUddd,RUddd,{1,3},{4,1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".",
 Cell[BoxData[
  FormBox["", TextForm]], ""],
 Cell[BoxData[
  FormBox["", TextForm]], ""]
}], "Text",
 FontSize->16],

Cell[TextData[{
 StyleBox["\tNote:",
  FontSlant->"Italic"],
 " When contracting a product of two tensors, as in example (c), one should \
always use ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 " to perform the contractions, thus avoiding the outer product calculation, \
which is very time / memory consuming. See also Example 1a in Section 3 and \
Example 4b in Section 5.1",
 Cell[BoxData[
  FormBox["", TextForm]], 
  "\.02\[YAcute]\t\[OSlash]\.03\.08\[CapitalCCedilla]`\.03\.08\
\[CapitalCCedilla]`"]
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "  ",
 StyleBox["1.4  Covariant differentiation of tensors",
  FontWeight->"Bold"]
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 "\t The function  ",
 StyleBox["covD[x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  takes two arguments -- an nth rank tensor, ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", and a list of numbers indicating the positions of the ",
 StyleBox["contravariant",
  FontSlant->"Italic"],
 "  (U) components of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " -- and produces an ",
 StyleBox["n+1",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 " rank tensor: the covariant derivative of ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". ",
 StyleBox["The last index is the differentiation index (d type)",
  FontSlant->"Italic"],
 ". If ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " has only d-type components, the second argument (empty list) can be \
omitted. Examples:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covD[Rdd]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (ddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox["R", 
     RowBox[{"ab", ";", "c"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covD[RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 5th rank (Udddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["R", "a"], 
     RowBox[{"bcd", ";", "e"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe function ",
 StyleBox["covDiv[x_,{i___,{s_}}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " acting on an nth rank tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with contravariant indices at positions {i..., s} returns an ",
 StyleBox["n-1",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 " rank tensor: the covariant ",
 StyleBox["divergence",
  FontSlant->"Italic"],
 " of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with respect to the contravariant index at position ",
 StyleBox["s",
  FontSlant->"Italic"],
 ". If there is only one contravariant index, the second argument can be \
written simply {s} rather than {{s}}. Examples (the Einstein summation \
convention holds):"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covDiv[RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (ddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["R", "s"], 
     RowBox[{"abc", ";", "s"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covDiv[RUdUd,{1,{3}}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (Udd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox[
      SubscriptBox[
       SuperscriptBox["R", "a"], "b"], "s"], 
     RowBox[{"c", ";", "s"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note1",
  FontSlant->"Italic"],
 ": It is ",
 StyleBox["much",
  FontSlant->"Italic"],
 " more efficient to use ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  than ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  followed by ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note2",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  can be very slow on high-rank tensors in high dimensions. However, they \
remember their values, so calling them again with the same arguments takes no \
time. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tUsing ",
 StyleBox["covD",
  FontFamily->"Courier"],
 " and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 ",  the function ",
 StyleBox["Bianchi[n_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", for n = 0, 1, 2, computes the full, once, twice contracted Bianchi \
identities and returns a list containing any non-vanishing terms. This list \
is normally the empty list, except when the simplification rules used imply \
relations among the 3rd derivatives of the metric functions (see Example 5). \
"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tEvaluation of the Bianchi Identities takes long: for the metrics in the \
examples, the time needed to evaluate ",
 StyleBox["Bianchi[1]",
  FontFamily->"Courier"],
 " is ~ 1 - 15 times the time taken by ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " to compute all basic tensors. ",
 StyleBox["Bianchi[0]",
  FontFamily->"Courier"],
 " takes considerably longer. (For the Bondi metric the times are ~ 22 min, \
11 min, 20 sec). "
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "  ",
 StyleBox["1.5  ",
  FontWeight->"Bold"],
 "Index of global names / variables"
}], "Subsubsection",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(i) ",
 StyleBox["Riemannian Geometry tensors / scalars",
  FontSlant->"Italic"],
 " "
}], "Subsubsection",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["gdd, gUU, GUdd, Rdddd, RUddd, Rdd, EUd, R, Wdddd, detg",
  FontWeight->"Bold"],
 "  \t(section 1.1)\n\t",
 StyleBox["epsilon, eta\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 1.1.1)\n\t",
 StyleBox["\[Omega]Ud \t\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 5.1)\n\t",
 StyleBox["PS[i], PH[i, j]\t,",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[CapitalLambda]\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 5.1.2)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(ii) ",
 StyleBox["Tensor operations / functions",
  FontSlant->"Italic"]
}], "Subsubsection",
 FontSize->16],

Cell[TextData[{
 " \t",
 StyleBox["RGtensors\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 1.1, 5.1, 5.2)\n\t",
 StyleBox["Raise, Lower, Outer, Transpose",
  FontWeight->"Bold"],
 "\t\t\t\t\t(section 1.2) \n\t",
 StyleBox["Contract, Dot, multiDot",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t(section 1.3) \n\t",
 StyleBox["covD, covDiv, Bianchi",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t(section 1.4)\n\t",
 StyleBox["HStar",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t\t(section 5.1.1)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(iii) ",
 StyleBox["Other global variables",
  FontSlant->"Italic"]
}], "Subsubsection",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["simpRules, Dim, coordList",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t(section 1.1, 4.3)\n\t",
 StyleBox["e[], d[]",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t\t(section 5.1)\n\t",
 StyleBox["deList, dxRuleList",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t(section 5.2)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(iv) ",
 StyleBox["Auxiliary functions",
  FontSlant->"Italic"]
}], "Subsubsection",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["zeroQ, nonZeroN, nonZeroL, indepTerms, FacSimp",
  FontWeight->"Bold"],
 "\t\t(section 4.2)\n\t",
 StyleBox["FuncRepRules\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 4.4)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(v) ",
 StyleBox["Functions / variables in  ",
  FontSlant->"Italic"],
 StyleBox["matrixEDCcode.nb",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Subsubsection",
 FontSize->16],

Cell[TextData[{
 "  \te.g., ",
 StyleBox["Wedge",
  FontWeight->"Bold"],
 ", ",
 StyleBox["d[]",
  FontWeight->"Bold"],
 ", ",
 StyleBox["DeclareForms",
  FontWeight->"Bold"],
 ", etc.\t\t\t\t\t see ",
 ButtonBox["EDC_Manual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/\
ExteriorDifferentialCalculus.html"], None}]
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Important Note:",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "As the behavior of ",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 " depends on the values of global variables like ",
 StyleBox["simpRules, deList, dxRuleList,",
  FontWeight->"Bold"],
 " one should normally restart the kernel to do calculations with a new \
metric."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 StyleBox["\t",
  FontSize->14],
 StyleBox["The executable cells in this notebook must be evaluated ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["in the order they appear",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[". However, read the instructions in section 5 before evaluating \
sections 5 or 6.",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[TextData[StyleBox["",
 FontSize->14]], "Text",
 FontSize->10,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 2  RG&TC-Code",
 FontWeight->"Bold"]], "Section",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TrigRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]_", "]"}], "2"]}]}], "->", "x"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x_.", 
        SuperscriptBox[
         RowBox[{"Cot", "[", "\[Theta]_", "]"}], "2"]}], "+", 
       RowBox[{"y_.", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]_", "]"}], "2"]}]}], ":>", 
      RowBox[{"y", "/;", 
       RowBox[{
        RowBox[{"x", "+", "y"}], "===", "0"}]}]}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FaSi", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FaSi", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"FaSi", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FacSimp", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "0", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Equal", "]"}], ":=", 
   RowBox[{"Equal", "[", 
    RowBox[{
     RowBox[{"FacSimp", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", 
       RowBox[{"x", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ",", "0"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_Rule", "]"}], ":=", 
   RowBox[{"Rule", "[", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"FacSimp", "[", "x_SeriesData", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "->", 
     RowBox[{"FacSimp", "[", 
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"coll", "[", "x", "]"}], "/.", "simpRules"}], ",", 
        "FormVars", ",", "Factor"}], "]"}], "/.", "simpRules"}], ")"}], "/;", 
    
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FacSimp", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Factor", "[", 
     RowBox[{"x", "/.", "simpRules"}], "]"}], "/.", "simpRules"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroQ", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Normal", "[", "x", "]"}]}], "}"}], "]"}], "]"}], "===", 
    RowBox[{"{", "0", "}"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroL", "[", "x_", "]"}], ":=", 
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Union", "[", 
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonZeroN", "[", "x_", "]"}], ":=", 
  RowBox[{"Length", "[", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"Normal", "[", "x", "]"}], "}"}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "=!=", "0"}], "&"}]}], "]"}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"indepTerms", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"redPlus", "[", 
    RowBox[{"redTimes", "[", 
     RowBox[{
      RowBox[{"nonZeroL", "[", "x", "]"}], ",", "opt"}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"redTimes", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"opt_:", 
     RowBox[{"{", "}"}]}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tmp$", " ", "=", " ", 
       RowBox[{"Select", "[", 
        RowBox[{"x", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "#1", "]"}], " ", "===", " ", "Times"}], " ", 
          "&"}]}], "]"}]}], ",", " ", "rst$"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"rst$", " ", "=", " ", 
      RowBox[{"Complement", "[", 
       RowBox[{"x", ",", " ", "tmp$"}], "]"}]}], ";", " ", 
     RowBox[{"Union", "[", 
      RowBox[{"rst$", ",", " ", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"numb2", "[", 
           RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", "tmp$"}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"NumericQ", "[", "x", "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{
     RowBox[{"x_", "^", "y_."}], ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"1", "/;", 
    RowBox[{"MemberQ", "[", 
     RowBox[{"opt", ",", "x"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"numb1", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", "x"}], ";", 
  RowBox[{
   RowBox[{"numb2", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"opt_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Times", "@@", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"numb1", "[", 
        RowBox[{"#", ",", "opt"}], "]"}], "&"}], ",", 
      RowBox[{"Level", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"redPlus", "[", "x_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"x", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "#", "]"}], "===", "Plus"}], "&"}]}], 
         "]"}]}], ",", "rst$", ",", "i$", ",", "negi$"}], "}"}], ",", 
     RowBox[{
      RowBox[{"rst$", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{"x", ",", "tmp$"}], "]"}]}], ";", 
      RowBox[{"i$", "=", "1"}], ";", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"i$", "<", 
         RowBox[{"Length", "[", "tmp$", "]"}]}], ",", 
        RowBox[{
         RowBox[{"negi$", "=", 
          RowBox[{"Select", "[", 
           RowBox[{"tmp$", ",", 
            RowBox[{
             RowBox[{"#", "===", 
              RowBox[{"-", 
               RowBox[{"tmp$", "[", 
                RowBox[{"[", "i$", "]"}], "]"}]}]}], "&"}]}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"negi$", "=!=", 
            RowBox[{"{", "}"}]}], ",", 
           RowBox[{"tmp$", "=", 
            RowBox[{"Complement", "[", 
             RowBox[{"tmp$", ",", "negi$"}], "]"}]}]}], "]"}], ";", 
         RowBox[{"i$", "=", 
          RowBox[{"i$", "+", "1"}]}]}]}], "]"}], ";", 
      RowBox[{"Union", "[", 
       RowBox[{"tmp$", ",", "rst$"}], "]"}]}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RiemSym", "[", "h_", "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "a_", ",", "c_", ",", "d_"}], "]"}], "=", "0"}], 
     ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}], 
     ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"b", ",", "a", ",", "c", ",", "d"}], "]"}]}], "/;", 
       RowBox[{"a", ">", "b"}]}]}], ";", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"h", "[", 
         RowBox[{"a", ",", "b", ",", "d", ",", "c"}], "]"}]}], "/;", 
       RowBox[{"c", ">", "d"}]}]}], ";", "\n", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"c", ",", "d", ",", "a", ",", "b"}], "]"}], "/;", 
       RowBox[{
        RowBox[{"a", ">", "c"}], "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", "===", "c"}], "&&", 
          RowBox[{"b", ">", "d"}]}], ")"}]}]}]}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"epsilon", "[", "a__", "]"}], ":=", 
   RowBox[{"Signature", "[", 
    RowBox[{"{", "a", "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"zeroTensor", "[", "rnk_", "]"}], ":=", 
   RowBox[{"Fold", "[", 
    RowBox[{"Table", ",", "0", ",", 
     RowBox[{"List", "/@", 
      RowBox[{"Table", "[", 
       RowBox[{"Dim", ",", 
        RowBox[{"{", "rnk", "}"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"f_", "[", "y__", "]"}], ",", "g_", ",", 
    RowBox[{"ord_:", "2"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"FuncRepRules", "[", 
    RowBox[{
     RowBox[{"f", "[", "y", "]"}], ",", "g", ",", "ord"}], "]"}], "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmp$", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "y", "]"}], "->", "g"}], "}"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"indexList", "[", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"{", "y", "}"}], "]"}], ",", "ord"}], "]"}]}]}], "}"}], 
     ",", "\n", "       ", 
     RowBox[{
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Derivative", "[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"indL", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "[", "f", "]"}], "[",
             "y", "]"}], " ", "->", " ", "\n", "            ", 
           RowBox[{"Expand", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"D", "[", 
              RowBox[{"g", ",", 
               RowBox[{"Sequence", "@@", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", "y", "}"}], ",", 
                   RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}]}]}], "]"}],
              "]"}], "]"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "indL", "]"}]}], "}"}]}], "]"}], ";", 
      "tmp$"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"indexList", "[", 
   RowBox[{"varNo_", ",", "ord_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"tmp$", ",", "indL"}], "}"}], ",", 
    RowBox[{
     RowBox[{"tmp$", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{"RotateRight", ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"varNo", "-", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"varNo", "-", "1"}]}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ord", ">", "1"}], ",", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"indL", "=", "tmp$"}], ";", 
          RowBox[{"Do", "[", 
           RowBox[{
            RowBox[{"tmp$", "=", 
             RowBox[{"Join", "[", 
              RowBox[{"tmp$", ",", 
               RowBox[{"Map", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Plus", "[", 
                   RowBox[{
                    RowBox[{"indL", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "#"}], "]"}], "&"}], 
                 ",", "indL"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "varNo"}], "}"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ord", "-", "1"}], "}"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"Union", "[", "tmp$", "]"}]}]}], "]"}]}]], "Input"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"MatrixForm", "[", "x", "]"}], "/;", 
    RowBox[{"Dim", "<", "10"}]}]}], ";", 
  RowBox[{
   RowBox[{"MF", "[", "x_", "]"}], ":=", "x"}], ";", 
  RowBox[{"DeclareForms", "[", 
   RowBox[{"1", ",", 
    RowBox[{"e", "[", "_", "]"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"stPrint", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"y_", ":", "Null"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"y", "===", "Null"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "20"}], ",", 
        RowBox[{"FontWeight", "\[Rule]", "\"\<Bold\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"Style", "[", 
       RowBox[{"x", ",", 
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontSlant", "\[Rule]", "\"\<Italic\>\""}], ",", 
        RowBox[{"FontColor", "\[Rule]", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"1", ",", "0", ",", "1"}], "]"}]}]}], "]"}], "]"}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"timePrint", "[", 
    RowBox[{"x_", ",", "sT_"}], "]"}], ":=", 
   RowBox[{"Print", "[", 
    RowBox[{
     RowBox[{"x", "<>", "\"\< computed in \>\""}], ",", 
     RowBox[{
      RowBox[{"TimeUsed", "[", "]"}], "-", "sT"}], ",", "\"\< sec\>\""}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"myCoef$", ",", 
    RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_SeriesData", ",", "y__"}], "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "->", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"#", ",", "y"}], "]"}], "&"}], ",", 
        RowBox[{"x", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ")"}]}]}], ";", 
  RowBox[{
   RowBox[{"myCoef$", "[", 
    RowBox[{"x_", ",", "y__"}], "]"}], ":=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{"gIN_", ",", "xIN_", ",", "opt___"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"frameOpt", "=", "0"}], ",", "eIN", ",", 
       RowBox[{"Ropt", "=", "True"}], ",", 
       RowBox[{"Wopt", "=", "True"}], ",", "idMat", ",", "eFrame", ",", 
       "dxRul", ",", "Bmat", ",", "Amat", ",", 
       RowBox[{"NP$", "=", "False"}], ",", "de", ",", "a", ",", "b", ",", "c",
        ",", "id", ",", "k", ",", "StrCon", ",", "\[Gamma]Udd", ",", 
       "\[Gamma]ddd", ",", "gddd", ",", "Gamddd", ",", "rmn", ",", "tmp", ",",
        "RUd", ",", "Rg", ",", "gg", ",", "sT", ",", "Cflat", ",", "EinSp"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{"Clear", "[", 
       RowBox[{
       "GUdd", ",", "\[Omega]Ud", ",", "RUddd", ",", "Rdd", ",", "EUd", ",", 
        "R", ",", "Wdddd", ",", "detg", ",", "rtAbsdetg", ",", "eta", ",", 
        "HStar", ",", "PS", ",", "PH"}], "]"}], ";", "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Transpose", "[", "gIN", "]"}], "=!=", "gIN"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"MatrixForm", "[", "gIN", "]"}], ",", 
           "\"\< is not a symmetric matrix\>\""}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", " ", 
      RowBox[{"Dim", "=", 
       RowBox[{"Length", "[", "xIN", "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Dim", "=!=", 
         RowBox[{"Length", "[", "gIN", "]"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{
          "\"\<Metric and coordinate dimensions don't match\>\"", ",", "1"}], 
          "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"gIN", "===", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"NP$", "=", "True"}]}], "]"}], ";", 
      RowBox[{"eFrame", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"e", ",", 
         RowBox[{"{", "Dim", "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"frameOpt", "=", 
         RowBox[{"0", " ", "=", 
          RowBox[{">", " ", "coordFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"1", " ", "=", 
          RowBox[{">", " ", "explicitFrame"}]}]}], ",", " ", 
        RowBox[{"frameOpt", "=", 
         RowBox[{"2", " ", "=", 
          RowBox[{">", " ", "implicitFrame"}]}]}]}], " ", "*)"}], "\n", 
      "\t\t", "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"{", "opt", "}"}], "]"}], ">", "0"}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", "opt", "}"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "e"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", "dxRuleList", "]"}], "===", "List"}], "&&", 
              RowBox[{
               RowBox[{"Head", "[", "deList", "]"}], "===", "List"}]}], ",", 
             RowBox[{
              RowBox[{"frameOpt", "=", "2"}], ";", 
              RowBox[{"eIN", "=", "eFrame"}]}], ",", 
             RowBox[{
              RowBox[{"stPrint", "[", 
               RowBox[{
               "\"\<dxRuleList and/or deList have not been defined!\>\"", ",",
                 "1"}], "]"}], ";", 
              RowBox[{"Return", "[", "]"}]}]}], "]"}]}], "]"}], ";", "\n", 
         "\t", 
         RowBox[{"Which", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"!", 
             RowBox[{"IntegerQ", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", "opt", "}"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&&", 
            RowBox[{
             RowBox[{"d", "[", "0", "]"}], "=!=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<matrixEDCcode.nb must be evaluated before section 2 \
RG&TC-Code!\>\"", ",", "1"}], "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "2"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{
               RowBox[{"{", "opt", "}"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"frameOpt", "=!=", "2"}], ",", 
              RowBox[{
               RowBox[{"eIN", "=", 
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ";", 
               RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"{", "opt", "}"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{"IntegerQ", "[", 
             RowBox[{"opt", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Ropt", "=", "False"}]}], "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"opt", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "===", "0"}], ",", 
              RowBox[{"Wopt", "=", "False"}]}], "]"}]}], ",", "\n", "\t", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"{", "opt", "}"}], "]"}], "===", "1"}], "&&", 
            RowBox[{
             RowBox[{"FormDegree", "[", 
              RowBox[{"opt", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "===", "1"}]}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"frameOpt", "=!=", "2"}], ",", 
             RowBox[{
              RowBox[{"eIN", "=", "opt"}], ";", 
              RowBox[{"frameOpt", "=", "1"}]}]}], "]"}], ",", "\n", "\t", 
           "True", ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<Wrong optional arguments!\>\"", ",", "1"}], "]"}], 
            ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"FreeQ", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"gIN", ",", "eIN", ",", 
             RowBox[{"{", "deList", "}"}]}], "}"}], ",", "SeriesData"}], 
          "]"}]}], ",", "\n", "\t", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{"gIN", ",", "eIN", ",", 
                 RowBox[{"{", "deList", "}"}]}], "}"}], "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "SeriesData"}], 
               "&"}]}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"xIN", ",", "tmp"}], "]"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"de", "[", "1", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<d\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{
             RowBox[{"de", "[", "2", "]"}], "=", 
             RowBox[{"ToExpression", "[", 
              RowBox[{"\"\<\[ScriptD]\>\"", "<>", 
               RowBox[{"ToString", "[", "tmp", "]"}]}], "]"}]}], ";", 
            RowBox[{"DeclareForms", "[", 
             RowBox[{"1", ",", 
              RowBox[{"\[ScriptD]", "[", "_", "]"}], ",", 
              RowBox[{"de", "[", "1", "]"}], ",", 
              RowBox[{"de", "[", "2", "]"}]}], "]"}], ";", 
            RowBox[{
             RowBox[{"d", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "1", "]"}]}], ";", 
            RowBox[{
             RowBox[{"\[ScriptD]", "[", "tmp", "]"}], "=", 
             RowBox[{"de", "[", "2", "]"}]}], ";", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"de", "[", "1", "]"}], "]"}], "=", "0"}]}], ",", 
           RowBox[{
            RowBox[{"d", "[", "tmp", "]"}], "=", "0"}]}], "]"}]}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "1"}], ",", 
        RowBox[{
         RowBox[{"DeclareForms", "[", 
          RowBox[{"1", ",", 
           RowBox[{"\[ScriptD]", "[", "_", "]"}]}], "]"}], ";", 
         RowBox[{"origFRin$", "=", 
          RowBox[{"eIN", "/.", 
           RowBox[{"MapThread", "[", 
            RowBox[{"Rule", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"d", "/@", "xIN"}], ",", 
               RowBox[{"\[ScriptD]", "/@", "xIN"}]}], "}"}]}], "]"}]}]}], ";", 
         RowBox[{"eTO$dx", "=", 
          RowBox[{"MapThread", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"e", "/@", 
               RowBox[{"Range", "[", "Dim", "]"}]}], ",", "origFRin$"}], 
             "}"}]}], "]"}]}]}]}], "]"}], ";", "\n", "\t\t\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"frameOpt", ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Union", "[", 
             RowBox[{"FormDegree", "/@", "eIN"}], "]"}], "=!=", 
            RowBox[{"{", "1", "}"}]}], "||", 
           RowBox[{
            RowBox[{"Length", "[", "eIN", "]"}], "=!=", "Dim"}], "||", 
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"eIN", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"e", "[", "_", "]"}], "->", "0"}], ",", 
                RowBox[{
                 RowBox[{"y_", "|", 
                  RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
                 RowBox[{"0", "/;", 
                  RowBox[{"MemberQ", "[", 
                   RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}],
              "]"}]}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", 
          RowBox[{"\"\<coframe has incorrect form\>\"", ",", "1"}], "]"}], 
         ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\t", "\n", "\t\t", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "Rule"}], "||", 
         RowBox[{
          RowBox[{"Head", "[", "simpRules", "]"}], "===", "RuleDelayed"}]}], 
        ",", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "simpRules", "}"}]}]}], "]"}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "simpRules", "]"}], "=!=", "List"}], ",", " ", 
        RowBox[{"simpRules", "=", 
         RowBox[{"{", "}"}]}]}], "]"}], ";", 
      RowBox[{"idMat", "=", 
       RowBox[{"IdentityMatrix", "[", "Dim", "]"}]}], ";", "\n", "\n", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Amat", "=", "idMat"}], ";", 
         RowBox[{"Bmat", "=", "idMat"}], ";", 
         RowBox[{"eIN", "=", 
          RowBox[{"d", "/@", "xIN"}]}], ";", 
         RowBox[{"dxRul", "=", 
          RowBox[{"{", "}"}]}]}], ",", "\n", 
        RowBox[{
         RowBox[{"frameOpt", "===", "1"}], "&&", 
         RowBox[{"zeroQ", "[", 
          RowBox[{"eIN", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"d", "[", "k_", "]"}], "->", "0"}], ",", 
             RowBox[{
              RowBox[{"y_", "|", 
               RowBox[{"Bar", "[", "y_", "]"}]}], ":>", 
              RowBox[{"0", "/;", 
               RowBox[{"MemberQ", "[", 
                RowBox[{"DifFormSymbols", ",", "y"}], "]"}]}]}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{"Bmat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"eIN", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"d", "[", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "b", "]"}], "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Det", "[", "Bmat", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"sT", "=", 
             RowBox[{"TimeUsed", "[", "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"ByteCount", "[", "eIN", "]"}], ">", 
               RowBox[{"1500", "*", "Dim"}]}], ",", 
              RowBox[{"stPrint", "[", 
               RowBox[{"\"\<Computing d[coframe]...\>\"", ",", "1"}], "]"}]}],
              "]"}], ";", 
            RowBox[{"Amat", "=", 
             RowBox[{"FaSi", "[", 
              RowBox[{"Inverse", "[", "Bmat", "]"}], "]"}]}], ";", 
            RowBox[{"dxRul", "=", 
             RowBox[{"MapThread", "[", 
              RowBox[{"Rule", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"d", "[", "xIN", "]"}], ",", 
                 RowBox[{"Amat", ".", "eFrame"}]}], "}"}]}], "]"}]}], ";", 
            RowBox[{"de", "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"FreeQ", "[", 
                RowBox[{"eIN", ",", "SeriesData"}], "]"}], ",", 
               RowBox[{"FacSimp", "[", 
                RowBox[{
                 RowBox[{"d", "[", "eIN", "]"}], "/.", "dxRul"}], "]"}], ",", 
               
               RowBox[{"FacSimp", "[", 
                RowBox[{"Wedge", "[", 
                 RowBox[{
                  RowBox[{"FacSimp", "[", 
                   RowBox[{
                    RowBox[{"FacSimp", "[", 
                    RowBox[{"d", "[", "Bmat", "]"}], "]"}], "/.", "dxRul"}], 
                   "]"}], ",", 
                  RowBox[{
                   RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], "]"}], 
                "]"}]}], "]"}]}], ";", 
            RowBox[{"timePrint", "[", 
             RowBox[{"\"\<d[coframe]\>\"", ",", "sT"}], "]"}], ";", 
            RowBox[{"tmp", "=", 
             RowBox[{
              RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
            RowBox[{"MapThread", "[", 
             RowBox[{"Set", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], 
             "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{"\"\<coframe does not span space!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Return", "[", "]"}]}]}], "]"}]}], ",", "\n", 
        RowBox[{"frameOpt", "===", "2"}], ",", 
        RowBox[{
         RowBox[{"de", "=", "deList"}], ";", 
         RowBox[{"dxRul", "=", "dxRuleList"}], ";", 
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"d", "[", "xIN", "]"}], "/.", "dxRul"}]}], ";", 
         RowBox[{"MapThread", "[", 
          RowBox[{"Set", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"d", "[", "xIN", "]"}], ",", "tmp"}], "}"}]}], "]"}], 
         ";", 
         RowBox[{"Amat", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"myCoef$", "[", 
             RowBox[{
              RowBox[{"tmp", "[", 
               RowBox[{"[", "a", "]"}], "]"}], ",", 
              RowBox[{"eIN", "[", 
               RowBox[{"[", "b", "]"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "Dim"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
      "\n", "\t\t", "\n", 
      RowBox[{"k", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "x_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "x_Symbol"}], ")"}], "b_."]}], "->", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["x", "2"]}], ")"}], "b"]}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "-", "y_Symbol"}], ")"}], "b_."], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x_Symbol", "+", "y_Symbol"}], ")"}], "b_."]}], 
          "\[Rule]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "-", 
             SuperscriptBox["y", "2"]}], ")"}], "b"]}]}], "}"}]}], ";", 
      RowBox[{"gdd", "=", "gIN"}], ";", 
      RowBox[{"coordList", "=", "xIN"}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gdd = \>\"", ",", 
        RowBox[{"MF", "[", "gdd", "]"}]}], "]"}], ";", 
      RowBox[{"tmp", "=", 
       RowBox[{"eIN", ".", "gIN", ".", "eIN"}]}], ";", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = \>\"", ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "tmp", "]"}], "===", "SeriesData"}], ",", 
           RowBox[{"FacSimp", "[", "tmp", "]"}], ",", 
           RowBox[{"Collect", "[", 
            RowBox[{
             RowBox[{"Expand", "[", "tmp", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"d", "[", "a_", "]"}], 
                RowBox[{"d", "[", "b_", "]"}]}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], "^", "2"}], ",", 
               RowBox[{
                RowBox[{"e", "[", "a_", "]"}], 
                RowBox[{"e", "[", "b_", "]"}]}]}], "}"}], ",", "Factor"}], 
            "]"}]}], "]"}], "//.", "k"}]}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"gUU", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Inverse", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      
      RowBox[{"detg", "=", 
       RowBox[{
        RowBox[{"FixedPoint", "[", 
         RowBox[{"FaSi", ",", 
          RowBox[{"Det", "[", "gIN", "]"}]}], "]"}], "//.", "k"}]}], ";", 
      "\n", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<gUU = \>\"", ",", 
        RowBox[{"MF", "[", "gUU", "]"}]}], "]"}], ";", 
      RowBox[{"Clear", "[", "k", "]"}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<gUU\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"rtAbsdetg", "=", 
       RowBox[{"PowerExpand", "[", 
        RowBox[{"Power", "[", 
         RowBox[{
          RowBox[{"Factor", "[", 
           RowBox[{"detg", "^", "2"}], "]"}], ",", 
          RowBox[{"1", "/", "4"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"SetAttributes", "[", 
       RowBox[{"HStar", ",", 
        RowBox[{"{", "Listable", "}"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", 
        RowBox[{"rtAbsdetg", "=", "I"}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_SeriesData", "]"}], ":=", 
       RowBox[{"x", "/.", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "->", 
         RowBox[{"HStar", "/@", 
          RowBox[{"x", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}]}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Plus", "]"}], ":=", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Plus", "@@", 
         RowBox[{"HStar", "/@", "x"}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_", "*", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"HStar", "[", "y", "]"}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Wedge", "@@", 
          RowBox[{"e", "/@", 
           RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "/;", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", "x_Wedge", "]"}], ":=", 
       RowBox[{
        RowBox[{"rtAbsdetg", "/", "detg"}], "/;", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], "===", "Dim"}]}]}], ";", 
      RowBox[{
       RowBox[{"HStar", "[", 
        RowBox[{"x_Wedge", "|", "x_e"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"HStar", "[", "x", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"FacSimp", "[", 
          RowBox[{"inn", "[", 
           RowBox[{"x", ",", 
            RowBox[{"Wedge", "@@", 
             RowBox[{"e", "/@", 
              RowBox[{"Range", "[", "Dim", "]"}]}]}]}], "]"}], "]"}]}]}]}], 
      ";", "\t\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "]"}], "=", 
        RowBox[{"rtAbsdetg", " ", 
         RowBox[{"Array", "[", 
          RowBox[{"epsilon", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", "Dim", "}"}]}], "]"}]}], "]"}]}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"eta", "[", "a__", "]"}], ":=", 
       RowBox[{
        RowBox[{"eta", "[", "a", "]"}], "=", 
        RowBox[{"Raise", "[", 
         RowBox[{
          RowBox[{"eta", "[", "]"}], ",", "a"}], "]"}]}]}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"e", "[", "a_", "]"}], "]"}], ":=", 
          RowBox[{"de", "[", 
           RowBox[{"[", "a", "]"}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "a_"}], "]"}], "=", "0"}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"StrCon", "[", 
             RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"StrCon", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{"-", 
           RowBox[{"myCoef$", "[", 
            RowBox[{
             RowBox[{"de", "[", 
              RowBox[{"[", "c", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"e", "[", "a", "]"}], "\[Wedge]", 
              RowBox[{"e", "[", "b", "]"}]}]}], "]"}]}]}], ";", "\n", 
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"StrCon", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", 
          RowBox[{"gdd", ".", "\[Gamma]Udd"}]}]}], ",", 
        RowBox[{
         RowBox[{"\[Gamma]Udd", "=", 
          RowBox[{"zeroTensor", "[", "3", "]"}]}], ";", 
         RowBox[{"\[Gamma]ddd", "=", "\[Gamma]Udd"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"(*", 
       RowBox[{"*", " ", "Tests"}], " ", "**)"}], 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{
         RowBox[{"tmp", "=", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "[", "gdd", "]"}], "/.", "dxRul"}], ")"}], "/.", 
           RowBox[{
            RowBox[{"e", "[", "_", "]"}], "->", "0"}]}]}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"!", 
            RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", 
             RowBox[{
             "\"\<Warning: d[] on some symbols not defined!\>\"", ",", "1"}], 
             "]"}], ";", 
            RowBox[{"Print", "[", 
             RowBox[{"indepTerms", "[", 
              RowBox[{"FacSimp", "[", "tmp", "]"}], "]"}], "]"}]}]}], "]"}], 
         ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"frameOpt", "===", "2"}], "&&", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"ByteCount", "[", "deList", "]"}], "+", 
                RowBox[{"ByteCount", "[", "dxRuleList", "]"}]}], ")"}], "/", 
              "Dim"}], "<", "6000"}]}], ",", 
           RowBox[{
            RowBox[{"tmp", "=", 
             RowBox[{"FacSimp", "[", 
              RowBox[{"d", "[", "deList", "]"}], "]"}]}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"zeroQ", "[", "tmp", "]"}]}], ",", 
              RowBox[{
               RowBox[{"stPrint", "[", 
                RowBox[{
                "\"\<Warning: deList not closed! d[deList]=\>\"", ",", "1"}], 
                "]"}], ";", 
               RowBox[{"Print", "[", "tmp", "]"}], ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"!", 
                  RowBox[{"zeroQ", "[", 
                   RowBox[{"tmp", "/.", 
                    RowBox[{
                    RowBox[{"d", "[", "_", "]"}], "->", "0"}]}], "]"}]}], ",", 
                 RowBox[{"Return", "[", "]"}]}], "]"}]}]}], "]"}]}]}], 
          "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "pD", "]"}], ";", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"pD", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Amat", "===", "idMat"}], ",", 
          RowBox[{"D", "[", 
           RowBox[{"x", ",", 
            RowBox[{"coordList", "[", 
             RowBox[{"[", "y", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "y"}], "]"}], "]"}], "*", 
             RowBox[{"D", "[", 
              RowBox[{"x", ",", 
               RowBox[{"coordList", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}]}], "]"}]}]}], ";", 
      "\t", "\n", "\t\t", "\n", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"gddd", "[", 
        RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"gddd", "[", 
         RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "c"}], "]"}], "]"}], ",", "b"}], "]"}], "+", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"b", ",", "c"}], "]"}], "]"}], ",", "a"}], "]"}], "-", 
            RowBox[{"pD", "[", 
             RowBox[{
              RowBox[{"gdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "b"}], "]"}], "]"}], ",", "c"}], "]"}]}], 
           ")"}], "/", "2"}], "]"}]}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", "===", "0"}], ",", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"gddd", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", 
         RowBox[{"Clear", "[", "tmp", "]"}], ";", 
         RowBox[{"k", "=", 
          RowBox[{"gUU", ".", "Gamddd"}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "b", ",", "a"}], "]"}], "/;", 
           RowBox[{"a", ">", "b"}]}]}], ";", 
         RowBox[{
          RowBox[{"tmp", "[", 
           RowBox[{"c_", ",", "a_", ",", "b_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"tmp", "[", 
            RowBox[{"c", ",", "a", ",", "b"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"k", "[", 
             RowBox[{"[", 
              RowBox[{"c", ",", "a", ",", "b"}], "]"}], "]"}], "]"}]}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}]}]}], ",",
         "\n", 
        RowBox[{
         RowBox[{"Gamddd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{
            RowBox[{"Array", "[", 
             RowBox[{"gddd", ",", 
              RowBox[{"{", 
               RowBox[{"Dim", ",", "Dim", ",", "Dim"}], "}"}]}], "]"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Gamma]ddd", "+", 
               RowBox[{"Transpose", "[", "\[Gamma]ddd", "]"}], "-", 
               RowBox[{"Transpose", "[", 
                RowBox[{"\[Gamma]ddd", ",", 
                 RowBox[{"{", 
                  RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], "]"}]}], ")"}], 
             "/", "2"}]}], "]"}]}], ";", 
         RowBox[{"GUdd", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Union", "[", 
               RowBox[{"NumericQ", "/@", 
                RowBox[{"Flatten", "[", "gUU", "]"}]}], "]"}], "===", 
              RowBox[{"{", "True", "}"}]}], "&&", 
             RowBox[{
              RowBox[{"nonZeroN", "[", "gUU", "]"}], "===", "Dim"}]}], ",", 
            RowBox[{"gUU", ".", "Gamddd"}], ",", 
            RowBox[{"FaSi", "[", 
             RowBox[{"gUU", ".", "Gamddd"}], "]"}]}], "]"}]}]}]}], "]"}], ";",
       "\n", "\t\t", "\n", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Gamma\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"frameOpt", ">", "0"}], ",", 
        RowBox[{"\[Omega]Ud", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], 
              RowBox[{"e", "[", "k", "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"a", ",", "Dim"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"b", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\t\t", "\n", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", 
      RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
      RowBox[{
       RowBox[{"rmn", "[", 
        RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"rmn", "[", 
         RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "id", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Amat", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id"}], "]"}], "]"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"Gamddd", "[", 
                RowBox[{"[", 
                 RowBox[{"a", ",", "c", ",", "b"}], "]"}], "]"}], ",", 
               RowBox[{"xIN", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "id", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "a"}], "]"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"Gamddd", "[", 
              RowBox[{"[", 
               RowBox[{"a", ",", "k", ",", "b"}], "]"}], "]"}], "*", 
             RowBox[{"\[Gamma]Udd", "[", 
              RowBox[{"[", 
               RowBox[{"k", ",", "c", ",", "id"}], "]"}], "]"}]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdddd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"rmn", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
        "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Riemann(dddd)\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdddd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Flat Space!\>\"", "]"}], ";", 
         RowBox[{"Clear", "[", 
          RowBox[{"Rdd", ",", "EUd", ",", "R", ",", "Wdddd"}], "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"Rg", "=", 
       RowBox[{"gUU", ".", "Rdddd"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{"Ropt", ",", 
        RowBox[{
         RowBox[{"Clear", "[", "rmn", "]"}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "c_"}], "]"}], "=", "0"}],
          ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"rmn", "[", 
             RowBox[{"a", ",", "b", ",", "id", ",", "c"}], "]"}]}], "/;", 
           RowBox[{"c", ">", "id"}]}]}], ";", 
         RowBox[{
          RowBox[{"rmn", "[", 
           RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
          RowBox[{
           RowBox[{"rmn", "[", 
            RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
           RowBox[{"FaSi", "[", 
            RowBox[{"Rg", "[", 
             RowBox[{"[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "]"}], 
            "]"}]}]}], ";", 
         RowBox[{"RUddd", "=", 
          RowBox[{"Array", "[", 
           RowBox[{"rmn", ",", 
            RowBox[{"{", 
             RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], "}"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Riemann(Uddd)\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"Rg", "=", "RUddd"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<RUddd not computed\>\"", ",", "1"}], "]"}]}], "]"}], 
      ";", "\n", "\t\t", "\n", 
      RowBox[{"Clear", "[", "tmp", "]"}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"b", ",", "a"}], "]"}], "/;", 
        RowBox[{"a", ">", "b"}]}]}], ";", 
      RowBox[{
       RowBox[{"tmp", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "=", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Rg", "[", 
            RowBox[{"[", 
             RowBox[{"k", ",", "a", ",", "k", ",", "b"}], "]"}], "]"}], ",", 
           " ", 
           RowBox[{"{", 
            RowBox[{"k", ",", "Dim"}], "}"}]}], "]"}], "]"}]}]}], ";", 
      RowBox[{"Rdd", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"{", 
          RowBox[{"Dim", ",", "Dim"}], "}"}]}], "]"}]}], ";", "\n", 
      "\t\t\t\t", "\n", 
      RowBox[{"RUd", "=", 
       RowBox[{"gUU", ".", "Rdd"}]}], ";", 
      RowBox[{"R", "=", 
       RowBox[{"FaSi", "[", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"RUd", "[", 
           RowBox[{"[", 
            RowBox[{"a", ",", "a"}], "]"}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"a", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], ";", 
      RowBox[{"timePrint", "[", 
       RowBox[{"\"\<Ricci\>\"", ",", "sT"}], "]"}], ";", 
      RowBox[{"sT", "=", 
       RowBox[{"TimeUsed", "[", "]"}]}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Wopt", "||", 
         RowBox[{"Dim", "<", "4"}]}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"Dim", ">", "3"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
             RowBox[{"Wdddd", "=", "Rdddd"}], ",", "\n", "\t", 
             RowBox[{
              RowBox[{"gg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "gdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"gg", "=", 
               RowBox[{"gg", "-", 
                RowBox[{"Transpose", "[", "gg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Transpose", "[", 
                RowBox[{
                 RowBox[{"Outer", "[", 
                  RowBox[{"Times", ",", "Rdd", ",", "gdd"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], 
                "]"}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", "Rg", "]"}]}]}], ";", 
              RowBox[{"Rg", "=", 
               RowBox[{"Rg", "-", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"Rg", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2", ",", "4", ",", "3"}], "}"}]}], 
                 "]"}]}]}], ";", "\n", 
              RowBox[{"Clear", "[", "rmn", "]"}], ";", 
              RowBox[{"RiemSym", "[", "rmn", "]"}], ";", 
              RowBox[{
               RowBox[{"rmn", "[", 
                RowBox[{"a_", ",", "b_", ",", "c_", ",", "id_"}], "]"}], ":=", 
               RowBox[{
                RowBox[{"rmn", "[", 
                 RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], "=", 
                RowBox[{"FaSi", "[", 
                 RowBox[{
                  RowBox[{"Rdddd", "[", 
                   RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                   "]"}], "-", 
                  RowBox[{
                   RowBox[{"Rg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], "+", 
                  RowBox[{"R", " ", 
                   RowBox[{
                    RowBox[{"gg", "[", 
                    RowBox[{"[", 
                    RowBox[{"a", ",", "b", ",", "c", ",", "id"}], "]"}], 
                    "]"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "1"}], ")"}], 
                    RowBox[{"(", 
                    RowBox[{"Dim", "-", "2"}], ")"}]}], ")"}]}]}]}], 
                 "]"}]}]}], ";", 
              RowBox[{"Wdddd", "=", 
               RowBox[{"Array", "[", 
                RowBox[{"rmn", ",", 
                 RowBox[{"{", 
                  RowBox[{"Dim", ",", "Dim", ",", "Dim", ",", "Dim"}], 
                  "}"}]}], "]"}]}]}]}], "]"}], ",", 
           RowBox[{"Wdddd", "=", 
            RowBox[{"zeroTensor", "[", "4", "]"}]}]}], "]"}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Weyl\>\"", ",", "sT"}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", "Wdddd", "]"}], ",", 
           RowBox[{
            RowBox[{"Cflat", "=", "True"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Dim", "=!=", "3"}], "||", 
               RowBox[{"zeroQ", "[", "CF3d", "]"}]}], ",", 
              RowBox[{"stPrint", "[", "\"\<Conformally Flat\>\"", "]"}]}], 
             "]"}]}]}], "]"}]}], ",", 
        RowBox[{"stPrint", "[", 
         RowBox[{"\"\<Weyl tensor not computed\>\"", ",", "1"}], "]"}]}], 
       "]"}], ";", "\n", "\t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"zeroQ", "[", "Rdd", "]"}], ",", 
        RowBox[{
         RowBox[{"stPrint", "[", "\"\<Ricci Flat\>\"", "]"}], ";", 
         RowBox[{"EUd", "=", "Rdd"}]}], ",", "\n", "\t\t\t", 
        RowBox[{
         RowBox[{"sT", "=", 
          RowBox[{"TimeUsed", "[", "]"}]}], ";", 
         RowBox[{"EUd", "=", 
          RowBox[{"FaSi", "[", 
           RowBox[{"RUd", " ", "-", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], " ", "R", "*", "idMat"}]}], 
           "]"}]}], ";", 
         RowBox[{"timePrint", "[", 
          RowBox[{"\"\<Einstein\>\"", ",", "sT"}], "]"}], ";", "\n", "\t\t", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"zeroQ", "[", 
            RowBox[{"EUd", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "-", 
                RowBox[{"1", "/", "Dim"}]}], ")"}], "R", "*", "idMat"}]}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"stPrint", "[", "\"\<Einstein Space\>\"", "]"}], ";", 
            RowBox[{"EinSp", "=", "True"}]}]}], "]"}]}]}], "]"}], ";", "\n", 
      "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", ">", "2"}], "&&", "Cflat", "&&", "EinSp"}], ")"}], "||", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dim", "===", "2"}], "&&", 
           RowBox[{"zeroQ", "[", 
            RowBox[{"FaSi", "[", 
             RowBox[{"covD", "[", "R", "]"}], "]"}], "]"}]}], ")"}]}], ",", 
        RowBox[{
        "stPrint", "[", "\"\<Space of Constant Curvature!\>\"", "]"}]}], 
       "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{"NP$", ",", "NPdefs"}], "]"}], ";"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CF3d", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"stPrint", "[", 
      RowBox[{"\"\<Testing for 3-dim conformal flatness...\>\"", ",", "1"}], 
      "]"}], ";", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"tmp$", "=", 
         RowBox[{
          RowBox[{"covD", "[", "Rdd", "]"}], "-", 
          RowBox[{"Outer", "[", 
           RowBox[{"Times", ",", "gdd", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"covD", "[", "R", "]"}], "/", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{"Dim", "-", "1"}], ")"}]}]}], "]"}]}]}], "}"}], ",", 
       RowBox[{"FaSi", "[", 
        RowBox[{"tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}]}], 
      "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NPdefs", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "2"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "4"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Rdd", "[", 
         RowBox[{"[", 
          RowBox[{"4", ",", "1"}], "]"}], "]"}]}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"0", ",", " ", "2"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"4", ",", "4"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"2", ",", " ", "0"}], "]"}], " ", "=", " ", 
      RowBox[{
       RowBox[{"Rdd", "[", 
        RowBox[{"[", 
         RowBox[{"3", ",", "3"}], "]"}], "]"}], "/", "2"}]}], ";", " ", 
     RowBox[{
      RowBox[{"PH", "[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], " ", "=", " ", 
      RowBox[{"FaSi", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], " ", "+", " ", 
          RowBox[{"Rdd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "4"}], "]"}], "]"}]}], ")"}], "/", "4"}], 
       "]"}]}], ";", 
     RowBox[{"\[CapitalLambda]", "=", 
      RowBox[{
       RowBox[{"-", "R"}], "/", 
       RowBox[{"2", "4"}]}]}], ";", 
     RowBox[{
     "tmp$", " ", "=", " ", 
      "\"\<NP variables PH[i,j], \[CapitalLambda] \>\""}], ";", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "Wdddd", "]"}], " ", "=!=", " ", "Symbol"}], ",",
        " ", 
       RowBox[{
        RowBox[{
         RowBox[{"PS", "[", "0", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "2", ",", "4"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "1", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4", ",", "2", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "2", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{
         RowBox[{"PS", "[", "3", "]"}], " ", "=", " ", 
         RowBox[{"Wdddd", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}], ";", 
        " ", 
        RowBox[{
         RowBox[{"PS", "[", "4", "]"}], " ", "=", " ", 
         RowBox[{"-", 
          RowBox[{"Wdddd", "[", 
           RowBox[{"[", 
            RowBox[{"3", ",", "1", ",", "3", ",", "1"}], "]"}], "]"}]}]}], 
        ";", " ", 
        RowBox[{"tmp$", " ", "=", " ", 
         RowBox[{"StringJoin", "[", 
          RowBox[{"tmp$", ",", " ", "\"\<and PS[i] \>\""}], "]"}]}]}]}], 
      "]"}], ";", " ", 
     RowBox[{"stPrint", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"tmp$", ",", " ", "\"\<defined.\>\""}], "]"}], ",", " ", 
       "1"}], "]"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{"y_Wedge", ",", "x_"}], "]"}], ":=", 
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"Rest", "[", "y", "]"}], ",", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"First", "[", "y", "]"}], ",", "x"}], "]"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "+", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "x"}], "]"}], "+", 
    RowBox[{"inn", "[", 
     RowBox[{
      RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"x_", "*", "y_"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", "*", 
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", "y"}], "]"}]}], "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_"}], "]"}], ":=", 
   RowBox[{"0", "/;", 
    RowBox[{
     RowBox[{"FormDegree", "[", "x", "]"}], "===", "0"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", "x_Wedge"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"inn", "[", 
      RowBox[{
       RowBox[{"e", "[", "a", "]"}], ",", 
       RowBox[{"First", "[", "x", "]"}]}], "]"}], "*", 
     RowBox[{"Rest", "[", "x", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", 
      RowBox[{"FormDegree", "[", 
       RowBox[{"First", "[", "x", "]"}], "]"}]}], "*", 
     RowBox[{
      RowBox[{"First", "[", "x", "]"}], "\[Wedge]", 
      RowBox[{"inn", "[", 
       RowBox[{
        RowBox[{"e", "[", "a", "]"}], ",", 
        RowBox[{"Rest", "[", "x", "]"}]}], "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"inn", "[", 
    RowBox[{
     RowBox[{"e", "[", "a_", "]"}], ",", 
     RowBox[{"e", "[", "b_", "]"}]}], "]"}], ":=", 
   RowBox[{"gUU", "[", 
    RowBox[{"[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MoveIndex", "[", 
    RowBox[{"x_", ",", "i_", ",", "g_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "indL"}], "}"}], ",", 
     "\n", "    ", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{"i", "===", "1"}], ",", 
       RowBox[{"g", ".", "x"}], ",", 
       RowBox[{"i", "===", "rnk1"}], ",", 
       RowBox[{"x", ".", "g"}], ",", "True", ",", 
       RowBox[{
        RowBox[{"indL", "=", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "->", "1"}], ",", 
            RowBox[{"1", "->", "i"}]}], "}"}]}]}], ";", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"g", ".", 
           RowBox[{"Transpose", "[", 
            RowBox[{"x", ",", "indL"}], "]"}]}], ",", "indL"}], "]"}]}]}], 
      "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lower", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gdd"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Raise", "[", 
    RowBox[{"x_", ",", "i__"}], "]"}], ":=", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"FoldList", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"MoveIndex", "[", 
         RowBox[{"#1", ",", "#2", ",", "gUU"}], "]"}], "&"}], ",", "x", ",", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "i", "}"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"multiDot", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"rnk2", "=", 
        RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Sort", "/@", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", "indPr", "}"}], "]"}]}]}], ",", 
       RowBox[{"ordPr", "=", 
        RowBox[{"Sort", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}], "||", 
         RowBox[{
          RowBox[{"Union", "[", 
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "=!=", 
          RowBox[{"indL", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "||", 
         RowBox[{
          RowBox[{
           RowBox[{"indL", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk2"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ordPr", "]"}], "===", "1"}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotOne", "[", 
          RowBox[{"x", ",", "y", ",", "indPr"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"rnk1", "===", "rnk2"}], "&&", 
         RowBox[{"rnk1", "===", 
          RowBox[{"Length", "[", "ordPr", "]"}]}]}], ",", 
        RowBox[{"FacSimp", "[", 
         RowBox[{"dotAll", "[", 
          RowBox[{"x", ",", "y", ",", "ordPr"}], "]"}], "]"}], ",", "True", 
        ",", 
        RowBox[{"OKindCon", "[", 
         RowBox[{
          RowBox[{"dotOne", "[", 
           RowBox[{"x", ",", "y", ",", 
            RowBox[{"ordPr", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{
           RowBox[{"renumb", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"ordPr", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "]"}], "/@", 
           RowBox[{"Rest", "[", "ordPr", "]"}]}]}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"renumb", "[", 
     RowBox[{"rnk_", ",", "j_"}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"a_", ",", "b_"}], "}"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"j", ">", "b"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "1"}], ",", 
       RowBox[{"b", "+", "rnk", "-", "2"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dotOne", "[", 
   RowBox[{"x_", ",", "y_", ",", 
    RowBox[{"{", 
     RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rnk1", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
      RowBox[{"rnk2", "=", 
       RowBox[{"TensorRank", "[", "y", "]"}]}], ",", 
      RowBox[{"tmp$", "=", 
       RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmp$", "===", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
       RowBox[{"tmp$", "=", "Wedge"}], ",", 
       RowBox[{"tmp$", "=", "Dot"}]}], "]"}], ";", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{"tmp$", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"x", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk1", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rnk1", "\[Rule]", "i"}], ",", 
              RowBox[{"i", "\[Rule]", "rnk1"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"Range", "[", "rnk2", "]"}], "/.", "\[InvisibleSpace]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"j", "\[Rule]", "1"}], ",", 
              RowBox[{"1", "\[Rule]", "j"}]}], "}"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}], ",", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"rnk1", ",", 
             RowBox[{"rnk1", "+", "j", "-", "2"}]}], "]"}], ",", "1"}], "]"}],
          ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"rnk1", "+", "j", "-", "1"}], ",", 
           RowBox[{"rnk1", "+", "rnk2", "-", "2"}]}], "]"}]}], "]"}]}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dotAll", "[", 
    RowBox[{"x_", ",", "y_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s$", ",", "allInd", ",", "sumInd", ",", 
       RowBox[{"tmp$", "=", 
        RowBox[{"FormDegree", "[", "0", "]"}]}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"allInd", "=", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{"s$", ",", 
          RowBox[{"Transpose", "[", "indPr", "]"}], ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], "/.", 
        RowBox[{
         RowBox[{"s$", "[", "i_", "]"}], ":>", 
         RowBox[{"ToExpression", "[", 
          RowBox[{"\"\<s$\>\"", "<>", 
           RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
      RowBox[{"sumInd", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"allInd", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", 
              RowBox[{"allInd", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "}"}]}], "]"}]}], "}"}],
         "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"tmp$", "===", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "x", "]"}], ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"FormDegree", "[", "y", "]"}], ">", "0"}]}], ",", 
        RowBox[{"tmp$", "=", "Wedge"}], ",", 
        RowBox[{"tmp$", "=", "Times"}]}], "]"}], ";", 
      RowBox[{"Sum", "@@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Unevaluated", "[", 
          RowBox[{"tmp$", "[", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], ",", 
            RowBox[{"y", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"allInd", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
          "]"}], ",", 
         RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}]}]}], "]"}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"x_", ",", "indPr__"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", 
       RowBox[{"indL", "=", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", "indPr", "}"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Union", "[", "indL", "]"}], "]"}], "<", 
         RowBox[{"Length", "[", "indL", "]"}]}], "||", 
        RowBox[{
         RowBox[{"Length", "[", "indL", "]"}], ">", "rnk1"}], "||", 
        RowBox[{
         RowBox[{
          RowBox[{"Sort", "[", "indL", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}], ">", "rnk1"}]}], ",", 
       RowBox[{"errWarn", ";", 
        RowBox[{"Return", "[", "]"}]}], ",", 
       RowBox[{"OKindCon", "[", 
        RowBox[{"x", ",", 
         RowBox[{"Sort", "[", 
          RowBox[{"Sort", "/@", 
           RowBox[{"{", "indPr", "}"}]}], "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"newPrList", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Rest", "[", "x", "]"}], "-", "1"}], "/.", 
    RowBox[{"k_", ":>", 
     RowBox[{
      RowBox[{"k", "-", "1"}], "/;", 
      RowBox[{"k", ">", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], "-", "1"}]}]}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"FacSimp", "[", 
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"Length", "[", "indPr", "]"}], "===", "1"}]}]}], ";", 
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"s$", ",", "allInd", ",", "sumInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"TensorRank", "[", "x", "]"}], "]"}], "/.", 
          RowBox[{"Apply", "[", 
           RowBox[{"Rule", ",", 
            RowBox[{"Apply", "[", 
             RowBox[{"Sequence", ",", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Transpose", "[", 
                  RowBox[{"{", 
                   RowBox[{"#", ",", 
                    RowBox[{
                    RowBox[{"s$", "[", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}], "]"}], "&"}], 
                ",", "indPr"}], "]"}], ",", "1"}], "]"}], ",", "1"}], "]"}]}],
          "/.", 
         RowBox[{
          RowBox[{"s$", "[", "i_", "]"}], ":>", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<s$\>\"", "<>", 
            RowBox[{"ToString", "[", "i", "]"}]}], "]"}]}]}]}], ";", 
       RowBox[{"sumInd", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Union", "[", "allInd", "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Dim", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "allInd", "]"}], "/", "2"}], "}"}]}], 
            "]"}]}], "}"}], "]"}]}], ";", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Sum", "@@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Unevaluated", "[", 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], "]"}], ",", 
           
           RowBox[{"Sequence", "@@", "sumInd"}]}], "}"}]}], "]"}]}]}], "]"}], 
    "/;", 
    RowBox[{
     RowBox[{"TensorRank", "[", "x", "]"}], "===", 
     RowBox[{"2", 
      RowBox[{"Length", "[", "indPr", "]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"OKindCon", "[", 
    RowBox[{"x_", ",", "indPr_"}], "]"}], ":=", 
   RowBox[{"OKindCon", "[", 
    RowBox[{
     RowBox[{"ConOne", "[", 
      RowBox[{"x", ",", 
       RowBox[{"indPr", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"newPrList", "[", "indPr", "]"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ConOne", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rnk1", "=", 
        RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "tr1List", ",", 
       "tr2List"}], "}"}], ",", 
     RowBox[{
      RowBox[{"tr1List", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Range", "[", "rnk1", "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{"j", "->", "i"}], "}"}]}], ")"}], "/.", 
        RowBox[{"k_", ":>", 
         RowBox[{
          RowBox[{"k", "-", "1"}], "/;", 
          RowBox[{"k", ">", "j"}]}]}]}]}], ";", 
      RowBox[{"tr2List", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"i", "-", "1"}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"i", ",", 
             RowBox[{"rnk1", "-", "1"}]}], "]"}], ",", "1"}], "]"}]}], 
        "]"}]}], ";", 
      RowBox[{"Apply", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"x", ",", "tr1List"}], "]"}], ",", "tr2List"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"rnk1", "-", "2"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"errWarn", ":=", 
   RowBox[{"stPrint", "[", 
    RowBox[{"\"\<Wrong tensor rank or number(s) of indices!\>\"", ",", "1"}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covDiv", "[", 
    RowBox[{"x_", ",", "UpList_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{"x", ",", "UpList"}], "]"}], "=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"k", "=", 
         RowBox[{"TensorRank", "[", "x", "]"}]}], ",", "divInd", ",", 
        "allInd", ",", "freeInd", ",", "hhD", ",", "s", ",", "lt", ",", 
        "aInd"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
          
          RowBox[{
           RowBox[{
            RowBox[{"Sort", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], ">", "k"}], "||", 
          RowBox[{
           RowBox[{"Head", "[", "x", "]"}], "=!=", "List"}]}], ",", 
         RowBox[{"errWarn", ";", 
          RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "1"}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"Select", "[", 
             RowBox[{"UpList", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"Head", "[", "#", "]"}], "===", "List"}], "&"}]}], 
             "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", 
         RowBox[{"divInd", "=", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"{", "UpList", "}"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ";", "\n", "\t\t\t", 
       RowBox[{"allInd", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"aInd", "/@", 
           RowBox[{"Range", "[", "k", "]"}]}], ")"}], "/.", 
         RowBox[{
          RowBox[{"aInd", "[", "divInd", "]"}], "->", "s"}]}]}], ";", 
       RowBox[{"freeInd", "=", 
        RowBox[{"Select", "[", 
         RowBox[{"allInd", ",", 
          RowBox[{
           RowBox[{"#", "=!=", "s"}], "&"}]}], "]"}]}], ";", 
       RowBox[{"Off", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"lt", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$VersionNumber", "<", "3.5"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"hhD", "[", 
                RowBox[{
                 RowBox[{"x", "[", 
                  RowBox[{"[", 
                   RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                 "s"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "+", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"MemberQ", "[", 
                  RowBox[{
                   RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], "]"}],
                  ",", 
                 RowBox[{
                  RowBox[{"GUdd", "[", 
                   RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                   "]"}]}]}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "Dim"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "k"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Unevaluated", "[", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"hhD", "[", 
                 RowBox[{
                  RowBox[{"x", "[", 
                   RowBox[{"[", 
                    RowBox[{"Sequence", "@@", "allInd"}], "]"}], "]"}], ",", 
                  "s"}], "]"}], "+", 
                RowBox[{"Sum", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "UpList", "]"}], ",", "i"}], 
                    "]"}], ",", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "s", ",", "j"}], 
                    "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"GUdd", "[", 
                    RowBox[{"[", 
                    RowBox[{"j", ",", "s", ",", 
                    RowBox[{"allInd", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], 
                    RowBox[{"x", "[", 
                    RowBox[{"[", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"ReplacePart", "[", 
                    RowBox[{"allInd", ",", "j", ",", "i"}], "]"}]}], "]"}], 
                    "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"j", ",", "Dim"}], "}"}]}], "]"}]}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"s", ",", "Dim"}], "}"}]}], "]"}], "]"}], ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"(", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"#", ",", "Dim"}], "]"}], "&"}], ",", "freeInd"}], 
               "]"}], ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"k", " ", ">", "1"}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{"Table", "@@", "lt"}]}], ",", 
         RowBox[{"lt", "=", 
          RowBox[{
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"pD", "[", 
              RowBox[{
               RowBox[{"x", "[", 
                RowBox[{"[", "s$", "]"}], "]"}], ",", "s$"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}], "+", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"GUdd", "[", 
               RowBox[{"[", 
                RowBox[{"s$", ",", "s$", ",", "j"}], "]"}], "]"}], 
              RowBox[{"x", "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "Dim"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"s$", ",", "Dim"}], "}"}]}], "]"}]}]}]}], "]"}], ";", 
       RowBox[{"On", "[", 
        RowBox[{"Part", "::", "\"\<pspec\>\""}], "]"}], ";", 
       RowBox[{"Return", "[", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"lt", "/.", 
           RowBox[{"hhD", "->", "pD"}]}], "]"}], "]"}], "]"}]}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"c$D", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"covD", "[", 
    RowBox[{"x_", ",", "y_List"}], "]"}], ":=", "errWarn"}], ";", 
  RowBox[{
   RowBox[{"covD", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"covD", "[", "x", "]"}], "=", 
    RowBox[{"c$D", "[", "x", "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c$D", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"UpList_:", 
      RowBox[{"{", "}"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", "=", 
       RowBox[{"TensorRank", "[", "x", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "UpList", "]"}], ">", "0"}], "&&", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", 
             RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], ">", "k"}], "||", 
           RowBox[{
            RowBox[{
             RowBox[{"Sort", "[", 
              RowBox[{"Flatten", "[", "UpList", "]"}], "]"}], 
             "\[LeftDoubleBracket]", 
             RowBox[{"-", "1"}], "\[RightDoubleBracket]"}], ">", "k"}]}], 
          ")"}]}], ",", 
        RowBox[{"errWarn", ";", 
         RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "x", "]"}], "===", "List"}], ",", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{"cDcomp", "[", 
           RowBox[{"x", ",", "k", ",", "UpList"}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"Dim", ",", 
            RowBox[{"{", 
             RowBox[{"k", "+", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"FaSi", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"pD", "[", 
            RowBox[{"x", ",", "i"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "Dim"}], "}"}]}], "]"}], "]"}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cDcomp", "[", 
     RowBox[{"x_", ",", "rnk_", ",", 
      RowBox[{"UpList_:", 
       RowBox[{"{", "}"}]}]}], "]"}], "[", "y__", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y$", "=", 
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"{", "y", "}"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ",", 
       RowBox[{"z$", "=", 
        RowBox[{
         RowBox[{"{", "y", "}"}], "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{
       RowBox[{"pD", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"Sequence", "@@", "y$"}], "]"}], "]"}], ",", "z$"}], "]"}],
        "+", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MemberQ", "[", 
            RowBox[{"UpList", ",", "i"}], "]"}], ",", 
           RowBox[{
            RowBox[{"GUdd", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"y$", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", "z$", ",", "j"}], "]"}], 
             "]"}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}], 
           ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"GUdd", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "z$", ",", 
                RowBox[{"y$", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], 
            RowBox[{"x", "[", 
             RowBox[{"[", 
              RowBox[{"Sequence", "@@", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"y$", ",", "j", ",", "i"}], "]"}]}], "]"}], "]"}]}]}],
           "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "Dim"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "rnk"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "0", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdddd", "]"}]}], "}"}], ",", 
     RowBox[{"FaSi", "[", 
      RowBox[{"indepTerms", "[", 
       RowBox[{"tmp$", "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "3"}], "}"}]}], 
         "]"}], "+", 
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp$", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "5", ",", "3", ",", "4"}], "}"}]}], 
         "]"}]}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "1", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp$", "=", 
       RowBox[{"covD", "[", "Rdd", "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "RUddd", "]"}], "===", "Symbol"}], ",", 
        RowBox[{"RUddd", "=", 
         RowBox[{"Raise", "[", 
          RowBox[{"Rdddd", ",", "1"}], "]"}]}]}], "]"}], ";", 
      RowBox[{"FaSi", "[", 
       RowBox[{"indepTerms", "[", 
        RowBox[{
         RowBox[{"covDiv", "[", 
          RowBox[{"RUddd", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}], "+", "tmp$", "-", 
         RowBox[{"Transpose", "[", 
          RowBox[{"tmp$", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2"}], "}"}]}], "]"}]}], "]"}], 
       "]"}]}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bianchi", "[", "2", "]"}], ":=", 
   RowBox[{"indepTerms", "[", 
    RowBox[{"covDiv", "[", 
     RowBox[{"EUd", ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PrePrint", "=", " ", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ByteCount", "[", "#", "]"}], " ", ">", " ", "200000"}], ",", 
      RowBox[{"Short", "[", 
       RowBox[{"#", ",", "100"}], "]"}], ",", " ", "#"}], "]"}], "&"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Protect", "[", 
   RowBox[{
   "cDcomp", ",", "CF3d", ",", "ConOne", ",", "c$D", ",", "dotAll", ",", 
    "dotOne", ",", "epsilon", ",", "errWarn", ",", "FacSimp", ",", "FaSi", 
    ",", "indexList", ",", "inn", ",", "MF", ",", "MoveIndex", ",", 
    "newPrList", ",", "NPdefs", ",", "numb1", ",", "numb2", ",", "OKindCon", 
    ",", "redPlus", ",", "redTimes", ",", "renumb", ",", "RiemSym", ",", 
    "zeroTensor"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[{
 " 3  Examples (~ 3 min) \n",
 StyleBox["(All timings refer to an Apple Power Macintosh G3/400 computer \
running ",
  FontSize->14,
  FontWeight->"Plain"],
 StyleBox["Mathematica",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" 3.0)",
  FontSize->14,
  FontWeight->"Plain"]
}], "Section",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 "\n\t",
 StyleBox["In each case, after ",
  FontSize->16],
 StyleBox["RGtensors",
  FontFamily->"Courier",
  FontSize->16],
 StyleBox[" is finished, examples of the use of other functions are given.",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"stTim", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
Example 0: Flat spacetime in rotating prolate spheroidal coordinates (~ 1 sec)\
\>", "Subsection",
 FontSize->16],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "Transform cylindrical coordinates (\[Rho], z, phi)",
 " to (\[Lambda], \[Mu], \[Phi])",
 ": ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Rho]", "2"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Lambda]", "2"], "-", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[Mu]", "2"]}], ")"}]}]}], ",", " ", 
   RowBox[{"z", "=", 
    RowBox[{"\[Lambda]", " ", "\[Mu]"}]}], ",", " ", 
   RowBox[{"phi", "=", 
    RowBox[{"\[Phi]", "+", 
     RowBox[{"\[CapitalOmega]", " ", "t"}]}]}]}]]],
 " :"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "\[CurlyPhi]", ",", "\[Lambda]", ",", "\[Mu]"}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"\[CapitalOmega]", "^", "2"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Lambda]", "^", "2"}], "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"-", "\[CapitalOmega]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "2"}], "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}], ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[CapitalOmega]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "2"}], "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Lambda]", "^", "2"}], "-", "1"}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}], ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Lambda]", "^", "2"}], "-", 
           RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "2"}], "-", "1"}], ")"}]}], ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Lambda]", "^", "2"}], "-", 
           RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Mu]", "^", "2"}]}], ")"}]}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
          SuperscriptBox["\[CapitalOmega]", "2"]}]}], 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Lambda]", "2"]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]"}], 
        "0", "0"},
       {
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Lambda]", "2"]}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}]}], "0", "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Lambda]", "2"]}], "+", 
          SuperscriptBox["\[Mu]", "2"]}], 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Lambda]", "2"]}]], "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Lambda]", "2"]}], "+", 
          SuperscriptBox["\[Mu]", "2"]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["\[Mu]", "2"]}]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
     1 - (-1 + $CellContext`\[Lambda]^2) (
       1 - $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega]^2, -(-1 + \
$CellContext`\[Lambda]^2) (
       1 - $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega], 0, 
      0}, {-(-1 + $CellContext`\[Lambda]^2) (
       1 - $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega], (
       1 - $CellContext`\[Lambda]^2) (1 - $CellContext`\[Mu]^2), 0, 0}, {
     0, 0, (-1 + $CellContext`\[Lambda]^2)^(-1) (-$CellContext`\[Lambda]^2 + \
$CellContext`\[Mu]^2), 0}, {
     0, 0, 0, (
        1 - $CellContext`\[Mu]^2)^(-1) (-$CellContext`\[Lambda]^2 + \
$CellContext`\[Mu]^2)}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5685688911222353`*^9, 3.5685692219021544`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(ds\\), \\(2\\)]\\) = \"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["\[Mu]", "2"]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Lambda]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Lambda]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Lambda]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Lambda]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Mu]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Mu]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Mu]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Mu]", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"e", "[", "1", "]"}], "2"], "-", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"e", "[", "2", "]"}]}], "+", 
        SuperscriptBox[
         RowBox[{"e", "[", "2", "]"}], "2"], "-", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["\[Lambda]", "2"], " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Lambda]", "4"], " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "r"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"m", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[CapitalOmega]", "2"], "-", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
        RowBox[{"m", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[CapitalOmega]", "2"], "-", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"e", "[", "2", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "3", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "4", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "m", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["\[CapitalOmega]", "2"], "-", 
              RowBox[{
               SuperscriptBox["\[Lambda]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["\[Lambda]", "2"], " ", 
               SuperscriptBox["\[Mu]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
            RowBox[{"e", "[", "2", "]"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "3", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "4", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["r", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", 
           RowBox[{"2", " ", "m"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", 
           RowBox[{"2", " ", "m"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[CapitalOmega]", "2"], "-", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", 
           RowBox[{"2", " ", "m"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", 
           RowBox[{"2", " ", "m"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[CapitalOmega]", "2"], "-", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "3", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"e", "[", "3", "]"}], " ", 
         RowBox[{"e", "[", "4", "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "4", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"e", "[", "2", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{"b", "-", "m"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "3", "]"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{"b", "-", "m"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "4", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"a", "-", 
               RowBox[{"2", " ", "m"}]}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", 
              RowBox[{"2", " ", "m"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["\[CapitalOmega]", "2"], "-", 
              RowBox[{
               SuperscriptBox["\[Lambda]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["\[Lambda]", "2"], " ", 
               SuperscriptBox["\[Mu]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
            RowBox[{"e", "[", "2", "]"}]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{"b", "-", "m"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "3", "]"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{"b", "-", "m"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "4", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["r", "3"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "m", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["m", "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[CapitalOmega]", "2"], "-", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", "m", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["m", "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["\[CapitalOmega]", "2"], "-", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[Lambda]", "2"], " ", 
            SuperscriptBox["\[Mu]", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "3", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"e", "[", "3", "]"}], " ", 
         RowBox[{"e", "[", "4", "]"}]}], "+", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"e", "[", "4", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"e", "[", "2", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"2", " ", "b", " ", "m"}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["m", "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "3", "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"2", " ", "b", " ", "m"}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["m", "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "4", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"e", "[", "1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", "m", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["m", "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["\[CapitalOmega]", "2"], "-", 
              RowBox[{
               SuperscriptBox["\[Lambda]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["\[Lambda]", "2"], " ", 
               SuperscriptBox["\[Mu]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]", "2"]}]}], ")"}], " ", 
            RowBox[{"e", "[", "2", "]"}]}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"2", " ", "b", " ", "m"}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["m", "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "3", "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"2", " ", "b", " ", "m"}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["m", "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SuperscriptBox["\[Mu]", "2"]}], ")"}], " ", "\[CapitalOmega]", 
            " ", 
            RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
            RowBox[{"e", "[", "4", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[$CellContext`r, 
       DirectedInfinity[1], {}, 0, 4, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 
     DirectedInfinity[1], {
     Rational[1, 
        2] (-1 + $CellContext`\[Lambda]^2)^(-1) (-1 + \
$CellContext`\[Mu]^2)^(-1) (
       2 $CellContext`\[Lambda]^2 $CellContext`d[$CellContext`\[Lambda]]^2 - 
       2 $CellContext`\[Mu]^2 $CellContext`d[$CellContext`\[Lambda]]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`d[$CellContext`\[Lambda]]^2 + 
       2 $CellContext`\[Mu]^4 $CellContext`d[$CellContext`\[Lambda]]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`d[$CellContext`\[Mu]]^2 + 
       2 $CellContext`\[Lambda]^4 $CellContext`d[$CellContext`\[Mu]]^2 + 
       2 $CellContext`\[Mu]^2 $CellContext`d[$CellContext`\[Mu]]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`d[$CellContext`\[Mu]]^2 + $CellContext`e[
         1]^2 - $CellContext`\[Lambda]^2 $CellContext`e[
         1]^2 - $CellContext`\[Mu]^2 $CellContext`e[
         1]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`e[
          1]^2 + $CellContext`\[CapitalOmega]^2 $CellContext`e[1]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[
         1]^2 + $CellContext`\[Lambda]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1]^2 - 
       2 $CellContext`\[Mu]^2 $CellContext`\[CapitalOmega]^2 $CellContext`e[
         1]^2 + 4 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1]^2 - 
       2 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
         1]^2 + $CellContext`\[Mu]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
         1]^2 + $CellContext`\[Lambda]^4 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1]^2 + 2 $CellContext`e[1] $CellContext`e[2] - 
       2 $CellContext`\[Lambda]^2 $CellContext`e[1] $CellContext`e[2] - 
       2 $CellContext`\[Mu]^2 $CellContext`e[1] $CellContext`e[2] + 
       2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`e[
         1] $CellContext`e[2] + 
       2 $CellContext`\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] - 
       4 $CellContext`\[Lambda]^2 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1] $CellContext`e[2] + 
       2 $CellContext`\[Lambda]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1] $CellContext`e[2] - 
       4 $CellContext`\[Mu]^2 $CellContext`\[CapitalOmega]^2 $CellContext`e[
        1] $CellContext`e[2] + 
       8 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] - 
       4 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] + 
       2 $CellContext`\[Mu]^4 $CellContext`\[CapitalOmega]^2 $CellContext`e[
         1] $CellContext`e[2] - 
       4 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] + 
       2 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] + $CellContext`e[
         2]^2 - $CellContext`\[Lambda]^2 $CellContext`e[
         2]^2 - $CellContext`\[Mu]^2 $CellContext`e[
         2]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`e[
          2]^2 + $CellContext`\[CapitalOmega]^2 $CellContext`e[2]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[
         2]^2 + $CellContext`\[Lambda]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[2]^2 - 
       2 $CellContext`\[Mu]^2 $CellContext`\[CapitalOmega]^2 $CellContext`e[
         2]^2 + 4 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[2]^2 - 
       2 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
         2]^2 + $CellContext`\[Mu]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[2]^2 - 
       2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
         2]^2 + $CellContext`\[Lambda]^4 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[2]^2), $CellContext`m (
        1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[1]^2 + $CellContext`m (
        1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2]^2 + $CellContext`e[2] (
        Complex[0, -1] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\
\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
        Complex[0, 
           1] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) \
$CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[4]) + $CellContext`e[1] (
        2 $CellContext`m (
          1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2] + 
        Complex[0, -1] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\
\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
        Complex[0, 
           1] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) \
$CellContext`\[CapitalOmega] Csc[$CellContext`\[Theta]] $CellContext`e[4]), 
      Rational[-1, 2] ($CellContext`a - 2 $CellContext`m) ($CellContext`a + 
        2 $CellContext`m) (
        1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[1]^2 + 
      Rational[-1, 2] ($CellContext`a - 2 $CellContext`m) ($CellContext`a + 
        2 $CellContext`m) (
        1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2]^2 + 
      Rational[-1, 
         2] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) 
       Csc[$CellContext`\[Theta]]^2 $CellContext`e[
         3]^2 + (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) 
       Csc[$CellContext`\[Theta]]^2 $CellContext`e[3] $CellContext`e[4] + 
      Rational[-1, 
         2] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) 
       Csc[$CellContext`\[Theta]]^2 $CellContext`e[4]^2 + $CellContext`e[2] (
        Complex[0, 
           1] ($CellContext`b - $CellContext`m) (-1 + \
$CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\
\[CapitalOmega] Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
        Complex[0, -1] ($CellContext`b - $CellContext`m) (-1 + $CellContext`\
\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[4]) + $CellContext`e[
        1] (-($CellContext`a - 2 $CellContext`m) ($CellContext`a + 
          2 $CellContext`m) (
          1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2] + 
        Complex[0, 
           1] ($CellContext`b - $CellContext`m) (-1 + \
$CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\
\[CapitalOmega] Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
        Complex[
          0, -1] ($CellContext`b - $CellContext`m) (-1 + $CellContext`\
\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[
          4]), (-2) $CellContext`m ($CellContext`a^2 - 2 $CellContext`m^2) (
        1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[1]^2 - 
      2 $CellContext`m ($CellContext`a^2 - 2 $CellContext`m^2) (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[
        2]^2 + $CellContext`b (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) Csc[$CellContext`\[Theta]]^2 $CellContext`e[3]^2 - 
      2 $CellContext`b (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\
\[Mu]^2) Csc[$CellContext`\[Theta]]^2 $CellContext`e[3] $CellContext`e[
       4] + $CellContext`b (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) 
       Csc[$CellContext`\[Theta]]^2 $CellContext`e[4]^2 + $CellContext`e[2] (
        Complex[0, 
           Rational[1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
          2 $CellContext`b $CellContext`m - 
          3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[3] + Complex[0, 
           Rational[-1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
          2 $CellContext`b $CellContext`m - 
          3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[4]) + $CellContext`e[
        1] ((-4) $CellContext`m ($CellContext`a^2 - 2 $CellContext`m^2) (
          1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2] + Complex[0, 
           Rational[1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
          2 $CellContext`b $CellContext`m - 
          3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[3] + Complex[0, 
           Rational[-1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
          2 $CellContext`b $CellContext`m - 
          3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
         Csc[$CellContext`\[Theta]] $CellContext`e[4])}, 0, 4, 1],
    Editable->False]}],
  SequenceForm["\!\(\*SuperscriptBox[\(ds\), \(2\)]\) = ", 
   SeriesData[$CellContext`r, 
    DirectedInfinity[1], {
    Rational[1, 
       2] (-1 + $CellContext`\[Lambda]^2)^(-1) (-1 + \
$CellContext`\[Mu]^2)^(-1) (
      2 $CellContext`\[Lambda]^2 $CellContext`d[$CellContext`\[Lambda]]^2 - 
      2 $CellContext`\[Mu]^2 $CellContext`d[$CellContext`\[Lambda]]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`d[$CellContext`\[Lambda]]^2 + 
      2 $CellContext`\[Mu]^4 $CellContext`d[$CellContext`\[Lambda]]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`d[$CellContext`\[Mu]]^2 + 
      2 $CellContext`\[Lambda]^4 $CellContext`d[$CellContext`\[Mu]]^2 + 
      2 $CellContext`\[Mu]^2 $CellContext`d[$CellContext`\[Mu]]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`d[$CellContext`\[Mu]]^2 + $CellContext`e[
        1]^2 - $CellContext`\[Lambda]^2 $CellContext`e[
        1]^2 - $CellContext`\[Mu]^2 $CellContext`e[
        1]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`e[
         1]^2 + $CellContext`\[CapitalOmega]^2 $CellContext`e[1]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[
        1]^2 + $CellContext`\[Lambda]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1]^2 - 
      2 $CellContext`\[Mu]^2 $CellContext`\[CapitalOmega]^2 $CellContext`e[
        1]^2 + 4 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1]^2 - 
      2 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
        1]^2 + $CellContext`\[Mu]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
        1]^2 + $CellContext`\[Lambda]^4 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1]^2 + 2 $CellContext`e[1] $CellContext`e[2] - 
      2 $CellContext`\[Lambda]^2 $CellContext`e[1] $CellContext`e[2] - 
      2 $CellContext`\[Mu]^2 $CellContext`e[1] $CellContext`e[2] + 
      2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`e[
        1] $CellContext`e[2] + 
      2 $CellContext`\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] - 
      4 $CellContext`\[Lambda]^2 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1] $CellContext`e[2] + 
      2 $CellContext`\[Lambda]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[1] $CellContext`e[2] - 
      4 $CellContext`\[Mu]^2 $CellContext`\[CapitalOmega]^2 $CellContext`e[
       1] $CellContext`e[2] + 
      8 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] - 
      4 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] + 
      2 $CellContext`\[Mu]^4 $CellContext`\[CapitalOmega]^2 $CellContext`e[
        1] $CellContext`e[2] - 
      4 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] + 
      2 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[1] $CellContext`e[2] + $CellContext`e[
        2]^2 - $CellContext`\[Lambda]^2 $CellContext`e[
        2]^2 - $CellContext`\[Mu]^2 $CellContext`e[
        2]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`e[
         2]^2 + $CellContext`\[CapitalOmega]^2 $CellContext`e[2]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[
        2]^2 + $CellContext`\[Lambda]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[2]^2 - 
      2 $CellContext`\[Mu]^2 $CellContext`\[CapitalOmega]^2 $CellContext`e[
        2]^2 + 4 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[2]^2 - 
      2 $CellContext`\[Lambda]^4 $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
        2]^2 + $CellContext`\[Mu]^4 $CellContext`\[CapitalOmega]^2 \
$CellContext`e[2]^2 - 
      2 $CellContext`\[Lambda]^2 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[
        2]^2 + $CellContext`\[Lambda]^4 $CellContext`\[Mu]^4 $CellContext`\
\[CapitalOmega]^2 $CellContext`e[2]^2), $CellContext`m (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[1]^2 + $CellContext`m (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2]^2 + $CellContext`e[2] (
       Complex[0, -1] (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
       Complex[0, 
          1] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) \
$CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[4]) + $CellContext`e[1] (
       2 $CellContext`m (
         1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2] + 
       Complex[0, -1] (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
       Complex[0, 
          1] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) \
$CellContext`\[CapitalOmega] Csc[$CellContext`\[Theta]] $CellContext`e[4]), 
     Rational[-1, 2] ($CellContext`a - 2 $CellContext`m) ($CellContext`a + 
       2 $CellContext`m) (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[1]^2 + 
     Rational[-1, 2] ($CellContext`a - 2 $CellContext`m) ($CellContext`a + 
       2 $CellContext`m) (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2]^2 + 
     Rational[-1, 
        2] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) 
      Csc[$CellContext`\[Theta]]^2 $CellContext`e[
        3]^2 + (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) 
      Csc[$CellContext`\[Theta]]^2 $CellContext`e[3] $CellContext`e[4] + 
     Rational[-1, 
        2] (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) 
      Csc[$CellContext`\[Theta]]^2 $CellContext`e[4]^2 + $CellContext`e[2] (
       Complex[0, 
          1] ($CellContext`b - $CellContext`m) (-1 + \
$CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\
\[CapitalOmega] Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
       Complex[0, -1] ($CellContext`b - $CellContext`m) (-1 + $CellContext`\
\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[4]) + $CellContext`e[
       1] (-($CellContext`a - 2 $CellContext`m) ($CellContext`a + 
         2 $CellContext`m) (
         1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2] + 
       Complex[0, 
          1] ($CellContext`b - $CellContext`m) (-1 + \
$CellContext`\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\
\[CapitalOmega] Csc[$CellContext`\[Theta]] $CellContext`e[3] + 
       Complex[0, -1] ($CellContext`b - $CellContext`m) (-1 + $CellContext`\
\[Lambda]^2) (-1 + $CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[
         4]), (-2) $CellContext`m ($CellContext`a^2 - 2 $CellContext`m^2) (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[1]^2 - 
     2 $CellContext`m ($CellContext`a^2 - 2 $CellContext`m^2) (
      1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[
       2]^2 + $CellContext`b (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) Csc[$CellContext`\[Theta]]^2 $CellContext`e[3]^2 - 
     2 $CellContext`b (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) 
     Csc[$CellContext`\[Theta]]^2 $CellContext`e[3] $CellContext`e[
      4] + $CellContext`b (-1 + $CellContext`\[Lambda]^2) (-1 + $CellContext`\
\[Mu]^2) Csc[$CellContext`\[Theta]]^2 $CellContext`e[4]^2 + $CellContext`e[
       2] (Complex[0, 
          Rational[1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
         2 $CellContext`b $CellContext`m - 
         3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[3] + Complex[0, 
          Rational[-1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
         2 $CellContext`b $CellContext`m - 
         3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[4]) + $CellContext`e[
       1] ((-4) $CellContext`m ($CellContext`a^2 - 2 $CellContext`m^2) (
         1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2) $CellContext`e[2] + Complex[0, 
          Rational[1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
         2 $CellContext`b $CellContext`m - 
         3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[3] + Complex[0, 
          Rational[-1, 2]] ($CellContext`a^2 - $CellContext`b^2 + 
         2 $CellContext`b $CellContext`m - 
         3 $CellContext`m^2) (-1 + $CellContext`\[Lambda]^2) (-1 + \
$CellContext`\[Mu]^2) $CellContext`\[CapitalOmega] 
        Csc[$CellContext`\[Theta]] $CellContext`e[4])}, 0, 4, 1]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5685688911222353`*^9, 3.5685696050660706`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", "\[CapitalOmega]"}], "0", "0"},
       {
        RowBox[{"-", "\[CapitalOmega]"}], 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["\[CapitalOmega]", "2"], "-", 
          RowBox[{
           SuperscriptBox["\[Lambda]", "2"], " ", 
           SuperscriptBox["\[CapitalOmega]", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox["\[CapitalOmega]", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["\[Lambda]", "2"], " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox["\[CapitalOmega]", "2"]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Lambda]", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Mu]", "2"]}], ")"}]}]], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], 
          RowBox[{
           SuperscriptBox["\[Lambda]", "2"], "-", 
           SuperscriptBox["\[Mu]", "2"]}]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Mu]", "2"]}], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["\[Lambda]", "2"]}], "+", 
           SuperscriptBox["\[Mu]", "2"]}]]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
     1, -$CellContext`\[CapitalOmega], 0, 
      0}, {-$CellContext`\[CapitalOmega], (-1 + \
$CellContext`\[Lambda]^2)^(-1) (-1 + $CellContext`\[Mu]^2)^(-1) (
       1 + $CellContext`\[CapitalOmega]^2 - $CellContext`\[Lambda]^2 \
$CellContext`\[CapitalOmega]^2 - $CellContext`\[Mu]^2 $CellContext`\
\[CapitalOmega]^2 + $CellContext`\[Lambda]^2 $CellContext`\[Mu]^2 \
$CellContext`\[CapitalOmega]^2), 0, 0}, {
     0, 0, -(-1 + $CellContext`\[Lambda]^2)/($CellContext`\[Lambda]^2 - \
$CellContext`\[Mu]^2), 0}, {
     0, 0, 0, -(-1 + $CellContext`\[Mu]^2)/(-$CellContext`\[Lambda]^2 + \
$CellContext`\[Mu]^2)}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5685688911222353`*^9, 3.5685696050710707`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.5685688911222353`*^9, 3.5685696050730705`*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.5685692184779587`*^9, 3.5685696050920715`*^9},
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GUdd", "[", 
  RowBox[{"[", 
   RowBox[{"3", ",", "1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Lambda]"}], ")"}], " ", "\[Lambda]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[Lambda]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "\[Mu]"}], ")"}], " ", "\[CapitalOmega]"}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Lambda]", "-", "\[Mu]"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Check covariant derivatives of metric tensor:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"covD", "[", "gdd", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"covD", "[", 
  RowBox[{"gUU", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 1: Schwarzschild  (~ 1 + 3 sec)", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"2", 
        RowBox[{"M", "/", "r"}]}]}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", 
          RowBox[{"M", "/", "r"}]}]}], ")"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"r", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"r", "^", "2"}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}], "]"}]}],
   ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[TextData[{
 "\t",
 StyleBox["TrigRules are predefined to implement the identities ",
  FontSize->16],
 Cell[BoxData[
  StyleBox[
   SuperscriptBox[
    RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"],
   FontSize->14]]],
 " ",
 StyleBox["+",
  FontSize->16],
 Cell[BoxData[
  RowBox[{" ", 
   StyleBox[
    SuperscriptBox[
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"],
    FontSize->14]}]]],
 StyleBox["=1 and ",
  FontSize->16],
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SuperscriptBox[
     RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"],
    FontSize->14], " "}]]],
 StyleBox["- ",
  FontSize->16],
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]],
  FontSize->14],
 StyleBox["=1.",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M"}], "r"]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "M"}], "r"]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1 - 2 (M/r), 0, 0, 0}, {0, (-1)/(1 - 2 (M/r)), 0, 0}, {
     0, 0, -r^2, 0}, {0, 0, 0, (-r^2) Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"r", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "r", "]"}], "2"]}], 
     RowBox[{
      RowBox[{"2", " ", "M"}], "-", "r"}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "t", "]"}], "2"]}], "r"], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((2 M - r)^(-1) r) d[r]^2 - ((2 M - r)/r) d[t]^2 - r^2 
   d[\[Theta]]^2 - (r^2 d[\[CurlyPhi]]^2) Sin[\[Theta]]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         FractionBox["r", 
          RowBox[{
           RowBox[{"2", " ", "M"}], "-", "r"}]]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], "r"]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["r", "2"]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], 
          SuperscriptBox["r", "2"]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{((-1)/(2 M - r)) r, 0, 0, 0}, {
     0, ((-1)/r) ((-2) M + r), 0, 0}, {0, 0, (-1) r^(-2), 0}, {
     0, 0, 0, ((-1) r^(-2)) Csc[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666699825`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.06666666666666998, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.03333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666699825`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.06666666666666998, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.466666666666661456`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RUddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "M"}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
    SuperscriptBox["r", "2"]}]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Check the full Bianchi identities:",
  FontSize->16]
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroQ", "[", 
   RowBox[{"Bianchi", "[", "0", "]"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3.16666666666666429`", " ", "Second"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 1a: Schwarzschild with Cosmological Constant (~ 1 + 1 sec)\
\>", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"2", 
        RowBox[{"M", "/", "r"}]}], "-", 
       RowBox[{"\[CapitalLambda]", " ", 
        RowBox[{
         RowBox[{"r", "^", "2"}], "/", "3"}]}]}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", 
          RowBox[{"M", "/", "r"}]}], "-", 
         RowBox[{"\[CapitalLambda]", " ", 
          RowBox[{
           RowBox[{"r", "^", "2"}], "/", "3"}]}]}], ")"}]}], ",", 
      RowBox[{"-", 
       RowBox[{"r", "^", "2"}]}], ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"r", "^", "2"}]}], 
       RowBox[{
        RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}], "]"}]}],
   ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M"}], "r"], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["r", "2"], " ", "\[CapitalLambda]"}], "3"]}], "0", 
        "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "M"}], "r"], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["r", "2"], " ", "\[CapitalLambda]"}], "3"]}]]}], 
        "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
     1 - 2 (M/r) + (Rational[-1, 3] r^2) \[CapitalLambda], 0, 0, 0}, {
     0, (-1)/(1 - 2 (M/r) + (Rational[-1, 3] r^2) \[CapitalLambda]), 0, 0}, {
     0, 0, -r^2, 0}, {0, 0, 0, (-r^2) Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"3", " ", "r", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "r", "]"}], "2"]}], 
     RowBox[{
      RowBox[{"6", " ", "M"}], "-", 
      RowBox[{"3", " ", "r"}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "M"}], "-", 
        RowBox[{"3", " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "t", "]"}], "2"]}], 
     RowBox[{"3", " ", "r"}]], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((3 r)/(6 M - 3 r + r^3 \[CapitalLambda])) 
    d[r]^2 + ((Rational[-1, 3]/r) (6 M - 3 r + r^3 \[CapitalLambda])) d[t]^2 - 
   r^2 d[\[Theta]]^2 - (r^2 d[\[CurlyPhi]]^2) Sin[\[Theta]]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", " ", "r"}], 
          RowBox[{
           RowBox[{"6", " ", "M"}], "-", 
           RowBox[{"3", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}]]}], "0", 
        "0", "0"},
       {"0", 
        FractionBox[
         RowBox[{
          RowBox[{"6", " ", "M"}], "-", 
          RowBox[{"3", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", "\[CapitalLambda]"}]}], 
         RowBox[{"3", " ", "r"}]], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          SuperscriptBox["r", "2"]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], 
          SuperscriptBox["r", "2"]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(-3) (r/(6 M - 3 r + r^3 \[CapitalLambda])), 0, 0, 0}, {
     0, (Rational[1, 3]/r) (6 M - 3 r + r^3 \[CapitalLambda]), 0, 0}, {
     0, 0, (-1) r^(-2), 0}, {0, 0, 0, ((-1) r^(-2)) Csc[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666628771`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.06666666666666288, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666699825`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.06666666666666998, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666628771`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.06666666666666288, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.03333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.11666666666666714`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.11666666666666714`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Einstein Space\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.600000000000001421`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rdd", "[", 
  RowBox[{"[", 
   RowBox[{"3", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "2"], " ", "\[CapitalLambda]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["R"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", "\[CapitalLambda]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Check the once-contracted Bianchi identities:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zeroQ", "[", 
  RowBox[{"Bianchi", "[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\t",
 StyleBox["Use ",
  FontSize->16],
 StyleBox["multiDot",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" and ",
  FontSize->16],
 StyleBox["Contract",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" to compute the quadratic and cubic Weyl tensors and invariants:",
  FontSize->16]
}], "Subsubsection",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WUUdd", "=", 
   RowBox[{"Raise", "[", 
    RowBox[{"Wdddd", ",", "1", ",", "2"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", " ", 
     StyleBox["W2",
      FontColor->RGBColor[0, 0, 1]]}], 
    StyleBox["=",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[
     RowBox[{"Weyl", " ", "squared"}],
     FontColor->RGBColor[0, 0, 1]]}], " ", "**)"}], 
  RowBox[{
   RowBox[{
    RowBox[{"W2UUdd", "=", 
     StyleBox[
      RowBox[{"multiDot", "[", 
       RowBox[{"WUUdd", ",", "WUUdd", ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "2"}], "}"}]}], "]"}],
      ShowStringCharacters->True,
      NumberMarks->True]}], 
    StyleBox[";",
     ShowStringCharacters->True,
     NumberMarks->True]}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"*", " ", 
      StyleBox["W3",
       FontColor->RGBColor[0, 0, 1]]}], 
     StyleBox["=",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[
      RowBox[{"Weyl", " ", "cubed"}],
      FontColor->RGBColor[0, 0, 1]]}], " ", "**)"}], 
   RowBox[{
    RowBox[{"W3UUdd", "=", 
     StyleBox[
      RowBox[{"multiDot", "[", 
       RowBox[{"W2UUdd", ",", "WUUdd", ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"4", ",", "2"}], "}"}]}], "]"}],
      ShowStringCharacters->True,
      NumberMarks->True]}], 
    StyleBox[";",
     ShowStringCharacters->True,
     NumberMarks->True]}]}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"quadraticInv", "=", 
   RowBox[{
    StyleBox["Contract",
     ShowStringCharacters->True,
     NumberMarks->True], 
    StyleBox["[",
     ShowStringCharacters->True,
     NumberMarks->True], 
    RowBox[{"W2UUdd", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"cubicInv", "=", 
   RowBox[{
    StyleBox["Contract",
     ShowStringCharacters->True,
     NumberMarks->True], 
    StyleBox["[",
     ShowStringCharacters->True,
     NumberMarks->True], 
    RowBox[{"W3UUdd", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"quadraticInv", ",", "cubicInv", ",", 
   RowBox[{
    RowBox[{"quadraticInv", "^", "3"}], "/", 
    RowBox[{"cubicInv", "^", "2"}]}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"48", " ", 
     SuperscriptBox["M", "2"]}], 
    SuperscriptBox["r", "6"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"96", " ", 
      SuperscriptBox["M", "3"]}], 
     SuperscriptBox["r", "9"]]}], ",", "12"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["The invariants can be computed directly using ",
  FontSize->16],
 StyleBox["multiDot",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[":",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  StyleBox[
   RowBox[{
    RowBox[{"multiDot", "[", 
     RowBox[{"WUUdd", ",", "WUUdd", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"multiDot", "[", 
     RowBox[{"W2UUdd", ",", "WUUdd", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}]}], "]"}]}],
   ShowStringCharacters->True,
   NumberMarks->True], 
  StyleBox["}",
   ShowStringCharacters->True,
   NumberMarks->True]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"48", " ", 
     SuperscriptBox["M", "2"]}], 
    SuperscriptBox["r", "6"]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"96", " ", 
      SuperscriptBox["M", "3"]}], 
     SuperscriptBox["r", "9"]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2: Robertson-Walker (~ 1 sec)", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           RowBox[{"r", "^", "2"}]}]}], ")"}]}], ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]}], 
        RowBox[{"r", "^", "2"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"r", "^", "2"}]}], 
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], "^", "2"}], 
        RowBox[{
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], 
          RowBox[{"1", "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["r", "2"]}]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, ((-1)/(1 - k r^2)) a[t]^2, 0, 0}, {
     0, 0, (-r^2) a[t]^2, 0}, {0, 0, 0, ((-r^2) a[t]^2) Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "r", "]"}], "2"]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"k", " ", 
       SuperscriptBox["r", "2"]}]}]], "+", 
    SuperscriptBox[
     RowBox[{"d", "[", "t", "]"}], "2"], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((-1 + k r^2)^(-1) a[t]^2) d[r]^2 + d[t]^2 - (r^2 a[t]^2) 
   d[\[Theta]]^2 - ((r^2 a[t]^2) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["r", "2"]}]}], 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, (-1 + k r^2) a[t]^(-2), 0, 0}, {
     0, 0, ((-1) r^(-2)) a[t]^(-2), 0}, {
     0, 0, 0, (((-1) r^(-2)) a[t]^(-2)) Csc[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666699825`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.06666666666666998, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0833333333333357018`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.0833333333333357, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333385439`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.033333333333338544`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.11666666666666714`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.11666666666666714`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Conformally Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666657192`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.01666666666666572, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.583333333333335701`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rdd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["a", "\[DoublePrime]",
      MultilineFunction->None], "[", "t", "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EUd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"k", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"a", "[", "t", "]"}], "2"]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Check the twice-contracted Bianchi identities:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zeroQ", "[", 
  RowBox[{"Bianchi", "[", "2", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 3: Conformally Flat 5-dim metrics (~ 2 + 2 sec)", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{
    RowBox[{"ConformalFactor", "^", "2"}], 
    RowBox[{"IdentityMatrix", "[", "5", "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
 "\t",
 StyleBox["(1) General Case:",
  FontSize->16]
}], "Subsubsection",
 FontSize->14,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{
    RowBox[{"g", "/.", 
     RowBox[{"ConformalFactor", "->", 
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}]}]}], 
    ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        SuperscriptBox[
         RowBox[{"\[CapitalOmega]", "[", 
          RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
         "2"], "0", "0", "0", "0"},
       {"0", 
        SuperscriptBox[
         RowBox[{"\[CapitalOmega]", "[", 
          RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
         "2"], "0", "0", "0"},
       {"0", "0", 
        SuperscriptBox[
         RowBox[{"\[CapitalOmega]", "[", 
          RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
         "2"], "0", "0"},
       {"0", "0", "0", 
        SuperscriptBox[
         RowBox[{"\[CapitalOmega]", "[", 
          RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
         "2"], "0"},
       {"0", "0", "0", "0", 
        SuperscriptBox[
         RowBox[{"\[CapitalOmega]", "[", 
          RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
         "2"]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{\[CapitalOmega][x1, x2, x3, x4, x5]^2, 0, 0, 0, 0}, {
     0, \[CapitalOmega][x1, x2, x3, x4, x5]^2, 0, 0, 0}, {
     0, 0, \[CapitalOmega][x1, x2, x3, x4, x5]^2, 0, 0}, {
     0, 0, 0, \[CapitalOmega][x1, x2, x3, x4, x5]^2, 0}, {
     0, 0, 0, 0, \[CapitalOmega][x1, x2, x3, x4, x5]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x1", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
      "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x2", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
      "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x3", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
      "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x4", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
      "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x5", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[CapitalOmega]", "[", 
       RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
      "2"]}]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", d[x1]^2 \[CapitalOmega][x1, x2, x3, x4, x5]^2 + 
   d[x2]^2 \[CapitalOmega][x1, x2, x3, x4, x5]^2 + 
   d[x3]^2 \[CapitalOmega][x1, x2, x3, x4, x5]^2 + 
   d[x4]^2 \[CapitalOmega][x1, x2, x3, x4, x5]^2 + 
   d[x5]^2 \[CapitalOmega][x1, x2, x3, x4, x5]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"\[CapitalOmega]", "[", 
           RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
          "2"]], "0", "0", "0", "0"},
       {"0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"\[CapitalOmega]", "[", 
           RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
          "2"]], "0", "0", "0"},
       {"0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"\[CapitalOmega]", "[", 
           RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
          "2"]], "0", "0"},
       {"0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"\[CapitalOmega]", "[", 
           RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
          "2"]], "0"},
       {"0", "0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"\[CapitalOmega]", "[", 
           RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
          "2"]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{\[CapitalOmega][x1, x2, x3, x4, x5]^(-2), 0, 0, 0, 0}, {
     0, \[CapitalOmega][x1, x2, x3, x4, x5]^(-2), 0, 0, 0}, {
     0, 0, \[CapitalOmega][x1, x2, x3, x4, x5]^(-2), 0, 0}, {
     0, 0, 0, \[CapitalOmega][x1, x2, x3, x4, x5]^(-2), 0}, {
     0, 0, 0, 0, \[CapitalOmega][x1, x2, x3, x4, x5]^(-2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0500000000000042632`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.05000000000000426, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.350000000000001421`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.3500000000000014, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.61666666666666714`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.6166666666666671, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.11666666666666714`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.11666666666666714`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.283333333333331438`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.28333333333333144`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Conformally Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666628771`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.06666666666666288, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.69999999999999573`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GUdd", "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[CapitalOmega]", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
  RowBox[{"\[CapitalOmega]", "[", 
   RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], 
   "]"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EUd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"\[CapitalOmega]", "[", 
     RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], "4"]], 
  RowBox[{"(", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalOmega]", "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
       " ", 
       RowBox[{
        SuperscriptBox["\[CapitalOmega]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"\[CapitalOmega]", "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
       " ", 
       RowBox[{
        SuperscriptBox["\[CapitalOmega]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"\[CapitalOmega]", "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
       " ", 
       RowBox[{
        SuperscriptBox["\[CapitalOmega]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}]}], 
      "+", 
      RowBox[{
       RowBox[{"\[CapitalOmega]", "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
       " ", 
       RowBox[{
        SuperscriptBox["\[CapitalOmega]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}]}], 
      "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CapitalOmega]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5"}], "]"}], 
        "2"]}]}], ")"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Of the 5^4 components in Rdddd",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonZeroN", "[", "Rdddd", "]"}]], "Input"],

Cell[BoxData["280"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["are non-zero, of which ",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"nonZeroL", "[", "Rdddd", "]"}], "]"}]], "Input"],

Cell[BoxData["40"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["are different. Of these ",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"indepTerms", "[", "Rdddd", "]"}], "]"}]], "Input"],

Cell[BoxData["20"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["are independent (modulo numerical factors).",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\t",
 StyleBox["(2) Constant Curvature Case:",
  FontSize->16]
}], "Subsubsection",
 FontSize->14,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{
    RowBox[{"g", "/.", 
     RowBox[{"{", 
      RowBox[{"ConformalFactor", "->", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           RowBox[{"K", "/", "4"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"x1", "^", "2"}], "+", 
             RowBox[{"x2", "^", "2"}], "+", 
             RowBox[{"x3", "^", "2"}], "+", 
             RowBox[{"x4", "^", "2"}], "+", 
             RowBox[{"x5", "^", "2"}]}], ")"}]}]}], ")"}]}]}], "}"}]}], ",", 
    "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             FractionBox["1", "4"], " ", "K", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["x5", "2"]}], ")"}]}]}], ")"}], "2"]], "0", "0",
         "0", "0"},
       {"0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             FractionBox["1", "4"], " ", "K", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["x5", "2"]}], ")"}]}]}], ")"}], "2"]], "0", "0",
         "0"},
       {"0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             FractionBox["1", "4"], " ", "K", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["x5", "2"]}], ")"}]}]}], ")"}], "2"]], "0", "0"},
       {"0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             FractionBox["1", "4"], " ", "K", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["x5", "2"]}], ")"}]}]}], ")"}], "2"]], "0"},
       {"0", "0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             FractionBox["1", "4"], " ", "K", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"], "+", 
               SuperscriptBox["x4", "2"], "+", 
               SuperscriptBox["x5", "2"]}], ")"}]}]}], ")"}], "2"]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{(
       1 + (Rational[1, 4] K) (x1^2 + x2^2 + x3^2 + x4^2 + x5^2))^(-2), 0, 0, 
      0, 0}, {0, (
       1 + (Rational[1, 4] K) (x1^2 + x2^2 + x3^2 + x4^2 + x5^2))^(-2), 0, 0, 
      0}, {0, 0, (
       1 + (Rational[1, 4] K) (x1^2 + x2^2 + x3^2 + x4^2 + x5^2))^(-2), 0, 
      0}, {0, 0, 
      0, (1 + (Rational[1, 4] K) (x1^2 + x2^2 + x3^2 + x4^2 + x5^2))^(-2), 
      0}, {0, 0, 0, 
      0, (1 + (Rational[1, 4] K) (x1^2 + x2^2 + x3^2 + x4^2 + x5^2))^(-2)}}]],
  
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x1", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x1", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x2", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x3", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x4", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x5", "2"]}]}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x2", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x1", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x2", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x3", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x4", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x5", "2"]}]}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x3", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x1", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x2", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x3", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x4", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x5", "2"]}]}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x4", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x1", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x2", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x3", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x4", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x5", "2"]}]}], ")"}], "2"]], "+", 
    FractionBox[
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x5", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x1", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x2", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x3", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x4", "2"]}], "+", 
        RowBox[{"K", " ", 
         SuperscriptBox["x5", "2"]}]}], ")"}], "2"]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (16 (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^(-2))
      d[x1]^2 + (16 (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^(-2)) 
    d[x2]^2 + (16 (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^(-2)) 
    d[x3]^2 + (16 (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^(-2)) 
    d[x4]^2 + (16 (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^(-2)) 
    d[x5]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{
         FractionBox["1", "16"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x2", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x4", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x5", "2"]}]}], ")"}], "2"]}], "0", "0", "0", "0"},
       {"0", 
        RowBox[{
         FractionBox["1", "16"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x2", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x4", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x5", "2"]}]}], ")"}], "2"]}], "0", "0", "0"},
       {"0", "0", 
        RowBox[{
         FractionBox["1", "16"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x2", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x4", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x5", "2"]}]}], ")"}], "2"]}], "0", "0"},
       {"0", "0", "0", 
        RowBox[{
         FractionBox["1", "16"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x2", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x4", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x5", "2"]}]}], ")"}], "2"]}], "0"},
       {"0", "0", "0", "0", 
        RowBox[{
         FractionBox["1", "16"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x1", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x2", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x3", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x4", "2"]}], "+", 
            RowBox[{"K", " ", 
             SuperscriptBox["x5", "2"]}]}], ")"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
     Rational[1, 16] (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^2, 0, 0,
       0, 0}, {0, 
      Rational[1, 16] (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^2, 0, 
      0, 0}, {0, 0, 
      Rational[1, 16] (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^2, 0, 
      0}, {0, 0, 0, 
      Rational[1, 16] (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^2, 
      0}, {0, 0, 0, 0, 
      Rational[1, 16] (4 + K x1^2 + K x2^2 + K x3^2 + K x4^2 + K x5^2)^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.383333333333332859`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.38333333333333286`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.36666666666666714`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.36666666666666714`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.200000000000002842`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.20000000000000284`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666657192`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.01666666666666572, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.216666666666668561`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.21666666666666856`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Conformally Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Einstein Space\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData["\<\"Space of Constant Curvature!\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.48333333333333428`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RUddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", "K"}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"4", "+", 
     RowBox[{"K", " ", 
      SuperscriptBox["x1", "2"]}], "+", 
     RowBox[{"K", " ", 
      SuperscriptBox["x2", "2"]}], "+", 
     RowBox[{"K", " ", 
      SuperscriptBox["x3", "2"]}], "+", 
     RowBox[{"K", " ", 
      SuperscriptBox["x4", "2"]}], "+", 
     RowBox[{"K", " ", 
      SuperscriptBox["x5", "2"]}]}], ")"}], "2"]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["R"], "Input"],

Cell[BoxData[
 RowBox[{"20", " ", "K"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Of the 5^4 components in RUddd",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nonZeroN", "[", "RUddd", "]"}]], "Input"],

Cell[BoxData["40"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["are non-zero, of which the following are independent (modulo \
numerical factors):",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"indepTerms", "[", "RUddd", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox["K", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"4", "+", 
      RowBox[{"K", " ", 
       SuperscriptBox["x1", "2"]}], "+", 
      RowBox[{"K", " ", 
       SuperscriptBox["x2", "2"]}], "+", 
      RowBox[{"K", " ", 
       SuperscriptBox["x3", "2"]}], "+", 
      RowBox[{"K", " ", 
       SuperscriptBox["x4", "2"]}], "+", 
      RowBox[{"K", " ", 
       SuperscriptBox["x5", "2"]}]}], ")"}], "2"]], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 4: Kerr in Boyer-Lindquist coordinates (Cos[\[Theta]] -> x)  (~ 3 + 3 \
sec)\
\>", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "x", "]"}], ";", 
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "x", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sigma", "=", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "+", 
    RowBox[{
     RowBox[{"a", "^", "2"}], 
     RowBox[{"x", "^", "2"}]}]}]}], ";", 
  RowBox[{"Delta", "=", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "+", 
    RowBox[{"a", "^", "2"}], "-", 
    RowBox[{"2", "M", " ", "r"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "-", 
        RowBox[{"2", "M", " ", 
         RowBox[{"r", "/", "Sigma"}]}]}], ",", "0", ",", "0", ",", 
       RowBox[{"2", "a", " ", "M", " ", "r", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"x", "^", "2"}]}], ")"}], "/", "Sigma"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", "Sigma"}], "/", "Delta"}], ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "Sigma"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"x", "^", "2"}]}], ")"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "a", " ", "M", " ", "r", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"x", "^", "2"}]}], ")"}], "/", "Sigma"}]}], ",", "0", ",", 
       "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"x", "^", "2"}]}], ")"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"r", "^", "2"}], "+", 
          RowBox[{"a", "^", "2"}], "+", 
          RowBox[{"2", 
           RowBox[{"a", "^", "2"}], "M", " ", "r", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"x", "^", "2"}]}], ")"}], "/", "Sigma"}]}]}], ")"}]}]}],
       "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M", " ", "r"}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["x", "2"]}]}]]}], "0", "0", 
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["x", "2"]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}]]},
       {"0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["r", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], "0", "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["r", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["x", "2"]}]], "0"},
       {
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["x", "2"]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}]], "0", "0", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["x", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"], "+", 
           FractionBox[
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", "M", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SuperscriptBox["x", "2"]}], ")"}]}], 
            RowBox[{
             SuperscriptBox["r", "2"], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["x", "2"]}]}]]}], ")"}]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
     1 - (2 M) (r/(r^2 + a^2 x^2)), 0, 
      0, (((2 a) M) r) ((1 - x^2)/(r^2 + a^2 x^2))}, {
     0, (a^2 - (2 M) r + r^2)^(-1) (-r^2 - a^2 x^2), 0, 0}, {
     0, 0, (1 - x^2)^(-1) (-r^2 - a^2 x^2), 
      0}, {(((2 a) M) r) ((1 - x^2)/(r^2 + a^2 x^2)), 0, 
      0, (-1 + x^2) (a^2 + 
       r^2 + (((2 a^2) M) r) ((1 - x^2)/(r^2 + a^2 x^2)))}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["x", "2"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"d", "[", "r", "]"}], "2"]}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "M", " ", "r"}], "+", 
      SuperscriptBox["r", "2"]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M", " ", "r"}], "-", 
        SuperscriptBox["r", "2"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "t", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x", "]"}], "2"]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["x", "2"]}]], "-", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "M", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["x", "2"]}], ")"}], " ", 
      RowBox[{"d", "[", "t", "]"}], " ", 
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["x", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "2"]}], "+", 
        SuperscriptBox["r", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", "r", " ", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (((-1)/(a^2 - (2 M) r + r^2)) (r^2 + a^2 x^2)) 
    d[r]^2 - (((2 M) r - r^2 - a^2 x^2)/(r^2 + a^2 x^2)) 
   d[t]^2 + ((-1 + x^2)^(-1) (r^2 + a^2 x^2)) 
    d[x]^2 - ((((((4 a) M) r) (-1 + x^2))/(r^2 + a^2 x^2)) d[t]) 
   d[\[CurlyPhi]] + (((-1 + x^2)/(r^2 + a^2 x^2)) (((2 a^2) M) r + a^2 r^2 + 
      r^4 + a^4 x^2 - (((2 a^2) M) r) x^2 + (a^2 r^2) x^2)) d[\[CurlyPhi]]^2],
  
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["r", "2"]}], "+", 
          SuperscriptBox["r", "4"], "+", 
          RowBox[{
           SuperscriptBox["a", "4"], " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", "M", " ", "r", " ", 
           SuperscriptBox["x", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"2", " ", "M", " ", "r"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["x", "2"]}]}], ")"}]}]], "0", "0", 
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"2", " ", "M", " ", "r"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["x", "2"]}]}], ")"}]}]]},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"2", " ", "M", " ", "r"}], "+", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["x", "2"]}]}]]}], "0", "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["x", "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}]], "0"},
       {
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"2", " ", "M", " ", "r"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["x", "2"]}]}], ")"}]}]], "0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"2", " ", "M", " ", "r"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["x", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["x", "2"]}]}], ")"}]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{((a^2 - (2 M) r + r^2)^(-1)/(r^2 + a^2 x^2)) (((2 a^2) M) r + 
       a^2 r^2 + r^4 + a^4 x^2 - (((2 a^2) M) r) x^2 + (a^2 r^2) x^2), 0, 
      0, (((2 a) M) r) ((a^2 - (2 M) r + r^2)^(-1)/(r^2 + a^2 x^2))}, {
     0, (-(a^2 - (2 M) r + r^2))/(r^2 + a^2 x^2), 0, 0}, {
     0, 0, (-1 + x^2)/(r^2 + a^2 x^2), 
      0}, {(((2 a) M) r) ((a^2 - (2 M) r + r^2)^(-1)/(r^2 + a^2 x^2)), 0, 
      0, (((a^2 - (2 M) r + r^2)^(-1)/(-1 + x^2))/(r^2 + 
       a^2 x^2)) (((-2) M) r + r^2 + a^2 x^2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.350000000000001421`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.3500000000000014, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.516666666666665719`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.5166666666666657, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.633333333333332859`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.6333333333333329, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "1.0833333333333357`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 1.0833333333333357`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.03333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2.85000000000000142`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GUdd", "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "2", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["a", "2"], " ", "x"}], 
  RowBox[{
   SuperscriptBox["r", "2"], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox["x", "2"]}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RUddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", "M", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "M", " ", "r"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["r", "2"]}]}], ")"}], " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["r", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "M", " ", "r"}], "+", 
      SuperscriptBox["r", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "3"]}]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Check the once-contracted Bianchi identities:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroQ", "[", 
   RowBox[{"Bianchi", "[", "1", "]"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3.11666666666666714`", " ", "Second"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Bianchi[1]",
  FontFamily->"Courier",
  FontSize->16],
 StyleBox[" calls ",
  FontSize->16],
 StyleBox["covD",
  FontFamily->"Courier",
  FontSize->16],
 StyleBox[" and ",
  FontSize->16],
 StyleBox["covDiv",
  FontFamily->"Courier",
  FontSize->16],
 StyleBox[" which remember their values; therefore, calling it again takes no \
time:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroQ", "[", 
   RowBox[{"Bianchi", "[", "1", "]"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.`", " ", "Second"}], ",", "True"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example 5: Floratos-Kehagias 8-dim Ricci-flat metric (",
 ButtonBox["hep_th/9802107",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://xxx.sissa.it/abs/hep-th/9802107"], None}],
 ") (~ 25 sec)"
}], "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"u", ",", "g", ",", "h", ",", "a", ",", "b", ",", "c"}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{
    "x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5", ",", "x6", ",", "x7", 
     ",", "x8"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gFloKeh", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"u", "^", "2"}], " ", 
        RowBox[{"g", "^", "2"}], " ", 
        RowBox[{"h", "^", "2"}]}], ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"u", "^", "2"}], " ", 
        RowBox[{"g", "^", "2"}], " ", 
        RowBox[{"h", "^", "2"}]}], ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"1", "/", 
        RowBox[{"u", "^", "2"}]}], ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", 
       RowBox[{"2", 
        RowBox[{"a", "/", 
         RowBox[{"u", "^", "2"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", 
        RowBox[{"g", "^", "2"}]}], ",", 
       RowBox[{"2", 
        RowBox[{"b", "/", 
         RowBox[{"g", "^", "2"}]}]}], ",", "0", ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"2", 
        RowBox[{"b", "/", 
         RowBox[{"g", "^", "2"}]}]}], ",", 
       RowBox[{
        RowBox[{"g", "^", "2"}], "+", 
        RowBox[{"4", 
         RowBox[{
          RowBox[{"b", "^", "2"}], "/", 
          RowBox[{"g", "^", "2"}]}]}]}], ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"h", "^", "2"}], "+", 
        RowBox[{"4", 
         RowBox[{
          RowBox[{"c", "^", "2"}], "/", 
          RowBox[{"h", "^", "2"}]}]}]}], ",", 
       RowBox[{"2", 
        RowBox[{"c", "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"2", 
        RowBox[{"c", "/", 
         RowBox[{"h", "^", "2"}]}]}], ",", 
       RowBox[{"1", "/", 
        RowBox[{"h", "^", "2"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"2", 
        RowBox[{"a", "/", 
         RowBox[{"u", "^", "2"}]}]}], ",", "0", ",", "0", ",", "0", ",", "0", 
       ",", 
       RowBox[{
        RowBox[{"4", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "/", 
          RowBox[{"u", "^", "2"}]}]}], "+", 
        RowBox[{"u", "^", "2"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell["\tThe symbols u, g, h, a, b, c are functions  x1, x2 :", "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{"U", "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";", 
  RowBox[{"g", "=", 
   RowBox[{"G", "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";", 
  RowBox[{"h", "=", 
   RowBox[{"H", "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";", 
  RowBox[{"a", "=", 
   RowBox[{"A", "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";", 
  RowBox[{"b", "=", 
   RowBox[{"B", "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";", 
  RowBox[{"c", "=", 
   RowBox[{"C", "[", 
    RowBox[{"x1", ",", "x2"}], "]"}]}], ";"}]], "Input"],

Cell["\<\
\tThe complex functions u^2 +2 i a, g^2 +2 i b, h^2 +2 i c  are assumed to be \
analytic functions of x1+i x2. Therefore, use simpRules to implement the \
Cauchy-Riemann & harmonic function conditions:\
\>", "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"simpRules", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"a", ",", "x1"}], "]"}], "->", 
     RowBox[{
      RowBox[{"-", "u"}], " ", 
      RowBox[{"D", "[", 
       RowBox[{"u", ",", "x2"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"a", ",", "x2"}], "]"}], "->", 
     RowBox[{"u", " ", 
      RowBox[{"D", "[", 
       RowBox[{"u", ",", "x1"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"b", ",", "x1"}], "]"}], "->", 
     RowBox[{
      RowBox[{"-", "g"}], " ", 
      RowBox[{"D", "[", 
       RowBox[{"g", ",", "x2"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"b", ",", "x2"}], "]"}], "->", 
     RowBox[{"g", " ", 
      RowBox[{"D", "[", 
       RowBox[{"g", ",", "x1"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"c", ",", "x1"}], "]"}], "->", 
     RowBox[{
      RowBox[{"-", "h"}], " ", 
      RowBox[{"D", "[", 
       RowBox[{"h", ",", "x2"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{"c", ",", "x2"}], "]"}], "->", 
     RowBox[{"h", " ", 
      RowBox[{"D", "[", 
       RowBox[{"h", ",", "x1"}], "]"}]}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Z_.", 
       TagBox[
        StyleBox[
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"0", ",", "2"}], "]"}], "[", "G_", "]"}], "[", 
          RowBox[{"x1", ",", "x2"}], "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True],
        FullForm]}], "+", 
      RowBox[{"Z_.", 
       TagBox[
        StyleBox[
         RowBox[{
          RowBox[{
           RowBox[{"Derivative", "[", 
            RowBox[{"2", ",", "0"}], "]"}], "[", "G_", "]"}], "[", 
          RowBox[{"x1", ",", "x2"}], "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True],
        FullForm]}]}], ":>", 
     RowBox[{
      RowBox[{"-", "Z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", 
               RowBox[{"1", ",", "0"}], "]"}], "[", "G", "]"}], "[", 
             RowBox[{"x1", ",", "x2"}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True],
           FullForm], "^", "2"}], "+", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{
             RowBox[{
              RowBox[{"Derivative", "[", 
               RowBox[{"0", ",", "1"}], "]"}], "[", "G", "]"}], "[", 
             RowBox[{"x1", ",", "x2"}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True],
           FullForm], "^", "2"}]}], ")"}], "/", 
       RowBox[{"G", "[", 
        RowBox[{"x1", ",", "x2"}], "]"}]}]}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["A", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"U", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}]}], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["A", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"x1", ",", "x2"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["B", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}]}], " ", 
     RowBox[{
      SuperscriptBox["G", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["B", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"G", "[", 
      RowBox[{"x1", ",", "x2"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["G", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["C", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"H", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}]}], " ", 
     RowBox[{
      SuperscriptBox["H", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["C", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x1", ",", "x2"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"H", "[", 
      RowBox[{"x1", ",", "x2"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x1", ",", "x2"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Z_.", " ", 
      RowBox[{
       SuperscriptBox["G_", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x1", ",", "x2"}], "]"}]}], "+", 
     RowBox[{"Z_.", " ", 
      RowBox[{
       SuperscriptBox["G_", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x1", ",", "x2"}], "]"}]}]}], "\[RuleDelayed]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Z", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["G", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["G", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], ")"}]}], 
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"gFloKeh", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "0", "0", "0", "0", "0", 
        "0", "0"},
       {"0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "0", "0", "0", "0", "0", 
        "0"},
       {"0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0", "0", "0", "0", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"A", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}]}], 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]]},
       {"0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"B", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}]}], 
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0", "0", "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"B", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}]}], 
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"B", "[", 
             RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"G", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "0", "0", "0"},
       {"0", "0", "0", "0", "0", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"C", "[", 
             RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"H", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"C", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}]}], 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0"},
       {"0", "0", "0", "0", "0", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"C", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}]}], 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"A", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}]}], 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0", "0", "0", "0", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"A", "[", 
             RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{(G[x1, x2]^2 H[x1, x2]^2) U[x1, x2]^2, 0, 0, 0, 0, 0, 0, 0}, {
     0, (G[x1, x2]^2 H[x1, x2]^2) U[x1, x2]^2, 0, 0, 0, 0, 0, 0}, {
     0, 0, U[x1, x2]^(-2), 0, 0, 0, 0, (2 A[x1, x2]) U[x1, x2]^(-2)}, {
     0, 0, 0, G[x1, x2]^(-2), (2 B[x1, x2]) G[x1, x2]^(-2), 0, 0, 0}, {
     0, 0, 0, (2 B[x1, x2]) G[x1, x2]^(-2), (4 B[x1, x2]^2) G[x1, x2]^(-2) + 
      G[x1, x2]^2, 0, 0, 0}, {
     0, 0, 0, 0, 0, (4 C[x1, x2]^2) H[x1, x2]^(-2) + 
      H[x1, x2]^2, (2 C[x1, x2]) H[x1, x2]^(-2), 0}, {
     0, 0, 0, 0, 0, (2 C[x1, x2]) H[x1, x2]^(-2), H[x1, x2]^(-2), 0}, {
     0, 0, (2 A[x1, x2]) U[x1, x2]^(-2), 0, 0, 0, 
      0, (4 A[x1, x2]^2) U[x1, x2]^(-2) + U[x1, x2]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"d", "[", "x4", "]"}], "2"], 
     SuperscriptBox[
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"B", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], " ", 
      RowBox[{"d", "[", "x4", "]"}], " ", 
      RowBox[{"d", "[", "x5", "]"}]}], 
     SuperscriptBox[
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"d", "[", "x5", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"B", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"G", "[", 
          RowBox[{"x1", ",", "x2"}], "]"}], "4"]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"C", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], " ", 
      RowBox[{"d", "[", "x6", "]"}], " ", 
      RowBox[{"d", "[", "x7", "]"}]}], 
     SuperscriptBox[
      RowBox[{"H", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"d", "[", "x7", "]"}], "2"], 
     SuperscriptBox[
      RowBox[{"H", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"d", "[", "x6", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"C", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", 
          RowBox[{"x1", ",", "x2"}], "]"}], "4"]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"H", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"d", "[", "x3", "]"}], "2"], 
     SuperscriptBox[
      RowBox[{"U", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"A", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], " ", 
      RowBox[{"d", "[", "x3", "]"}], " ", 
      RowBox[{"d", "[", "x8", "]"}]}], 
     SuperscriptBox[
      RowBox[{"U", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x1", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"U", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"d", "[", "x2", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"G", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"U", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"d", "[", "x8", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"A", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"U", "[", 
          RowBox[{"x1", ",", "x2"}], "]"}], "4"]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"U", "[", 
       RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", 
   d[x4]^2 G[x1, x2]^(-2) + (((4 B[x1, x2]) d[x4]) d[x5]) 
    G[x1, x2]^(-2) + (d[x5]^2 G[x1, x2]^(-2)) (4 B[x1, x2]^2 + 
     G[x1, x2]^4) + (((4 C[x1, x2]) d[x6]) d[x7]) H[x1, x2]^(-2) + 
   d[x7]^2 H[x1, x2]^(-2) + (d[x6]^2 H[x1, x2]^(-2)) (4 C[x1, x2]^2 + 
     H[x1, x2]^4) + 
   d[x3]^2 U[x1, x2]^(-2) + (((4 A[x1, x2]) d[x3]) d[x8]) 
    U[x1, x2]^(-2) + ((d[x1]^2 G[x1, x2]^2) H[x1, x2]^2) 
    U[x1, x2]^2 + ((d[x2]^2 G[x1, x2]^2) H[x1, x2]^2) 
    U[x1, x2]^2 + (d[x8]^2 U[x1, x2]^(-2)) (4 A[x1, x2]^2 + U[x1, x2]^4)],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"G", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]}]], "0", "0", "0", "0", 
        "0", "0", "0"},
       {"0", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"G", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]}]], "0", "0", "0", "0", 
        "0", "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"A", "[", 
             RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "4"]}], 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0", "0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"A", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}]}], 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}]},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"B", "[", 
             RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"G", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "4"]}], 
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"B", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}]}], 
          SuperscriptBox[
           RowBox[{"G", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}], "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"B", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}]}], 
          SuperscriptBox[
           RowBox[{"G", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}], 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"G", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0", "0", "0"},
       {"0", "0", "0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"C", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}]}], 
          SuperscriptBox[
           RowBox[{"H", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}], "0"},
       {"0", "0", "0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"C", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}]}], 
          SuperscriptBox[
           RowBox[{"H", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}], 
        FractionBox[
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"C", "[", 
             RowBox[{"x1", ",", "x2"}], "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{"H", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "4"]}], 
         SuperscriptBox[
          RowBox[{"H", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]], "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"A", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}]}], 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}], "0", "0", "0", "0", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"x1", ",", "x2"}], "]"}], "2"]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(G[x1, x2]^(-2) H[x1, x2]^(-2)) U[x1, x2]^(-2), 0, 0, 0, 0, 0,
       0, 0}, {0, (G[x1, x2]^(-2) H[x1, x2]^(-2)) U[x1, x2]^(-2), 0, 0, 0, 0, 
      0, 0}, {0, 0, U[x1, x2]^(-2) (4 A[x1, x2]^2 + U[x1, x2]^4), 0, 0, 0, 
      0, ((-2) A[x1, x2]) U[x1, x2]^(-2)}, {
     0, 0, 0, G[x1, x2]^(-2) (4 B[x1, x2]^2 + G[x1, x2]^4), ((-2) B[x1, x2]) 
      G[x1, x2]^(-2), 0, 0, 0}, {
     0, 0, 0, ((-2) B[x1, x2]) G[x1, x2]^(-2), G[x1, x2]^(-2), 0, 0, 0}, {
     0, 0, 0, 0, 0, H[x1, x2]^(-2), ((-2) C[x1, x2]) H[x1, x2]^(-2), 0}, {
     0, 0, 0, 0, 0, ((-2) C[x1, x2]) H[x1, x2]^(-2), 
      H[x1, x2]^(-2) (4 C[x1, x2]^2 + H[x1, x2]^4), 0}, {
     0, 0, ((-2) A[x1, x2]) U[x1, x2]^(-2), 0, 0, 0, 0, U[x1, x2]^(-2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666699825`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.06666666666666998, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.533333333333331438`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.5333333333333314, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "3.80000000000000426`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 3.8000000000000043`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "17.7499999999999991`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 17.75, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.566666666666662877`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.5666666666666629, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"22.9500000000000037`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["zeroQ[Bianchi[1]]",
  FontFamily->"Courier"],
 " in this case gives ",
 StyleBox["False",
  FontFamily->"Courier"],
 " (after ~70 sec)! The reason is that the ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 " used imply relations among the 3rd derivatives of the functions ",
 StyleBox["U[x1,x2],",
  FontFamily->"Courier"],
 " ",
 StyleBox["G[x1,x2],",
  FontFamily->"Courier"],
 " ",
 StyleBox["H[x1,x2]",
  FontFamily->"Courier"],
 ".\n\t",
 StyleBox["Exercise",
  FontSlant->"Italic"],
 ": Find the additional two rules needed to satisfy the Bianchi identities."
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"u", ",", "g", ",", "h", ",", "a", ",", "b", ",", "c"}], 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 6: Harrison metric II-A-7 (Phys. Rev. 116, 1285) (~ 20 sec)\
\>", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "x", "]"}], ";", 
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rt3", "=", 
   RowBox[{"Sqrt", "[", "3", "]"}]}], ";", 
  RowBox[{"F1", "=", 
   RowBox[{
    RowBox[{"x", "/", "rt3"}], "-", 
    RowBox[{
     RowBox[{"t", "^", "2"}], "/", "12"}]}]}], " ", ";", 
  RowBox[{
   RowBox[{
    SuperscriptBox["F2", "\[Prime]",
     MultilineFunction->None], "[", "z", "]"}], "=", 
   RowBox[{
    RowBox[{"F2", "[", "z", "]"}], 
    RowBox[{
     RowBox[{"v", "[", "z", "]"}], "/", "z"}]}]}], ";", 
  RowBox[{
   RowBox[{
    SuperscriptBox["v", "\[Prime]",
     MultilineFunction->None], "[", "z", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "z", "]"}], "^", "2"}], "-", "1"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "z"}], ")"}]}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "  ", 
       RowBox[{
        RowBox[{"v", "[", "z", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}]}]}], "+", 
      RowBox[{"4", "/", "rt3"}]}], ")"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n1", "[", "t", "]"}], "=", 
   RowBox[{"2", "+", "rt3"}]}], ";", 
  RowBox[{
   RowBox[{"n1", "[", "x", "]"}], "=", 
   RowBox[{"1", "+", "rt3"}]}], ";", 
  RowBox[{
   RowBox[{"n1", "[", "y", "]"}], "=", 
   RowBox[{"-", "rt3"}]}], ";", 
  RowBox[{
   RowBox[{"n1", "[", "z", "]"}], "=", 
   RowBox[{"3", "+", "rt3"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n2", "[", "t", "]"}], "=", 
   RowBox[{"1", "+", 
    RowBox[{"2", "/", "rt3"}]}]}], ";", 
  RowBox[{
   RowBox[{"n2", "[", "x", "]"}], "=", 
   RowBox[{"1", "+", 
    RowBox[{"2", "/", "rt3"}]}]}], ";", 
  RowBox[{
   RowBox[{"n2", "[", "y", "]"}], "=", 
   RowBox[{"-", "1"}]}], ";", 
  RowBox[{
   RowBox[{"n2", "[", "z", "]"}], "=", 
   RowBox[{"1", "+", 
    RowBox[{"2", "/", "rt3"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n3", "[", "t", "]"}], "=", 
   RowBox[{"1", "/", "rt3"}]}], ";", 
  RowBox[{
   RowBox[{"n3", "[", "x", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"1", "/", "rt3"}]}], ")"}]}], ";", 
  RowBox[{
   RowBox[{"n3", "[", "y", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "/", "rt3"}]}], ";", 
  RowBox[{
   RowBox[{"n3", "[", "z", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{"2", "+", 
     RowBox[{"1", "/", "rt3"}]}], ")"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"F1", "^", 
        RowBox[{"n1", "[", "t", "]"}]}], 
       RowBox[{
        RowBox[{"F2", "[", "z", "]"}], "^", 
        RowBox[{"n2", "[", "t", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "z"}], ")"}], "^", 
        RowBox[{"n3", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"F1", "^", 
         RowBox[{"n1", "[", "x", "]"}]}]}], 
       RowBox[{
        RowBox[{"F2", "[", "z", "]"}], "^", 
        RowBox[{"n2", "[", "x", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "z"}], ")"}], "^", 
        RowBox[{"n3", "[", "x", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"F1", "^", 
         RowBox[{"n1", "[", "y", "]"}]}]}], 
       RowBox[{
        RowBox[{"F2", "[", "z", "]"}], "^", 
        RowBox[{"n2", "[", "y", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "z"}], ")"}], "^", 
        RowBox[{"n3", "[", "y", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"F1", "^", 
         RowBox[{"n1", "[", "z", "]"}]}]}], 
       RowBox[{
        RowBox[{"F2", "[", "z", "]"}], "^", 
        RowBox[{"n2", "[", "z", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "z"}], ")"}], "^", 
        RowBox[{"n3", "[", "z", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", "z", "]"}], "^", "2"}], "-", "1"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}]}]}]}], "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["t", "2"], "12"]}], "+", 
            FractionBox["x", 
             SqrtBox["3"]]}], ")"}], 
          RowBox[{"2", "+", 
           SqrtBox["3"]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            FractionBox["1", "z"]}], ")"}], 
          FractionBox["1", 
           SqrtBox["3"]]], " ", 
         SuperscriptBox[
          RowBox[{"F2", "[", "z", "]"}], 
          RowBox[{"1", "+", 
           FractionBox["2", 
            SqrtBox["3"]]}]]}], "0", "0", "0"},
       {"0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox["t", "2"], "12"]}], "+", 
             FractionBox["x", 
              SqrtBox["3"]]}], ")"}], 
           RowBox[{"1", "+", 
            SqrtBox["3"]}]]}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            FractionBox["1", "z"]}], ")"}], 
          RowBox[{"1", "+", 
           FractionBox["1", 
            SqrtBox["3"]]}]], " ", 
         SuperscriptBox[
          RowBox[{"F2", "[", "z", "]"}], 
          RowBox[{"1", "+", 
           FractionBox["2", 
            SqrtBox["3"]]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["t", "2"], "12"]}], "+", 
              FractionBox["x", 
               SqrtBox["3"]]}], ")"}], 
            RowBox[{"-", 
             SqrtBox["3"]}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              FractionBox["1", "z"]}], ")"}], 
            RowBox[{"-", 
             FractionBox["1", 
              SqrtBox["3"]]}]]}], 
          RowBox[{"F2", "[", "z", "]"}]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["t", "2"], "12"]}], "+", 
              FractionBox["x", 
               SqrtBox["3"]]}], ")"}], 
            RowBox[{"3", "+", 
             SqrtBox["3"]}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              FractionBox["1", "z"]}], ")"}], 
            RowBox[{"2", "+", 
             FractionBox["1", 
              SqrtBox["3"]]}]], " ", 
           SuperscriptBox[
            RowBox[{"F2", "[", "z", "]"}], 
            RowBox[{"1", "+", 
             FractionBox["2", 
              SqrtBox["3"]]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox[
              RowBox[{"v", "[", "z", "]"}], "2"]}], ")"}]}], 
          RowBox[{
           RowBox[{"-", "1"}], "+", "z"}]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{((Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(2 + 
         3^Rational[1, 2]) ((-1)/z)^(3^Rational[-1, 2])) 
      F2[z]^(1 + 2 3^Rational[-1, 2]), 0, 0, 0}, {
     0, ((-(Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(1 + 
          3^Rational[1, 2])) ((-1)/z)^(1 + 3^Rational[-1, 2])) 
      F2[z]^(1 + 2 3^Rational[-1, 2]), 0, 0}, {
     0, 0, (-(Rational[-1, 12] t^2 + 
         3^Rational[-1, 2] x)^(-3^Rational[1, 2])) (((-1)/
         z)^(-3^Rational[-1, 2])/F2[z]), 0}, {
     0, 0, 0, ((((-(Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(3 + 
            3^Rational[1, 2]))/(-1 + z)) ((-1)/z)^(2 + 3^Rational[-1, 2])) 
       F2[z]^(1 + 2 3^Rational[-1, 2])) (-1 + v[z]^2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["t", "2"], "12"]}], "+", 
          FractionBox["x", 
           SqrtBox["3"]]}], ")"}], 
        RowBox[{"-", 
         SqrtBox["3"]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox["1", "z"]}], ")"}], 
        RowBox[{"-", 
         FractionBox["1", 
          SqrtBox["3"]]}]], " ", 
       SuperscriptBox[
        RowBox[{"d", "[", "y", "]"}], "2"]}]}], 
     RowBox[{"F2", "[", "z", "]"}]], "+", 
    RowBox[{
     FractionBox["1", "144"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["t", "2"], "12"]}], "+", 
        FractionBox["x", 
         SqrtBox["3"]]}], ")"}], 
      SqrtBox["3"]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t", "4"], "-", 
       RowBox[{"8", " ", 
        SqrtBox["3"], " ", 
        SuperscriptBox["t", "2"], " ", "x"}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", 
        FractionBox["1", "z"]}], ")"}], 
      FractionBox["1", 
       SqrtBox["3"]]], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"F2", "[", "z", "]"}], 
      RowBox[{"1", "+", 
       FractionBox["2", 
        SqrtBox["3"]]}]]}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["t", "2"], "12"]}], "+", 
         FractionBox["x", 
          SqrtBox["3"]]}], ")"}], 
       SqrtBox["3"]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "2"], "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"], " ", "x"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["1", "z"]}], ")"}], 
       FractionBox["1", 
        SqrtBox["3"]]], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"F2", "[", "z", "]"}], 
       RowBox[{"1", "+", 
        FractionBox["2", 
         SqrtBox["3"]]}]]}], 
     RowBox[{"12", " ", "z"}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["t", "2"], "12"]}], "+", 
         FractionBox["x", 
          SqrtBox["3"]]}], ")"}], 
       SqrtBox["3"]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t", "6"], "-", 
        RowBox[{"12", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["t", "4"], " ", "x"}], "+", 
        RowBox[{"144", " ", 
         SuperscriptBox["t", "2"], " ", 
         SuperscriptBox["x", "2"]}], "-", 
        RowBox[{"192", " ", 
         SqrtBox["3"], " ", 
         SuperscriptBox["x", "3"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", 
         FractionBox["1", "z"]}], ")"}], 
       FractionBox["1", 
        SqrtBox["3"]]], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "z", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"F2", "[", "z", "]"}], 
       RowBox[{"1", "+", 
        FractionBox["2", 
         SqrtBox["3"]]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"v", "[", "z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"v", "[", "z", "]"}]}], ")"}]}], 
     RowBox[{"1728", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
      SuperscriptBox["z", "2"]}]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((-(Rational[-1, 12] t^2 + 
        3^Rational[-1, 2] x)^(-3^Rational[1, 2])) ((-1)/
       z)^(-3^Rational[-1, 2])) (d[y]^2/F2[
     z]) + ((((
        Rational[
         1, 144] (Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(3^
          Rational[1, 2])) (t^4 - ((8 3^Rational[1, 2]) t^2) x + 
        48 x^2)) ((-1)/z)^(3^Rational[-1, 2])) d[t]^2) 
    F2[z]^(1 + 2 
       3^Rational[-1, 2]) + (((((
         Rational[-1, 12] (Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(3^
           Rational[1, 2])) (t^2 - (4 3^Rational[1, 2]) x)) ((-1)/z)^(3^
         Rational[-1, 2]))/z) d[x]^2) 
    F2[z]^(1 + 2 
       3^Rational[-1, 
          2]) + ((((((((
            Rational[
             1, 1728] (Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(3^
              Rational[1, 2])) (t^6 - ((12 3^Rational[1, 2]) t^4) 
            x + (144 t^2) x^2 - (192 3^Rational[1, 2]) x^3))/(-1 + 
          z)) ((-1)/z)^(3^Rational[-1, 2])) z^(-2)) d[z]^2) 
      F2[z]^(1 + 2 3^Rational[-1, 2])) (-1 + v[z])) (1 + v[z])],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox[
         RowBox[{"144", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox["t", "2"], "12"]}], "+", 
             FractionBox["x", 
              SqrtBox["3"]]}], ")"}], 
           RowBox[{"-", 
            SqrtBox["3"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["t", "8"], "-", 
            RowBox[{"16", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["t", "6"], " ", "x"}], "+", 
            RowBox[{"288", " ", 
             SuperscriptBox["t", "4"], " ", 
             SuperscriptBox["x", "2"]}], "-", 
            RowBox[{"768", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["t", "2"], " ", 
             SuperscriptBox["x", "3"]}], "+", 
            RowBox[{"2304", " ", 
             SuperscriptBox["x", "4"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", 
             FractionBox["1", "z"]}], ")"}], 
           RowBox[{"-", 
            FractionBox["1", 
             SqrtBox["3"]]}]], " ", 
          SuperscriptBox[
           RowBox[{"F2", "[", "z", "]"}], 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            FractionBox["2", 
             SqrtBox["3"]]}]]}], 
         RowBox[{
          SuperscriptBox["t", "12"], "-", 
          RowBox[{"24", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["t", "10"], " ", "x"}], "+", 
          RowBox[{"720", " ", 
           SuperscriptBox["t", "8"], " ", 
           SuperscriptBox["x", "2"]}], "-", 
          RowBox[{"3840", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["t", "6"], " ", 
           SuperscriptBox["x", "3"]}], "+", 
          RowBox[{"34560", " ", 
           SuperscriptBox["t", "4"], " ", 
           SuperscriptBox["x", "4"]}], "-", 
          RowBox[{"55296", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["t", "2"], " ", 
           SuperscriptBox["x", "5"]}], "+", 
          RowBox[{"110592", " ", 
           SuperscriptBox["x", "6"]}]}]], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"12", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["t", "2"], "12"]}], "+", 
              FractionBox["x", 
               SqrtBox["3"]]}], ")"}], 
            RowBox[{"-", 
             SqrtBox["3"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["t", "10"], "-", 
             RowBox[{"20", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["t", "8"], " ", "x"}], "+", 
             RowBox[{"480", " ", 
              SuperscriptBox["t", "6"], " ", 
              SuperscriptBox["x", "2"]}], "-", 
             RowBox[{"1920", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["t", "4"], " ", 
              SuperscriptBox["x", "3"]}], "+", 
             RowBox[{"11520", " ", 
              SuperscriptBox["t", "2"], " ", 
              SuperscriptBox["x", "4"]}], "-", 
             RowBox[{"9216", " ", 
              SqrtBox["3"], " ", 
              SuperscriptBox["x", "5"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              FractionBox["1", "z"]}], ")"}], 
            RowBox[{"-", 
             FractionBox["1", 
              SqrtBox["3"]]}]], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"F2", "[", "z", "]"}], 
            RowBox[{
             RowBox[{"-", "1"}], "-", 
             FractionBox["2", 
              SqrtBox["3"]]}]]}], 
          RowBox[{
           SuperscriptBox["t", "12"], "-", 
           RowBox[{"24", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["t", "10"], " ", "x"}], "+", 
           RowBox[{"720", " ", 
            SuperscriptBox["t", "8"], " ", 
            SuperscriptBox["x", "2"]}], "-", 
           RowBox[{"3840", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["t", "6"], " ", 
            SuperscriptBox["x", "3"]}], "+", 
           RowBox[{"34560", " ", 
            SuperscriptBox["t", "4"], " ", 
            SuperscriptBox["x", "4"]}], "-", 
           RowBox[{"55296", " ", 
            SqrtBox["3"], " ", 
            SuperscriptBox["t", "2"], " ", 
            SuperscriptBox["x", "5"]}], "+", 
           RowBox[{"110592", " ", 
            SuperscriptBox["x", "6"]}]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox["t", "2"], "12"]}], "+", 
             FractionBox["x", 
              SqrtBox["3"]]}], ")"}], 
           SqrtBox["3"]]}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            FractionBox["1", "z"]}], ")"}], 
          FractionBox["1", 
           SqrtBox["3"]]], " ", 
         RowBox[{"F2", "[", "z", "]"}]}], "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{"1728", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               SuperscriptBox["t", "2"], "12"]}], "+", 
             FractionBox["x", 
              SqrtBox["3"]]}], ")"}], 
           RowBox[{"-", 
            SqrtBox["3"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["t", "6"], "-", 
            RowBox[{"12", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["t", "4"], " ", "x"}], "+", 
            RowBox[{"144", " ", 
             SuperscriptBox["t", "2"], " ", 
             SuperscriptBox["x", "2"]}], "-", 
            RowBox[{"192", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["x", "3"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", 
             FractionBox["1", "z"]}], ")"}], 
           RowBox[{"-", 
            FractionBox["1", 
             SqrtBox["3"]]}]], " ", 
          SuperscriptBox["z", "2"], " ", 
          SuperscriptBox[
           RowBox[{"F2", "[", "z", "]"}], 
           RowBox[{
            RowBox[{"-", "1"}], "-", 
            FractionBox["2", 
             SqrtBox["3"]]}]]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["t", "12"], "-", 
            RowBox[{"24", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["t", "10"], " ", "x"}], "+", 
            RowBox[{"720", " ", 
             SuperscriptBox["t", "8"], " ", 
             SuperscriptBox["x", "2"]}], "-", 
            RowBox[{"3840", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["t", "6"], " ", 
             SuperscriptBox["x", "3"]}], "+", 
            RowBox[{"34560", " ", 
             SuperscriptBox["t", "4"], " ", 
             SuperscriptBox["x", "4"]}], "-", 
            RowBox[{"55296", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["t", "2"], " ", 
             SuperscriptBox["x", "5"]}], "+", 
            RowBox[{"110592", " ", 
             SuperscriptBox["x", "6"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"v", "[", "z", "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"v", "[", "z", "]"}]}], ")"}]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{((((
          144 (Rational[-1, 12] t^2 + 
            3^Rational[-1, 2] x)^(-3^Rational[1, 2])) (
          t^8 - ((16 3^Rational[1, 2]) t^6) 
          x + (288 t^4) x^2 - ((768 3^Rational[1, 2]) t^2) x^3 + 2304 x^4))/(
        t^12 - ((24 3^Rational[1, 2]) t^10) 
        x + (720 t^8) x^2 - ((3840 3^Rational[1, 2]) t^6) 
        x^3 + (34560 t^4) x^4 - ((55296 3^Rational[1, 2]) t^2) x^5 + 
        110592 x^6)) ((-1)/z)^(-3^Rational[-1, 2])) 
      F2[z]^(-1 - 2 3^Rational[-1, 2]), 0, 0, 0}, {
     0, ((((((-12) (Rational[-1, 12] t^2 + 
             3^Rational[-1, 2] x)^(-3^Rational[1, 2])) (
           t^10 - ((20 3^Rational[1, 2]) t^8) 
           x + (480 t^6) x^2 - ((1920 3^Rational[1, 2]) t^4) 
           x^3 + (11520 t^2) x^4 - (9216 3^Rational[1, 2]) x^5))/(
         t^12 - ((24 3^Rational[1, 2]) t^10) 
         x + (720 t^8) x^2 - ((3840 3^Rational[1, 2]) t^6) 
         x^3 + (34560 t^4) x^4 - ((55296 3^Rational[1, 2]) t^2) x^5 + 
         110592 x^6)) ((-1)/z)^(-3^Rational[-1, 2])) z) 
      F2[z]^(-1 - 2 3^Rational[-1, 2]), 0, 0}, {
     0, 0, ((-(Rational[-1, 12] t^2 + 3^Rational[-1, 2] x)^(3^
          Rational[1, 2])) ((-1)/z)^(3^Rational[-1, 2])) F2[z], 0}, {
     0, 0, 0, (((((((
             1728 (Rational[-1, 12] t^2 + 
               3^Rational[-1, 2] x)^(-3^Rational[1, 2])) (
             t^6 - ((12 3^Rational[1, 2]) t^4) 
             x + (144 t^2) x^2 - (192 3^Rational[1, 2]) x^3))/(
           t^12 - ((24 3^Rational[1, 2]) t^10) 
           x + (720 t^8) x^2 - ((3840 3^Rational[1, 2]) t^6) 
           x^3 + (34560 t^4) x^4 - ((55296 3^Rational[1, 2]) t^2) x^5 + 
           110592 x^6)) (-1 + z)) ((-1)/z)^(-3^Rational[-1, 2])) z^2) 
       F2[z]^(-1 - 2 3^Rational[-1, 2])) ((-1 + v[z])^(-1)/(1 + v[z]))}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.966666666666668561`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.9666666666666686, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "1.4166666666666714`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 1.4166666666666714`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "7.13333333333332575`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 7.133333333333326, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "4.88333333333333996`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 4.88333333333334, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "4.84999999999999431`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 4.849999999999994, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"19.6166666666666742`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["detg"], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2985984", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
    SuperscriptBox["z", "3"]}]], 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["t", "2"], "12"]}], "+", 
       FractionBox["x", 
        SqrtBox["3"]]}], ")"}], 
     RowBox[{"2", " ", 
      SqrtBox["3"]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["t", "12"], "-", 
      RowBox[{"24", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["t", "10"], " ", "x"}], "+", 
      RowBox[{"720", " ", 
       SuperscriptBox["t", "8"], " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"3840", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["t", "6"], " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"34560", " ", 
       SuperscriptBox["t", "4"], " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"55296", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["t", "2"], " ", 
       SuperscriptBox["x", "5"]}], "+", 
      RowBox[{"110592", " ", 
       SuperscriptBox["x", "6"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", 
       FractionBox["1", "z"]}], ")"}], 
     FractionBox["2", 
      SqrtBox["3"]]], " ", 
    SuperscriptBox[
     RowBox[{"F2", "[", "z", "]"}], 
     RowBox[{"2", "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"]}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"v", "[", "z", "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"v", "[", "z", "]"}]}], ")"}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["\tMathematica",
  FontSlant->"Italic"],
 " 4 is able to factor the long polynomial (",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    StyleBox["t",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"Outline"->False,
     "Shadow"->False,
     "Underline"->False}], "12"], "..."}]], "Input"],
 ")  appearing in ",
 StyleBox["detg",
  FontFamily->"Courier"],
 "  as  ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["t", "2"], "-", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "x"}]}], ")"}], "6"]]],
 " (and also the other polynomials in gUU). As a result the calculation is \
completed in 1/3 the time!"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 7: Bondi metric (Proc. Roy. Soc. A269, 21) (~ 40 + 15 sec)\
\>", "Subsection",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"u", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"2", " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], 
         RowBox[{
          RowBox[{"V", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "/", "r"}]}], "-", 
        RowBox[{
         RowBox[{"r", "^", "2"}], 
         RowBox[{"Exp", "[", 
          RowBox[{"2", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], 
         RowBox[{
          RowBox[{"U", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "^", "2"}]}]}], 
       ",", 
       RowBox[{"Exp", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], ",", 
       RowBox[{
        RowBox[{"r", "^", "2"}], 
        RowBox[{"Exp", "[", 
         RowBox[{"2", 
          RowBox[{"\[Gamma]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], 
        RowBox[{"U", "[", 
         RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], ",", "0", 
       ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "^", "2"}], 
        RowBox[{"Exp", "[", 
         RowBox[{"2", 
          RowBox[{"\[Gamma]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], 
        RowBox[{"U", "[", 
         RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"r", "^", "2"}]}], 
        RowBox[{"Exp", "[", 
         RowBox[{"2", 
          RowBox[{"\[Gamma]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}]}], ",", 
       "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"r", "^", "2"}]}], 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], 
          RowBox[{"\[Gamma]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "]"}], 
        RowBox[{
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["E", 
            RowBox[{"2", " ", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]]}], " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "2"]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{"2", " ", 
             RowBox[{"\[Beta]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
           RowBox[{"V", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "r"]}], 
        SuperscriptBox["E", 
         RowBox[{"2", " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "0"},
       {
        SuperscriptBox["E", 
         RowBox[{"2", " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], "0", "0", 
        "0"},
       {
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["E", 
           RowBox[{"2", " ", 
            RowBox[{"\[Gamma]", "[", 
             RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]]}], " ", 
         SuperscriptBox["r", "2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["E", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"\[Gamma]", "[", 
             RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]]}], " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{((-E^(2 \[Gamma][u, r, \[Theta]])) r^2) 
       U[u, r, \[Theta]]^2 + (E^(2 \[Beta][u, r, \[Theta]])/r) 
       V[u, r, \[Theta]], 
      E^(2 \[Beta][u, r, \[Theta]]), (E^(2 \[Gamma][u, r, \[Theta]]) r^2) 
      U[u, r, \[Theta]], 0}, {
     E^(2 \[Beta][u, r, \[Theta]]), 0, 0, 
      0}, {(E^(2 \[Gamma][u, r, \[Theta]]) r^2) U[u, r, \[Theta]], 
      0, (-E^(2 \[Gamma][u, r, \[Theta]])) r^2, 0}, {
     0, 0, 0, ((-E^((-2) \[Gamma][u, r, \[Theta]])) r^2) Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Beta]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     RowBox[{"d", "[", "r", "]"}], " ", 
     RowBox[{"d", "[", "u", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"d", "[", "u", "]"}], " ", 
     RowBox[{"d", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"U", "[", 
      RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"d", "[", "u", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         RowBox[{"V", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]}], ")"}]}], 
     "r"]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((2 E^(2 \[Beta][u, r, \[Theta]])) d[r]) d[u] - (
    E^(2 \[Gamma][u, r, \[Theta]]) r^2) 
   d[\[Theta]]^2 - ((E^((-2) \[Gamma][u, r, \[Theta]]) r^2) d[\[CurlyPhi]]^2) 
   Sin[\[Theta]]^2 + ((((2 E^(2 \[Gamma][u, r, \[Theta]])) r^2) d[u]) 
     d[\[Theta]]) U[u, r, \[Theta]] - (r^(-1) 
    d[u]^2) ((E^(2 \[Gamma][u, r, \[Theta]]) r^3) U[u, r, \[Theta]]^2 - 
    E^(2 \[Beta][u, r, \[Theta]]) V[u, r, \[Theta]])],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"0", 
        SuperscriptBox["E", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], "0", "0"},
       {
        SuperscriptBox["E", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"\[Beta]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
           RowBox[{"V", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "r"]}], 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "0"},
       {"0", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["E", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"\[Gamma]", "[", 
             RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], 
          SuperscriptBox["r", "2"]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{"2", " ", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], 
          SuperscriptBox["r", "2"]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{0, E^((-2) \[Beta][u, r, \[Theta]]), 0, 0}, {
     E^((-2) \[Beta][u, r, \[Theta]]), ((-E^((-2) \[Beta][u, r, \[Theta]]))/r)
        V[u, r, \[Theta]], E^((-2) \[Beta][u, r, \[Theta]]) U[u, r, \[Theta]],
       0}, {0, E^((-2) \[Beta][u, r, \[Theta]]) 
      U[u, r, \[Theta]], (-E^((-2) \[Gamma][u, r, \[Theta]])) r^(-2), 0}, {
     0, 0, 0, ((-E^(2 \[Gamma][u, r, \[Theta]])) r^(-2)) Csc[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999971578`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.04999999999999716, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.799999999999997157`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.7999999999999972, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "3.40000000000000568`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 3.4000000000000057`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "12.6666666666666705`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 12.666666666666671`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "5.48333333333333428`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 5.483333333333334, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "11.7500000000000004`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 11.75, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "4.11666666666667424`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 4.116666666666674, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"38.4500000000000152`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GUdd", "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "2", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["E", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"\[Beta]", "[", 
     RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Beta]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     RowBox[{
      SuperscriptBox["\[Beta]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rdd", "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"r", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Gamma]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "2"]}]}], ")"}]}], 
   "r"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EUd", "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox["r", "2"]}]], 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["E", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"\[Beta]", "[", 
       RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       RowBox[{
        SuperscriptBox["V", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       RowBox[{"V", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Gamma]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{
        SuperscriptBox["V", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"V", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{
        SuperscriptBox["V", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{"V", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{"U", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{
        SuperscriptBox["V", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{"V", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", "r", " ", 
       RowBox[{"V", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Beta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Beta]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Gamma]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"2", " ", 
         RowBox[{"\[Gamma]", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
       SuperscriptBox["r", "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]}], ")"}]}], 
   ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"covD", "[", "gdd", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Verification of the Bianchi identities for this metric takes ~ 33 \
min (22 min + 11 min + 20 sec).",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 "\n\t",
 StyleBox["One can choose to skip the time consuming RUddd and/or Wdddd \
computations by calling ",
  FontSize->16],
 StyleBox["RGtensors",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" wirh a 3rd argument:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["E", 
            RowBox[{"2", " ", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]]}], " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "2"]}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{"2", " ", 
             RowBox[{"\[Beta]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
           RowBox[{"V", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "r"]}], 
        SuperscriptBox["E", 
         RowBox[{"2", " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "0"},
       {
        SuperscriptBox["E", 
         RowBox[{"2", " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], "0", "0", 
        "0"},
       {
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["E", 
           RowBox[{"2", " ", 
            RowBox[{"\[Gamma]", "[", 
             RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]]}], " ", 
         SuperscriptBox["r", "2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["E", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"\[Gamma]", "[", 
             RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]]}], " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{((-E^(2 \[Gamma][u, r, \[Theta]])) r^2) 
       U[u, r, \[Theta]]^2 + (E^(2 \[Beta][u, r, \[Theta]])/r) 
       V[u, r, \[Theta]], 
      E^(2 \[Beta][u, r, \[Theta]]), (E^(2 \[Gamma][u, r, \[Theta]]) r^2) 
      U[u, r, \[Theta]], 0}, {
     E^(2 \[Beta][u, r, \[Theta]]), 0, 0, 
      0}, {(E^(2 \[Gamma][u, r, \[Theta]]) r^2) U[u, r, \[Theta]], 
      0, (-E^(2 \[Gamma][u, r, \[Theta]])) r^2, 0}, {
     0, 0, 0, ((-E^((-2) \[Gamma][u, r, \[Theta]])) r^2) Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Beta]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     RowBox[{"d", "[", "r", "]"}], " ", 
     RowBox[{"d", "[", "u", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["E", 
      RowBox[{"2", " ", 
       RowBox[{"\[Gamma]", "[", 
        RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"d", "[", "u", "]"}], " ", 
     RowBox[{"d", "[", "\[Theta]", "]"}], " ", 
     RowBox[{"U", "[", 
      RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"d", "[", "u", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Gamma]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"2", " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         RowBox[{"V", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]}], ")"}]}], 
     "r"]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((2 E^(2 \[Beta][u, r, \[Theta]])) d[r]) d[u] - (
    E^(2 \[Gamma][u, r, \[Theta]]) r^2) 
   d[\[Theta]]^2 - ((E^((-2) \[Gamma][u, r, \[Theta]]) r^2) d[\[CurlyPhi]]^2) 
   Sin[\[Theta]]^2 + ((((2 E^(2 \[Gamma][u, r, \[Theta]])) r^2) d[u]) 
     d[\[Theta]]) U[u, r, \[Theta]] - (r^(-1) 
    d[u]^2) ((E^(2 \[Gamma][u, r, \[Theta]]) r^3) U[u, r, \[Theta]]^2 - 
    E^(2 \[Beta][u, r, \[Theta]]) V[u, r, \[Theta]])],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"0", 
        SuperscriptBox["E", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], "0", "0"},
       {
        SuperscriptBox["E", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"\[Beta]", "[", 
           RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"\[Beta]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
           RowBox[{"V", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "r"]}], 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], "0"},
       {"0", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"\[Beta]", "[", 
            RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
         RowBox[{"U", "[", 
          RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}], 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox["E", 
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{"\[Gamma]", "[", 
             RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], 
          SuperscriptBox["r", "2"]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["E", 
            RowBox[{"2", " ", 
             RowBox[{"\[Gamma]", "[", 
              RowBox[{"u", ",", "r", ",", "\[Theta]"}], "]"}]}]], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], 
          SuperscriptBox["r", "2"]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{0, E^((-2) \[Beta][u, r, \[Theta]]), 0, 0}, {
     E^((-2) \[Beta][u, r, \[Theta]]), ((-E^((-2) \[Beta][u, r, \[Theta]]))/r)
        V[u, r, \[Theta]], E^((-2) \[Beta][u, r, \[Theta]]) U[u, r, \[Theta]],
       0}, {0, E^((-2) \[Beta][u, r, \[Theta]]) 
      U[u, r, \[Theta]], (-E^((-2) \[Gamma][u, r, \[Theta]])) r^(-2), 0}, {
     0, 0, 0, ((-E^(2 \[Gamma][u, r, \[Theta]])) r^(-2)) Csc[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0499999999999829469`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.04999999999998295, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.833333333333342807`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.8333333333333428, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "3.51666666666667993`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 3.51666666666668, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"RUddd not computed\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "5.53333333333333143`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 5.533333333333331, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Weyl tensor not computed\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "4.16666666666668561`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 4.166666666666686, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"14.3666666666666742`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example 8: Kerr with Cos[\[Theta]],  Sin[\[Theta]] (~ 45 + 5 sec)\
\>", "Subsection",
 FontSize->16],

Cell["\<\
\tTransform Boyer-Lindquist t, \[CurlyPhi]BL coordinates:  \
d[t]->d[u]+(r^2+a^2) d[r]/(r^2-2M r+a^2),  d[\[CurlyPhi]BL]->d[\[CurlyPhi]]+a \
d[r]/(r^2-2M r+a^2);\
\>", "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"u", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"2", " ", "M", " ", "r"}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], ",", "1", ",",
        "0", ",", 
       FractionBox[
        RowBox[{"2", "a", "  ", "M", " ", "r", " ", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", "a"}], "  ", 
        RowBox[{
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"r", "^", "2"}], "+", 
          RowBox[{
           RowBox[{"a", "^", "2"}], 
           RowBox[{
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "^", "2"}]}]}], ")"}]}], 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"2", "a", "  ", "M", " ", "r", " ", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}], 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], ",", 
       RowBox[{
        RowBox[{"-", "a"}], "  ", 
        RowBox[{
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}], ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["r", "2"]}], "+", 
           SuperscriptBox["r", "4"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              RowBox[{"2", " ", "M", " ", "r"}], "+", 
              SuperscriptBox["r", "2"]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]}]}], 
      "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[{
 "\n\n\t",
 StyleBox["(1)  Use TrigRules in simpRules and do not compute theWeyl tensor:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M", " ", "r"}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], "1", "0", 
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]},
       {"1", "0", "0", 
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], "0"},
       {
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], 
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["r", "2"]}], "+", 
             SuperscriptBox["r", "4"], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                RowBox[{"2", " ", "M", " ", "r"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
     1 - (2 M) (r/(r^2 + a^2 Cos[\[Theta]]^2)), 1, 
      0, ((((2 a) M) r)/(r^2 + a^2 Cos[\[Theta]]^2)) Sin[\[Theta]]^2}, {
     1, 0, 0, (-a) Sin[\[Theta]]^2}, {
     0, 0, -r^2 - a^2 Cos[\[Theta]]^2, 
      0}, {((((2 a) M) r)/(r^2 + a^2 Cos[\[Theta]]^2)) Sin[\[Theta]]^2, (-a) 
      Sin[\[Theta]]^2, 
      0, (((-1)/(r^2 + a^2 Cos[\[Theta]]^2)) (((2 a^2) M) r + a^2 r^2 + 
        r^4 + (a^2 (a^2 - (2 M) r + r^2)) Cos[\[Theta]]^2)) 
      Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"d", "[", "r", "]"}], " ", 
     RowBox[{"d", "[", "u", "]"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M", " ", "r"}], "-", 
        SuperscriptBox["r", "2"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "u", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"d", "[", "r", "]"}], " ", 
     RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "M", " ", "r", " ", 
      RowBox[{"d", "[", "u", "]"}], " ", 
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "2"]}], "+", 
        SuperscriptBox["r", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (2 d[r]) d[u] - (((2 M) r - r^2 - a^2 Cos[\[Theta]]^2)/(
    r^2 + a^2 Cos[\[Theta]]^2)) 
   d[u]^2 + (-r^2 - a^2 Cos[\[Theta]]^2) d[\[Theta]]^2 - (((2 a) d[r]) 
    d[\[CurlyPhi]]) 
   Sin[\[Theta]]^2 + ((((((4 a) M) r)/(r^2 + a^2 Cos[\[Theta]]^2)) d[u]) 
     d[\[CurlyPhi]]) 
    Sin[\[Theta]]^2 - (((r^2 + a^2 Cos[\[Theta]]^2)^(-1) (((2 a^2) M) r + 
      a^2 r^2 + r^4 + a^4 Cos[\[Theta]]^2 - (((2 a^2) M) r) 
      Cos[\[Theta]]^2 + (a^2 r^2) Cos[\[Theta]]^2)) d[\[CurlyPhi]]^2) 
   Sin[\[Theta]]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "-", 
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}], "0", 
        FractionBox["a", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]},
       {
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "-", 
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}], 
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]], "0", 
        RowBox[{"-", 
         FractionBox["a", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "-", 
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}]},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], "0"},
       {
        FractionBox["a", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox["a", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "-", 
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}], "0", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
     a^2 (Sin[\[Theta]]^2/(-a^2 - r^2 + 
       a^2 Sin[\[Theta]]^2)), (-(a^2 + r^2))/(-a^2 - r^2 + 
      a^2 Sin[\[Theta]]^2), 0, a/(-a^2 - r^2 + 
      a^2 Sin[\[Theta]]^2)}, {(-(a^2 + r^2))/(-a^2 - r^2 + 
      a^2 Sin[\[Theta]]^2), (a^2 - (2 M) r + r^2)/(-a^2 - r^2 + 
      a^2 Sin[\[Theta]]^2), 0, (-a)/(-a^2 - r^2 + a^2 Sin[\[Theta]]^2)}, {
     0, 0, (-1)/(r^2 + a^2 Cos[\[Theta]]^2), 0}, {
     a/(-a^2 - r^2 + a^2 Sin[\[Theta]]^2), (-a)/(-a^2 - r^2 + 
      a^2 Sin[\[Theta]]^2), 0, Csc[\[Theta]]^2/(-a^2 - r^2 + 
      a^2 Sin[\[Theta]]^2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "1.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 1., " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.983333333333348491`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.9833333333333485, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "3.19999999999998863`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 3.1999999999999886`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "20.6166666666666742`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 20.616666666666674`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "8.48333333333332006`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 8.48333333333332, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Weyl tensor not computed\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "11.0666666666666624`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 11.066666666666663`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"45.5500000000000149`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Note that, using TrigRules, ",
  FontSize->16],
 StyleBox["RGtensors",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" is unable to verify that the metric is Ricci-Flat. ",
  FontSize->16],
 StyleBox["Rdd",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" has two independent non-vanishing components:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"indepTerms", "[", "Rdd", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"9", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"5", " ", "M", " ", 
         SuperscriptBox["r", "8"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["r", "9"], " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "3"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"7", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "5"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "7"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "7"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "7"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "7"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "7"], " ", 
         RowBox[{"Cot", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"7", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"5", " ", "M", " ", 
         SuperscriptBox["r", "8"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["r", "9"], " ", 
         RowBox[{"Csc", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"5", " ", "M", " ", 
         SuperscriptBox["r", "8"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["r", "9"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"17", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "5"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "5"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "5"]}]}], ")"}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "4"], " ", 
      
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "-", 
         SuperscriptBox["r", "2"], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "2"]}], 
     ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"]}], "+", 
        RowBox[{"M", " ", 
         SuperscriptBox["r", "8"]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"15", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"18", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"M", " ", 
         SuperscriptBox["r", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"19", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"18", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"10", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{"18", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{"17", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"]}], "-", 
        RowBox[{"15", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "10"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", "M", " ", 
         SuperscriptBox["r", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", "M", " ", 
         SuperscriptBox["r", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"], " ", 
         SuperscriptBox[
          RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"7", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"M", " ", 
         SuperscriptBox["r", "8"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"18", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"23", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"9", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"15", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"24", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"27", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"9", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"15", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "8"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", 
         SuperscriptBox["r", "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "7"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"18", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"10", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["r", "5"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"24", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "6"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "M", " ", 
         SuperscriptBox["r", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", "M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "6"]}], "-", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "8"], " ", "M", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "6"]}]}], ")"}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "4"], " ", 
      
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "2"]}], 
     ")"}]}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RUddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["a", "2"], " ", "M", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["r", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "4"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["r", "2"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n\n\t",
 StyleBox["(2)  To simplify denominators in gUU and elsewhere, use extra rule \
in simpRules:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"simpRules", "=", 
  RowBox[{"Join", "[", 
   RowBox[{"TrigRules", ",", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "n_"], ":>", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], 
         RowBox[{"n", "-", "2"}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], "/;", 
       RowBox[{"n", ">", "1"}]}]}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]_", "]"}], "2"], " ", "x_."}], "+", 
     RowBox[{"x_.", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]_", "]"}], "2"]}]}], "\[Rule]", "x"}], 
   ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cot", "[", "\[Theta]_", "]"}], "2"], " ", "x_."}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Csc", "[", "\[Theta]_", "]"}], "2"], " ", "y_."}]}], 
    "\[RuleDelayed]", 
    RowBox[{"y", "/;", 
     RowBox[{
      RowBox[{"x", "+", "y"}], "===", "0"}]}]}], ",", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Sin", "[", "\[Theta]", "]"}], "n_"], "\[RuleDelayed]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{"n", "-", "2"}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], "/;", 
     RowBox[{"n", ">", "1"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M", " ", "r"}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], "1", "0", 
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]},
       {"1", "0", "0", 
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], "0"},
       {
        FractionBox[
         RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], 
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              SuperscriptBox["r", "2"]}], "+", 
             SuperscriptBox["r", "4"], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                RowBox[{"2", " ", "M", " ", "r"}], "+", 
                SuperscriptBox["r", "2"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
     1 - (2 M) (r/(r^2 + a^2 Cos[\[Theta]]^2)), 1, 
      0, ((((2 a) M) r)/(r^2 + a^2 Cos[\[Theta]]^2)) Sin[\[Theta]]^2}, {
     1, 0, 0, (-a) Sin[\[Theta]]^2}, {
     0, 0, -r^2 - a^2 Cos[\[Theta]]^2, 
      0}, {((((2 a) M) r)/(r^2 + a^2 Cos[\[Theta]]^2)) Sin[\[Theta]]^2, (-a) 
      Sin[\[Theta]]^2, 
      0, (((-1)/(r^2 + a^2 Cos[\[Theta]]^2)) (((2 a^2) M) r + a^2 r^2 + 
        r^4 + (a^2 (a^2 - (2 M) r + r^2)) Cos[\[Theta]]^2)) 
      Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"d", "[", "r", "]"}], " ", 
     RowBox[{"d", "[", "u", "]"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M", " ", "r"}], "-", 
        SuperscriptBox["r", "2"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "u", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"d", "[", "r", "]"}], " ", 
     RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "M", " ", "r", " ", 
      RowBox[{"d", "[", "u", "]"}], " ", 
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "2"]}], "+", 
        SuperscriptBox["r", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "M", " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (2 d[r]) d[u] - (((2 M) r - r^2 - a^2 Cos[\[Theta]]^2)/(
    r^2 + a^2 Cos[\[Theta]]^2)) 
   d[u]^2 + (-r^2 - a^2 Cos[\[Theta]]^2) d[\[Theta]]^2 - (((2 a) d[r]) 
    d[\[CurlyPhi]]) 
   Sin[\[Theta]]^2 + ((((((4 a) M) r)/(r^2 + a^2 Cos[\[Theta]]^2)) d[u]) 
     d[\[CurlyPhi]]) 
    Sin[\[Theta]]^2 - (((r^2 + a^2 Cos[\[Theta]]^2)^(-1) (((2 a^2) M) r + 
      a^2 r^2 + r^4 + a^4 Cos[\[Theta]]^2 - (((2 a^2) M) r) 
      Cos[\[Theta]]^2 + (a^2 r^2) Cos[\[Theta]]^2)) d[\[CurlyPhi]]^2) 
   Sin[\[Theta]]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], 
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], "0", 
        RowBox[{"-", 
         FractionBox["a", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]},
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"2", " ", "M", " ", "r"}], "+", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], "0", 
        FractionBox["a", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], "0"},
       {
        RowBox[{"-", 
         FractionBox["a", 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}], 
        FractionBox["a", 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]], "0", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(a^2 (-1 + Cos[\[Theta]])) ((1 + Cos[\[Theta]])/(r^2 + 
       a^2 Cos[\[Theta]]^2)), (a^2 + r^2)/(r^2 + a^2 Cos[\[Theta]]^2), 
      0, (-a)/(r^2 + a^2 Cos[\[Theta]]^2)}, {(a^2 + r^2)/(r^2 + 
      a^2 Cos[\[Theta]]^2), (-(a^2 - (2 M) r + r^2))/(r^2 + 
      a^2 Cos[\[Theta]]^2), 0, a/(r^2 + a^2 Cos[\[Theta]]^2)}, {
     0, 0, (-1)/(r^2 + a^2 Cos[\[Theta]]^2), 0}, {(-a)/(r^2 + 
      a^2 Cos[\[Theta]]^2), a/(r^2 + a^2 Cos[\[Theta]]^2), 
      0, (-1 + Cos[\[Theta]])^(-1) ((1 + Cos[\[Theta]])^(-1)/(r^2 + 
       a^2 Cos[\[Theta]]^2))}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "1.13333333333332575`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 1.1333333333333258`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.766666666666651508`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.7666666666666515, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "1.0833333333333428`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 1.0833333333333428`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "1.96666666666666856`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 1.9666666666666686`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0833333333333428072`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.08333333333334281, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"5.2666666666666515`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GUdd", "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", "2", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "2"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RUddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "3"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["a", "2"], " ", "M", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
   "3"]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Note the speed improvement with the extra simplification rule!",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[TextData[{
 "\n\t",
 StyleBox["There are more examples in Sections 5 and 6.",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Total time = \>\"", ",", 
   RowBox[{"Round", "[", 
    RowBox[{
     RowBox[{"AbsoluteTime", "[", "]"}], "-", "stTim"}], "]"}], ",", 
   "\"\< sec\>\""}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total time = \"\>", "\[InvisibleSpace]", "190", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Total time = ", 190, " sec"],
  Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox[" 4  Usage Tips",
  FontWeight->"Bold"],
 " & Auxiliary Functions"
}], "Section",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "  4.1  Avoid displaying long expressions & keep intermediate results"
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe most important thing to keep in mind when working with nested lists \
is that one can easily generate huge outputs that can tax the graphics \
capabilities of any system and may even cause ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to crash. Besides, not much is gained by viewing on screen deeply nested \
lists containing mostly zeros! Thus, as a general rule, ",
 StyleBox["never evaluate an input line that does not end in a semi-colon",
  FontSlant->"Italic"],
 "(",
 StyleBox[";",
  FontFamily->"Courier"],
 "). As a safeguard, the printed form of any expression that exceeds 200KB \
will be shortened."
}], "Text",
 FontSize->16],

Cell["\<\
\tOne must, therefore, get used to working with symbols representing such \
tensors and only occasionally view individual components or subparts. Also, \
because operations on lists are time-consuming, one must save intermediate \
results in case they are needed later on. For these reasons, a consistent \
system of naming tensors is necessary to keep track of what has been \
calculated.\
\>", "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe U/d naming convention is reasonably short and visually conveys the \
properties (rank, index type) of the tensor represented. For contractions, \
the convention can be extended by using upper/lower case letters (S, s) for \
pairs of contracted indices. Finally, for covariant derivatives, one can use \
the letter j (resembling ",
 StyleBox[";",
  FontFamily->"Courier"],
 ") to separate covariant differentiation indices. For example, the symbol \
RUdddjd is an obvious candidate for ",
 StyleBox["covD[RUddd,{1}]",
  FontFamily->"Courier"],
 ", while RSdddjs can be used for ",
 StyleBox["covDiv[RUddd,{1}]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tAnother notation, similar to the one used for ",
 StyleBox["eta",
  FontFamily->"Courier"],
 " (Section 1.1.1), is to define an appropriately named ",
 StyleBox["function",
  FontSlant->"Italic"],
 " for each tensor, with arguments the positions of the contravariant \
indices. For example, for the Riemann tensor, the definition"
}], "Text",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Riem", "[", "]"}], "=", "Rdddd"}], ";", 
  RowBox[{
   RowBox[{"Riem", "[", "a__", "]"}], ":=", 
   RowBox[{
    RowBox[{"Riem", "[", "a", "]"}], "=", 
    RowBox[{"Raise", "[", 
     RowBox[{"Rdddd", ",", "a"}], "]"}]}]}], ";"}]], "Input"],

Cell[TextData[{
 "would enable one to use the notation ",
 StyleBox["Riem[1]",
  FontFamily->"Courier"],
 " for the tensor ",
 StyleBox["RUddd",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Riem[3,4]",
  FontFamily->"Courier"],
 " for the tensor ",
 StyleBox["RddUU",
  FontFamily->"Courier"],
 ", etc."
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "  4.2  Auxiliary functions for examining and simplifying lists"
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe following auxiliary functions have been defined and are useful in \
examining high rank tensors:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(1) ",
 StyleBox["zeroQ[x_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " tests if the tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is the zero tensor, returning ",
 StyleBox["True",
  FontFamily->"Courier"],
 " or ",
 StyleBox["False",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(2) ",
 StyleBox["nonZeroN[x_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " returns the ",
 StyleBox["Number",
  FontSlant->"Italic"],
 " of non-zero components of the tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(3) ",
 StyleBox["nonZeroL[x_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " returns a ",
 StyleBox["List",
  FontSlant->"Italic"],
 " containing the ",
 StyleBox["distinct ",
  FontSlant->"Italic"],
 "non-zero components of the tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (if ",
 StyleBox["Z",
  FontFamily->"Courier"],
 " is any expression, ",
 StyleBox["Z,-Z,2Z",
  FontFamily->"Courier"],
 "  are considered distinct)."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(4) ",
 StyleBox["indepTerms[x_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " returns a list of the \"independent\" components of the tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". Independent here means not equal to  \[PlusMinus]  a numerical multiple \
of another component. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["indepTerms",
  FontFamily->"Courier"],
 " can take an optional second argument - a list of symbols which, when \
appearing as overall factors, can be ignored in testing equivalence.  For \
example, for the list ",
 StyleBox["s={Z,",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox["a", "2"]]],
 StyleBox["Z,2a*M*Z}",
  FontFamily->"Courier"],
 ",",
 StyleBox[" indepTerms[s]",
  FontFamily->"Courier"],
 " returns ",
 StyleBox["{Z,",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox["a", "2"]]],
 StyleBox["Z,a*M*Z}",
  FontFamily->"Courier"],
 " , while  ",
 StyleBox["indepTerms[s,{a}]",
  FontFamily->"Courier"],
 "  returns  ",
 StyleBox["{Z,M*Z}",
  FontFamily->"Courier"],
 " and ",
 StyleBox["indepTerms[s,{a,M}]",
  FontFamily->"Courier"],
 " returns ",
 StyleBox["{Z}",
  FontFamily->"Courier"],
 ". This option can be useful in reducing the number of independent terms \
when the metric depends on arbitrary constants (a, M as in the Kerr metric). \
"
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["nonZeroL",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["indepTerms",
  FontFamily->"Courier"],
 "  do not perform any reductions: if ",
 StyleBox["s=(a+b)^2,",
  FontFamily->"Courier"],
 " then  ",
 StyleBox["zeroQ[s-Expand[s]]",
  FontFamily->"Courier"],
 " returns ",
 StyleBox["False",
  FontFamily->"Courier"],
 ", while ",
 StyleBox["indepTerms[{s,Expand[s]}]",
  FontFamily->"Courier"],
 " returns ",
 StyleBox["{",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"a", "+", "b"}], ")"}], "2"]]],
 StyleBox[",",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   RowBox[{"2", " ", "a", " ", "b"}], "+", 
   SuperscriptBox["b", "2"]}]]],
 StyleBox["}",
  FontFamily->"Courier"],
 ". "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(5) ",
 StyleBox["FacSimp[x_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " applies the simplification rules defined in ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 " and factors each component of the tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". All basic tensors calculated initially by ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " as well as those returned by the functions ",
 StyleBox["Raise",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Lower",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 ", ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 ",",
 StyleBox["covD",
  FontFamily->"Courier"],
 ", ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["Bianchi",
  FontFamily->"Courier"],
 " have been simplified using ",
 StyleBox["FacSimp",
  FontFamily->"Courier"],
 ". Even though it can be very slow on high-rank tensors and /or when ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 " contains many rules, ",
 StyleBox["FacSimp",
  FontFamily->"Courier"],
 " should ",
 StyleBox["always",
  FontSlant->"Italic"],
 " be used to simplify sums and products (",
 StyleBox["Dot",
  FontFamily->"Courier"],
 " or ",
 StyleBox["Outer",
  FontFamily->"Courier"],
 ") of these tensors. (see \"Taking advantage of symmetries\")"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIf ",
 StyleBox["zeroQ[expr]",
  FontFamily->"Courier"],
 " on an expression that is expected to vanish gives ",
 StyleBox["False",
  FontFamily->"Courier"],
 ",  try ",
 StyleBox["zeroQ[FacSimp[expr]]",
  FontFamily->"Courier"],
 " or,  for high-rank tensors with symmetries,  ",
 StyleBox["zeroQ[FacSimp[indepTerms[expr]]]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "  4.3  Choosing simpRules"
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIt is impossible to overemphasize the importance of choosing appropriate \
simplification rules to be applied by ",
 StyleBox["FacSimp",
  FontFamily->"Courier"],
 ". As ",
 StyleBox["FacSimp",
  FontFamily->"Courier"],
 " is used repeatedly by all functions, minor changes in ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 " can have dramatic effects. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tWhen applying ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " to a new metric, it may not be clear what, if any, ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 " should be used. In such cases, start with no rules and abort ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " after Gamma has been computed. Look at the expressions for gUU and GUdd: \
apart from being factored, are they as simple as they could be? Could a \
simple substitution rule further simplify these expressions? If yes, include \
it in ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 ". As gUU and GUdd are used repeatedly by other functions, even minor \
improvements can have significant effects (see Example 8)."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Exercise",
  FontSlant->"Italic"],
 ": Find the ",
 StyleBox["simpRules",
  FontFamily->"Courier"],
 " that must be used in order that ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " prints ",
 StyleBox["Ricci Flat",
  FontSlant->"Italic"],
 " when applied to the Kruskal form of the Schwarzschild metric:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["gKRUSKAL={{0,-8M^2(1-2M/r[u,v])/(u*v),0,0},{-8M^2(1-2M/r[u,v])/(u*\
v),0,0,0},{0,0,-r[u,v]^2,0},{0,0,0,-r[u,v]^2Sin[\[Theta]]^2}};",
  FontFamily->"Courier"]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["xCoord={u,v,\[Theta],\[CurlyPhi]};",
  FontFamily->"Courier"]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tWhere ",
 StyleBox["r[u,v]",
  FontFamily->"Courier"],
 " is related to the coordinates ",
 StyleBox["u,v",
  FontFamily->"Courier"],
 " by the equation ",
 StyleBox["(2M-r[u,v])Exp[r[u,v]/(2M)]-2M*u*v=0",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIn formulating substitution rules it is better to use many specific rules \
rather than few general ones. The reason is that a general pattern will match \
more instances (even if it fails) and thus slow down the computation. For \
rules and patterns see the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Book, chapters 2.3 and 2.4."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "  4.4  Substituting new functions"
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe function ",
 StyleBox["FuncRepRules[f[y__],g_,n_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (\"Function Replacement Rules\") generates a list of rules for replacing \
the function ",
 StyleBox["f[y]",
  FontFamily->"Courier"],
 " ",
 StyleBox["and all its derivatives up to order n",
  FontSlant->"Italic"],
 " by ",
 StyleBox["g",
  FontFamily->"Courier"],
 " and the corresponding derivatives of ",
 StyleBox["g",
  FontFamily->"Courier"],
 ", where ",
 StyleBox["g",
  FontFamily->"Courier"],
 " can be any expression. The third argument (",
 StyleBox["n",
  FontFamily->"Courier"],
 ") is optional. When it is omitted, rules up to the second derivatives are \
generated. For example:"
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], ",", 
    RowBox[{
     RowBox[{"x", " ", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"u", "[", "x", "]"}], ",", "x"}], "]"}]}], "-", 
     RowBox[{"u", "[", "x", "]"}]}], ",", "3"}], "]"}],
  FontFamily->"Courier",
  FontWeight->"Bold"]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"u", "[", "x", "]"}]}], "+", 
     RowBox[{"x", " ", 
      RowBox[{
       SuperscriptBox["u", "\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
    RowBox[{"x", " ", 
     RowBox[{
      SuperscriptBox["u", "\[DoublePrime]",
       MultilineFunction->None], "[", "x", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[DoublePrime]",
      MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["u", "\[DoublePrime]",
       MultilineFunction->None], "[", "x", "]"}], "+", 
     RowBox[{"x", " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "x", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      TagBox[
       RowBox[{"(", "3", ")"}],
       Derivative],
      MultilineFunction->None], "[", "x", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "x", "]"}]}], "+", 
     RowBox[{"x", " ", 
      RowBox[{
       SuperscriptBox["u", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "x", "]"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{"t", ",", "r"}], "]"}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"r", "-", "t"}], "]"}], "+", 
       RowBox[{"f2", "[", 
        RowBox[{"r", "+", "t"}], "]"}]}], ")"}], "/", "r"}]}], "]"}],
  FontFamily->"Courier",
  FontWeight->"Bold"]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"U", "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"f1", "[", 
       RowBox[{"r", "-", "t"}], "]"}], "+", 
      RowBox[{"f2", "[", 
       RowBox[{"r", "+", "t"}], "]"}]}], "r"]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["U", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"f1", "[", 
        RowBox[{"r", "-", "t"}], "]"}], 
       SuperscriptBox["r", "2"]]}], "-", 
     FractionBox[
      RowBox[{"f2", "[", 
       RowBox[{"r", "+", "t"}], "]"}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "-", "t"}], "]"}], "r"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f2", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "+", "t"}], "]"}], "r"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["U", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"f1", "[", 
        RowBox[{"r", "-", "t"}], "]"}]}], 
      SuperscriptBox["r", "3"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"f2", "[", 
        RowBox[{"r", "+", "t"}], "]"}]}], 
      SuperscriptBox["r", "3"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{"r", "-", "t"}], "]"}]}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["f2", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{"r", "+", "t"}], "]"}]}], 
      SuperscriptBox["r", "2"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f1", "\[DoublePrime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "-", "t"}], "]"}], "r"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f2", "\[DoublePrime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "+", "t"}], "]"}], "r"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["U", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", 
        RowBox[{"r", "-", "t"}], "]"}], "r"]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f2", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "+", "t"}], "]"}], "r"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["U", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "-", "t"}], "]"}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f2", "\[Prime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "+", "t"}], "]"}], 
      SuperscriptBox["r", "2"]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f1", "\[DoublePrime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "-", "t"}], "]"}], "r"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f2", "\[DoublePrime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "+", "t"}], "]"}], "r"]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["U", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "r"}], "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["f1", "\[DoublePrime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "-", "t"}], "]"}], "r"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["f2", "\[DoublePrime]",
        MultilineFunction->None], "[", 
       RowBox[{"r", "+", "t"}], "]"}], "r"]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"FuncRepRules", "[", 
   RowBox[{
    RowBox[{"H", "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "u", "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "^", "2"}], "-", 
        RowBox[{"y", "^", "2"}]}], ")"}]}], "+", 
     RowBox[{"2", 
      RowBox[{"b", "[", "u", "]"}], "x", " ", "y"}]}]}], "]"}],
  FontFamily->"Courier",
  FontWeight->"Bold"]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"H", "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], ")"}], " ", 
      RowBox[{"a", "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "x", " ", "y", " ", 
      RowBox[{"b", "[", "u", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "y", " ", 
      RowBox[{"a", "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "x", " ", 
      RowBox[{"b", "[", "u", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"a", "[", "u", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", "x", " ", 
      RowBox[{"a", "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "y", " ", 
      RowBox[{"b", "[", "u", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{"2", " ", 
     RowBox[{"b", "[", "u", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{"2", " ", 
     RowBox[{"a", "[", "u", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["y", "2"], " ", 
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "x", " ", "y", " ", 
      RowBox[{
       SuperscriptBox["b", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "y", " ", 
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "x", " ", 
      RowBox[{
       SuperscriptBox["b", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", "x", " ", 
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "y", " ", 
      RowBox[{
       SuperscriptBox["b", "\[Prime]",
        MultilineFunction->None], "[", "u", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["H", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"u", ",", "x", ",", "y"}], "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      RowBox[{
       SuperscriptBox["a", "\[DoublePrime]",
        MultilineFunction->None], "[", "u", "]"}]}], "-", 
     RowBox[{
      SuperscriptBox["y", "2"], " ", 
      RowBox[{
       SuperscriptBox["a", "\[DoublePrime]",
        MultilineFunction->None], "[", "u", "]"}]}], "+", 
     RowBox[{"2", " ", "x", " ", "y", " ", 
      RowBox[{
       SuperscriptBox["b", "\[DoublePrime]",
        MultilineFunction->None], "[", "u", "]"}]}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tOne can thus calculate, say, the Ricci tensor for a metric that depends \
on arbitrary functions of the coordinates and then use ",
 StyleBox["FuncRepRules",
  FontFamily->"Courier"],
 " to substitute specific functions / functional forms. "
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "  4.5  Taking advantage of symmetries"
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe greatest drawback of the functions defined in this package is that \
they do not take advantage of the symmetry properties of tensors to reduce \
the amount (and time) of a computation. (This is not true of the main \
procedure - ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " - but this is called only once!). Thus, ",
 StyleBox["FacSimp[Rdddd]",
  FontFamily->"Courier"],
 " factors ",
 StyleBox["every component",
  FontSlant->"Italic"],
 " of the Riemann tensor! As a result, high rank tensor calculations tend to \
be very slow, especially in high dimensions. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tIn such cases one should define a temporary function for the components \
of the tensor to be computed, having the correct symmetries, and then use ",
 StyleBox["Array",
  FontFamily->"Courier"],
 " to construct the tensor (see how Rdddd, RUddd, Rdd, Wdddd are computed by ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 "). ",
 StyleBox["FacSimp",
  FontFamily->"Courier"],
 " should always be applied to the independent components only!"
}], "Text",
 FontSize->16]
}, Closed]]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[0, 0, 1],
 CellTags->"blank 4"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 5  Tensor Components in an Arbitrary Frame",
 FontWeight->"Bold"]], "Section",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 "\t",
 StyleBox["Warning",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": It is best to study the Examples in Section 3 and become familiar with \
calculations in the default coordinate-frame ",
 StyleBox["before reading this section",
  FontSlant->"Italic"],
 ". Otherwise, it may appear very confusing!"
}], "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "0", "]"}], "=!=", "0"}], "||", 
     RowBox[{
      RowBox[{"zeroQ", "[", "0", "]"}], "=!=", "True"}]}], ",", 
    RowBox[{
     RowBox[{"NotebookWrite", "[", 
      RowBox[{
       RowBox[{"SelectedNotebook", "[", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cell", "[", 
          RowBox[{
          "\"\<   You must evaluate matrixEDCcode.nb first  -  Abort \
evaluation and read instructions in section 5!\>\"", ",", " ", "\"\<Text\>\"",
            ",", 
           RowBox[{"FontSize", "->", "24"}], ",", 
           RowBox[{"FontWeight", "->", "\"\<Bold\>\""}], ",", 
           RowBox[{"FontSlant", "->", "\"\<Italic\>\""}], ",", 
           RowBox[{"FontColor", "->", 
            RowBox[{"RGBColor", "[", 
             RowBox[{"1", ",", " ", "0", ",", " ", "1"}], "]"}]}], ",", 
           RowBox[{"CellTags", "->", 
            RowBox[{"{", "\"\<blank 4\>\"", "}"}]}]}], "]"}], ",", 
         RowBox[{"NotebookLocate", "[", "\"\<blank 4\>\"", "]"}]}], "}"}]}], 
      "]"}], ";", 
     RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}]], "Input",
 FontSize->9,
 FontColor->GrayLevel[1]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe computation of tensor components in an arbitrary frame involves some \
elementary operations of exterior differential calculus. We use the notation \
and conventions of the package ",
 ButtonBox["Exterior Differential Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/\
ExteriorDifferentialCalculus.html"], None}],
 ". Familiarity with that package is not required, unless one wants to do \
further calculations with the connection 1-form tensor \[Omega]Ud which is \
computed by ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 ".  "
}], "Text",
 FontSize->16],

Cell["\tThus, to do calculations in an arbitrary frame, one must ", "Text",
 FontSize->16],

Cell[TextData[{
 "FIRST evaluate the notebook ",
 StyleBox["matrixEDCcode.nb",
  FontWeight->"Bold"],
 " (in ",
 ButtonBox["Exterior Differential Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/\
ExteriorDifferentialCalculus.html"], None}],
 ", also available ",
 ButtonBox["here",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mathsource.com/cgi-bin/msitem?0211-789"], None}],
 ")."
}], "Text",
 FontSize->16],

Cell[TextData[{
 "THEN evaluate section ",
 StyleBox["2 RG&TC-Code ",
  FontWeight->"Bold"],
 "of this notebook."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 "  5.1",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "   ",
 StyleBox["Explicit Frame Calculations",
  FontWeight->"Bold"]
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIn this case, one must"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "(i) Define, in addition to the coordinates (",
 StyleBox["xIN",
  FontWeight->"Bold"],
 ") and the metric (",
 StyleBox["gIN",
  FontWeight->"Bold"],
 "),  a list of 1-forms (",
 StyleBox["eIN",
  FontWeight->"Bold"],
 ") -- the coframe -- written as linear combinations of the coordinate \
differentials. The components of ",
 StyleBox["gIN",
  FontWeight->"Bold"],
 " must, of course, be given with respect to the coframe ",
 StyleBox["eIN",
  FontWeight->"Bold"],
 ". "
}], "Text",
 FontSize->16],

Cell[TextData[{
 "(ii) Evaluate ",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 " with the coframe as a third argument: ",
 StyleBox["RGtensors[gIN,xIN,eIN]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " now computes all tensor components with respect to the given frame. (The \
same holds true, of course, for all other tensor functions - ",
 StyleBox["covD",
  FontFamily->"Courier"],
 ", ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 ", etc.). When it is finished, in addition to the other global tensors \
(Rdddd, Rdd, etc.), the connection 1-form tensor \[Omega]Ud with components  \
\[Omega]Ud[[a,b]] =",
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox[
    SuperscriptBox["\[Omega]", "a"], "b"]}]]],
 " is now stored in memory. \[Omega]Ud satisfies the equation  \
d[eIN]+\[Omega]Ud\[Wedge]eIN= 0, or, in components, d[e",
 Cell[BoxData[
  SuperscriptBox["", "a"]]],
 "]+",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Omega]", "a"], "b"]]],
 "\[Wedge]e",
 Cell[BoxData[
  SuperscriptBox["", "b"]]],
 "= 0, where e",
 Cell[BoxData[
  SuperscriptBox["", "a"]]],
 "=eIN[[a]]. (Wedge multiplication of lists acts like ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 " - it sums the last index of the first list with the first index of the \
second list). The notation ",
 StyleBox["e[a]",
  FontFamily->"Courier"],
 " is used for e",
 Cell[BoxData[
  SuperscriptBox["", "a"]]],
 " and all differential forms are written as linear combinations of the bases \
",
 StyleBox["e[a]",
  FontFamily->"Courier"],
 ", ",
 StyleBox["e[a]\[Wedge]e[b]",
  FontFamily->"Courier"],
 ", etc. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": The exterior derivative operator ",
 StyleBox["d[]",
  FontFamily->"Courier"],
 " treats all symbols as variables. Therefore, constants must be explicitly \
defined to have zero exterior derivative, e.g., ",
 StyleBox["d[a]=0",
  FontFamily->"Courier"],
 " and ",
 StyleBox["d[M]=0",
  FontFamily->"Courier"],
 " for the Kerr metric. Otherwise, warning messages are generated."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\<\
\t\[FilledSmallSquare]   Example 4a: Kerr in Boyer-Lindquist coordinates \
(Cos[\[Theta]] -> x)  -- rotating coordinate frame
\
\>", "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "x", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coFrame", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "t", "]"}], "+", 
      RowBox[{"2", "a", " ", "M", " ", "r", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"x", "^", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"Sigma", "-", 
          RowBox[{"2", "M", " ", "r"}]}], ")"}]}], 
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}]}], ",", 
     RowBox[{"d", "[", "r", "]"}], ",", 
     RowBox[{"d", "[", "x", "]"}], ",", 
     RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sigma", "=", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "+", 
    RowBox[{
     RowBox[{"a", "^", "2"}], 
     RowBox[{"x", "^", "2"}]}]}]}], ";", 
  RowBox[{"Delta", "=", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "+", 
    RowBox[{"a", "^", "2"}], "-", 
    RowBox[{"2", "M", " ", "r"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"2", "M", " ", 
        RowBox[{"r", "/", "Sigma"}]}]}], ",", 
      RowBox[{
       RowBox[{"-", "Sigma"}], "/", "Delta"}], ",", 
      RowBox[{
       RowBox[{"-", "Sigma"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"x", "^", "2"}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{"-", "Delta"}], " ", "Sigma", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"x", "^", "2"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"Sigma", "-", 
          RowBox[{"2", "M", " ", "r"}]}], ")"}]}]}]}], "}"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "a", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "M", "]"}], "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord", ",", "coFrame"}], "]"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"d[coframe] computed in \"\>", "\[InvisibleSpace]", 
   "0.199999999999988631`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["d[coframe] computed in ", 0.19999999999998863`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M", " ", "r"}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["x", "2"]}]}]]}], "0", "0", "0"},
       {"0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["r", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], "0", "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["r", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{"1", "-", 
          SuperscriptBox["x", "2"]}]], "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"2", " ", "M", " ", "r"}], "-", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox["x", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["x", "2"]}]}], ")"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1 - (2 M) (r/(r^2 + a^2 x^2)), 0, 0, 0}, {
     0, (a^2 - (2 M) r + r^2)^(-1) (-r^2 - a^2 x^2), 0, 0}, {
     0, 0, (1 - x^2)^(-1) (-r^2 - a^2 x^2), 0}, {
     0, 0, 0, ((-a^2 + (2 M) r - r^2) (1 - x^2)) ((r^2 + a^2 x^2)/(((-2) M) r + 
       r^2 + a^2 x^2))}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M", " ", "r"}], "-", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["x", "2"]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"e", "[", "1", "]"}], "2"]}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"e", "[", "2", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "M", " ", "r"}], "+", 
      SuperscriptBox["r", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"e", "[", "3", "]"}], "2"]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["x", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "M", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["x", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"e", "[", "4", "]"}], "2"]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", ((-((2 M) r - r^2 - a^2 x^2))/(r^2 + a^2 x^2)) 
    e[1]^2 - ((a^2 - (2 M) r + r^2)^(-1) (r^2 + a^2 x^2)) 
   e[2]^2 + ((-1 + x^2)^(-1) (r^2 + a^2 x^2)) 
    e[3]^2 + ((((a^2 - (2 M) r + r^2) (-1 + x^2)) (r^2 + a^2 x^2))/(((-2) M) 
      r + r^2 + a^2 x^2)) e[4]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        FractionBox[
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}]], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "2"], "-", 
           RowBox[{"2", " ", "M", " ", "r"}], "+", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["x", "2"]}]}]]}], "0", "0"},
       {"0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["x", "2"]}], 
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}]], "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["x", "2"]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"2", " ", "M", " ", "r"}], "+", 
            SuperscriptBox["r", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["x", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["x", "2"]}]}], ")"}]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(r^2 + a^2 x^2)/(((-2) M) r + r^2 + a^2 x^2), 0, 0, 0}, {
     0, (-(a^2 - (2 M) r + r^2))/(r^2 + a^2 x^2), 0, 0}, {
     0, 0, (-1 + x^2)/(r^2 + a^2 x^2), 0}, {
     0, 0, 0, (((a^2 - (2 M) r + r^2)^(-1)/(-1 + x^2))/(r^2 + 
       a^2 x^2)) (((-2) M) r + r^2 + a^2 x^2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.450000000000017053`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.45000000000001705`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "1.14999999999997726`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 1.1499999999999773`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "1.21666666666666856`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 1.2166666666666686`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.716666666666668561`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.7166666666666686, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666628771`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.06666666666666288, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4.06666666666666287`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["detg"], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], "2"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RUddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"M", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"4", " ", "M", " ", "r"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"2", " ", "M", " ", "r"}], "-", 
      SuperscriptBox["r", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "M", " ", "r"}], "-", 
      SuperscriptBox["r", "2"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "2"]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]Ud", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"M", " ", 
     RowBox[{"(", 
      RowBox[{"r", "-", 
       RowBox[{"a", " ", "x"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"a", " ", "x"}]}], ")"}], " ", 
     RowBox[{"e", "[", "1", "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "M", " ", "r"}], "-", 
       SuperscriptBox["r", "2"], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}]}]]}], "-", 
  FractionBox[
   RowBox[{"a", " ", "M", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r"}], "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"e", "[", "4", "]"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], "2"]]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIt is still possible to skip computation of RUddd and/or Wdddd by calling \
",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " with an extra (fourth!) argument of the form ",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 ". Thus ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " can be called with 2, 3 or 4 arguments, in the following order:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t ",
 StyleBox["RGtensors[gIN,xIN]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " - computes all tensors in the coordinate frame"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t ",
 StyleBox["RGtensors[gIN,xIN,{1,0}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " - computes all tensors except Wdddd in the coordinate frame"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t ",
 StyleBox["RGtensors[gIN,xIN,eIN]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " - computes all tensors in the frame specified by eIN"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t ",
 StyleBox["RGtensors[gIN,xIN,eIN,{0,0}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " - computes all tensors except RUddd and Wdddd in the frame specified by \
eIN\n"
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]],
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]],
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Important note on repeated frame calculations:",
  FontWeight->"Plain",
  FontSlant->"Italic"]
}], "Subsubsection",
 FontSize->16,
 FontWeight->"Bold",
 CellTags->"sec 5"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tAfter a calculation in a particular frame, the coordinate differentials \
are stored as linear combinations of the coframe basis ",
 StyleBox["e[a]",
  FontFamily->"Courier"],
 ":"
}], "Text",
 FontSize->16,
 CellTags->"sec 5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "t", "]"}]], "Input",
 CellTags->"sec 5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"e", "[", "1", "]"}], "+", 
  FractionBox[
   RowBox[{"2", " ", "a", " ", "M", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "x"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}], " ", 
    RowBox[{"e", "[", "4", "]"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "M", " ", "r"}], "+", 
    SuperscriptBox["r", "2"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["x", "2"]}]}]]}]], "Output"]
}, Open  ]],

Cell["\<\
 Thus, if a subsequent calculation in a different frame is to be carried out, \
these values must be cleared:\
\>", "Text",
 FontSize->16,
 CellTags->"sec 5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "x", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "=."}], ";"}]], "Input",
 CellTags->"sec 5"],

Cell[TextData[{
 " \tIt is safer, however, to reevaluate ",
 StyleBox["matrixEDCcode.nb",
  FontWeight->"Bold"],
 "  and ",
 StyleBox["RG&TC-Code",
  FontWeight->"Bold"],
 "  - which clears ALL variables - before starting a calculation with a new \
frame (or metric)."
}], "Text",
 FontSize->16,
 CellTags->"sec 5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "  5.1.1",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "   ",
 StyleBox["Hodge Duality\n",
  FontWeight->"Bold"]
}], "Subsubsection",
 FontSize->16],

Cell[TextData[{
 "\tA new function that can be used now is ",
 StyleBox["HStar[x_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: applied to any ",
 StyleBox["p",
  FontSlant->"Italic"],
 "-form scalar or tensor expression ",
 StyleBox["x",
  FontFamily->"Courier"],
 ", it gives the \"Hodge Dual\" of ",
 StyleBox["x",
  FontFamily->"Courier"],
 ", i.e., the result of replacing each ",
 StyleBox["p",
  FontSlant->"Italic"],
 "-form basis ",
 StyleBox["e[a1]\[Wedge]e[a2]\[Wedge]...\[Wedge]e[ap] ",
  FontFamily->"Courier"],
 "by (the Einstein summation convention holds)"
}], "Text",
 FontSize->16],

Cell[TextData[Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], 
        ")"}], 
       RowBox[{"1", "/", "2"}]], 
      SuperscriptBox["g", 
       RowBox[{"a1", " ", "b1"}]], 
      SuperscriptBox["g", 
       RowBox[{"a2", " ", "b2"}]]}], ".."}], 
    SuperscriptBox["g", 
     RowBox[{"ap", " ", "bp"}]], 
    StyleBox[
     RowBox[{"epsilon", "[", 
      RowBox[{"b1", ",", "b2", ",", 
       RowBox[{"..", "bp"}], ",", 
       RowBox[{"bp", "+", "1"}], ",", "..", ",", "Dim"}], "]"}],
     FontFamily->"Courier"], 
    StyleBox[
     RowBox[{
      RowBox[{"e", "[", 
       RowBox[{"bp", "+", "1"}], "]"}], "\[Wedge]"}],
     FontFamily->"Courier"]}], 
   StyleBox["..",
    FontFamily->"Courier"]}], 
  StyleBox["\[Wedge]",
   FontFamily->"Courier"], 
  StyleBox[
   RowBox[{
    RowBox[{"e", "[", "Dim", "]"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Dim", "-", "p"}], ")"}], "!"}]}],
   FontFamily->"Courier"]}]]]], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": The default volume ",
 StyleBox["Dim",
  FontSlant->"Italic"],
 "-form used as the ",
 StyleBox["definition",
  FontSlant->"Italic"],
 " of ",
 StyleBox["HStar[1]",
  FontFamily->"Courier"],
 " is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], 
       ")"}], 
      RowBox[{"1", "/", "2"}]], 
     StyleBox[
      RowBox[{
       RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "2", "]"}], "\[Wedge]"}],
      FontFamily->"Courier"]}], 
    StyleBox["...",
     FontFamily->"Courier"]}], 
   StyleBox["\[Wedge]",
    FontFamily->"Courier"], 
   StyleBox[
    RowBox[{"e", "[", "Dim", "]"}],
    FontFamily->"Courier"]}]]],
 ", except in the case of a Newman-Penrose null frame (see section 5.1.2) \
where the (real) volume 4-form  ",
 StyleBox["I",
  FontFamily->"Courier"],
 " ",
 StyleBox["e[1]\[Wedge]e[2]\[Wedge]e[3]\[Wedge]e[4]",
  FontFamily->"Courier"],
 " is used.  If in a particular case a different volume form must be used as \
the definition of ",
 StyleBox["HStar[1]",
  FontFamily->"Courier"],
 ", one must define a new ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for Hodge-Dual, as a simple multiple of ",
 StyleBox["HStar",
  FontFamily->"Courier"],
 ": ",
 StyleBox["newHstar[x_]:= \[Alpha]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 StyleBox["HStar[x]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", where ",
 StyleBox["\[Alpha]",
  FontWeight->"Bold"],
 " is the ratio newVolumeForm / defaultVolumeForm."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
\t\[FilledSmallSquare]   Example 4b: Kerr in Boyer-Lindquist coordinates \
(Cos[\[Theta]] -> x)  --  orthonormal frame
\
\>", "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "x", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sigma", "=", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "+", 
    RowBox[{
     RowBox[{"a", "^", "2"}], 
     RowBox[{"x", "^", "2"}]}]}]}], ";", 
  RowBox[{"Delta", "=", 
   RowBox[{
    RowBox[{"r", "^", "2"}], "+", 
    RowBox[{"a", "^", "2"}], "-", 
    RowBox[{"2", "M", " ", "r"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"coFrame", "=", 
   RowBox[{"PowerExpand", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Sigma", "-", 
           RowBox[{"2", "M", " ", "r"}]}], ")"}], "/", "Sigma"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", "[", "t", "]"}], "+", 
         RowBox[{"2", "a", " ", "M", " ", "r", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"x", "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"Sigma", "-", 
             RowBox[{"2", "M", " ", "r"}]}], ")"}]}], 
          RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}]}], ")"}]}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"Sigma", "/", "Delta"}], "]"}], 
       RowBox[{"d", "[", "r", "]"}]}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"Sigma", "/", 
         RowBox[{"(", 
          StyleBox[
           RowBox[{"1", "-", 
            RowBox[{"x", "^", "2"}]}],
           FontFamily->"Courier"], ")"}]}], "]"}], 
       RowBox[{"d", "[", "x", "]"}]}], ",", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"Delta", " ", "Sigma", 
         RowBox[{
          StyleBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"x", "^", "2"}]}], ")"}],
           FontFamily->"Courier"], "/", 
          RowBox[{"(", 
           RowBox[{"Sigma", "-", 
            RowBox[{"2", "M", " ", "r"}]}], ")"}]}]}], "]"}], 
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}]}], "}"}], "]"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "\t",
 StyleBox["Note",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": ",
 StyleBox["PowerExpand",
  FontFamily->"Courier"],
 " must always be used when the argument of ",
 StyleBox["Sqrt",
  FontFamily->"Courier"],
 " is a product of factors.  Otherwise simplifications cannot be carried out. \
 "
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "a", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "M", "]"}], "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "x"}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], "/", 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"]}]]}]}], "->", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"]}]]}]}], "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord", ",", "coFrame", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"d[coframe] computed in \"\>", "\[InvisibleSpace]", 
   "1.06666666666666287`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["d[coframe] computed in ", 1.0666666666666629`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, -1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"e", "[", "1", "]"}], "2"], "-", 
    SuperscriptBox[
     RowBox[{"e", "[", "2", "]"}], "2"], "-", 
    SuperscriptBox[
     RowBox[{"e", "[", "3", "]"}], "2"], "-", 
    SuperscriptBox[
     RowBox[{"e", "[", "4", "]"}], "2"]}]}],
  SequenceForm["\!\(ds\^2\) = ", e[1]^2 - e[2]^2 - e[3]^2 - e[4]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, -1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.583333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.5833333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "5.93333333333333712`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 5.933333333333337, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"RUddd not computed\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.183333333333308701`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.1833333333333087, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Weyl tensor not computed\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8.04999999999998294`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["detg"], "Input"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rdddd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2", ",", "1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"M", " ", "r", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"4", " ", "M", " ", "r"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "M", " ", "r"}], "-", 
     SuperscriptBox["r", "2"], "-", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], "3"]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]Ud", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"M", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "M", " ", "r"}], "+", 
      SuperscriptBox["r", "2"]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r"}], "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"e", "[", "1", "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "M", " ", "r"}], "-", 
      SuperscriptBox["r", "2"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], "-", 
  FractionBox[
   RowBox[{"a", " ", "M", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "r"}], "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", 
      RowBox[{"a", " ", "x"}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox["x", "2"]}]], " ", 
    RowBox[{"e", "[", "4", "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "M", " ", "r"}], "-", 
      SuperscriptBox["r", "2"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "        \[FilledSmallSquare]   ",
 StyleBox["Sample calculations with tensor-valued differential forms:",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 "\t\[FilledSmallCircle] Construct the (rank-2) 2-form curvature tensor \
\[CapitalOmega]Ud with components \[CapitalOmega]Ud[[a,b]] =",
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox[
    SuperscriptBox["\[CapitalOmega]", "a"], "b"]}]]],
 Cell[BoxData[
  RowBox[{"=", 
   RowBox[{
    FractionBox["1", "2"], 
    SubscriptBox[
     SuperscriptBox["R", "a"], "bcd"], 
    SuperscriptBox["e", "c"]}]}]]],
 Cell[BoxData[
  RowBox[{"\[Wedge]", 
   SuperscriptBox["e", "d"]}]]],
 ". (eUU is the 2-form- basis tensor: eUU[[a,b]]=e[a]\[Wedge]e[b])."
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eUU", "=", 
   RowBox[{"Outer", "[", 
    RowBox[{"Wedge", ",", 
     RowBox[{"e", "/@", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], ",", 
     RowBox[{"e", "/@", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}]}], "]"}]}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalOmega]Ud", "=", 
    RowBox[{"multiDot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"gUU", ".", "Rdddd"}], "/", "2"}], ",", "eUU", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}]}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2.`", " ", "Second"}], ",", "Null"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t\[FilledSmallCircle] Verify that  ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[CapitalOmega]", "a"], "b"]]],
 " equals  d[",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Omega]", "a"], "b"]]],
 "]+",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Omega]", "a"], "s"]]],
 "\[Wedge]",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Omega]", "s"], "b"]]],
 ". (Wedge multiplication of tensors acts like ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 " - contracts last index of first tensor with first index of second \
tensor)."
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroQ", "[", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"d", "[", "\[Omega]Ud", "]"}], "+", 
     RowBox[{"\[Omega]Ud", "\[Wedge]", "\[Omega]Ud"}], "-", 
     "\[CapitalOmega]Ud"}], "]"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"19.0666666666666628`", " ", "Second"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
\t\[FilledSmallCircle] Verify Bianchi identities using \[CapitalOmega]Ud:\
\>", "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroQ", "[", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"d", "[", "\[CapitalOmega]Ud", "]"}], "+", 
     RowBox[{"\[Omega]Ud", "\[Wedge]", "\[CapitalOmega]Ud"}], "-", 
     RowBox[{"\[CapitalOmega]Ud", "\[Wedge]", "\[Omega]Ud"}]}], "]"}], "]"}], 
  "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"49.083333333333341`", " ", "Second"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t\[FilledSmallCircle] If both tensors to be contracted with ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 " are differential forms, then their components are multiplied using wedge:"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"multiDot", "[", 
   RowBox[{"\[CapitalOmega]Ud", ",", "\[CapitalOmega]Ud", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.83333333333331438`", " ", "Second"}], ",", 
   FractionBox[
    RowBox[{"48", " ", "a", " ", 
     SuperscriptBox["M", "2"], " ", "r", " ", "x", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], " ", 
     RowBox[{
      RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "4", "]"}]}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["x", "2"]}]}], ")"}], "6"]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t\[FilledSmallCircle] ",
 StyleBox["HStar",
  FontFamily->"Courier"],
 " gives the Hodge-dual:"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pseudoScalar", "=", 
  RowBox[{"HStar", "[", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"48", " ", "a", " ", 
   SuperscriptBox["M", "2"], " ", "r", " ", "x", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], "6"]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t\[FilledSmallCircle] This invariant equals ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], 
   SubscriptBox[
    SuperscriptBox["R", "ab"], "cd"]}]]],
 Cell[BoxData[
  RowBox[{
   SubscriptBox[
    SuperscriptBox["R", "cd"], "ef"], 
   SubscriptBox[
    SuperscriptBox["\[Eta]", "ef"], "ab"]}]]],
 "  and can also be obtained as follows:"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RUUdd", "=", 
    RowBox[{"Raise", "[", 
     RowBox[{"Rdddd", ",", "1", ",", "2"}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.71666666666664013`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RstarUUdd", "=", 
    RowBox[{"multiDot", "[", 
     RowBox[{
      RowBox[{"RUUdd", "/", "2"}], ",", 
      RowBox[{"eta", "[", 
       RowBox[{"1", ",", "2"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "2"}], "}"}]}], "]"}]}], ";"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.83333333333337122`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"multiDot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "RUUdd"}], "/", "2"}], ",", "RstarUUdd", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"48", " ", "a", " ", 
    SuperscriptBox["M", "2"], " ", "r", " ", "x", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["r", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["r", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["x", "2"]}]}], ")"}], "6"]]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t\[FilledSmallCircle] The invariant  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], 
   SubscriptBox[
    SuperscriptBox["R", "ab"], "cd"]}]]],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "cd"], "ab"]]],
 "  can be obtained either as:"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"multiDot", "[", 
   RowBox[{"RUUdd", ",", "RUUdd", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}]}], "]"}], "/", "2"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"24", " ", 
   SuperscriptBox["M", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"r", "-", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"r", "+", 
     RowBox[{"a", " ", "x"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"4", " ", "a", " ", "r", " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{"4", " ", "a", " ", "r", " ", "x"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["x", "2"]}]}], ")"}], "6"]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tor, using \[CapitalOmega]Ud and",
 " ",
 StyleBox["HStar",
  FontFamily->"Courier"],
 ", as:"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HStar", "[", 
   RowBox[{"multiDot", "[", 
    RowBox[{"\[CapitalOmega]Ud", ",", 
     RowBox[{"HStar", "[", "\[CapitalOmega]Ud", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}], "]"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4.05000000000001136`", " ", "Second"}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"24", " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"a", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", 
        RowBox[{"a", " ", "x"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", "r", " ", "x"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"4", " ", "a", " ", "r", " ", "x"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["x", "2"]}]}], ")"}], "6"]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "a", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "M", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "x", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "=."}], ";", 
  RowBox[{"On", "[", 
   RowBox[{
    RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
    RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
  5.1.2   Newman-Penrose Null Frame
\
\>", "Subsection",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tWhen the metric equals ",
 StyleBox["{{0,1,0,0},{1,0,0,0},{0,0,0,-1},{0,0,-1,0}}",
  FontFamily->"Courier"],
 ", ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " defines the global variables ",
 StyleBox["PH[i,j]",
  FontFamily->"Courier"],
 ", ",
 StyleBox["\[CapitalLambda]",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["PS[i]",
  FontFamily->"Courier"],
 " for the Newman-Penrose scalars ",
 Cell[BoxData[
  SubscriptBox["\[CapitalPhi]", "ij"]]],
 ", ",
 StyleBox["\[CapitalLambda]",
  FontFamily->"Courier"],
 ", and ",
 Cell[BoxData[
  SubscriptBox["\[CapitalPsi]", "i"]]],
 ", respectively, assuming that the null basis given in the coframe is ",
 StyleBox["{\[DoubleStruckL],\[DoubleStruckN],\[DoubleStruckM],Bar[\
\[DoubleStruckM]]}",
  FontFamily->"Courier"],
 ". "
}], "Text",
 FontSize->16]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "  5.2",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "   ",
 StyleBox["Implicit Frame Calculations",
  FontWeight->"Bold"]
}], "Subsection",
 FontSize->16],

Cell[TextData[{
 "\tFor some problems, giving the explicit form of the coframe (in terms of \
the coordinate differentials) is not the most efficient way of doing the \
calculations. This is particularly true if the exterior derivatives of the \
coframe satisfy simple expressions, not involving the coordinates, as in the \
Bianchi cosmological models, for which d[e",
 Cell[BoxData[
  SuperscriptBox["", "a"]]],
 "]= -",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", "2"], 
   SubscriptBox[
    SuperscriptBox["C", "a"], "bc"]}]]],
 "e",
 Cell[BoxData[
  SuperscriptBox["", "b"]]],
 "\[Wedge]e",
 Cell[BoxData[
  SuperscriptBox["", "c"]]],
 ", with ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["C", "a"], "bc"]]],
 "=constants. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tTo do the calculations in such cases, ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " makes use of two global variables - ",
 StyleBox["deList",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and ",
 StyleBox["dxRuleList",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " - which must be defined by the user. The first (",
 StyleBox["deList",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ") must be set equal to the expressions for ",
 StyleBox["d[e",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox["", "a"]]],
 StyleBox["]",
  FontFamily->"Courier"],
 ",  and the second (",
 StyleBox["dxRuleList",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ") must be set equal to a list of rules for replacing the coordinate \
differentials in terms of the ",
 StyleBox["e[a]",
  FontFamily->"Courier"],
 " basis. Actually, only the differentials of  those coordinates that appear \
in the metric and in the expressions for ",
 StyleBox["d[e[a]]",
  FontFamily->"Courier"],
 " should be included in ",
 StyleBox["dxRuleList",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". Finally, one must call ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " with ",
 StyleBox["{e[]}",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " as third argument: ",
 StyleBox["RGtensors[gIN,xIN,{e[]}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ". The coframe thus remains undefined in terms of the coordinate \
differentials, but its exterior derivative is known. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Warning",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": When the differentials of only ",
 StyleBox["some",
  FontSlant->"Italic"],
 " of the coordinates are included in ",
 StyleBox["dxRuleList",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["covD",
  FontFamily->"Courier"],
 " and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 " behave as if differentiations with respect to the remaining coordinates \
give zero. "
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\<\
\t\[FilledSmallSquare]   Example 9: Diagonal, Class-A, Bianchi Cosmological \
Models \
\>", "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"x1", ",", "x2", ",", "x3", ",", "t"}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"A", "[", "t", "]"}]}], ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", 
        RowBox[{"B", "[", "t", "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", 
        RowBox[{"C", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"F", "[", "t", "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[{
 "\tThe components of ",
 StyleBox["g",
  FontFamily->"Courier"],
 " refer to an undefined coframe ",
 StyleBox["{e[1],e[2],....,e[Dim]}",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"dxRuleList", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "[", "t", "]"}], "->", 
     RowBox[{"e", "[", "4", "]"}]}], "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deList", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"n", "[", "1", "]"}], 
     RowBox[{
      RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "3", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"n", "[", "2", "]"}], 
     RowBox[{
      RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "1", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"n", "[", "3", "]"}], 
     RowBox[{
      RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "2", "]"}]}]}], ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "1", "]"}], " ", 
    RowBox[{
     RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
     RowBox[{"e", "[", "3", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"n", "[", "2", "]"}]}], " ", 
    RowBox[{
     RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"e", "[", "3", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], " ", 
    RowBox[{
     RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
     RowBox[{"e", "[", "2", "]"}]}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\tThe elements of ",
 StyleBox["deList",
  FontFamily->"Courier"],
 " are, by definition, ",
 StyleBox["{d[e[1]],d[e[2]],....,d[e[Dim]]}",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{"*", " ", 
     RowBox[{"d", "[", 
      RowBox[{"n", "[", "_", "]"}], "]"}]}], "=", "0"}], ";"}], " ", 
  "**)"}]], "Input"],

Cell[TextData[{
 "\t",
 StyleBox["d[n[_]]",
  FontFamily->"Courier"],
 " is left undefined intentionally to generate a warning message. "
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{"g", ",", "xCoord", ",", 
    RowBox[{"{", 
     RowBox[{"e", "[", "]"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         RowBox[{"A", "[", "t", "]"}]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         RowBox[{"B", "[", "t", "]"}]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         RowBox[{"C", "[", "t", "]"}]}], "0"},
       {"0", "0", "0", 
        RowBox[{"F", "[", "t", "]"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-A[t], 0, 0, 0}, {0, -B[t], 0, 0}, {0, 0, -C[t], 0}, {0, 0, 0, 
      F[t]}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"A", "[", "t", "]"}]}], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
    RowBox[{
     RowBox[{"B", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
    RowBox[{
     RowBox[{"C", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "3", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"e", "[", "4", "]"}], "2"], " ", 
     RowBox[{"F", "[", "t", "]"}]}]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (-A[t]) e[1]^2 - B[t] e[2]^2 - C[t] e[3]^2 + e[4]^2 F[t]],
  
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"A", "[", "t", "]"}]]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"B", "[", "t", "]"}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"C", "[", "t", "]"}]]}], "0"},
       {"0", "0", "0", 
        FractionBox["1", 
         RowBox[{"F", "[", "t", "]"}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(-1)/A[t], 0, 0, 0}, {0, (-1)/B[t], 0, 0}, {
     0, 0, (-1)/C[t], 0}, {0, 0, 0, F[t]^(-1)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0500000000000113686`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.05000000000001137, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Warning: deList not closed! d[deList]=\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"n", "[", "1", "]"}], "]"}], "\[Wedge]", 
    RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
    RowBox[{"e", "[", "3", "]"}]}], ",", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"n", "[", "2", "]"}], "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
      RowBox[{"e", "[", "3", "]"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"n", "[", "3", "]"}], "]"}], "\[Wedge]", 
    RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
    RowBox[{"e", "[", "2", "]"}]}], ",", "0"}], "}"}]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.199999999999988631`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.19999999999998863`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.166666666666628771`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.16666666666662877`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.300000000000011368`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.30000000000001137`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.216666666666696983`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.21666666666669698`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.633333333333325754`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.6333333333333258, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.199999999999988631`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.19999999999998863`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1.88333333333332575`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";"}]], "Input"],

Cell[BoxData["\n"], "Input"],

Cell["\<\
\tChoosing n[i_] and A[t], B[t], C[t], F[t] appropriately, particular models \
can be selected: \
\>", "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", 
    StyleBox["Taub",
     FontColor->RGBColor[0, 0, 1]]}], 
   StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]], "**)"}], 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"n", "[", "_", "]"}], "=", 
     RowBox[{"-", "1"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"RGtensors", "[", 
     RowBox[{
      RowBox[{"g", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"A", "[", "t", "]"}], "->", 
          RowBox[{"1", "+", 
           RowBox[{"t", "^", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{"B", "[", "t", "]"}], "->", 
          RowBox[{"1", "+", 
           RowBox[{"t", "^", "2"}]}]}], ",", 
         RowBox[{
          RowBox[{"C", "[", "t", "]"}], "->", 
          RowBox[{"4", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", "a", " ", "t"}], "-", 
              RowBox[{"t", "^", "2"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"t", "^", "2"}]}], ")"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"F", "[", "t", "]"}], "->", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"t", "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", "a", " ", "t"}], "-", 
             RowBox[{"t", "^", "2"}]}], ")"}]}]}]}], "}"}]}], ",", "xCoord", 
      ",", 
      RowBox[{"{", 
       RowBox[{"e", "[", "]"}], "}"}]}], "]"}], "//", "Timing"}]}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         SuperscriptBox["t", "2"]}], "0", "0", "0"},
       {"0", 
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         SuperscriptBox["t", "2"]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "a", " ", "t"}], "-", 
             SuperscriptBox["t", "2"]}], ")"}]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"]}]]}], "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{"1", "+", 
          SuperscriptBox["t", "2"]}], 
         RowBox[{"1", "+", 
          RowBox[{"2", " ", "a", " ", "t"}], "-", 
          SuperscriptBox["t", "2"]}]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-1 - t^2, 0, 0, 0}, {0, -1 - t^2, 0, 0}, {
     0, 0, (-4) ((1 + (2 a) t - t^2)/(1 + t^2)), 0}, {
     0, 0, 0, (1 + (2 a) t - t^2)^(-1) (1 + t^2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SuperscriptBox["t", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "1", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SuperscriptBox["t", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "2", "]"}], "2"]}], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"2", " ", "a", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"e", "[", "3", "]"}], "2"]}], 
     RowBox[{"1", "+", 
      SuperscriptBox["t", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["t", "2"]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"e", "[", "4", "]"}], "2"]}], 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "a", " ", "t"}], "-", 
      SuperscriptBox["t", "2"]}]]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (-1 - t^2) e[1]^2 + (-1 - t^2) 
    e[2]^2 + ((4/(1 + t^2)) (-1 - (2 a) t + t^2)) 
    e[3]^2 + ((1 + (2 a) t - t^2)^(-1) (1 + t^2)) e[4]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"]}]]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"]}], 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "a", " ", "t"}], "-", 
             SuperscriptBox["t", "2"]}], ")"}]}]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"2", " ", "a", " ", "t"}], "+", 
           SuperscriptBox["t", "2"]}], 
          RowBox[{"1", "+", 
           SuperscriptBox["t", "2"]}]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(-1)/(1 + t^2), 0, 0, 0}, {0, (-1)/(1 + t^2), 0, 0}, {
     0, 0, (Rational[-1, 4]/(1 + (2 a) t - t^2)) (1 + t^2), 0}, {
     0, 0, 0, ((-1)/(1 + t^2)) (-1 - (2 a) t + t^2)}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.116666666666674245`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.11666666666667425`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Warning: d[] on some symbols not defined!\"\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"t", " ", 
     RowBox[{"d", "[", "a", "]"}]}], 
    RowBox[{"1", "+", 
     SuperscriptBox["t", "2"]}]], ",", 
   FractionBox[
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["t", "2"]}], ")"}], " ", 
     RowBox[{"d", "[", "a", "]"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", "a", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"]]}], "}"}]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.233333333333291648`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.23333333333329165`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.116666666666617402`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.1166666666666174, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.133333333333382597`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.1333333333333826, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666515084`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.01666666666665151, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.866666666666617402`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zeroQ", "[", 
   RowBox[{"Bianchi", "[", "0", "]"}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"6.68333333333333712`", " ", "Second"}], ",", "True"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";"}]], "Input"],

Cell[BoxData["\n"], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", " ", 
    StyleBox["Kasner",
     FontColor->RGBColor[0, 0, 1]]}], 
   StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]], "**)"}], 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"n", "[", "_", "]"}], "=", "0"}], ";", 
    RowBox[{
     RowBox[{"d", "[", "u", "]"}], "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"RGtensors", "[", 
     RowBox[{
      RowBox[{"g", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", "t", "]"}], "->", "1"}], ",", 
         RowBox[{
          RowBox[{"A", "[", "t", "]"}], "->", 
          RowBox[{"t", "^", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], 
             RowBox[{"u", "/", 
              RowBox[{"(", 
               RowBox[{"1", "+", "u", "+", 
                RowBox[{"u", "^", "2"}]}], ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{"B", "[", "t", "]"}], "->", 
          RowBox[{"t", "^", 
           RowBox[{"(", 
            RowBox[{"2", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "u"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "+", "u", "+", 
                RowBox[{"u", "^", "2"}]}], ")"}]}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{"C", "[", "t", "]"}], "->", 
          RowBox[{"t", "^", 
           RowBox[{"(", 
            RowBox[{"2", "u", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "u"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"1", "+", "u", "+", 
                RowBox[{"u", "^", "2"}]}], ")"}]}]}], ")"}]}]}]}], "}"}]}], 
      ",", "xCoord", ",", 
      RowBox[{"{", 
       RowBox[{"e", "[", "]"}], "}"}]}], "]"}], "//", "Timing"}]}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         SuperscriptBox["t", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "u"}], 
            RowBox[{"1", "+", "u", "+", 
             SuperscriptBox["u", "2"]}]]}]]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         SuperscriptBox["t", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "u"}], ")"}]}], 
           RowBox[{"1", "+", "u", "+", 
            SuperscriptBox["u", "2"]}]]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         SuperscriptBox["t", 
          FractionBox[
           RowBox[{"2", " ", "u", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "u"}], ")"}]}], 
           RowBox[{"1", "+", "u", "+", 
            SuperscriptBox["u", "2"]}]]]}], "0"},
       {"0", "0", "0", "1"}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-t^((-2) (u/(1 + u + u^2))), 0, 0, 0}, {
     0, -t^(2 ((1 + u)/(1 + u + u^2))), 0, 0}, {
     0, 0, -t^((2 u) ((1 + u)/(1 + u + u^2))), 0}, {0, 0, 0, 1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["t", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "u"}], 
         RowBox[{"1", "+", "u", "+", 
          SuperscriptBox["u", "2"]}]]}]]}], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "1", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["t", 
      RowBox[{
       FractionBox["2", 
        RowBox[{"1", "+", "u", "+", 
         SuperscriptBox["u", "2"]}]], "+", 
       FractionBox[
        RowBox[{"2", " ", "u"}], 
        RowBox[{"1", "+", "u", "+", 
         SuperscriptBox["u", "2"]}]]}]], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "2", "]"}], "2"]}], "-", 
    RowBox[{
     SuperscriptBox["t", 
      FractionBox[
       RowBox[{"2", " ", "u", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "u"}], ")"}]}], 
       RowBox[{"1", "+", "u", "+", 
        SuperscriptBox["u", "2"]}]]], " ", 
     SuperscriptBox[
      RowBox[{"e", "[", "3", "]"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"e", "[", "4", "]"}], "2"]}]}],
  SequenceForm[
  "\!\(ds\^2\) = ", (-t^((-2) (u/(1 + u + u^2)))) e[1]^2 - 
   t^(2/(1 + u + u^2) + 2 (u/(1 + u + u^2))) e[2]^2 - 
   t^((2 u) ((1 + u)/(1 + u + u^2))) e[3]^2 + e[4]^2],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        RowBox[{"-", 
         SuperscriptBox["t", 
          FractionBox[
           RowBox[{"2", " ", "u"}], 
           RowBox[{"1", "+", "u", "+", 
            SuperscriptBox["u", "2"]}]]]}], "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         SuperscriptBox["t", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["2", 
             RowBox[{"1", "+", "u", "+", 
              SuperscriptBox["u", "2"]}]]}], "-", 
           FractionBox[
            RowBox[{"2", " ", "u"}], 
            RowBox[{"1", "+", "u", "+", 
             SuperscriptBox["u", "2"]}]]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         SuperscriptBox["t", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "u", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "u"}], ")"}]}], 
            RowBox[{"1", "+", "u", "+", 
             SuperscriptBox["u", "2"]}]]}]]}], "0"},
       {"0", "0", "0", "1"}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{-t^(2 (u/(1 + u + u^2))), 0, 0, 0}, {
     0, -t^((-2)/(1 + u + u^2) - 2 (u/(1 + u + u^2))), 0, 0}, {
     0, 0, -t^(((-2) u) ((1 + u)/(1 + u + u^2))), 0}, {0, 0, 0, 1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.100000000000022737`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.10000000000002274`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.233333333333348491`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.2333333333333485, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.116666666666674245`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.11666666666667425`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.116666666666674245`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.11666666666667425`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666515084`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.01666666666665151, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0., " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Ricci Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.849999999999965893`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zeroQ", "[", 
  RowBox[{"Bianchi", "[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "u", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"n", ",", "dxRuleList", ",", "deList", ",", "g"}], "]"}], 
  ";"}]], "Input"]
}, Open  ]],

Cell["\tSee also Example 12 in Section 6.", "Text",
 FontSize->16]
}, Open  ]]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox[" 6  Approximations - Series Expansions\n",
  FontWeight->"Bold"],
 StyleBox["(New version: requires version 3.3.5 of  ",
  FontSize->14,
  FontWeight->"Plain"],
 StyleBox[ButtonBox["Exterior Differential Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/\
ExteriorDifferentialCalculus.html"], None}],
  FontSize->14,
  FontWeight->"Plain"],
 StyleBox["  to work properly)",
  FontSize->14,
  FontWeight->"Plain"]
}], "Section",
 FontSize->24,
 FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Series[", "MR",
  FontFamily->"Courier"],
 StyleBox["f", "TI",
  FontFamily->"Courier"],
 StyleBox[",", "MR",
  FontFamily->"Courier"],
 Cell[BoxData[
  FormBox["{", TraditionalForm]], "InlineFormula",
  FontFamily->"Courier"],
 StyleBox["x", "TI",
  FontFamily->"Courier"],
 StyleBox[",", "MR",
  FontFamily->"Courier"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"x\\\\\\\"\\\", \\\"TI\\\"]\
\\)\"\>", "0"], TraditionalForm]], "InlineFormula",
  FontFamily->"Courier"],
 StyleBox[",", "MR",
  FontFamily->"Courier"],
 StyleBox["n", "TI",
  FontFamily->"Courier"],
 Cell[BoxData[
  FormBox["}", TraditionalForm]], "InlineFormula",
  FontFamily->"Courier"],
 StyleBox["]", "MR",
  FontFamily->"Courier"],
 ", which gives the series expansion of the function ",
 StyleBox["f",
  FontFamily->"Courier"],
 " around ",
 StyleBox["x0",
  FontFamily->"Courier"],
 " up to order ",
 StyleBox["n",
  FontFamily->"Courier"],
 ", can be applied to lists, and thus to tensors. ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " and the other functions defined in this package (version 2.3 or later) can \
handle ",
 StyleBox["SeriesData",
  FontFamily->"Courier"],
 " objects as input - ",
 StyleBox["gIN",
  FontFamily->"Courier"],
 " (metric) and ",
 StyleBox["eIN",
  FontFamily->"Courier"],
 " (coframe) -  and thus allow approximate calculations (perturbations of a \
given solution, asymptotic expansion of the metric or the frame, etc.)."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThere are several points, however, that must be kept in mind in doing \
calculations with series: "
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(1) Under ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 3.0, algebraically equivalent expressions do not have identical series \
approximations (this problem does not arise in version 4.0 or higher):"
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"m", "/", "r"}]}], "+", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "/", 
     RowBox[{"r", "^", "2"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "Infinity", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{"2", " ", "m"}], "r"], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "r"], ")"}], "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "3"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 0, 3, 1]]}],
  SeriesData[r, 
   DirectedInfinity[1], {1, (-2) m, a^2}, 0, 3, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "-", 
      RowBox[{"2", "m"}], "+", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "/", "r"}]}], ")"}], "/", "r"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "Infinity", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{"2", " ", "m"}], "r"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "2"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 0, 2, 1]]}],
  SeriesData[r, 
   DirectedInfinity[1], {1, (-2) m}, 0, 2, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "-", 
      RowBox[{"2", "m", " ", "r"}], "+", 
      RowBox[{"a", "^", "2"}]}], ")"}], "/", 
    RowBox[{"r", "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "Infinity", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "1"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 0, 1, 1]]}],
  SeriesData[r, 
   DirectedInfinity[1], {1}, 0, 1, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe reason is, apparently, that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 3.0 applies ",
 StyleBox["Series",
  FontFamily->"Courier"],
 " separately to the numerator and denominator of a fraction. Therefore, in \
applying ",
 StyleBox["Series",
  FontFamily->"Courier"],
 " to fractions whose numerator and denominator do not have finite limits at \
the expansion point, one should keep more terms: "
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", "^", "2"}], "-", 
      RowBox[{"2", "m", " ", "r"}], "+", 
      RowBox[{"a", "^", "2"}]}], ")"}], "/", 
    RowBox[{"r", "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "Infinity", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "-", 
   FractionBox[
    RowBox[{"2", " ", "m"}], "r"], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", "r"], ")"}], "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "3"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 0, 3, 1]]}],
  SeriesData[r, 
   DirectedInfinity[1], {1, (-2) m, a^2}, 0, 3, 1]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(2)  When the series expansion of the metric or the coframe is with \
respect to one of the coordinates, the notation ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 " for the differential of that coordinate cannot be used because ",
 StyleBox["Series",
  FontFamily->"Courier"],
 " will consider ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 " a function of ",
 StyleBox["x",
  FontFamily->"Courier"],
 " and formally expand it (using ",
 StyleBox["d[0]",
  FontFamily->"Courier"],
 "=0):"
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "x", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["d", "\[Prime]",
      MultilineFunction->None], "[", "0", "]"}], " ", "x"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["d", "\[Prime]",
        MultilineFunction->None], "[", "0", "]"}], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["d", "\[DoublePrime]",
         MultilineFunction->None], "[", "0", "]"}], "2"]}], ")"}], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "3"],
    SeriesData[x, 0, {}, 1, 3, 1]]}],
  SeriesData[x, 0, {
    Derivative[1][d][0], Derivative[1][d][0] + 
    Rational[1, 2] Derivative[2][d][0]}, 1, 3, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 " \tWhen only the metric is expanded, ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " will automatically introduce the notation ",
 StyleBox["dx",
  FontFamily->"Courier"],
 " for ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 ". The symbol ",
 StyleBox["dx",
  FontFamily->"Courier"],
 " will then be treated correctly as a closed 1-form. The user can still \
input ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 ".\n\tIf the series expansion is with respect to a parameter, that parameter \
is treated as a constant."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 "\t\[FilledSmallSquare]   Example 10: Perturbation of the Schwarzschild \
solution with two constants, ",
 StyleBox["a",
  FontSlant->"Italic"],
 ", ",
 StyleBox["b",
  FontSlant->"Italic"]
}], "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";", 
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", "r", "]"}], "=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"m", "/", "r"}]}], "+", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "/", 
     RowBox[{"r", "^", "2"}]}]}]}], ";", 
  RowBox[{
   RowBox[{"B", "[", "r", "]"}], "=", 
   RowBox[{"Exp", "[", 
    RowBox[{"2", 
     RowBox[{"b", "/", "r"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "[", "n_", "]"}], ":=", 
  RowBox[{"FacSimp", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"DiagonalMatrix", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"A", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"-", "1"}], "/", 
         RowBox[{"A", "[", "r", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"r", "^", "2"}]}], "/", 
         RowBox[{"B", "[", "r", "]"}]}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"r", "^", "2"}]}], 
         RowBox[{"B", "[", "r", "]"}], 
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}], "]"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "Infinity", ",", "n"}], "}"}]}], "]"}], 
   "]"}]}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "m"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "4"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 0, 4, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {1, (-2) m, a^2}, 0, 4, 1]], ",", "0", ",", "0", 
     ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       FractionBox[
        RowBox[{"2", " ", "m"}], "r"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", 
          RowBox[{"2", " ", "m"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          RowBox[{"2", " ", "m"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], "+", 
       RowBox[{"4", " ", "m", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m", "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "4"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 0, 4, 1]]}],
      SeriesData[r, 
       DirectedInfinity[
       1], {-1, (-2) m, (a - 2 m) (a + 2 m), (4 m) (a^2 - 2 m^2)}, 0, 4, 1]], 
     ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "r"], ")"}], "2"]]}], "+", 
       FractionBox[
        RowBox[{"2", " ", "b"}], 
        FractionBox["1", "r"]], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox["b", "3"]}], 
        RowBox[{"3", " ", "r"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "2"],
        SeriesData[r, 
         DirectedInfinity[1], {}, -2, 2, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {-1, 2 b, (-2) b^2, Rational[4, 3] b^3}, -2, 2, 
       1]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["1", "r"], ")"}], "2"]]}], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"b", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], 
        FractionBox["1", "r"]], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "3"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], 
        RowBox[{"3", " ", "r"}]], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "2"],
        SeriesData[r, 
         DirectedInfinity[1], {}, -2, 2, 1]]}],
      SeriesData[r, 
       DirectedInfinity[
       1], {-Sin[\[Theta]]^2, ((-2) b) Sin[\[Theta]]^2, ((-2) b^2) 
        Sin[\[Theta]]^2, (Rational[-4, 3] b^3) Sin[\[Theta]]^2}, -2, 2, 1]]}],
     "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{
     RowBox[{"g", "[", "4", "]"}], ",", "xCoord"}], "]"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"*", 
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox["In",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox["  ",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[
      SuperscriptBox["ds", "2"],
      FontColor->RGBColor[0, 0, 1]]}], 
    StyleBox[",",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[
     RowBox[{
     "note", " ", "the", " ", "use", " ", "of", " ", "dr", " ", "in", " ", 
      "place", " ", "of", " ", 
      RowBox[{"d", "[", "r", "]"}]}],
     FontColor->RGBColor[0, 0, 1]]}], " ", "**)"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        InterpretationBox[
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", "m"}], "r"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "5"],
           SeriesData[r, 
            DirectedInfinity[1], {}, 0, 5, 1]]}],
         SeriesData[r, 
          DirectedInfinity[1], {1, (-2) m, a^2}, 0, 5, 1]], "0", "0", "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          FractionBox[
           RowBox[{"2", " ", "m"}], "r"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", 
             RowBox[{"2", " ", "m"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", 
             RowBox[{"2", " ", "m"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "+", 
          RowBox[{"4", " ", "m", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["m", "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "3"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "m"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["m", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "m"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["m", "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "4"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "5"],
           SeriesData[r, 
            DirectedInfinity[1], {}, 0, 5, 1]]}],
         SeriesData[r, 
          DirectedInfinity[
          1], {-1, (-2) 
           m, (a - 2 m) (a + 2 m), (4 m) (a^2 - 2 
            m^2), (-(a^2 - (2 a) m - 4 m^2)) (a^2 + (2 a) m - 4 m^2)}, 0, 5, 
          1]], "0", "0"},
       {"0", "0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["1", "r"], ")"}], "2"]]}], "+", 
          FractionBox[
           RowBox[{"2", " ", "b"}], 
           FractionBox["1", "r"]], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox["b", "3"]}], 
           RowBox[{"3", " ", "r"}]], "-", 
          RowBox[{
           FractionBox["2", "3"], " ", 
           SuperscriptBox["b", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "3"],
           SeriesData[r, 
            DirectedInfinity[1], {}, -2, 3, 1]]}],
         SeriesData[r, 
          DirectedInfinity[
          1], {-1, 2 b, (-2) b^2, Rational[4, 3] b^3, Rational[-2, 3] 
           b^4}, -2, 3, 1]], "0"},
       {"0", "0", "0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["1", "r"], ")"}], "2"]]}], "-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"b", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], 
           FractionBox["1", "r"]], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "3"], " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}]}], 
           RowBox[{"3", " ", "r"}]], "-", 
          RowBox[{
           FractionBox["2", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "3"],
           SeriesData[r, 
            DirectedInfinity[1], {}, -2, 3, 1]]}],
         SeriesData[r, 
          DirectedInfinity[
          1], {-Sin[\[Theta]]^2, ((-2) b) Sin[\[Theta]]^2, ((-2) b^2) 
           Sin[\[Theta]]^2, (Rational[-4, 3] b^3) 
           Sin[\[Theta]]^2, (Rational[-2, 3] b^4) Sin[\[Theta]]^2}, -2, 3, 1]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{
      SeriesData[r, 
       DirectedInfinity[1], {1, (-2) m, a^2}, 0, 5, 1], 0, 0, 0}, {0, 
      SeriesData[r, 
       DirectedInfinity[
       1], {-1, (-2) 
        m, (a - 2 m) (a + 2 m), (4 m) (a^2 - 2 
         m^2), (-(a^2 - (2 a) m - 4 m^2)) (a^2 + (2 a) m - 4 m^2)}, 0, 5, 1], 
      0, 0}, {0, 0, 
      SeriesData[r, 
       DirectedInfinity[
       1], {-1, 2 b, (-2) b^2, Rational[4, 3] b^3, Rational[-2, 3] b^4}, -2, 
       3, 1], 0}, {0, 0, 0, 
      SeriesData[r, 
       DirectedInfinity[
       1], {-Sin[\[Theta]]^2, ((-2) b) Sin[\[Theta]]^2, ((-2) b^2) 
        Sin[\[Theta]]^2, (Rational[-4, 3] b^3) 
        Sin[\[Theta]]^2, (Rational[-2, 3] b^4) Sin[\[Theta]]^2}, -2, 3, 1]}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "r"], ")"}], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", "[", "\[Theta]", "]"}], "-", 
         RowBox[{
          RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", "[", "\[Theta]", "]"}], "+", 
         RowBox[{
          RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}], 
      FractionBox["1", "r"]], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["dr", "2"]}], "+", 
       SuperscriptBox[
        RowBox[{"d", "[", "t", "]"}], "2"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox[
         RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["dr", "2"], " ", "m"}], "+", 
         RowBox[{"3", " ", "m", " ", 
          SuperscriptBox[
           RowBox[{"d", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox[
           RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox[
           RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], 
      RowBox[{"3", " ", "r"}]], "+", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["dr", "2"]}], "-", 
        RowBox[{"12", " ", 
         SuperscriptBox["dr", "2"], " ", 
         SuperscriptBox["m", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "t", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox[
          RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "r"], ")"}], "2"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "3"],
      SeriesData[r, 
       DirectedInfinity[1], {}, -2, 3, 1]]}],
    SeriesData[r, 
     DirectedInfinity[
     1], {-d[\[Theta]]^2 - d[\[CurlyPhi]]^2 
      Sin[\[Theta]]^2, ((2 b) (d[\[Theta]] - d[\[CurlyPhi]] Sin[\[Theta]])) (
       d[\[Theta]] + d[\[CurlyPhi]] Sin[\[Theta]]), -dr^2 + d[t]^2 - (2 b^2) 
      d[\[Theta]]^2 - ((2 b^2) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2, 
      Rational[-2, 3] ((3 dr^2) m + (3 m) d[t]^2 - (2 b^3) 
       d[\[Theta]]^2 + ((2 b^3) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2), 
      Rational[1, 3] ((3 a^2) dr^2 - (12 dr^2) m^2 + (3 a^2) d[t]^2 - (2 b^4) 
       d[\[Theta]]^2 - ((2 b^4) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2)}, -2, 3, 
     1]]}],
  SequenceForm["\!\(ds\^2\) = ", 
   SeriesData[r, 
    DirectedInfinity[
    1], {-d[\[Theta]]^2 - d[\[CurlyPhi]]^2 
     Sin[\[Theta]]^2, ((2 b) (d[\[Theta]] - d[\[CurlyPhi]] Sin[\[Theta]])) (
      d[\[Theta]] + d[\[CurlyPhi]] Sin[\[Theta]]), -dr^2 + d[t]^2 - (2 b^2) 
     d[\[Theta]]^2 - ((2 b^2) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2, 
     Rational[-2, 3] ((3 dr^2) m + (3 m) d[t]^2 - (2 b^3) 
      d[\[Theta]]^2 + ((2 b^3) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2), 
     Rational[1, 3] ((3 a^2) dr^2 - (12 dr^2) m^2 + (3 a^2) d[t]^2 - (2 b^4) 
      d[\[Theta]]^2 - ((2 b^4) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2)}, -2, 3, 1]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {
        InterpretationBox[
         RowBox[{"1", "+", 
          FractionBox[
           RowBox[{"2", " ", "m"}], "r"], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", 
             RowBox[{"2", " ", "m"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", 
             RowBox[{"2", " ", "m"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "+", 
          RowBox[{"4", " ", "m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["m", "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "3"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "m"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["m", "2"]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             RowBox[{"2", " ", "a", " ", "m"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox["m", "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "4"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "5"],
           SeriesData[r, 
            DirectedInfinity[1], {}, 0, 5, 1]]}],
         SeriesData[r, 
          DirectedInfinity[1], {
          1, 2 m, (-(a - 2 m)) (a + 2 m), (4 m) (-a^2 + 2 m^2), (a^2 - (2 a) 
            m - 4 m^2) (a^2 + (2 a) m - 4 m^2)}, 0, 5, 1]], "0", "0", "0"},
       {"0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          FractionBox[
           RowBox[{"2", " ", "m"}], "r"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "5"],
           SeriesData[r, 
            DirectedInfinity[1], {}, 0, 5, 1]]}],
         SeriesData[r, 
          DirectedInfinity[1], {-1, 2 m, -a^2}, 0, 5, 1]], "0", "0"},
       {"0", "0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "2"]}], "-", 
          RowBox[{"2", " ", "b", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "3"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "4"]}], "-", 
          RowBox[{
           FractionBox["4", "3"], " ", 
           SuperscriptBox["b", "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "5"]}], "-", 
          RowBox[{
           FractionBox["2", "3"], " ", 
           SuperscriptBox["b", "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "6"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "7"],
           SeriesData[r, 
            DirectedInfinity[1], {}, 2, 7, 1]]}],
         SeriesData[r, 
          DirectedInfinity[
          1], {-1, (-2) b, (-2) b^2, Rational[-4, 3] b^3, Rational[-2, 3] 
           b^4}, 2, 7, 1]], "0"},
       {"0", "0", "0", 
        InterpretationBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["1", "r"], ")"}], "2"]}]}], "+", 
          RowBox[{"2", " ", "b", " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "3"]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox[
              RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "4"]}], "+", 
          RowBox[{
           FractionBox["4", "3"], " ", 
           SuperscriptBox["b", "3"], " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "5"]}], "-", 
          RowBox[{
           FractionBox["2", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox[
              RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "r"], ")"}], "6"]}], "+", 
          InterpretationBox[
           SuperscriptBox[
            RowBox[{"O", "[", 
             FractionBox["1", "r"], "]"}], "7"],
           SeriesData[r, 
            DirectedInfinity[1], {}, 2, 7, 1]]}],
         SeriesData[r, 
          DirectedInfinity[
          1], {-Csc[\[Theta]]^2, (2 b) Csc[\[Theta]]^2, ((-2) b^2) 
           Csc[\[Theta]]^2, (Rational[4, 3] b^3) 
           Csc[\[Theta]]^2, (Rational[-2, 3] b^4) Csc[\[Theta]]^2}, 2, 7, 
          1]]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{
      SeriesData[r, 
       DirectedInfinity[1], {
       1, 2 m, (-(a - 2 m)) (a + 2 m), (4 m) (-a^2 + 2 m^2), (a^2 - (2 a) m - 
         4 m^2) (a^2 + (2 a) m - 4 m^2)}, 0, 5, 1], 0, 0, 0}, {0, 
      SeriesData[r, 
       DirectedInfinity[1], {-1, 2 m, -a^2}, 0, 5, 1], 0, 0}, {0, 0, 
      SeriesData[r, 
       DirectedInfinity[
       1], {-1, (-2) b, (-2) b^2, Rational[-4, 3] b^3, Rational[-2, 3] b^4}, 
       2, 7, 1], 0}, {0, 0, 0, 
      SeriesData[r, 
       DirectedInfinity[
       1], {-Csc[\[Theta]]^2, (2 b) Csc[\[Theta]]^2, ((-2) b^2) 
        Csc[\[Theta]]^2, (Rational[4, 3] b^3) 
        Csc[\[Theta]]^2, (Rational[-2, 3] b^4) Csc[\[Theta]]^2}, 2, 7, 1]}}]],
  
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.516666666666651508`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.5166666666666515, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.166666666666685614`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.16666666666668561`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.266666666666651508`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.2666666666666515, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.3333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333598602`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.03333333333335986, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.399999999999977262`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.39999999999997726`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666515084`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.01666666666665151, " sec"],
  Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Rdd"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 4, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {a^2}, 4, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 4, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {-a^2 - 2 b^2}, 4, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "6"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 2, 6, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {(2 b) Cot[\[Theta]]}, 2, 6, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "6"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 2, 6, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {(2 b) Cot[\[Theta]]}, 2, 6, 1]], ",", 
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "b"}], "r"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"2", " ", "b", " ", "m"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "3"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 1, 3, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {2 b, a^2 - 2 b^2 - (2 b) m}, 1, 3, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "r"], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"2", " ", "b", " ", "m"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "3"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 1, 3, 1]]}],
      SeriesData[r, 
       DirectedInfinity[
       1], {(2 b) Sin[\[Theta]]^2, (a^2 + 6 b^2 + (2 b) m) Sin[\[Theta]]^2}, 
       1, 3, 1]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 "However, if the coframe (which depends on ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 ") is to be expanded with respect to the coordinate x, the user must \
introduce the symbol ",
 StyleBox["dx",
  FontFamily->"Courier"],
 " for ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 StyleBox["before",
  FontSlant->"Italic"],
 " expanding the coframe. This is achieved with the following commands (where \
",
 StyleBox["x",
  FontFamily->"Courier"],
 " is the symbol for the expansion coordinate) :"
}], "Text",
 FontSize->16],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeclareForms", "[", 
   RowBox[{"1", ",", "dx"}], "]"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "x", "]"}], "=", "dx"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "dx", "]"}], "=", "0"}], ";"}]], "Input"],

Cell[TextData[{
 " \tThen ",
 StyleBox["Series",
  FontFamily->"Courier"],
 " does not expand ",
 StyleBox["d[x]",
  FontFamily->"Courier"],
 " (= ",
 StyleBox["dx",
  FontFamily->"Courier"],
 "):"
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "x", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"dx", "+", 
   RowBox[{"dx", " ", "x"}], "+", 
   RowBox[{"dx", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "x", "]"}], "3"],
    SeriesData[x, 0, {}, 0, 3, 1]]}],
  SeriesData[x, 0, {dx, dx, dx}, 0, 3, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 " \tAnd ",
 StyleBox["dx",
  FontFamily->"Courier"],
 " is treated correctly as a closed 1-form:  "
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "x", "]"}], "2"],
  SeriesData[x, 0, {}, 2, 2, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%%", "\[Wedge]", "%%"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "x", "]"}], "3"],
  SeriesData[x, 0, {}, 3, 3, 1]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIf repeated calculations (for different orders) are to be performed, the \
differentials of the coordinates ",
 "(and of the symbol dx) must be cleared before each new calculation",
 " - see \"",
 ButtonBox["Note on repeated frame calculations",
  BaseStyle->"Hyperlink",
  ButtonData:>"sec 5"],
 "\" in section 5.1."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\<\
\t\[FilledSmallSquare]   Example 11: Example 10 in an orthonormal frame \
\>", "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "m", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "a", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "b", "]"}], "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeclareForms", "[", 
   RowBox[{"1", ",", "dr"}], "]"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=", "dr"}], ";", 
  RowBox[{
   RowBox[{"d", "[", "dr", "]"}], "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ONframe", "=", 
   RowBox[{"PowerExpand", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"A", "[", "r", "]"}], "]"}], 
       RowBox[{"d", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{"d", "[", "r", "]"}], "/", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"A", "[", "r", "]"}], "]"}]}], ",", 
      RowBox[{"r", " ", 
       RowBox[{
        RowBox[{"d", "[", "\[Theta]", "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"B", "[", "r", "]"}], "]"}]}]}], ",", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{"Sqrt", "[", 
        RowBox[{"B", "[", "r", "]"}], "]"}], 
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}]}], "}"}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gON", "=", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ONfrSer", "[", "n_", "]"}], ":=", 
  RowBox[{"FacSimp", "[", 
   RowBox[{"Series", "[", 
    RowBox[{"ONframe", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "Infinity", ",", "n"}], "}"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["Order",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["4",
     FontColor->RGBColor[0, 0, 1]]}], " ", "**)"}], 
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{"gON", ",", "xCoord", ",", 
     RowBox[{"ONfrSer", "[", "4", "]"}]}], "]"}], ";"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"d[coframe] computed in \"\>", "\[InvisibleSpace]", 
   "0.866666666666617402`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["d[coframe] computed in ", 0.8666666666666174, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, -1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"e", "[", "1", "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"e", "[", "2", "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"e", "[", "3", "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"e", "[", "4", "]"}], "2"]}], ")"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 0, 4, 1]]}],
    SeriesData[r, 
     DirectedInfinity[1], {e[1]^2 - e[2]^2 - e[3]^2 - e[4]^2}, 0, 4, 1]]}],
  SequenceForm["\!\(ds\^2\) = ", 
   SeriesData[r, 
    DirectedInfinity[1], {e[1]^2 - e[2]^2 - e[3]^2 - e[4]^2}, 0, 4, 1]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, -1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0500000000000113686`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.05000000000001137, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", "0.25`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.25, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.28333333333335986`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.28333333333335986`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.149999999999977262`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.14999999999997726`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666667083518`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.016666666666708352`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.216666666666640139`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.21666666666664014`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0., " sec"],
  Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Rdd"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 4, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {-a^2 - 2 b^2}, 4, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "4"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 4, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {(2 b) Cot[\[Theta]]}, 3, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "4"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 4, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {(2 b) Cot[\[Theta]]}, 3, 4, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "4"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 4, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {2 b}, 3, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "4"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 4, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {2 b}, 3, 4, 1]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\

\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[Theta]", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "=."}], ";", 
  RowBox[{"dr", "=."}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=", "dr"}], ";"}]], "Input"],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tNote that, after clearing the values of the differentials, ",
 StyleBox["d[r]",
  FontFamily->"Courier"],
 " must again be set equal to ",
 StyleBox["dr",
  FontFamily->"Courier"]
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"*", 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["Order",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["5",
     FontColor->RGBColor[0, 0, 1]]}], " ", "**)"}], 
  RowBox[{
   RowBox[{"RGtensors", "[", 
    RowBox[{"gON", ",", "xCoord", ",", 
     RowBox[{"ONfrSer", "[", "5", "]"}]}], "]"}], ";"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"d[coframe] computed in \"\>", "\[InvisibleSpace]", 
   "1.43333333333333712`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["d[coframe] computed in ", 1.4333333333333371`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, -1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"e", "[", "1", "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"e", "[", "2", "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"e", "[", "3", "]"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"e", "[", "4", "]"}], "2"]}], ")"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 0, 5, 1]]}],
    SeriesData[r, 
     DirectedInfinity[1], {e[1]^2 - e[2]^2 - e[3]^2 - e[4]^2}, 0, 5, 1]]}],
  SequenceForm["\!\(ds\^2\) = ", 
   SeriesData[r, 
    DirectedInfinity[1], {e[1]^2 - e[2]^2 - e[3]^2 - e[4]^2}, 0, 5, 1]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", "1"}], "0", "0"},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, -1}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333030168`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.03333333333330302, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.266666666666651508`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.2666666666666515, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.350000000000022737`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.35000000000002274`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.183333333333337122`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.18333333333333712`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333030168`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.03333333333330302, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.266666666666651508`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.2666666666666515, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666515084`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.01666666666665151, " sec"],
  Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Rdd"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 4, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {a^2}, 4, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["b", "2"], " ", "m", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "5"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "6"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 4, 6, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {-a^2 - 2 b^2, (4 b^2) m}, 4, 6, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"b", "-", "m"}], ")"}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[
       1], {(2 b) Cot[\[Theta]], ((2 b) (b - m)) Cot[\[Theta]]}, 3, 5, 1]], 
     ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{"b", "-", "m"}], ")"}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[
       1], {(2 b) Cot[\[Theta]], ((2 b) (b - m)) Cot[\[Theta]]}, 3, 5, 1]], 
     ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"2", " ", "b", " ", "m"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {2 b, a^2 + 2 b^2 - (2 b) m}, 3, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "6"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 6, 6, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      RowBox[{
       RowBox[{"2", " ", "b", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "3"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"2", " ", "b", " ", "m"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "4"]}], "+", 
       InterpretationBox[
        SuperscriptBox[
         RowBox[{"O", "[", 
          FractionBox["1", "r"], "]"}], "5"],
        SeriesData[r, 
         DirectedInfinity[1], {}, 3, 5, 1]]}],
      SeriesData[r, 
       DirectedInfinity[1], {2 b, a^2 + 2 b^2 + (2 b) m}, 3, 5, 1]]}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(3) If an implicit frame is used (see Section 5.2), then, in addition to \
the metric, the expressions in ",
 StyleBox["deList",
  FontFamily->"Courier"],
 " and ",
 StyleBox["dxRuleList",
  FontFamily->"Courier"],
 " must be expanded in a series, especially if they are complicated. The \
reason is that before a normal expression can be multiplied by a series, it \
must be expanded itself in a series. Thus, if ",
 StyleBox["deList",
  FontFamily->"Courier"],
 " and ",
 StyleBox["dxRuleList",
  FontFamily->"Courier"],
 " are given as normal expressions, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will keep expanding these expressions again and again every time it \
performs a differentiation, causing the calculations to proceed very slowly."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\<\
\t\[FilledSmallSquare]   Example 12: Example 10 in an implicit NP null frame\
\>", "Text",
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[Theta]", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "=."}], ";", 
  RowBox[{"dr", "=."}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=", "dr"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NPframe", "=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"FacSimp", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ONframe", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"ONframe", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", 
       SqrtBox["2"]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ONframe", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"ONframe", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", 
       SqrtBox["2"]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ONframe", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "+", 
         RowBox[{"I", " ", 
          RowBox[{"ONframe", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}]}], ")"}], "/", 
       SqrtBox["2"]}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ONframe", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "-", 
         RowBox[{"I", " ", 
          RowBox[{"ONframe", "[", 
           RowBox[{"[", "4", "]"}], "]"}]}]}], ")"}], "/", 
       SqrtBox["2"]}]}], "}"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"dr", " ", "r"}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]]}]]}], "+", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{"d", "[", "t", "]"}]}], 
     RowBox[{
      SqrtBox["2"], " ", "r"}]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"dr", " ", "r"}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]]}]], "+", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{"d", "[", "t", "]"}]}], 
     RowBox[{
      SqrtBox["2"], " ", "r"}]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        FractionBox["b", "r"]}]], " ", "r", " ", 
      RowBox[{"d", "[", "\[Theta]", "]"}]}], 
     SqrtBox["2"]], "+", 
    FractionBox[
     RowBox[{"I", " ", 
      SuperscriptBox["E", 
       RowBox[{"b", "/", "r"}]], " ", "r", " ", 
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     SqrtBox["2"]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        FractionBox["b", "r"]}]], " ", "r", " ", 
      RowBox[{"d", "[", "\[Theta]", "]"}]}], 
     SqrtBox["2"]], "-", 
    FractionBox[
     RowBox[{"I", " ", 
      SuperscriptBox["E", 
       RowBox[{"b", "/", "r"}]], " ", "r", " ", 
      RowBox[{"d", "[", "\[CurlyPhi]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     SqrtBox["2"]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dxTOe", "=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"NPframe", "==", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"e", "[", "1", "]"}], ",", 
          RowBox[{"e", "[", "2", "]"}], ",", 
          RowBox[{"e", "[", "3", "]"}], ",", 
          RowBox[{"e", "[", "4", "]"}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"d", "[", "t", "]"}], ",", 
         RowBox[{"d", "[", "r", "]"}], ",", 
         RowBox[{"d", "[", "\[Theta]", "]"}], ",", 
         RowBox[{"d", "[", "\[CurlyPhi]", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "\[Theta]", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       RowBox[{"e", "[", "3", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       RowBox[{"e", "[", "4", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]]}]}], ",", 
   RowBox[{
    RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"I", " ", 
        SuperscriptBox["E", 
         RowBox[{"-", 
          FractionBox["b", "r"]}]], " ", 
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"e", "[", "3", "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "r"}]]}], "+", 
     FractionBox[
      RowBox[{"I", " ", 
       SuperscriptBox["E", 
        RowBox[{"-", 
         FractionBox["b", "r"]}]], " ", 
       RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"e", "[", "4", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]]}]}], ",", 
   RowBox[{
    RowBox[{"d", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{"r", " ", 
       RowBox[{"e", "[", "1", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]]}]], "+", 
     FractionBox[
      RowBox[{"r", " ", 
       RowBox[{"e", "[", "2", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]]}]]}]}], ",", 
   RowBox[{"dr", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"e", "[", "1", "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "r"}]]}], "+", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{"e", "[", "2", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dNPframeTOee", "=", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"FacSimp", "[", 
    RowBox[{
     RowBox[{"d", "[", "NPframe", "]"}], "/.", "dxTOe"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"m", " ", "r"}]}], ")"}], " ", 
      RowBox[{
       RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "2", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"m", " ", "r"}]}], ")"}], " ", 
      RowBox[{
       RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "2", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]]}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{
        RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
        RowBox[{"e", "[", "3", "]"}]}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox["r", "2"]}]]}], "-", 
    FractionBox[
     RowBox[{"b", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{
       RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "4", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{
       RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "3", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "2"]}]], "+", 
    FractionBox[
     RowBox[{"b", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{
       RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "4", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "3"]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"b", "/", "r"}]], " ", 
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "4", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", "r"}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"b", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{
        RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
        RowBox[{"e", "[", "3", "]"}]}]}], 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox["r", "3"]}]]}], "-", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{
       RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "4", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "2"]}]], "+", 
    FractionBox[
     RowBox[{"b", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{
       RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "3", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "3"]}]], "+", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{
       RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "4", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["r", "2"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"b", "/", "r"}]], " ", 
      RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
      RowBox[{
       RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
       RowBox[{"e", "[", "4", "]"}]}]}], 
     RowBox[{
      SqrtBox["2"], " ", "r"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tFor implicit frame calculations, the user must define the global \
variables ",
 StyleBox["deList",
  FontFamily->"Courier"],
 " and ",
 StyleBox["dxRuleList",
  FontFamily->"Courier"],
 ". For this problem, only the ",
 StyleBox["\[Theta]",
  FontFamily->"Courier"],
 ", ",
 StyleBox["r",
  FontFamily->"Courier"],
 " differentials need to be included in ",
 StyleBox["dxRuleList",
  FontFamily->"Courier"],
 " :"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"deList", "=", "dNPframeTOee"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dxTOe2", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"dxTOe", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dxRuleList", "=", "dxTOe2"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "\[Theta]", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       RowBox[{"e", "[", "3", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       RowBox[{"e", "[", "4", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]]}]}], ",", 
   RowBox[{"dr", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"e", "[", "1", "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "r"}]]}], "+", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{"e", "[", "2", "]"}]}], 
      RowBox[{
       SqrtBox["2"], " ", "r"}]]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(1) Exact calculation (~3.5 sec):"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}],
     FontFamily->"Courier"], ",", "xCoord", ",", 
    RowBox[{"{", 
     RowBox[{"e", "[", "]"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{0, 1, 0, 0}, {1, 0, 0, 0}, {0, 0, 0, -1}, {0, 0, -1, 0}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"e", "[", "1", "]"}], " ", 
     RowBox[{"e", "[", "2", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"e", "[", "3", "]"}], " ", 
     RowBox[{"e", "[", "4", "]"}]}]}]}],
  SequenceForm["\!\(ds\^2\) = ", (2 e[1]) e[2] - (2 e[3]) e[4]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{0, 1, 0, 0}, {1, 0, 0, 0}, {0, 0, 0, -1}, {0, 0, -1, 0}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0500000000000113686`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.05000000000001137, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "2.36666666666667424`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 2.3666666666666742`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.466666666666696983`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.466666666666697, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.216666666666640139`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.21666666666664014`, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0666666666666628771`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.06666666666666288, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.266666666666651508`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.2666666666666515, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0833333333333712289`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.08333333333337123, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"NP variables PH[i,j], \[CapitalLambda] and PS[i] defined.\"\
\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"3.61666666666667424`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactRdd", "=", "Rdd"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}], ")"}]}], 
       SuperscriptBox["r", "6"]]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", "m", " ", "r"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["r", "2"]}]}], 
      SuperscriptBox["r", "6"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"b", " ", 
        SuperscriptBox["E", 
         RowBox[{"b", "/", "r"}]], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
       SuperscriptBox["r", "4"]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"b", " ", 
        SuperscriptBox["E", 
         RowBox[{"b", "/", "r"}]], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
       SuperscriptBox["r", "4"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"], " ", "m", " ", "r"}], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["r", "2"]}]}], 
      SuperscriptBox["r", "6"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}], ")"}]}], 
       SuperscriptBox["r", "6"]]}], ",", 
     FractionBox[
      RowBox[{"b", " ", 
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
      SuperscriptBox["r", "4"]], ",", 
     FractionBox[
      RowBox[{"b", " ", 
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
      SuperscriptBox["r", "4"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"b", " ", 
        SuperscriptBox["E", 
         RowBox[{"b", "/", "r"}]], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
       SuperscriptBox["r", "4"]]}], ",", 
     FractionBox[
      RowBox[{"b", " ", 
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
      SuperscriptBox["r", "4"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"m", " ", "r"}]}], ")"}]}], 
       SuperscriptBox["r", "5"]]}], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["E", 
         FractionBox[
          RowBox[{"2", " ", "b"}], "r"]], " ", 
        SuperscriptBox["r", "2"]}]}], 
      SuperscriptBox["r", "4"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"b", " ", 
        SuperscriptBox["E", 
         RowBox[{"b", "/", "r"}]], " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          RowBox[{"2", " ", "m", " ", "r"}], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
       SuperscriptBox["r", "4"]]}], ",", 
     FractionBox[
      RowBox[{"b", " ", 
       SuperscriptBox["E", 
        RowBox[{"b", "/", "r"}]], " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         RowBox[{"2", " ", "m", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]], " ", 
       RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
      SuperscriptBox["r", "4"]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       SuperscriptBox["r", "2"], "+", 
       RowBox[{
        SuperscriptBox["E", 
         FractionBox[
          RowBox[{"2", " ", "b"}], "r"]], " ", 
        SuperscriptBox["r", "2"]}]}], 
      SuperscriptBox["r", "4"]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "b", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"m", " ", "r"}]}], ")"}]}], 
       SuperscriptBox["r", "5"]]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"PH", "[", 
    RowBox[{"0", ",", "0"}], "]"}], ",", 
   RowBox[{"PH", "[", 
    RowBox[{"0", ",", "2"}], "]"}], ",", 
   RowBox[{"PH", "[", 
    RowBox[{"1", ",", "2"}], "]"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "6"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"m", " ", "r"}]}], ")"}]}], 
     SuperscriptBox["r", "5"]]}], ",", 
   FractionBox[
    RowBox[{"b", " ", 
     SuperscriptBox["E", 
      RowBox[{"b", "/", "r"}]], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"2", " ", "m", " ", "r"}], "+", 
       SuperscriptBox["r", "2"]}]], " ", 
     RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["r", "4"]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactPS", "=", 
  RowBox[{"PS", "/@", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{"b", " ", 
     SuperscriptBox["E", 
      RowBox[{"b", "/", "r"}]], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "-", 
       RowBox[{"2", " ", "m", " ", "r"}], "+", 
       SuperscriptBox["r", "2"]}]], " ", 
     RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["r", "4"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", "m", " ", "r"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["r", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["r", "2"]}], "+", 
      RowBox[{"6", " ", "m", " ", 
       SuperscriptBox["r", "3"]}], "-", 
      SuperscriptBox["r", "4"], "+", 
      RowBox[{
       SuperscriptBox["E", 
        FractionBox[
         RowBox[{"2", " ", "b"}], "r"]], " ", 
       SuperscriptBox["r", "4"]}]}], 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "6"]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"b", " ", 
      SuperscriptBox["E", 
       RowBox[{"b", "/", "r"}]], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "m", " ", "r"}], "+", 
        SuperscriptBox["r", "2"]}]], " ", 
      RowBox[{"Cot", "[", "\[Theta]", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"]}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData["\n"], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(2) Approximate calculation (~9 sec):"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "t", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[Theta]", "]"}], "=."}], ";", 
  RowBox[{
   RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "=."}], ";", 
  RowBox[{"dr", "=."}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "r", "]"}], "=", "dr"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deList", "=", 
  RowBox[{"FacSimp", "[", 
   RowBox[{"Series", "[", 
    RowBox[{"dNPframeTOee", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "Infinity", ",", "3"}], "}"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"m", " ", 
        RowBox[{
         RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
         RowBox[{"e", "[", "2", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "m"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "m"}], ")"}], " ", 
       RowBox[{
        RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
        RowBox[{"e", "[", "2", "]"}]}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "3"]}], 
      SqrtBox["2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 2, 4, 1]]}],
    SeriesData[r, 
     DirectedInfinity[1], {((-2^Rational[-1, 2]) m) Wedge[
        e[1], 
        e[2]], ((2^Rational[-1, 2] (a - m)) (a + m)) Wedge[
        e[1], 
        e[2]]}, 2, 4, 1]], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"m", " ", 
        RowBox[{
         RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
         RowBox[{"e", "[", "2", "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox["1", "r"], ")"}], "2"]}], 
       SqrtBox["2"]]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "m"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "m"}], ")"}], " ", 
       RowBox[{
        RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
        RowBox[{"e", "[", "2", "]"}]}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "3"]}], 
      SqrtBox["2"]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 2, 4, 1]]}],
    SeriesData[r, 
     DirectedInfinity[1], {((-2^Rational[-1, 2]) m) Wedge[
        e[1], 
        e[2]], ((2^Rational[-1, 2] (a - m)) (a + m)) Wedge[
        e[1], 
        e[2]]}, 2, 4, 1]], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
          RowBox[{"e", "[", "3", "]"}]}], 
         SqrtBox["2"]]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
         RowBox[{"e", "[", "3", "]"}]}], 
        SqrtBox["2"]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
          RowBox[{"e", "[", "4", "]"}]}]}], 
        SqrtBox["2"]]}], "r"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"m", " ", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "3", "]"}]}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{"b", " ", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{"m", " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "3", "]"}]}]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{"b", " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{"b", " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "r"], ")"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "m"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "m"}], ")"}], " ", 
           RowBox[{
            RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
            RowBox[{"e", "[", "3", "]"}]}]}], 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]]}], "+", 
        FractionBox[
         RowBox[{"b", " ", "m", " ", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "m"}], ")"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "3", "]"}]}]}], 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]], "-", 
        FractionBox[
         RowBox[{"b", " ", "m", " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "r"], ")"}], "3"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 1, 4, 1]]}],
    SeriesData[r, 
     DirectedInfinity[1], {(-2^Rational[-1, 2]) Wedge[
         e[1], 
         e[3]] + 2^Rational[-1, 2] Wedge[
         e[2], 
         e[3]] - (2^Rational[-1, 2] Cot[\[Theta]]) Wedge[
        e[3], 
        e[4]], (2^Rational[-1, 2] m) Wedge[
         e[1], 
         e[3]] - (2^Rational[-1, 2] b) Wedge[
        e[1], 
        e[4]] - (2^Rational[-1, 2] m) Wedge[
        e[2], 
        e[3]] + (2^Rational[-1, 2] b) Wedge[
         e[2], 
         e[4]] - ((2^Rational[-1, 2] b) Cot[\[Theta]]) Wedge[
        e[3], 
        e[4]], (((Rational[-1, 2] 2^Rational[-1, 2]) (a - m)) (a + m)) Wedge[
         e[1], 
         e[3]] + ((2^Rational[-1, 2] b) m) Wedge[
         e[1], 
         e[4]] + (((Rational[1, 2] 2^Rational[-1, 2]) (a - m)) (a + m)) 
       Wedge[
         e[2], 
         e[3]] - ((2^Rational[-1, 2] b) m) Wedge[
        e[2], 
        e[4]] + (((Rational[-1, 2] 2^Rational[-1, 2]) b^2) Cot[\[Theta]]) 
       Wedge[
         e[3], 
         e[4]]}, 1, 4, 1]], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
          RowBox[{"e", "[", "4", "]"}]}], 
         SqrtBox["2"]]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
         RowBox[{"e", "[", "4", "]"}]}], 
        SqrtBox["2"]], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
         RowBox[{
          RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
          RowBox[{"e", "[", "4", "]"}]}]}], 
        SqrtBox["2"]]}], "r"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"b", " ", 
           RowBox[{
            RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
            RowBox[{"e", "[", "3", "]"}]}]}], 
          SqrtBox["2"]]}], "+", 
        FractionBox[
         RowBox[{"m", " ", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{"b", " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "3", "]"}]}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{"m", " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{"b", " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         SqrtBox["2"]]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "r"], ")"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"b", " ", "m", " ", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "3", "]"}]}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "m"}], ")"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "1", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]], "-", 
        FractionBox[
         RowBox[{"b", " ", "m", " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "3", "]"}]}]}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "m"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "m"}], ")"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "2", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{
           RowBox[{"e", "[", "3", "]"}], "\[Wedge]", 
           RowBox[{"e", "[", "4", "]"}]}]}], 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "r"], ")"}], "3"]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 1, 4, 1]]}],
    SeriesData[r, 
     DirectedInfinity[1], {(-2^Rational[-1, 2]) Wedge[
         e[1], 
         e[4]] + 2^Rational[-1, 2] Wedge[
         e[2], 
         e[4]] + (2^Rational[-1, 2] Cot[\[Theta]]) Wedge[
         e[3], 
         e[4]], ((-2^Rational[-1, 2]) b) Wedge[
         e[1], 
         e[3]] + (2^Rational[-1, 2] m) Wedge[
         e[1], 
         e[4]] + (2^Rational[-1, 2] b) Wedge[
         e[2], 
         e[3]] - (2^Rational[-1, 2] m) Wedge[
        e[2], 
        e[4]] + ((2^Rational[-1, 2] b) Cot[\[Theta]]) Wedge[
         e[3], 
         e[4]], ((2^Rational[-1, 2] b) m) Wedge[
         e[1], 
         e[3]] + (((Rational[-1, 2] 2^Rational[-1, 2]) (a - m)) (a + m)) Wedge[
         e[1], 
         e[4]] - ((2^Rational[-1, 2] b) m) Wedge[
        e[2], 
        e[3]] + (((Rational[1, 2] 2^Rational[-1, 2]) (a - m)) (a + m)) Wedge[
         e[2], 
         e[4]] + (((Rational[1, 2] 2^Rational[-1, 2]) b^2) Cot[\[Theta]]) 
       Wedge[
         e[3], 
         e[4]]}, 1, 4, 1]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dxRuleList", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Rule", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"FacSimp", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", "Infinity", ",", "3"}], "}"}]}], "]"}], "]"}]}], 
      "]"}], "&"}], ",", "dxTOe2"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "\[Theta]", "]"}], "\[Rule]", 
    InterpretationBox[
     RowBox[{
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"e", "[", "3", "]"}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{"e", "[", "4", "]"}], 
         SqrtBox["2"]]}], "r"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"b", " ", 
           RowBox[{"e", "[", "3", "]"}]}], 
          SqrtBox["2"]], "+", 
         FractionBox[
          RowBox[{"b", " ", 
           RowBox[{"e", "[", "4", "]"}]}], 
          SqrtBox["2"]]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"e", "[", "3", "]"}]}], 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"e", "[", "4", "]"}]}], 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "3"]}], "+", 
      InterpretationBox[
       SuperscriptBox[
        RowBox[{"O", "[", 
         FractionBox["1", "r"], "]"}], "4"],
       SeriesData[r, 
        DirectedInfinity[1], {}, 1, 4, 1]]}],
     SeriesData[r, 
      DirectedInfinity[1], {
      2^Rational[-1, 2] e[3] + 
       2^Rational[-1, 2] e[4], (2^Rational[-1, 2] b) 
        e[3] + (2^Rational[-1, 2] b) 
        e[4], ((Rational[1, 2] 2^Rational[-1, 2]) b^2) 
        e[3] + ((Rational[1, 2] 2^Rational[-1, 2]) b^2) e[4]}, 1, 4, 1]]}], 
   ",", 
   RowBox[{"dr", "\[Rule]", 
    InterpretationBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"e", "[", "1", "]"}], 
          SqrtBox["2"]]}], "+", 
        FractionBox[
         RowBox[{"e", "[", "2", "]"}], 
         SqrtBox["2"]]}], ")"}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"m", " ", 
          RowBox[{"e", "[", "1", "]"}]}], 
         SqrtBox["2"]], "-", 
        FractionBox[
         RowBox[{"m", " ", 
          RowBox[{"e", "[", "2", "]"}]}], 
         SqrtBox["2"]]}], "r"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "m"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "m"}], ")"}], " ", 
            RowBox[{"e", "[", "1", "]"}]}], 
           RowBox[{"2", " ", 
            SqrtBox["2"]}]]}], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "m"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "m"}], ")"}], " ", 
           RowBox[{"e", "[", "2", "]"}]}], 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "m"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "m"}], ")"}], " ", 
           RowBox[{"e", "[", "1", "]"}]}], 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]], "-", 
         FractionBox[
          RowBox[{"m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "m"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "m"}], ")"}], " ", 
           RowBox[{"e", "[", "2", "]"}]}], 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["1", "r"], ")"}], "3"]}], "+", 
      InterpretationBox[
       SuperscriptBox[
        RowBox[{"O", "[", 
         FractionBox["1", "r"], "]"}], "4"],
       SeriesData[r, 
        DirectedInfinity[1], {}, 0, 4, 1]]}],
     SeriesData[r, 
      DirectedInfinity[
      1], {(-2^Rational[-1, 2]) e[1] + 
       2^Rational[-1, 2] e[2], (2^Rational[-1, 2] m) e[1] - (
        2^Rational[-1, 2] m) 
       e[2], (((Rational[-1, 2] 2^Rational[-1, 2]) (a - m)) (a + m)) 
        e[1] + (((Rational[1, 2] 2^Rational[-1, 2]) (a - m)) (a + m)) 
        e[2], ((((Rational[1, 2] 2^Rational[-1, 2]) m) (-a + m)) (a + m)) 
        e[1] + ((((Rational[-1, 2] 2^Rational[-1, 2]) m) (-a + m)) (a + m)) 
        e[2]}, 0, 4, 1]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RGtensors", "[", 
   RowBox[{
    StyleBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}],
     FontFamily->"Courier"], ",", "xCoord", ",", 
    RowBox[{"{", 
     RowBox[{"e", "[", "]"}], "}"}]}], "]"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{0, 1, 0, 0}, {1, 0, 0, 0}, {0, 0, 0, -1}, {0, 0, -1, 0}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(ds\\^2\\) = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"e", "[", "1", "]"}], " ", 
     RowBox[{"e", "[", "2", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"e", "[", "3", "]"}], " ", 
     RowBox[{"e", "[", "4", "]"}]}]}]}],
  SequenceForm["\!\(ds\^2\) = ", (2 e[1]) e[2] - (2 e[3]) e[4]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"0", "1", "0", "0"},
       {"1", "0", "0", "0"},
       {"0", "0", "0", 
        RowBox[{"-", "1"}]},
       {"0", "0", 
        RowBox[{"-", "1"}], "0"}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{0, 1, 0, 0}, {1, 0, 0, 0}, {0, 0, 0, -1}, {0, 0, -1, 0}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0500000000000113686`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.05000000000001137, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "7.19999999999998863`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 7.199999999999989, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.416666666666685614`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.4166666666666856, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", "0.25`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.25, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333598602`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.03333333333335986, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.366666666666617402`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.3666666666666174, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333598602`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.03333333333335986, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"NP variables PH[i,j], \[CapitalLambda] and PS[i] defined.\"\
\>"], "Output",
 FontSize->16,
 FontSlant->"Italic",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8.60000000000002273`", " ", "Second"}], ",", "Null"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactRdd", "-", "Rdd"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "4"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 4, 4, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]], ",", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        FractionBox["1", "r"], "]"}], "5"],
      SeriesData[r, 
       DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe function ",
 StyleBox["zeroQ[]",
  FontFamily->"Courier"],
 " ignores ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"O", "[", 
    FractionBox["1", "r"], "]"}], "n"]]],
 " terms:"
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zeroQ", "[", "%", "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExactPS", "-", 
  RowBox[{"PS", "/@", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "4"}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "5"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 5, 5, 1]], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "5"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 5, 5, 1]], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "3"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 3, 3, 1]], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "5"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 5, 5, 1]], ",", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "r"], "]"}], "5"],
    SeriesData[r, 
     DirectedInfinity[1], {}, 5, 5, 1]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.0 has better handling of ",
 StyleBox["SeriesData",
  FontFamily->"Courier"],
 " objects. As a result it returns ",
 Cell[BoxData[
  InterpretationBox[
   SuperscriptBox[
    RowBox[{"O", "[", 
     FractionBox["1", "r"], "]"}], "5"],
   SeriesData[r, 
    DirectedInfinity[1], {}, 5, 5, 1]]]],
 " for all elements in the last two lists."
}], "Text",
 FontSize->16,
 FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tIf only ",
 StyleBox["deList",
  FontFamily->"Courier"],
 " is expanded, ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " takes ~20% longer, while if only ",
 StyleBox["dxRuleList",
  FontFamily->"Courier"],
 " is expanded, it takes ~60% longer!"
}], "Text",
 FontSize->16]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "blank 4"->{
  Cell[491277, 15169, 84, 3, 23, "Text",
   CellTags->"blank 4"]},
 "sec 5"->{
  Cell[514966, 16026, 405, 17, 32, "Subsubsection",
   CellTags->"sec 5"],
  Cell[515374, 16045, 341, 14, 33, "Text",
   CellTags->"sec 5"],
  Cell[515740, 16063, 74, 2, 31, "Input",
   CellTags->"sec 5"],
  Cell[516354, 16087, 168, 5, 33, "Text",
   CellTags->"sec 5"],
  Cell[516525, 16094, 296, 10, 31, "Input",
   CellTags->"sec 5"],
  Cell[516824, 16106, 315, 11, 33, "Text",
   CellTags->"sec 5"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"blank 4", 698944, 22405},
 {"sec 5", 699023, 22408}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 363, 13, 120, "Text"],
Cell[933, 37, 150, 5, 30, "Text"],
Cell[1086, 44, 1095, 41, 165, "Text"]
}, Open  ]],
Cell[2196, 88, 676, 27, 41, "Text"],
Cell[CellGroupData[{
Cell[2897, 119, 154, 4, 76, "Section"],
Cell[CellGroupData[{
Cell[3076, 127, 126, 5, 39, "Subsection"],
Cell[3205, 134, 358, 8, 55, "Text"],
Cell[3566, 144, 155, 7, 33, "Text"],
Cell[3724, 153, 54, 1, 33, "Text"],
Cell[3781, 156, 176, 7, 35, "Text"],
Cell[3960, 165, 224, 8, 35, "Text"],
Cell[4187, 175, 247, 8, 35, "Text"],
Cell[4437, 185, 159, 7, 59, "Text"],
Cell[4599, 194, 896, 31, 77, "Text"],
Cell[5498, 227, 209, 8, 33, "Text"],
Cell[5710, 237, 215, 8, 33, "Text"],
Cell[5928, 247, 265, 10, 33, "Text"],
Cell[6196, 259, 250, 11, 33, "Text"],
Cell[6449, 272, 269, 11, 33, "Text"],
Cell[6721, 285, 373, 17, 33, "Text"],
Cell[7097, 304, 507, 24, 33, "Text"],
Cell[7607, 330, 213, 12, 33, "Text"],
Cell[7823, 344, 217, 8, 33, "Text"],
Cell[8043, 354, 785, 28, 55, "Text"],
Cell[8831, 384, 709, 23, 77, "Text"],
Cell[CellGroupData[{
Cell[9565, 411, 90, 1, 31, "Subsubsection"],
Cell[9658, 414, 645, 22, 55, "Text"],
Cell[10306, 438, 467, 20, 34, "Text"],
Cell[10776, 460, 456, 21, 34, "Text"],
Cell[11235, 483, 568, 23, 56, "Text"],
Cell[11806, 508, 436, 20, 33, "Text"],
Cell[12245, 530, 145, 9, 33, "Text"],
Cell[12393, 541, 581, 25, 33, "Text"],
Cell[12977, 568, 1422, 58, 99, "Text"]
}, Open  ]],
Cell[14414, 629, 290, 11, 55, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14741, 645, 144, 5, 39, "Subsection"],
Cell[14888, 652, 281, 12, 70, "Text"],
Cell[15172, 666, 182, 8, 70, "Text"],
Cell[15357, 676, 300, 15, 70, "Text"],
Cell[15660, 693, 212, 9, 70, "Text"],
Cell[15875, 704, 464, 21, 70, "Text"],
Cell[16342, 727, 464, 21, 70, "Text"],
Cell[16809, 750, 660, 32, 70, "Text"],
Cell[17472, 784, 567, 27, 70, "Text"],
Cell[18042, 813, 309, 15, 70, "Text"],
Cell[18354, 830, 518, 24, 70, "Text"],
Cell[18875, 856, 1111, 54, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[20023, 915, 125, 5, 31, "Subsection"],
Cell[20151, 922, 661, 19, 70, "Text"],
Cell[20815, 943, 375, 18, 70, "Text"],
Cell[21193, 963, 246, 13, 70, "Text"],
Cell[21442, 978, 446, 20, 70, "Text"],
Cell[21891, 1000, 431, 16, 70, "Text"],
Cell[22325, 1018, 616, 24, 70, "Text"],
Cell[22944, 1044, 1910, 81, 70, "Text"],
Cell[24857, 1127, 540, 15, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[25434, 1147, 132, 5, 31, "Subsection"],
Cell[25569, 1154, 893, 33, 70, "Text"],
Cell[26465, 1189, 406, 21, 70, "Text"],
Cell[26874, 1212, 442, 22, 70, "Text"],
Cell[27319, 1236, 889, 33, 70, "Text"],
Cell[28211, 1271, 442, 22, 70, "Text"],
Cell[28656, 1295, 499, 24, 70, "Text"],
Cell[29158, 1321, 443, 24, 70, "Text"],
Cell[29604, 1347, 474, 20, 70, "Text"],
Cell[30081, 1369, 653, 23, 70, "Text"],
Cell[30737, 1394, 485, 14, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[31259, 1413, 231, 12, 26, "Subsubsection"],
Cell[CellGroupData[{
Cell[31515, 1429, 236, 12, 70, "Subsubsection"],
Cell[31754, 1443, 490, 18, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[32281, 1466, 223, 11, 70, "Subsubsection"],
Cell[32507, 1479, 510, 18, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[33054, 1502, 217, 11, 70, "Subsubsection"],
Cell[33274, 1515, 321, 12, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[33632, 1532, 213, 11, 70, "Subsubsection"],
Cell[33848, 1545, 238, 9, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[34123, 1559, 295, 14, 70, "Subsubsection"],
Cell[34421, 1575, 395, 17, 70, "Text"]
}, Closed]],
Cell[34831, 1595, 529, 22, 70, "Text"]
}, Closed]],
Cell[35375, 1620, 449, 16, 30, "Text"]
}, Open  ]],
Cell[35839, 1639, 97, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[35961, 1646, 120, 3, 76, "Section"],
Cell[36084, 1651, 187, 5, 31, "Input"],
Cell[36274, 1658, 719, 23, 33, "Input"],
Cell[36996, 1683, 661, 21, 31, "Input"],
Cell[37660, 1706, 1740, 57, 92, "Input"],
Cell[39403, 1765, 318, 10, 31, "Input"],
Cell[39724, 1777, 327, 10, 31, "Input"],
Cell[40054, 1789, 330, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[40409, 1803, 321, 11, 31, "Input"],
Cell[40733, 1816, 915, 28, 31, "Input"],
Cell[41651, 1846, 1009, 35, 52, "Input"],
Cell[42663, 1883, 1486, 43, 52, "Input"]
}, Open  ]],
Cell[44164, 1929, 1378, 41, 72, "Input"],
Cell[45545, 1972, 167, 5, 31, "Input"],
Cell[45715, 1979, 307, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[46047, 1992, 1820, 52, 72, "Input"],
Cell[47870, 2046, 1543, 44, 52, "Input"]
}, Open  ]],
Cell[49428, 2093, 359, 11, 31, "Input"],
Cell[49790, 2106, 947, 25, 52, "Input"],
Cell[50740, 2133, 325, 10, 31, "Input"],
Cell[51068, 2145, 777, 24, 52, "Input"],
Cell[51848, 2171, 46355, 1197, 1942, "Input"],
Cell[98206, 3370, 926, 27, 31, "Input"],
Cell[99135, 3399, 4515, 133, 92, "Input"],
Cell[103653, 3534, 2300, 78, 132, "Input"],
Cell[105956, 3614, 1034, 31, 52, "Input"],
Cell[106993, 3647, 494, 15, 31, "Input"],
Cell[107490, 3664, 494, 15, 31, "Input"],
Cell[CellGroupData[{
Cell[108009, 3683, 2808, 78, 92, "Input"],
Cell[110820, 3763, 551, 19, 31, "Input"],
Cell[111374, 3784, 2389, 66, 72, "Input"],
Cell[113766, 3852, 2292, 64, 72, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116095, 3921, 1181, 35, 52, "Input"],
Cell[117279, 3958, 424, 15, 31, "Input"],
Cell[117706, 3975, 3010, 86, 132, "Input"],
Cell[120719, 4063, 1453, 45, 52, "Input"]
}, Open  ]],
Cell[122187, 4111, 188, 5, 31, "Input"],
Cell[122378, 4118, 9082, 233, 252, "Input"],
Cell[CellGroupData[{
Cell[131485, 4355, 535, 17, 31, "Input"],
Cell[132023, 4374, 1725, 51, 52, "Input"],
Cell[133751, 4427, 2192, 66, 92, "Input"]
}, Open  ]],
Cell[135958, 4496, 729, 21, 31, "Input"],
Cell[136690, 4519, 913, 27, 31, "Input"],
Cell[137606, 4548, 231, 7, 31, "Input"],
Cell[137840, 4557, 323, 10, 31, "Input"],
Cell[138166, 4569, 477, 9, 52, "Input"],
Cell[138646, 4580, 186, 5, 31, "Input"]
}, Closed]],
Cell[138847, 4588, 62, 2, 23, "Text"],
Cell[CellGroupData[{
Cell[138934, 4594, 379, 15, 94, "Section"],
Cell[139316, 4611, 276, 10, 45, "Text"],
Cell[139595, 4623, 106, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[139726, 4630, 123, 3, 36, "Subsection"],
Cell[139852, 4635, 692, 25, 37, "Text"],
Cell[140547, 4662, 168, 5, 27, "Input"],
Cell[140718, 4669, 2092, 67, 43, "Input"],
Cell[142813, 4738, 94, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[142932, 4745, 120, 3, 27, "Input"],
Cell[143055, 4750, 3204, 88, 70, "Print"],
Cell[146262, 4840, 50671, 1103, 70, "Print"],
Cell[196936, 5945, 2957, 77, 70, "Print"],
Cell[199896, 6024, 288, 6, 70, "Print"],
Cell[200187, 6032, 170, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200394, 6041, 114, 3, 27, "Input"],
Cell[200511, 6046, 540, 17, 47, "Output"]
}, Open  ]],
Cell[201066, 6066, 140, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[201231, 6075, 59, 1, 27, "Input"],
Cell[201293, 6078, 1540, 43, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202870, 6126, 131, 4, 27, "Input"],
Cell[203004, 6132, 1540, 43, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[204593, 6181, 76, 1, 36, "Subsection"],
Cell[204672, 6184, 161, 5, 27, "Input"],
Cell[204836, 6191, 620, 22, 27, "Input"],
Cell[205459, 6215, 83, 2, 27, "Input"],
Cell[205545, 6219, 779, 35, 32, "Text"],
Cell[CellGroupData[{
Cell[206349, 6258, 120, 3, 27, "Input"],
Cell[206472, 6263, 915, 29, 101, "Print"],
Cell[207390, 6294, 1001, 30, 40, "Print"],
Cell[208394, 6326, 998, 32, 111, "Print"],
Cell[209395, 6360, 256, 5, 20, "Print"],
Cell[209654, 6367, 260, 5, 20, "Print"],
Cell[209917, 6374, 276, 5, 20, "Print"],
Cell[210196, 6381, 276, 5, 20, "Print"],
Cell[210475, 6388, 224, 5, 20, "Print"],
Cell[210702, 6395, 222, 5, 20, "Print"],
Cell[210927, 6402, 112, 3, 35, "Output"],
Cell[211042, 6407, 128, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211207, 6416, 125, 3, 27, "Input"],
Cell[211335, 6421, 218, 8, 48, "Output"]
}, Open  ]],
Cell[211568, 6432, 144, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[211737, 6442, 122, 3, 27, "Input"],
Cell[211862, 6447, 127, 4, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[212038, 6457, 111, 3, 36, "Subsection"],
Cell[212152, 6462, 161, 5, 27, "Input"],
Cell[212316, 6469, 850, 28, 27, "Input"],
Cell[213169, 6499, 83, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[213277, 6505, 120, 3, 27, "Input"],
Cell[213400, 6510, 1267, 39, 110, "Print"],
Cell[214670, 6551, 1331, 38, 45, "Print"],
Cell[216004, 6591, 1313, 39, 118, "Print"],
Cell[217320, 6632, 256, 5, 20, "Print"],
Cell[217579, 6639, 260, 5, 20, "Print"],
Cell[217842, 6646, 276, 5, 20, "Print"],
Cell[218121, 6653, 276, 5, 20, "Print"],
Cell[218400, 6660, 260, 5, 20, "Print"],
Cell[218663, 6667, 257, 5, 20, "Print"],
Cell[218923, 6674, 230, 5, 20, "Print"],
Cell[219156, 6681, 116, 3, 35, "Output"],
Cell[219275, 6686, 128, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219440, 6695, 103, 3, 27, "Input"],
Cell[219546, 6700, 89, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219672, 6707, 27, 0, 27, "Input"],
Cell[219702, 6709, 83, 2, 27, "Output"]
}, Open  ]],
Cell[219800, 6714, 140, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[219965, 6723, 92, 2, 27, "Input"],
Cell[220060, 6727, 31, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[220128, 6732, 361, 15, 28, "Subsubsection"],
Cell[220492, 6749, 187, 5, 27, "Input"],
Cell[220682, 6756, 143, 4, 27, "Input"],
Cell[220828, 6762, 1436, 50, 43, "Input"],
Cell[222267, 6814, 790, 28, 43, "Input"],
Cell[CellGroupData[{
Cell[223082, 6846, 192, 5, 27, "Input"],
Cell[223277, 6853, 309, 11, 49, "Output"]
}, Open  ]],
Cell[223601, 6867, 234, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[223860, 6881, 868, 28, 27, "Input"],
Cell[224731, 6911, 298, 11, 49, "Output"]
}, Open  ]],
Cell[225044, 6925, 186, 5, 27, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[225279, 6936, 74, 1, 36, "Subsection"],
Cell[225356, 6939, 161, 5, 27, "Input"],
Cell[225520, 6946, 1040, 34, 27, "Input"],
Cell[226563, 6982, 83, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[226671, 6988, 120, 3, 27, "Input"],
Cell[226794, 6993, 1089, 33, 90, "Print"],
Cell[227886, 7028, 1126, 33, 42, "Print"],
Cell[229015, 7063, 1168, 36, 110, "Print"],
Cell[230186, 7101, 256, 5, 20, "Print"],
Cell[230445, 7108, 260, 5, 20, "Print"],
Cell[230708, 7115, 275, 5, 20, "Print"],
Cell[230986, 7122, 276, 5, 20, "Print"],
Cell[231265, 7129, 262, 5, 20, "Print"],
Cell[231530, 7136, 257, 5, 20, "Print"],
Cell[231790, 7143, 118, 3, 35, "Output"],
Cell[231911, 7148, 266, 5, 20, "Print"],
Cell[232180, 7155, 128, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232345, 7164, 103, 3, 27, "Input"],
Cell[232451, 7169, 220, 7, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232708, 7181, 103, 3, 27, "Input"],
Cell[232814, 7186, 301, 10, 53, "Output"]
}, Open  ]],
Cell[233130, 7199, 141, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[233296, 7208, 92, 2, 27, "Input"],
Cell[233391, 7212, 31, 0, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[233471, 7218, 92, 1, 36, "Subsection"],
Cell[233566, 7221, 159, 5, 27, "Input"],
Cell[233728, 7228, 168, 5, 27, "Input"],
Cell[233899, 7235, 94, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[234018, 7242, 136, 6, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[234179, 7252, 301, 8, 27, "Input"],
Cell[234483, 7262, 1469, 38, 101, "Print"],
Cell[235955, 7302, 1617, 45, 23, "Print"],
Cell[237575, 7349, 1639, 43, 146, "Print"],
Cell[239217, 7394, 256, 5, 20, "Print"],
Cell[239476, 7401, 260, 5, 20, "Print"],
Cell[239739, 7408, 274, 5, 20, "Print"],
Cell[240016, 7415, 273, 5, 20, "Print"],
Cell[240292, 7422, 259, 5, 20, "Print"],
Cell[240554, 7429, 258, 5, 20, "Print"],
Cell[240815, 7436, 118, 3, 35, "Output"],
Cell[240936, 7441, 266, 5, 20, "Print"],
Cell[241205, 7448, 127, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241369, 7457, 114, 3, 27, "Input"],
Cell[241486, 7462, 421, 12, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241944, 7479, 103, 3, 27, "Input"],
Cell[242050, 7484, 2549, 72, 91, "Output"]
}, Open  ]],
Cell[244614, 7559, 125, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[244764, 7568, 65, 1, 27, "Input"],
Cell[244832, 7571, 30, 0, 27, "Output"]
}, Open  ]],
Cell[244877, 7574, 118, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[245020, 7583, 98, 2, 27, "Input"],
Cell[245121, 7587, 29, 0, 27, "Output"]
}, Open  ]],
Cell[245165, 7590, 119, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[245309, 7599, 100, 2, 27, "Input"],
Cell[245412, 7603, 29, 0, 27, "Output"]
}, Open  ]],
Cell[245456, 7606, 138, 5, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[245631, 7616, 147, 6, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[245803, 7626, 634, 19, 27, "Input"],
Cell[246440, 7647, 3317, 91, 176, "Print"],
Cell[249760, 7740, 3287, 96, 94, "Print"],
Cell[253050, 7838, 3562, 98, 136, "Print"],
Cell[256615, 7938, 256, 5, 20, "Print"],
Cell[256874, 7945, 260, 5, 20, "Print"],
Cell[257137, 7952, 275, 5, 20, "Print"],
Cell[257415, 7959, 276, 5, 20, "Print"],
Cell[257694, 7966, 260, 5, 20, "Print"],
Cell[257957, 7973, 258, 5, 20, "Print"],
Cell[258218, 7980, 118, 3, 35, "Output"],
Cell[258339, 7985, 230, 5, 20, "Print"],
Cell[258572, 7992, 116, 3, 35, "Output"],
Cell[258691, 7997, 130, 3, 35, "Output"],
Cell[258824, 8002, 127, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258988, 8011, 125, 3, 27, "Input"],
Cell[259116, 8016, 460, 15, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[259613, 8036, 27, 0, 27, "Input"],
Cell[259643, 8038, 51, 1, 27, "Output"]
}, Open  ]],
Cell[259709, 8042, 125, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[259859, 8051, 65, 1, 27, "Input"],
Cell[259927, 8054, 29, 0, 27, "Output"]
}, Open  ]],
Cell[259971, 8057, 177, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[260173, 8067, 67, 1, 27, "Input"],
Cell[260243, 8070, 472, 15, 51, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[260776, 8092, 129, 4, 36, "Subsection"],
Cell[260908, 8098, 196, 6, 27, "Input"],
Cell[261107, 8106, 343, 12, 27, "Input"],
Cell[261453, 8120, 1586, 50, 43, "Input"],
Cell[263042, 8172, 94, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[263161, 8179, 120, 3, 27, "Input"],
Cell[263284, 8184, 2977, 88, 132, "Print"],
Cell[266264, 8274, 3320, 100, 45, "Print"],
Cell[269587, 8376, 4364, 122, 130, "Print"],
Cell[273954, 8500, 254, 5, 20, "Print"],
Cell[274211, 8507, 258, 5, 20, "Print"],
Cell[274472, 8514, 274, 5, 20, "Print"],
Cell[274749, 8521, 273, 5, 20, "Print"],
Cell[275025, 8528, 260, 5, 20, "Print"],
Cell[275288, 8535, 222, 5, 20, "Print"],
Cell[275513, 8542, 112, 3, 35, "Output"],
Cell[275628, 8547, 127, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275792, 8556, 114, 3, 27, "Input"],
Cell[275909, 8561, 220, 8, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[276166, 8574, 125, 3, 27, "Input"],
Cell[276294, 8579, 945, 32, 57, "Output"]
}, Open  ]],
Cell[277254, 8614, 140, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[277419, 8623, 122, 3, 27, "Input"],
Cell[277544, 8628, 127, 4, 27, "Output"]
}, Open  ]],
Cell[277686, 8635, 431, 19, 30, "Text"],
Cell[CellGroupData[{
Cell[278142, 8658, 122, 3, 27, "Input"],
Cell[278267, 8663, 107, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[278423, 8672, 253, 8, 36, "Subsection"],
Cell[278679, 8682, 143, 4, 27, "Input"],
Cell[278825, 8688, 200, 6, 27, "Input"],
Cell[279028, 8696, 2563, 76, 58, "Input"],
Cell[281594, 8774, 116, 2, 30, "Text"],
Cell[281713, 8778, 568, 19, 27, "Input"],
Cell[282284, 8799, 271, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[282580, 8809, 2913, 95, 43, "Input"],
Cell[285496, 8906, 4742, 170, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290275, 9081, 126, 3, 27, "Input"],
Cell[290404, 9086, 4954, 139, 227, "Print"],
Cell[295361, 9227, 4379, 132, 90, "Print"],
Cell[299743, 9361, 5252, 147, 245, "Print"],
Cell[304998, 9510, 256, 5, 20, "Print"],
Cell[305257, 9517, 258, 5, 20, "Print"],
Cell[305518, 9524, 274, 5, 20, "Print"],
Cell[305795, 9531, 260, 5, 20, "Print"],
Cell[306058, 9538, 258, 5, 20, "Print"],
Cell[306319, 9545, 222, 5, 20, "Print"],
Cell[306544, 9552, 112, 3, 35, "Output"],
Cell[306659, 9557, 127, 4, 27, "Output"]
}, Open  ]],
Cell[306801, 9564, 663, 25, 68, "Text"],
Cell[307467, 9591, 124, 3, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[307628, 9599, 112, 3, 36, "Subsection"],
Cell[307743, 9604, 183, 5, 27, "Input"],
Cell[307929, 9611, 1036, 36, 27, "Input"],
Cell[308968, 9649, 385, 13, 27, "Input"],
Cell[309356, 9664, 458, 16, 27, "Input"],
Cell[309817, 9682, 512, 18, 27, "Input"],
Cell[310332, 9702, 1822, 59, 43, "Input"],
Cell[312157, 9763, 94, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[312276, 9770, 120, 3, 27, "Input"],
Cell[312399, 9775, 4084, 123, 181, "Print"],
Cell[316486, 9900, 5025, 160, 128, "Print"],
Cell[321514, 10062, 9710, 260, 204, "Print"],
Cell[331227, 10324, 254, 5, 20, "Print"],
Cell[331484, 10331, 257, 5, 20, "Print"],
Cell[331744, 10338, 272, 5, 20, "Print"],
Cell[332019, 10345, 271, 5, 20, "Print"],
Cell[332293, 10352, 256, 5, 20, "Print"],
Cell[332552, 10359, 222, 5, 20, "Print"],
Cell[332777, 10366, 112, 3, 35, "Output"],
Cell[332892, 10371, 127, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333056, 10380, 30, 0, 27, "Input"],
Cell[333089, 10382, 1728, 59, 58, "Output"]
}, Open  ]],
Cell[334832, 10444, 783, 29, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[335652, 10478, 111, 3, 36, "Subsection"],
Cell[335766, 10483, 161, 5, 27, "Input"],
Cell[335930, 10490, 2574, 76, 43, "Input"],
Cell[338507, 10568, 83, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[338615, 10574, 120, 3, 27, "Input"],
Cell[338738, 10579, 3082, 82, 92, "Print"],
Cell[341823, 10663, 2679, 71, 42, "Print"],
Cell[344505, 10736, 2691, 72, 113, "Print"],
Cell[347199, 10810, 256, 5, 20, "Print"],
Cell[347458, 10817, 258, 5, 20, "Print"],
Cell[347719, 10824, 274, 5, 20, "Print"],
Cell[347996, 10831, 274, 5, 20, "Print"],
Cell[348273, 10838, 256, 5, 20, "Print"],
Cell[348532, 10845, 242, 5, 20, "Print"],
Cell[348777, 10852, 262, 5, 20, "Print"],
Cell[349042, 10859, 127, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349206, 10868, 114, 3, 27, "Input"],
Cell[349323, 10873, 1137, 36, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350497, 10914, 103, 3, 27, "Input"],
Cell[350603, 10919, 784, 26, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351424, 10950, 103, 3, 27, "Input"],
Cell[351530, 10955, 17141, 483, 196, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[368708, 11443, 59, 1, 27, "Input"],
Cell[368770, 11446, 1540, 43, 43, "Output"]
}, Open  ]],
Cell[370325, 11492, 194, 6, 30, "Text"],
Cell[370522, 11500, 298, 11, 45, "Text"],
Cell[CellGroupData[{
Cell[370845, 11515, 181, 5, 27, "Input"],
Cell[371029, 11522, 3082, 82, 92, "Print"],
Cell[374114, 11606, 2679, 71, 42, "Print"],
Cell[376796, 11679, 2691, 72, 113, "Print"],
Cell[379490, 11753, 256, 5, 20, "Print"],
Cell[379749, 11760, 258, 5, 20, "Print"],
Cell[380010, 11767, 271, 5, 20, "Print"],
Cell[380284, 11774, 121, 3, 31, "Output"],
Cell[380408, 11779, 256, 5, 20, "Print"],
Cell[380667, 11786, 127, 3, 31, "Output"],
Cell[380797, 11791, 262, 5, 20, "Print"],
Cell[381062, 11798, 127, 4, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[381238, 11808, 110, 3, 36, "Subsection"],
Cell[381351, 11813, 231, 6, 49, "Text"],
Cell[381585, 11821, 161, 5, 27, "Input"],
Cell[381749, 11828, 3011, 89, 90, "Input"],
Cell[384763, 11919, 165, 5, 60, "Text"],
Cell[384931, 11926, 83, 2, 27, "Input"],
Cell[CellGroupData[{
Cell[385039, 11932, 181, 5, 27, "Input"],
Cell[385223, 11939, 3416, 94, 108, "Print"],
Cell[388642, 12035, 3503, 97, 90, "Print"],
Cell[392148, 12134, 4576, 132, 125, "Print"],
Cell[396727, 12268, 220, 5, 20, "Print"],
Cell[396950, 12275, 258, 5, 20, "Print"],
Cell[397211, 12282, 274, 5, 20, "Print"],
Cell[397488, 12289, 274, 5, 20, "Print"],
Cell[397765, 12296, 255, 5, 20, "Print"],
Cell[398023, 12303, 127, 3, 31, "Output"],
Cell[398153, 12308, 264, 5, 20, "Print"],
Cell[398420, 12315, 127, 4, 27, "Output"]
}, Open  ]],
Cell[398562, 12322, 401, 15, 49, "Text"],
Cell[CellGroupData[{
Cell[398988, 12341, 65, 1, 27, "Input"],
Cell[399056, 12344, 43939, 1077, 70, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[443032, 13426, 125, 3, 21, "Input"],
Cell[443160, 13431, 1777, 54, 57, "Output"]
}, Open  ]],
Cell[444952, 13488, 181, 6, 60, "Text"],
Cell[CellGroupData[{
Cell[445158, 13498, 563, 17, 33, "Input"],
Cell[445724, 13517, 1095, 36, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446856, 13558, 120, 3, 27, "Input"],
Cell[446979, 13563, 3416, 94, 108, "Print"],
Cell[450398, 13659, 3503, 97, 90, "Print"],
Cell[453904, 13758, 4336, 123, 123, "Print"],
Cell[458243, 13883, 254, 5, 20, "Print"],
Cell[458500, 13890, 258, 5, 20, "Print"],
Cell[458761, 13897, 273, 5, 20, "Print"],
Cell[459037, 13904, 274, 5, 20, "Print"],
Cell[459314, 13911, 260, 5, 20, "Print"],
Cell[459577, 13918, 222, 5, 20, "Print"],
Cell[459802, 13925, 112, 3, 35, "Output"],
Cell[459917, 13930, 126, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460080, 13939, 114, 3, 27, "Input"],
Cell[460197, 13944, 374, 12, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460608, 13961, 125, 3, 27, "Input"],
Cell[460736, 13966, 679, 23, 57, "Output"]
}, Open  ]],
Cell[461430, 13992, 157, 5, 30, "Text"]
}, Open  ]],
Cell[461602, 14000, 141, 5, 45, "Text"],
Cell[CellGroupData[{
Cell[461768, 14009, 225, 6, 27, "Input"],
Cell[461996, 14017, 215, 5, 20, "Print"]
}, Open  ]]
}, Closed]],
Cell[462238, 14026, 62, 2, 23, "Text"],
Cell[CellGroupData[{
Cell[462325, 14032, 153, 6, 76, "Section"],
Cell[CellGroupData[{
Cell[462503, 14042, 214, 9, 36, "Subsection"],
Cell[462720, 14053, 766, 22, 87, "Text"],
Cell[463489, 14077, 428, 8, 68, "Text"],
Cell[463920, 14087, 786, 23, 106, "Text"],
Cell[464709, 14112, 377, 10, 49, "Text"],
Cell[465089, 14124, 287, 9, 27, "Input"],
Cell[465379, 14135, 329, 15, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[465745, 14155, 208, 9, 36, "Subsection"],
Cell[465956, 14166, 242, 10, 70, "Text"],
Cell[466201, 14178, 446, 23, 70, "Text"],
Cell[466650, 14203, 394, 20, 70, "Text"],
Cell[467047, 14225, 603, 29, 70, "Text"],
Cell[CellGroupData[{
Cell[467675, 14258, 432, 17, 70, "Text"],
Cell[468110, 14277, 1135, 45, 70, "Text"]
}, Open  ]],
Cell[469260, 14325, 988, 46, 70, "Text"],
Cell[470251, 14373, 1483, 62, 70, "Text"],
Cell[471737, 14437, 498, 21, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[472272, 14463, 171, 9, 28, "Subsection"],
Cell[472446, 14474, 501, 19, 70, "Text"],
Cell[472950, 14495, 850, 25, 70, "Text"],
Cell[CellGroupData[{
Cell[473825, 14524, 468, 21, 70, "Text"],
Cell[474296, 14547, 312, 12, 70, "Text"],
Cell[474611, 14561, 216, 11, 70, "Text"],
Cell[474830, 14574, 377, 18, 70, "Text"]
}, Closed]],
Cell[475222, 14595, 483, 15, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[475742, 14615, 179, 9, 28, "Subsection"],
Cell[475924, 14626, 844, 33, 68, "Text"],
Cell[CellGroupData[{
Cell[476793, 14663, 365, 12, 27, "Input"],
Cell[477161, 14677, 1641, 56, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478839, 14738, 409, 14, 27, "Input"],
Cell[479251, 14754, 4677, 157, 119, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[483965, 14916, 474, 16, 27, "Input"],
Cell[484442, 14934, 4975, 162, 71, "Output"]
}, Open  ]],
Cell[489432, 15099, 382, 13, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[489851, 15117, 183, 9, 36, "Subsection"],
Cell[490037, 15128, 719, 22, 70, "Text"],
Cell[490759, 15152, 491, 13, 70, "Text"]
}, Closed]]
}, Closed]],
Cell[491277, 15169, 84, 3, 23, "Text",
 CellTags->"blank 4"],
Cell[CellGroupData[{
Cell[491386, 15176, 149, 3, 76, "Section"],
Cell[491538, 15181, 404, 13, 55, "Text"],
Cell[491945, 15196, 1226, 32, 58, "Input"],
Cell[493174, 15230, 737, 22, 55, "Text"],
Cell[493914, 15254, 90, 1, 33, "Text"],
Cell[494007, 15257, 482, 17, 33, "Text"],
Cell[494492, 15276, 140, 6, 33, "Text"],
Cell[CellGroupData[{
Cell[494657, 15286, 223, 12, 40, "Subsection"],
Cell[494883, 15300, 164, 9, 33, "Text"],
Cell[495050, 15311, 517, 19, 55, "Text"],
Cell[495570, 15332, 240, 10, 34, "Text"],
Cell[495813, 15344, 1583, 57, 99, "Text"],
Cell[497399, 15403, 567, 22, 55, "Text"],
Cell[CellGroupData[{
Cell[497991, 15429, 217, 7, 55, "Text"],
Cell[498211, 15438, 154, 5, 31, "Input"],
Cell[498368, 15445, 615, 18, 31, "Input"],
Cell[498986, 15465, 343, 12, 31, "Input"],
Cell[499332, 15479, 755, 25, 31, "Input"],
Cell[500090, 15506, 158, 5, 31, "Input"],
Cell[500251, 15513, 94, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[500370, 15520, 139, 4, 31, "Input"],
Cell[500512, 15526, 270, 5, 23, "Print"],
Cell[500785, 15533, 2322, 69, 127, "Print"],
Cell[503110, 15604, 2548, 80, 45, "Print"],
Cell[505661, 15686, 2500, 74, 133, "Print"],
Cell[508164, 15762, 256, 5, 23, "Print"],
Cell[508423, 15769, 258, 5, 23, "Print"],
Cell[508684, 15776, 274, 5, 23, "Print"],
Cell[508961, 15783, 274, 5, 23, "Print"],
Cell[509238, 15790, 260, 5, 23, "Print"],
Cell[509501, 15797, 222, 5, 23, "Print"],
Cell[509726, 15804, 112, 3, 38, "Output"],
Cell[509841, 15809, 127, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510005, 15818, 30, 0, 31, "Input"],
Cell[510038, 15820, 227, 8, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510302, 15833, 125, 3, 31, "Input"],
Cell[510430, 15838, 1230, 41, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[511697, 15884, 110, 3, 31, "Input"],
Cell[511810, 15889, 1427, 49, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[513264, 15942, 493, 19, 55, "Text"],
Cell[513760, 15963, 275, 13, 34, "Text"],
Cell[514038, 15978, 294, 13, 34, "Text"],
Cell[514335, 15993, 285, 13, 34, "Text"],
Cell[514623, 16008, 318, 14, 56, "Text"],
Cell[CellGroupData[{
Cell[514966, 16026, 405, 17, 32, "Subsubsection",
 CellTags->"sec 5"],
Cell[515374, 16045, 341, 14, 33, "Text",
 CellTags->"sec 5"],
Cell[CellGroupData[{
Cell[515740, 16063, 74, 2, 31, "Input",
 CellTags->"sec 5"],
Cell[515817, 16067, 522, 17, 48, "Output"]
}, Open  ]],
Cell[516354, 16087, 168, 5, 33, "Text",
 CellTags->"sec 5"],
Cell[516525, 16094, 296, 10, 31, "Input",
 CellTags->"sec 5"],
Cell[516824, 16106, 315, 11, 33, "Text",
 CellTags->"sec 5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517176, 16122, 216, 12, 52, "Subsubsection"],
Cell[517395, 16136, 609, 22, 70, "Text"],
Cell[518007, 16160, 1103, 39, 70, "Text"],
Cell[519113, 16201, 1829, 72, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[520979, 16278, 210, 7, 52, "Text"],
Cell[521192, 16287, 154, 5, 31, "Input"],
Cell[521349, 16294, 343, 12, 31, "Input"],
Cell[521695, 16308, 1644, 50, 52, "Input"],
Cell[523342, 16360, 376, 15, 33, "Text"],
Cell[523721, 16377, 246, 8, 31, "Input"],
Cell[523970, 16387, 158, 5, 31, "Input"],
Cell[524131, 16394, 481, 18, 45, "Input"],
Cell[CellGroupData[{
Cell[524637, 16416, 197, 5, 31, "Input"],
Cell[524837, 16423, 268, 5, 23, "Print"],
Cell[525108, 16430, 482, 16, 65, "Print"],
Cell[525593, 16448, 472, 13, 23, "Print"],
Cell[526068, 16463, 482, 16, 65, "Print"],
Cell[526553, 16481, 220, 5, 23, "Print"],
Cell[526776, 16488, 258, 5, 23, "Print"],
Cell[527037, 16495, 272, 5, 23, "Print"],
Cell[527312, 16502, 121, 3, 34, "Output"],
Cell[527436, 16507, 258, 5, 23, "Print"],
Cell[527697, 16514, 127, 3, 34, "Output"],
Cell[527827, 16519, 112, 3, 38, "Output"],
Cell[527942, 16524, 127, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[528106, 16533, 30, 0, 31, "Input"],
Cell[528139, 16535, 45, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[528221, 16541, 125, 3, 31, "Input"],
Cell[528349, 16546, 992, 34, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[529378, 16585, 110, 3, 31, "Input"],
Cell[529491, 16590, 1751, 61, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[531279, 16656, 226, 7, 33, "Text"],
Cell[531508, 16665, 617, 20, 38, "Text"],
Cell[532128, 16687, 498, 14, 31, "Input"],
Cell[CellGroupData[{
Cell[532651, 16705, 372, 12, 31, "Input"],
Cell[533026, 16719, 107, 3, 30, "Output"]
}, Open  ]],
Cell[533148, 16725, 631, 24, 33, "Text"],
Cell[CellGroupData[{
Cell[533804, 16753, 270, 7, 31, "Input"],
Cell[534077, 16762, 127, 4, 30, "Output"]
}, Open  ]],
Cell[534219, 16769, 143, 4, 33, "Text"],
Cell[CellGroupData[{
Cell[534387, 16777, 323, 8, 31, "Input"],
Cell[534713, 16787, 126, 4, 30, "Output"]
}, Open  ]],
Cell[534854, 16794, 265, 7, 33, "Text"],
Cell[CellGroupData[{
Cell[535144, 16805, 268, 7, 31, "Input"],
Cell[535415, 16814, 1074, 33, 57, "Output"]
}, Open  ]],
Cell[536504, 16850, 172, 7, 33, "Text"],
Cell[CellGroupData[{
Cell[536701, 16861, 146, 4, 31, "Input"],
Cell[536850, 16867, 704, 24, 57, "Output"]
}, Open  ]],
Cell[537569, 16894, 443, 17, 38, "Text"],
Cell[CellGroupData[{
Cell[538037, 16915, 178, 6, 31, "Input"],
Cell[538218, 16923, 127, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[538382, 16932, 394, 13, 31, "Input"],
Cell[538779, 16947, 127, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[538943, 16956, 376, 12, 31, "Input"],
Cell[539322, 16970, 768, 26, 57, "Output"]
}, Open  ]],
Cell[540105, 16999, 330, 13, 38, "Text"],
Cell[CellGroupData[{
Cell[540460, 17016, 360, 11, 31, "Input"],
Cell[540823, 17029, 897, 30, 57, "Output"]
}, Open  ]],
Cell[541735, 17062, 171, 8, 33, "Text"],
Cell[CellGroupData[{
Cell[541931, 17074, 344, 10, 31, "Input"],
Cell[542278, 17086, 1124, 35, 57, "Output"]
}, Open  ]],
Cell[543417, 17124, 544, 17, 31, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[544010, 17147, 81, 4, 59, "Subsection"],
Cell[544094, 17153, 924, 37, 70, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[545067, 17196, 223, 12, 40, "Subsection"],
Cell[545293, 17210, 765, 26, 60, "Text"],
Cell[546061, 17238, 1532, 53, 103, "Text"],
Cell[547596, 17293, 600, 27, 56, "Text"],
Cell[CellGroupData[{
Cell[548221, 17324, 176, 6, 33, "Text"],
Cell[548400, 17332, 144, 4, 31, "Input"],
Cell[548547, 17338, 638, 20, 31, "Input"],
Cell[549188, 17360, 243, 10, 33, "Text"],
Cell[549434, 17372, 188, 6, 31, "Input"],
Cell[CellGroupData[{
Cell[549647, 17382, 565, 18, 27, "Input"],
Cell[550215, 17402, 558, 18, 27, "Output"]
}, Open  ]],
Cell[550788, 17423, 245, 10, 30, "Text"],
Cell[551036, 17435, 190, 7, 27, "Input"],
Cell[551229, 17444, 195, 7, 30, "Text"],
Cell[551427, 17453, 94, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[551546, 17460, 181, 5, 27, "Input"],
Cell[551730, 17467, 640, 21, 70, "Print"],
Cell[552373, 17490, 755, 24, 23, "Print"],
Cell[553131, 17516, 771, 25, 110, "Print"],
Cell[553905, 17543, 256, 5, 20, "Print"],
Cell[554164, 17550, 141, 3, 31, "Output"],
Cell[554308, 17555, 653, 19, 20, "Print"],
Cell[554964, 17576, 260, 5, 20, "Print"],
Cell[555227, 17583, 276, 5, 20, "Print"],
Cell[555506, 17590, 276, 5, 20, "Print"],
Cell[555785, 17597, 260, 5, 20, "Print"],
Cell[556048, 17604, 256, 5, 20, "Print"],
Cell[556307, 17611, 266, 5, 20, "Print"],
Cell[556576, 17618, 127, 4, 27, "Output"]
}, Open  ]],
Cell[556718, 17625, 92, 3, 27, "Input"],
Cell[556813, 17630, 28, 0, 43, "Input"],
Cell[556844, 17632, 166, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[557035, 17641, 1580, 50, 58, "Input"],
Cell[558618, 17693, 1174, 36, 107, "Print"],
Cell[559795, 17731, 1359, 43, 45, "Print"],
Cell[561157, 17776, 1319, 40, 122, "Print"],
Cell[562479, 17818, 256, 5, 20, "Print"],
Cell[562738, 17825, 144, 3, 31, "Output"],
Cell[562885, 17830, 551, 19, 50, "Print"],
Cell[563439, 17851, 260, 5, 20, "Print"],
Cell[563702, 17858, 274, 5, 20, "Print"],
Cell[563979, 17865, 274, 5, 20, "Print"],
Cell[564256, 17872, 260, 5, 20, "Print"],
Cell[564519, 17879, 222, 5, 20, "Print"],
Cell[564744, 17886, 112, 3, 35, "Output"],
Cell[564859, 17891, 128, 4, 27, "Output"],
Cell[CellGroupData[{
Cell[565012, 17899, 122, 3, 27, "Input"],
Cell[565137, 17904, 127, 4, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[565291, 17912, 92, 3, 31, "Input"],
Cell[565386, 17917, 28, 0, 52, "Input"],
Cell[CellGroupData[{
Cell[565439, 17921, 1816, 56, 52, "Input"],
Cell[567258, 17979, 1257, 38, 113, "Print"],
Cell[568518, 18019, 1363, 42, 36, "Print"],
Cell[569884, 18063, 1380, 41, 113, "Print"],
Cell[571267, 18106, 256, 5, 23, "Print"],
Cell[571526, 18113, 258, 5, 23, "Print"],
Cell[571787, 18120, 276, 5, 23, "Print"],
Cell[572066, 18127, 276, 5, 23, "Print"],
Cell[572345, 18134, 260, 5, 23, "Print"],
Cell[572608, 18141, 222, 5, 23, "Print"],
Cell[572833, 18148, 112, 3, 38, "Output"],
Cell[572948, 18153, 128, 4, 30, "Output"],
Cell[CellGroupData[{
Cell[573101, 18161, 92, 2, 31, "Input"],
Cell[573196, 18165, 31, 0, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[573254, 18169, 253, 8, 31, "Input"]
}, Open  ]],
Cell[573522, 18180, 66, 1, 33, "Text"]
}, Open  ]]
}, Closed]],
Cell[573615, 18185, 62, 2, 23, "Text"],
Cell[CellGroupData[{
Cell[573702, 18191, 554, 18, 94, "Section"],
Cell[574259, 18211, 1703, 63, 109, "Text"],
Cell[575965, 18276, 240, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[576230, 18290, 350, 13, 49, "Text"],
Cell[CellGroupData[{
Cell[576605, 18307, 305, 10, 27, "Input"],
Cell[576913, 18319, 499, 17, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[577449, 18341, 310, 10, 27, "Input"],
Cell[577762, 18353, 357, 12, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[578156, 18370, 344, 11, 27, "Input"],
Cell[578503, 18383, 292, 10, 46, "Output"]
}, Open  ]],
Cell[578810, 18396, 554, 20, 68, "Text"],
Cell[CellGroupData[{
Cell[579389, 18420, 344, 11, 27, "Input"],
Cell[579736, 18433, 499, 17, 47, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[580284, 18456, 633, 25, 68, "Text"],
Cell[CellGroupData[{
Cell[580942, 18485, 246, 8, 27, "Input"],
Cell[581191, 18495, 773, 24, 46, "Output"]
}, Open  ]],
Cell[581979, 18522, 572, 20, 68, "Text"],
Cell[CellGroupData[{
Cell[582576, 18546, 285, 11, 30, "Text"],
Cell[582864, 18559, 210, 6, 27, "Input"],
Cell[583077, 18567, 1187, 40, 43, "Input"],
Cell[CellGroupData[{
Cell[584289, 18611, 54, 1, 27, "Input"],
Cell[584346, 18614, 4129, 128, 98, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[588512, 18747, 800, 27, 30, "Input"],
Cell[589315, 18776, 6485, 182, 135, "Print"],
Cell[595803, 18960, 4794, 124, 129, "Print"],
Cell[600600, 19086, 6779, 188, 112, "Print"],
Cell[607382, 19276, 254, 5, 20, "Print"],
Cell[607639, 19283, 260, 5, 20, "Print"],
Cell[607902, 19290, 274, 5, 20, "Print"],
Cell[608179, 19297, 274, 5, 20, "Print"],
Cell[608456, 19304, 260, 5, 20, "Print"],
Cell[608719, 19311, 258, 5, 20, "Print"],
Cell[608980, 19318, 266, 5, 20, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[609283, 19328, 29, 0, 27, "Input"],
Cell[609315, 19330, 5856, 185, 120, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[615220, 19521, 644, 26, 68, "Text"],
Cell[615867, 19549, 234, 7, 27, "Input"],
Cell[616104, 19558, 224, 12, 30, "Text"],
Cell[CellGroupData[{
Cell[616353, 19574, 246, 8, 27, "Input"],
Cell[616602, 19584, 327, 10, 30, "Output"]
}, Open  ]],
Cell[616944, 19597, 143, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[617112, 19607, 54, 1, 27, "Input"],
Cell[617169, 19610, 135, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617341, 19619, 58, 1, 27, "Input"],
Cell[617402, 19622, 135, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[617564, 19630, 458, 16, 49, "Text"],
Cell[CellGroupData[{
Cell[618047, 19650, 163, 5, 30, "Text"],
Cell[618213, 19657, 220, 7, 27, "Input"],
Cell[618436, 19666, 234, 7, 27, "Input"],
Cell[618673, 19675, 801, 24, 27, "Input"],
Cell[619477, 19701, 248, 8, 27, "Input"],
Cell[619728, 19711, 258, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[620011, 19723, 447, 15, 27, "Input"],
Cell[620461, 19740, 268, 5, 20, "Print"],
Cell[620732, 19747, 482, 16, 70, "Print"],
Cell[621217, 19765, 897, 26, 39, "Print"],
Cell[622117, 19793, 482, 16, 70, "Print"],
Cell[622602, 19811, 256, 5, 20, "Print"],
Cell[622861, 19818, 228, 5, 20, "Print"],
Cell[623092, 19825, 275, 5, 20, "Print"],
Cell[623370, 19832, 276, 5, 20, "Print"],
Cell[623649, 19839, 262, 5, 20, "Print"],
Cell[623914, 19846, 258, 5, 20, "Print"],
Cell[624175, 19853, 230, 5, 20, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[624442, 19863, 29, 0, 27, "Input"],
Cell[624474, 19865, 4789, 154, 83, "Output"]
}, Open  ]],
Cell[629278, 20022, 25, 3, 41, "Text"],
Cell[629306, 20027, 313, 10, 27, "Input"],
Cell[629622, 20039, 97, 3, 27, "Input"],
Cell[629722, 20044, 351, 15, 30, "Text"],
Cell[CellGroupData[{
Cell[630098, 20063, 447, 15, 27, "Input"],
Cell[630548, 20080, 268, 5, 20, "Print"],
Cell[630819, 20087, 482, 16, 70, "Print"],
Cell[631304, 20105, 897, 26, 39, "Print"],
Cell[632204, 20133, 482, 16, 70, "Print"],
Cell[632689, 20151, 256, 5, 20, "Print"],
Cell[632948, 20158, 258, 5, 20, "Print"],
Cell[633209, 20165, 276, 5, 20, "Print"],
Cell[633488, 20172, 276, 5, 20, "Print"],
Cell[633767, 20179, 260, 5, 20, "Print"],
Cell[634030, 20186, 256, 5, 20, "Print"],
Cell[634289, 20193, 266, 5, 20, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[634592, 20203, 29, 0, 27, "Input"],
Cell[634624, 20205, 6579, 207, 155, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[641264, 20419, 902, 28, 106, "Text"],
Cell[CellGroupData[{
Cell[642191, 20451, 167, 5, 30, "Text"],
Cell[642361, 20458, 313, 10, 27, "Input"],
Cell[642677, 20470, 97, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[642799, 20477, 1243, 39, 80, "Input"],
Cell[644045, 20518, 2108, 73, 118, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[646190, 20596, 736, 20, 27, "Input"],
Cell[646929, 20618, 2540, 87, 119, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[649506, 20710, 204, 6, 27, "Input"],
Cell[649713, 20718, 4959, 168, 217, "Output"]
}, Open  ]],
Cell[654687, 20889, 586, 26, 49, "Text"],
Cell[655276, 20917, 83, 2, 27, "Input"],
Cell[655362, 20921, 186, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[655573, 20931, 63, 1, 27, "Input"],
Cell[655639, 20934, 1196, 42, 59, "Output"]
}, Open  ]],
Cell[656850, 20979, 142, 9, 30, "Text"],
Cell[656995, 20990, 206, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[657226, 21004, 655, 19, 27, "Input"],
Cell[657884, 21025, 457, 15, 70, "Print"],
Cell[658344, 21042, 414, 11, 23, "Print"],
Cell[658761, 21055, 457, 15, 70, "Print"],
Cell[659221, 21072, 256, 5, 20, "Print"],
Cell[659480, 21079, 258, 5, 20, "Print"],
Cell[659741, 21086, 273, 5, 20, "Print"],
Cell[660017, 21093, 276, 5, 20, "Print"],
Cell[660296, 21100, 260, 5, 20, "Print"],
Cell[660559, 21107, 256, 5, 20, "Print"],
Cell[660818, 21114, 266, 5, 20, "Print"],
Cell[661087, 21121, 162, 4, 31, "Output"],
Cell[661252, 21127, 127, 4, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[661416, 21136, 58, 1, 27, "Input"],
Cell[661477, 21139, 5961, 188, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[667475, 21332, 247, 8, 27, "Input"],
Cell[667725, 21342, 992, 34, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[668754, 21381, 159, 4, 27, "Input"],
Cell[668916, 21387, 1625, 51, 57, "Output"]
}, Open  ]],
Cell[670556, 21441, 28, 0, 43, "Input"],
Cell[CellGroupData[{
Cell[670609, 21445, 210, 10, 30, "Text"],
Cell[670822, 21457, 313, 10, 27, "Input"],
Cell[671138, 21469, 97, 3, 27, "Input"],
Cell[CellGroupData[{
Cell[671260, 21476, 232, 7, 27, "Input"],
Cell[671495, 21485, 11694, 365, 365, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[683226, 21855, 523, 16, 27, "Input"],
Cell[683752, 21873, 4759, 149, 156, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[688548, 22027, 655, 19, 27, "Input"],
Cell[689206, 22048, 457, 15, 70, "Print"],
Cell[689666, 22065, 414, 11, 23, "Print"],
Cell[690083, 22078, 457, 15, 70, "Print"],
Cell[690543, 22095, 256, 5, 20, "Print"],
Cell[690802, 22102, 256, 5, 20, "Print"],
Cell[691061, 22109, 274, 5, 20, "Print"],
Cell[691338, 22116, 244, 5, 20, "Print"],
Cell[691585, 22123, 260, 5, 20, "Print"],
Cell[691848, 22130, 256, 5, 20, "Print"],
Cell[692107, 22137, 266, 5, 20, "Print"],
Cell[692376, 22144, 162, 4, 31, "Output"],
Cell[692541, 22150, 127, 4, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[692717, 22160, 58, 1, 27, "Input"],
Cell[692778, 22163, 3185, 106, 82, "Output"]
}, Open  ]],
Cell[695978, 22272, 356, 18, 39, "Text"],
Cell[CellGroupData[{
Cell[696359, 22294, 58, 1, 27, "Input"],
Cell[696420, 22297, 31, 0, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[696488, 22302, 159, 4, 27, "Input"],
Cell[696650, 22308, 923, 32, 46, "Output"]
}, Open  ]],
Cell[697588, 22343, 567, 24, 59, "Text"]
}, Open  ]],
Cell[698170, 22370, 393, 18, 49, "Text"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
